/****************************************************************************** 
 * Job:           ACCOUNT_SCORE_PRE_DETAIL                  A5V75JN3.BN000034 * 
 * Description:   This job picks up data from CAS_EXT and AM_EXT for the      * 
 *                 ACCOUNT_SCORE pre-detail table.                            * 
 *                                                                            * 
 * Repository:    Foundation                                A0000001.A5V75JN3 * 
 * Server:        SASMain                                   A5V75JN3.AT000001 * 
 *                                                                            * 
 * Source Tables: CAS_EXT - martscr.CAS_EXT                 A5V75JN3.BE0000IL * 
 *                AM_EXT - martscr.AM_EXT                   A5V75JN3.BE0000I8 * 
 * Target Table:  ACCOUNT_SCORE_PRE_DETAIL -                A5V75JN3.BE0000L2 * 
 *                 martscr.ACCOUNT_SCORE_PRE_DETAIL                           * 
 *                                                                            * 
 * Generated on:  Wednesday, December 10, 2008 12:19:20 PM IST                * 
 * Generated by:  sasadm                                                      * 
 * Version:       9.1.20060626.51875                                          * 
 ******************************************************************************
 * Notes:                                                                     * 
 * ACCOUNT_SCORE_PRE_DETAIL                                                   * 
 * Job Name: ACCOUNT_SCORE_PRE_DETAILJob Desc Pre Process: NoneMain: a)       * 
 * Score details of accounts obtained by joining CAS_EXT and AM_EXT on        * 
 * MODEL_RK and LOAD_END_DTTM. This table acts as a pre-detail table for      * 
 * ACCOUNT_SCORE_DETAIL.Post Process: NoneParameters: a)                      * 
 * PRD_MODEL_DEPLOYMENT is used for Champion Model.b)ACCT_SCORE_MODEL is to   * 
 * specify the account score model. For e.g. up sell model, retention model   * 
 * and so onc)ACCT_SCORE_PRD_TYPE is to specify the product type(s) for       * 
 * account score. For e.g. mortgage product, loan product and so              * 
 *  onDeveloped by: sinahkReviewed by:Tested by:                              * 
 ******************************************************************************/ 



%let jobID = %quote(A5V75JN3.BN000034);

/* Setup for capturing job status  */ 
data _null_; 
   call symput('etls_startTime',put(datetime(),datetime.));
run;

%let etls_jobName = ACCOUNT_SCORE_PRE_DETAIL;
%let etls_recordsBefore = 0;
%let etls_recordsAfter = 0;
%let etls_lib = 0;
%let etls_table = 0;

/* Setup to capture return codes  */ 
%global job_rc trans_rc sqlrc; 
%let job_rc = 0;
%let trans_rc = 0;
%let sqlrc = 0;
%global syserr; 

%macro rcSet(error); 
   %if (&error gt &trans_rc) %then 
      %let trans_rc = &error;
   %if (&error gt &job_rc) %then 
      %let job_rc = &error;
%mend rcSet; 

%macro rcSetDS(error); 
   if &error gt input(symget('trans_rc'),12.) then 
      call symput('trans_rc',trim(left(put(&error,12.))));
   if &error gt input(symget('job_rc'),12.) then 
      call symput('job_rc',trim(left(put(&error,12.))));
%mend rcSetDS; 

%global etls_debug; 
%macro etls_setDebug; 
   %if %str(&etls_debug) ne 0 %then 
      OPTIONS MPRINT%str(;); 
%mend; 
%etls_setDebug; 

/*============================================================================* 
 * Step:          Score details of accounts                 A5V75JN3.BO0005PF * 
 * Transform:     SQL Join (Version 2)                                        * 
 * Description:   Score details of accounts obtained by joining CAS_EXT and   * 
 *                 AM_EXT on MODEL_RK.                                        * 
 *                                                                            * 
 * Source Tables: CAS_EXT - martscr.CAS_EXT                 A5V75JN3.BE0000IL * 
 *                AM_EXT - martscr.AM_EXT                   A5V75JN3.BE0000I8 * 
 * Target Table:  SQL Target -                              A5V75JN3.BP0004TC * 
 *                 martscr.ACCOUNT_SCORE_BEFORE_PRE_DETAIL                    * 
 *============================================================================*/ 

/* Access the data for Scratch for Mart  */ 
LIBNAME martscr BASE "Data/bisdata/scratch/mart" ;
%rcSet(&syslibrc); 

%let transformID = %quote(A5V75JN3.BO0005PF); 

%let trans_rc = 0; 

proc datasets lib = martscr nolist nowarn memtype = (data view);
   delete ACCOUNT_SCORE_BEFORE_PRE_DETAIL;
quit;

proc sql;
   create table martscr.ACCOUNT_SCORE_BEFORE_PRE_DETAIL as
      select
         CAS_EXT.ACCOUNT_RK length = 8
                            format = 12.
                            informat = 12.
                            label = "Account Key",
         CAS_EXT.MODEL_RK length = 8
                          format = 12.
                          informat = 12.
                          label = "Model Key",
         CAS_EXT.SCORE_DT as LATEST_SCORE_DT length = 8
                                             format = NLDATE10.
                                             informat = NLDATE10.
                                             label = "Score Date",
         CAS_EXT.CUSTOMER_ACCOUNT_SCORE_NO as LATEST_SCORE_NO length = 8
                                                              format = NLNUM12.8
                                                              informat = NLNUM12.8
                                                              label = "Customer Account Score No",
         CAS_EXT.SCORE_POINTS_NO as LATEST_SCORE_POINTS_NO length = 8
                                                           label = "Score Points No",
         CAS_EXT.LOAD_END_DTTM length = 8
                               format = NLDATM21.
                               informat = NLDATM21.
                               label = "Load End Datetime"
      from
         martscr.CAS_EXT, 
         martscr.AM_EXT
      where
         CAS_EXT.MODEL_RK = AM_EXT.MODEL_RK
         and CAS_EXT.LOAD_END_DTTM = AM_EXT.LOAD_END_DTTM
         and AM_EXT.MODEL_DEPLOYMENT_CD IN (&PRD_MODEL_DEPLOYMENT, &DEV_MODEL_DEPLOYMENT)
         and AM_EXT.MODEL_TYPE_CD IN (&ACCT_SCORE_MODEL)
         and AM_EXT.MODEL_PRODUCT_TYPE_CD IN (&ACCT_SCORE_PRD_TYPE)
      ;
quit;

%rcSet(&sqlrc); 

%macro etls_completeTarget();
   /*---- Create the integrity constraints for a table  ----*/ 
   %put %str(NOTE: Creating integrity constraints ...);
   proc datasets library=martscr nolist;
      modify ACCOUNT_SCORE_BEFORE_PRE_DETAIL;
         ic create not null (ACCOUNT_RK);
         ic create not null (MODEL_RK);
         ic create not null (LATEST_SCORE_DT);
   quit;
   
   %rcSet(&syserr); 
   
%mend etls_completeTarget;
%etls_completeTarget;

/*============================================================================* 
 * Step:          Code to deduplicate Score Details of      A5V75JN3.BO0005PE * 
 *                 Accounts                                                   * 
 * Transform:     User Written Code                                           * 
 * Description:   Code to deduplicate Score Details of Accounts before SCD2   * 
 *                                                                            * 
 * Source Table:  SQL Target -                              A5V75JN3.BP0004TC * 
 *                 martscr.ACCOUNT_SCORE_BEFORE_PRE_DETAIL                    * 
 * Target Table:  User Written Code Target -                A5V75JN3.BP0004TB * 
 *                 martscr.ACCOUNT_SCORE_PRE_DETAIL                           * 
 *                                                                            * 
 * User Written:  code for deduplicate Score Details        A5V75JN3.AF000MUK * 
 *                code for deduplicate Score Details                          * 
 *============================================================================*/ 

%let SYSLAST = %nrquote(martscr.ACCOUNT_SCORE_BEFORE_PRE_DETAIL); 

%let transformID = %quote(A5V75JN3.BO0005PE); 

%let trans_rc = 0; 

%let _OUTPUT = %nrquote(martscr.ACCOUNT_SCORE_PRE_DETAIL); 

/*---- Start of User Written Code  ----*/ 

%let sort_col=ACCOUNT_RK MODEL_RK LOAD_END_DTTM; 
%let etl_str=KTRIM(KLEFT(ACCOUNT_RK))||
KTRIM(KLEFT(MODEL_RK))||
KTRIM(KLEFT(LATEST_SCORE_DT))||
KTRIM(KLEFT(LATEST_SCORE_NO))||
KTRIM(KLEFT(LATEST_SCORE_POINTS_NO));

%deduplicate(in_table=&SYSLAST,sort_col=&sort_col,out_table=&_OUTPUT,etls_str_in=&etl_str)


/*---- End of User Written Code  ----*/ 

%rcSet(&syserr); 
%rcSet(&sqlrc); 

/*============================================================================* 
 * Step:          Dummy Loader                              A5V75JN3.BO0005PD * 
 * Transform:     Table Loader                                                * 
 * Description:                                                               * 
 *                                                                            * 
 * Source Table:  User Written Code Target -                A5V75JN3.BP0004TB * 
 *                 martscr.ACCOUNT_SCORE_PRE_DETAIL                           * 
 * Target Table:  ACCOUNT_SCORE_PRE_DETAIL -                A5V75JN3.BE0000L2 * 
 *                 martscr.ACCOUNT_SCORE_PRE_DETAIL                           * 
 *============================================================================*
 *                                                                            * 
 * Nothing will be generated for this process because the "Do not generate    * 
 *  code for this process" option is selected.                                * 
 *                                                                            * 
 *============================================================================*/ 

data _null_; 
   call symput('etls_endTime',put(datetime(),datetime.));
run;

/* Check return code for job  */ 
%macro etls_jobRCChk; 
   %if (&job_rc eq 4) %then
   %do; 
      %on_success(Job_nm=&etls_jobName..sas, param_table=&status_table);
   %end; 
%mend etls_jobRCChk; 
%etls_jobRCChk; 

/* Check return code for job  */ 
%macro etls_jobRCChk; 
   %if (&job_rc ge 5) %then
   %do; 
      %on_success(Job_nm=&etls_jobName..sas, param_table=&status_table);
   %end; 
%mend etls_jobRCChk; 
%etls_jobRCChk; 

/* Check return code for job  */ 
%macro etls_jobRCChk; 
   %if (&job_rc eq 0) %then
   %do; 
      %on_success(Job_nm=&etls_jobName..sas, param_table=&status_table);
   %end; 
%mend etls_jobRCChk; 
%etls_jobRCChk; 

/*---- Job status macro  ----*/ 
