/****************************************************************************** 
 * Job:           ACCT_SCR_RANGE                            A5V75JN3.BN0000WD * 
 * Description:   This job picks up data from ACCOUNT_SCORE and               * 
 *                 SCORE_CARD_RANGE.                                          * 
 *                                                                            * 
 * Repository:    Foundation                                A0000001.A5V75JN3 * 
 * Server:        SASMain                                   A5V75JN3.AT000001 * 
 *                                                                            * 
 * Source Tables: SCORE_CARD_RANGE -                        A5V75JN3.BE0000W4 * 
 *                 martscr.SCORE_CARD_RANGE                                   * 
 *                ACCOUNT_MODEL_SCORE -                     A5V75JN3.BE0000W1 * 
 *                 martscr.ACCOUNT_MODEL_SCORE                                * 
 * Target Table:  ACCT_SCR_RANGE - martscr.ACCT_SCR_RANGE   A5V75JN3.BE0000WP * 
 *                                                                            * 
 * Generated on:  Wednesday, December 17, 2008 11:17:39 AM IST                * 
 * Generated by:  D108INA4\sasadm                                             * 
 * Version:       9.1.20060626.51875                                          * 
 ******************************************************************************/ 


%let jobID = %quote(A5V75JN3.BN0000WD);

/* Setup for capturing job status  */ 
data _null_; 
   call symput('etls_startTime',put(datetime(),datetime.));
run;

%let etls_jobName = ACCT_SCR_RANGE;
%let etls_recordsBefore = 0;
%let etls_recordsAfter = 0;
%let etls_lib = 0;
%let etls_table = 0;

/* Setup to capture return codes  */ 
%global job_rc trans_rc sqlrc; 
%let job_rc = 0;
%let trans_rc = 0;
%let sqlrc = 0;
%global syserr; 

%macro rcSet(error); 
   %if (&error gt &trans_rc) %then 
      %let trans_rc = &error;
   %if (&error gt &job_rc) %then 
      %let job_rc = &error;
%mend rcSet; 

%macro rcSetDS(error); 
   if &error gt input(symget('trans_rc'),12.) then 
      call symput('trans_rc',trim(left(put(&error,12.))));
   if &error gt input(symget('job_rc'),12.) then 
      call symput('job_rc',trim(left(put(&error,12.))));
%mend rcSetDS; 

%global etls_debug; 
%macro etls_setDebug; 
   %if %str(&etls_debug) ne 0 %then 
      OPTIONS MPRINT%str(;); 
%mend; 
%etls_setDebug; 

/*============================================================================* 
 * Step:          To obtain the account count and default   A5V75JN3.BO0005OG * 
 *                 count                                                      * 
 * Transform:     SQL Join (Version 2)                                        * 
 * Description:   To obtain the account count and default count by joining    * 
 *                SCORE_CARD_RANGE and ACCOUNT_SCORE on MODEL_SK by           * 
 *                 grouping on MODEL_SK, FROM_SCORE and TO_SCORE.             * 
 *                                                                            * 
 * Source Tables: SCORE_CARD_RANGE -                        A5V75JN3.BE0000W4 * 
 *                 martscr.SCORE_CARD_RANGE                                   * 
 *                ACCOUNT_MODEL_SCORE -                     A5V75JN3.BE0000W1 * 
 *                 martscr.ACCOUNT_MODEL_SCORE                                * 
 * Target Table:  SQL Target - martscr.ACCT_SCR_RANGE_TMP   A5V75JN3.BP0004SU * 
 *============================================================================*/ 

/* Access the data for Scratch for Mart  */ 
LIBNAME martscr BASE "Data/bisdata/scratch/mart" ;
%rcSet(&syslibrc); 

%let transformID = %quote(A5V75JN3.BO0005OG); 

%let trans_rc = 0; 

proc datasets lib = martscr nolist nowarn memtype = (data view);
   delete ACCT_SCR_RANGE_TMP;
quit;

proc sql;
   create table martscr.ACCT_SCR_RANGE_TMP as
      select
         SCORE_CARD_RANGE.MODEL_SK length = 8
                                   format = 12.
                                   informat = 12.
                                   label = "Surrogate key for the analytical model dimension.",
         SCORE_CARD_RANGE.FROM_SCORE length = 8,
         SCORE_CARD_RANGE.TO_SCORE length = 8,
         COUNT(distinct ACCOUNT_MODEL_SCORE.ACCOUNT_RK) as NO_OF_ACCOUNTS length = 8,
         SUM(CASE  WHEN ACCOUNT_MODEL_SCORE.TGT_VAR = 1  THEN 1 ELSE 0 END) as NO_OF_DEFAULTS length = 8,
         ACCOUNT_MODEL_SCORE.VARIABLE_NAME length = 100,
         ACCOUNT_MODEL_SCORE.VARIABLE_GROUP_NO length = 8
      from
         martscr.SCORE_CARD_RANGE, 
         martscr.ACCOUNT_MODEL_SCORE
      where
         SCORE_CARD_RANGE.MODEL_SK = ACCOUNT_MODEL_SCORE.MODEL_SK
         and ACCOUNT_MODEL_SCORE.SCORE_POINTS > SCORE_CARD_RANGE.FROM_SCORE
         and ACCOUNT_MODEL_SCORE.SCORE_POINTS <= SCORE_CARD_RANGE.TO_SCORE
      group by
         SCORE_CARD_RANGE.MODEL_SK, 
         SCORE_CARD_RANGE.FROM_SCORE, 
         SCORE_CARD_RANGE.TO_SCORE, 
         ACCOUNT_MODEL_SCORE.VARIABLE_NAME, 
         ACCOUNT_MODEL_SCORE.VARIABLE_GROUP_NO
      ;
quit;

%rcSet(&sqlrc); 

%macro etls_completeTarget();
%mend etls_completeTarget;
%etls_completeTarget;

/*============================================================================* 
 * Step:          Get all Score Range Variable Groupings    A5V75JN3.BO0005OH * 
 * Transform:     User Written Code                                           * 
 * Description:                                                               * 
 *                                                                            * 
 * Source Table:  SQL Target - martscr.ACCT_SCR_RANGE_TMP   A5V75JN3.BP0004SU * 
 * Target Table:  User Written Code Target -                A5V75JN3.BP0004ST * 
 *                 martscr.ACCT_SCR_RANGE                                     * 
 *                                                                            * 
 * User Written:  Get all Score Range Variable Groupings    A5V75JN3.AF000MO4 * 
 *                /*Get all of the possible Score Range/ Variable Groupings   * 
 *                 for the model*/                                            * 
 *============================================================================*/ 

%let SYSLAST = %nrquote(martscr.ACCT_SCR_RANGE_TMP); 

%let transformID = %quote(A5V75JN3.BO0005OH); 

%let trans_rc = 0; 

%let _OUTPUT = %nrquote(martscr.ACCT_SCR_RANGE); 

/*---- Start of User Written Code  ----*/ 

/*Get all of the possible Score Range/ Variable Groupings for the model. 
Merge this dataset with the above dataset to create the final target table. 
This is done to ensure that all the VARIABLE_GROUP_NO are present in the target table 
even if there are no accounts within the score range and variable for development sample 
and scoring sample. 
E.g. For one analytical_model (say Model_sk =2) has score ranges 0-240, 240-300, 300-360. 
For 0-240 range, there are no accounts in development sample and scoring sample for 
VARIABLE_GROUP_NO = 2. 
With the changes done (for CS 4.3 HF2) will ensure that the following row is inserted 
(Model_Sk = 2, From_score = 0, To_score = 240, Variable_Group_No = 2 
with No_of_accounts and No_of_defaults set as 0.)

/* Start of CS4.3 HF2 */ 


/*Get all of the possible Score Range/ Variable Groupings for the model*/

proc sql;
  create table martscr.ALL_POSSIBLE_GROUP_RANGES as 
  select SCORE_CARD_RANGE.MODEL_SK,
  FROM_SCORE, 
  TO_SCORE, 
  VARIABLE_NAME,
  VARIABLE_GROUP_NO
  from MARTSCR.SCORE_CARD_RANGE, MARTSCR.VARIABLE_GROUPS_MODEL 
  where score_card_range.MODEL_SK = variable_groups_model.MODEL_SK
  and  VARIABLE_GROUP_NO ne -2 
  order by MODEL_SK, FROM_SCORE, TO_SCORE, VARIABLE_NAME, VARIABLE_GROUP_NO;
quit;

 

/*If one of the score range/variable groupings is not on the development sample, 
  set the number of accounts and defaults to 0*/

data martscr.acct_scr_range;
   merge martscr.ALL_POSSIBLE_GROUP_RANGES martscr.acct_scr_range_tmp;
     by model_sk from_score to_score variable_name variable_group_no;

   NO_OF_ACCOUNTS=coalesce(NO_OF_ACCOUNTS,0);
   NO_OF_DEFAULTS=coalesce(NO_OF_DEFAULTS,0);
run;

 
/* End of CS4.3 HF2 */


/*---- End of User Written Code  ----*/ 

%rcSet(&syserr); 
%rcSet(&sqlrc); 

/*============================================================================* 
 * Step:          Dummy Loader                              A5V75JN3.BO0005OF * 
 * Transform:     Table Loader (Version 2)                                    * 
 * Description:                                                               * 
 *                                                                            * 
 * Source Table:  User Written Code Target -                A5V75JN3.BP0004ST * 
 *                 martscr.ACCT_SCR_RANGE                                     * 
 * Target Table:  ACCT_SCR_RANGE - martscr.ACCT_SCR_RANGE   A5V75JN3.BE0000WP * 
 *============================================================================*
 *                                                                            * 
 * Nothing will be generated for this process because the "Do not generate    * 
 *  code for this process" option is selected.                                * 
 *                                                                            * 
 *============================================================================*/ 

data _null_; 
   call symput('etls_endTime',put(datetime(),datetime.));
run;

/* Check return code for job  */ 
%macro etls_jobRCChk; 
   %if (&job_rc eq 0) %then
   %do; 
      %on_success(Job_nm=&etls_jobName..sas, param_table=&status_table);
   %end; 
%mend etls_jobRCChk; 
%etls_jobRCChk; 

/*---- Job status macro  ----*/ 
/* Check return code for job  */ 
%macro etls_jobRCChk; 
   %if (&job_rc eq 4) %then
   %do; 
      %on_success(Job_nm=&etls_jobName..sas, param_table=&status_table);
   %end; 
%mend etls_jobRCChk; 
%etls_jobRCChk; 

/* Check return code for job  */ 
%macro etls_jobRCChk; 
   %if (&job_rc ge 5) %then
   %do; 
      %on_success(Job_nm=&etls_jobName..sas, param_table=&status_table);
   %end; 
%mend etls_jobRCChk; 
%etls_jobRCChk; 

