/****************************************************************************** 
 * Job:           AM_CAS_LGD                                A5V75JN3.BN0000SO * 
 * Description:   This job picks up the data from AM_EXT  and CAS_EXT.        * 
 *                                                                            * 
 * Repository:    Foundation                                A0000001.A5V75JN3 * 
 * Server:        SASMain                                   A5V75JN3.AT000001 * 
 *                                                                            * 
 * Source Tables: AM_EXT - martscr.AM_EXT                   A5V75JN3.BE0000I8 * 
 *                CAS_EXT - martscr.CAS_EXT                 A5V75JN3.BE0000IL * 
 * Target Table:  AM_CAS_LGD - martscr.AM_CAS_LGD           A5V75JN3.BE0000SK * 
 *                                                                            * 
 * Generated on:  Wednesday, December 10, 2008 12:36:54 PM IST                * 
 * Generated by:  sasadm                                                      * 
 * Version:       9.1.20060626.51875                                          * 
 ******************************************************************************/ 

/* Setup for capturing job status  */ 
data _null_; 
   call symput('etls_startTime',put(datetime(),datetime.));
run;

%let etls_jobName = AM_CAS_LGD;
%let etls_recordsBefore = 0;
%let etls_recordsAfter = 0;
%let etls_lib = 0;
%let etls_table = 0;

/* Setup to capture return codes  */ 
%global job_rc trans_rc sqlrc; 
%let job_rc = 0;
%let trans_rc = 0;
%let sqlrc = 0;
%global syserr; 

%macro rcSet(error); 
   %if (&error gt &trans_rc) %then 
      %let trans_rc = &error;
   %if (&error gt &job_rc) %then 
      %let job_rc = &error;
%mend rcSet; 

%macro rcSetDS(error); 
   if &error gt input(symget('trans_rc'),12.) then 
      call symput('trans_rc',trim(left(put(&error,12.))));
   if &error gt input(symget('job_rc'),12.) then 
      call symput('job_rc',trim(left(put(&error,12.))));
%mend rcSetDS; 

%global etls_debug; 
%macro etls_setDebug; 
   %if %str(&etls_debug) ne 0 %then 
      OPTIONS MPRINT%str(;); 
%mend; 
%etls_setDebug; 

/*============================================================================* 
 * Step:          Finding account, model and customer key   A5V75JN3.BO0005N0 * 
 * Transform:     SQL Join (Version 2)                                        * 
 * Description:   Finding account, model and customer key  by inner joining   * 
 *                 table AM_EXT and CAS_EXT  on MODEL_RK                      * 
 *                                                                            * 
 * Source Tables: AM_EXT - martscr.AM_EXT                   A5V75JN3.BE0000I8 * 
 *                CAS_EXT - martscr.CAS_EXT                 A5V75JN3.BE0000IL * 
 * Target Table:  SQL Target - martscr.AM_CAS_LGD           A5V75JN3.BP0004RZ * 
 *============================================================================*/ 

/* Access the data for Scratch for Mart  */ 
LIBNAME martscr BASE "Data/bisdata/scratch/mart" ;
%rcSet(&syslibrc); 

%let trans_rc = 0; 

proc datasets lib = martscr nolist nowarn memtype = (data view);
   delete AM_CAS_LGD;
quit;

proc sql;
   create table martscr.AM_CAS_LGD as
      select
         CAS_EXT.ACCOUNT_RK length = 8
                            format = 12.
                            informat = 12.
                            label = "Account Key",
         AM_EXT.MODEL_RK length = 8
                         format = 12.
                         informat = 12.
                         label = "Model Key",
         CAS_EXT.ESTIMATED_RT as ESTIMATED_ACCOUNT_LGD length = 8
                                                       format = NLNUM9.4
                                                       informat = NLNUM9.4
                                                       label = "Estimated Rate",
         intnx('MONTH',&LOAD_STAR_USER_INPUT_DATE,AM_EXT.TARGET_PERIOD_MTHS_CNT,'END') as TARGET_TIME length = 8
                                                                                                      format = NLDATE10.
                                                                                                      informat = NLDATE10.,
         &LOAD_STAR_USER_INPUT_DATE as SCORE_TIME length = 8
                                                  format = NLDATE10.
                                                  informat = NLDATE10.
      from
         martscr.AM_EXT, 
         martscr.CAS_EXT
      where
         AM_EXT.MODEL_RK = CAS_EXT.MODEL_RK
         and AM_EXT.MODEL_TYPE_CD IN (&LGD_MODEL)
         and AM_EXT.MODEL_DEPLOYMENT_CD IN (&PRD_MODEL_DEPLOYMENT, &DEV_MODEL_DEPLOYMENT)
      group by
         CAS_EXT.ACCOUNT_RK, 
         CAS_EXT.MODEL_RK
      having
         CAS_EXT.SCORE_DT = max(CAS_EXT.SCORE_DT )
      ;
quit;

%rcSet(&sqlrc); 

%macro etls_completeTarget();
   /*---- Create the integrity constraints for a table  ----*/ 
   %put %str(NOTE: Creating integrity constraints ...);
   proc datasets library=martscr nolist;
      modify AM_CAS_LGD;
         ic create not null (ACCOUNT_RK);
         ic create not null (MODEL_RK);
   quit;
   
   %rcSet(&syserr); 
   
%mend etls_completeTarget;
%etls_completeTarget;

/*============================================================================* 
 * Step:          Dummy  Loader                             A5V75JN3.BO0005MZ * 
 * Transform:     Table Loader (Version 2)                                    * 
 * Description:                                                               * 
 *                                                                            * 
 * Source Table:  SQL Target - martscr.AM_CAS_LGD           A5V75JN3.BP0004RZ * 
 * Target Table:  AM_CAS_LGD - martscr.AM_CAS_LGD           A5V75JN3.BE0000SK * 
 *============================================================================*
 *                                                                            * 
 * Nothing will be generated for this process because the "Do not generate    * 
 *  code for this process" option is selected.                                * 
 *                                                                            * 
 *============================================================================*/ 

data _null_; 
   call symput('etls_endTime',put(datetime(),datetime.));
run;

/* Check return code for job  */ 
%macro etls_jobRCChk; 
   %if (&job_rc eq 4) %then
   %do; 
      %on_success(Job_nm=&etls_jobName..sas, param_table=&status_table);
   %end; 
%mend etls_jobRCChk; 
%etls_jobRCChk; 

/*---- Job status macro  ----*/ 
/* Check return code for job  */ 
%macro etls_jobRCChk; 
   %if (&job_rc eq 0) %then
   %do; 
      %on_success(Job_nm=&etls_jobName..sas, param_table=&status_table);
   %end; 
%mend etls_jobRCChk; 
%etls_jobRCChk; 

/* Check return code for job  */ 
%macro etls_jobRCChk; 
   %if (&job_rc ge 5) %then
   %do; 
      %on_success(Job_nm=&etls_jobName..sas, param_table=&status_table);
   %end; 
%mend etls_jobRCChk; 
%etls_jobRCChk; 

/*============================================================================* 
 * Post-Process code for the job                            A5V75JN3.AY000418 * 
 *                                                                            * 
 * User Written:  Creating a simple index on ACCOUNT_RK.    A5V75JN3.AF000MKL * 
 *                Creating a simple index on ACCOUNT_RK.                      * 
 *============================================================================*/ 

/*---- Start of User Written Code  ----*/ 

/*Creating a simple index on ACCOUNT_RK*/
PROC SQL;
CREATE INDEX ACCOUNT_RK 
ON MARTSCR.AM_CAS_LGD(ACCOUNT_RK);
QUIT
/*---- End of User Written Code  ----*/ 

%rcSet(&syserr); 
%rcSet(&sqlrc); 

