/****************************************************************************** 
 * Job:           APS_EXT                                   A5V75JN3.BN00000I * 
 * Description:   This job picks up data from  APPLICATION_SCORE              * 
 *                                                                            * 
 * Repository:    Foundation                                A0000001.A5V75JN3 * 
 * Server:        SASMain                                   A5V75JN3.AT000001 * 
 *                                                                            * 
 * Source Tables: LOAD_CONTROL - control.LOAD_CONTROL       A5V75JN3.BE0000I0 * 
 *                APPLICATION_SCORE - DDS.APPLICATION_SCORE A5V75JN3.BE00000B * 
 * Target Table:  APS_EXT - martscr.APS_EXT                 A5V75JN3.BE0000IG * 
 *                                                                            * 
 * Generated on:  Wednesday, December 10, 2008 12:43:07 PM IST                * 
 * Generated by:  sasadm                                                      * 
 * Version:       9.1.20060626.51875                                          * 
 ******************************************************************************
 * Notes:                                                                     * 
 * APS_EXT                                                                    * 
 * Job Name: APS_EXTJob Desc Pre Process: NoneMain:a)This job extracts and    * 
 * loads data from APPLICATION_SCORE using SQL join with LOAD_CONTROL based   * 
 * on conditions:LOAD_CONTROL.LOAD_FLG = CHECK_FLAG_TRUEand                   * 
 * LOAD_CONTROL.RUN_STATUS = RUNNING_STATUSand APPLICATION_SCORE.SCORE_DT     * 
 * between datepart(LOAD_CONTROL.LOAD_START_DTTM) and                         * 
 * datepart(LOAD_CONTROL.LOAD_END_DTTM)Post Process: Creating index on        * 
 * MODEL_RK column and LOAD_END_DTTM column.Parameters: CHECK_FLAG_TRUE and   * 
 * RUNNING_STATUS are the user defined parameters. CHECK_FLAG_TRUE is set     * 
 * to 'Y' and RUNNING_STATUS is to 'Running' for each month of data           * 
 *  load.Developed by: singupReviewed by:Tested by:                           * 
 ******************************************************************************/ 



%let jobID = %quote(A5V75JN3.BN00000I);

/* Setup for capturing job status  */ 
data _null_; 
   call symput('etls_startTime',put(datetime(),datetime.));
run;

%let etls_jobName = APS_EXT;
%let etls_recordsBefore = 0;
%let etls_recordsAfter = 0;
%let etls_lib = 0;
%let etls_table = 0;

/* Setup to capture return codes  */ 
%global job_rc trans_rc sqlrc; 
%let job_rc = 0;
%let trans_rc = 0;
%let sqlrc = 0;
%global syserr; 

%macro rcSet(error); 
   %if (&error gt &trans_rc) %then 
      %let trans_rc = &error;
   %if (&error gt &job_rc) %then 
      %let job_rc = &error;
%mend rcSet; 

%macro rcSetDS(error); 
   if &error gt input(symget('trans_rc'),12.) then 
      call symput('trans_rc',trim(left(put(&error,12.))));
   if &error gt input(symget('job_rc'),12.) then 
      call symput('job_rc',trim(left(put(&error,12.))));
%mend rcSetDS; 

%global etls_debug; 
%macro etls_setDebug; 
   %if %str(&etls_debug) ne 0 %then 
      OPTIONS MPRINT%str(;); 
%mend; 
%etls_setDebug; 

/*============================================================================* 
 * Pre-Process code for the job                             A5V75JN3.AY0004MW * 
 *                                                                            * 
 * User Written:  Oracle Date Problem Fix                   A5V75JN3.AF000PHU * 
 *                Oracle Date Problem Fix                                     * 
 *============================================================================*/ 

/*---- Start of User Written Code  ----*/ 

proc contents data=DDS.APPLICATION_SCORE out=_etlsEngine(keep=Engine) noprint;
run;

data _null_;
	set _etlsEngine;
	if _n_=1;
	  call symput('mEngine', kleft(kright(Engine)));
run;

/*---- End of User Written Code  ----*/ 

%rcSet(&syserr); 
%rcSet(&sqlrc); 

/*============================================================================* 
 * Step:          Extraction and Loading of  data as per    A5V75JN3.BO0006Y6 * 
 *                 the loading period                                         * 
 * Transform:     SQL Join (Version 2)                                        * 
 * Description:   Extract and load data based on load period mentioned in     * 
 *                 LOAD_CONTROL table                                         * 
 *                                                                            * 
 * Source Tables: LOAD_CONTROL - control.LOAD_CONTROL       A5V75JN3.BE0000I0 * 
 *                APPLICATION_SCORE - DDS.APPLICATION_SCORE A5V75JN3.BE00000B * 
 * Target Table:  SQL Target - martscr.APS_EXT              A5V75JN3.BP00066B * 
 *============================================================================*/ 

/* Access the data for Control  */ 
LIBNAME control BASE "Data/bisdata/control" ;
%rcSet(&syslibrc); 

/* Access the data for Detail Data Store  */ 
LIBNAME DDS BASE "Data/bisdata/dds" ;
%rcSet(&syslibrc); 

/* Access the data for Scratch for Mart  */ 
LIBNAME martscr BASE "Data/bisdata/scratch/mart" ;
%rcSet(&syslibrc); 

%let transformID = %quote(A5V75JN3.BO0006Y6); 

%let trans_rc = 0; 

proc datasets lib = martscr nolist nowarn memtype = (data view);
   delete APS_EXT;
quit;

proc sql;
   create table martscr.APS_EXT as
      select
         APPLICATION_SCORE.FINANCIAL_APPLICATION_RK length = 8
                                                    format = 12.
                                                    informat = 12.
                                                    label = "Financial Application Key",
         LOAD_CONTROL.LOAD_END_DTTM length = 8
                                    format = NLDATM21.
                                    informat = NLDATM21.
                                    label = "Load End Datetime",
         APPLICATION_SCORE.MODEL_RK length = 8
                                    format = 12.
                                    informat = 12.
                                    label = "Model Key",
         CASE symget('mEngine')  
         	WHEN "ORACLE" THEN datepart(APPLICATION_SCORE.SCORE_DT) 	ELSE APPLICATION_SCORE.SCORE_DT  
         END as SCORE_DT length = 8
                         format = NLDATE10.
                         informat = NLDATE10.
                         label = "Score Date",
         APPLICATION_SCORE.APPLICATION_SCORE_NO length = 8
                                                format = NLNUM12.8
                                                informat = NLNUM12.8
                                                label = "Application Score No",
         APPLICATION_SCORE.SCORE_POINTS_NO length = 8
                                           label = "Score Points No",
         APPLICATION_SCORE.ESTIMATED_RT length = 8
                                        format = NLNUM9.4
                                        informat = NLNUM9.4
                                        label = "Estimated Rate"
      from
         control.LOAD_CONTROL, 
         DDS.APPLICATION_SCORE
      where
         LOAD_CONTROL.LOAD_FLG IN (&CHECK_FLAG_TRUE)
         and LOAD_CONTROL.RUN_STATUS IN (&RUNNING_STATUS)
         and CASE symget('mEngine')  
                 WHEN "ORACLE" THEN datepart(APPLICATION_SCORE.SCORE_DT)
                 ELSE APPLICATION_SCORE.SCORE_DT
         END >= datepart(LOAD_CONTROL.LOAD_START_DTTM)
         and CASE symget('mEngine')  
                 WHEN "ORACLE" THEN datepart(APPLICATION_SCORE.SCORE_DT)
                 ELSE APPLICATION_SCORE.SCORE_DT
         END <= datepart(LOAD_CONTROL.LOAD_END_DTTM)
      group by
         APPLICATION_SCORE.MODEL_RK, 
         APPLICATION_SCORE.FINANCIAL_APPLICATION_RK, 
         LOAD_CONTROL.LOAD_END_DTTM
      having
         CASE symget('mEngine')  
                 WHEN "ORACLE" THEN datepart(APPLICATION_SCORE.SCORE_DT)
                 ELSE APPLICATION_SCORE.SCORE_DT
         END = MAX(CASE symget('mEngine')  
                 WHEN "ORACLE" THEN datepart(APPLICATION_SCORE.SCORE_DT)
                 ELSE APPLICATION_SCORE.SCORE_DT
         END)
      ;
quit;

%rcSet(&sqlrc); 

%macro etls_completeTarget();
%mend etls_completeTarget;
%etls_completeTarget;

/*============================================================================* 
 * Step:          Dummy Loader                              A5V75JN3.BO0006Y5 * 
 * Transform:     Table Loader                                                * 
 * Description:                                                               * 
 *                                                                            * 
 * Source Table:  SQL Target - martscr.APS_EXT              A5V75JN3.BP00066B * 
 * Target Table:  APS_EXT - martscr.APS_EXT                 A5V75JN3.BE0000IG * 
 *============================================================================*
 *                                                                            * 
 * Nothing will be generated for this process because the "Do not generate    * 
 *  code for this process" option is selected.                                * 
 *                                                                            * 
 *============================================================================*/ 

data _null_; 
   call symput('etls_endTime',put(datetime(),datetime.));
run;

/* Check return code for job  */ 
%macro etls_jobRCChk; 
   %if (&job_rc eq 4) %then
   %do; 
      %on_success(Job_nm=&etls_jobName..sas, param_table=&status_table);
   %end; 
%mend etls_jobRCChk; 
%etls_jobRCChk; 

/* Check return code for job  */ 
%macro etls_jobRCChk; 
   %if (&job_rc ge 5) %then
   %do; 
      %on_success(Job_nm=&etls_jobName..sas, param_table=&status_table);
   %end; 
%mend etls_jobRCChk; 
%etls_jobRCChk; 

/* Check return code for job  */ 
%macro etls_jobRCChk; 
   %if (&job_rc eq 0) %then
   %do; 
      %on_success(Job_nm=&etls_jobName..sas, param_table=&status_table);
   %end; 
%mend etls_jobRCChk; 
%etls_jobRCChk; 

/*---- Job status macro  ----*/ 
/*============================================================================* 
 * Post-Process code for the job                            A5V75JN3.AY0004MX * 
 *                                                                            * 
 * User Written:  Creating index on MODEL_RK,LOAD_END_DTTM  A5V75JN3.AF000PHV * 
 *                 columns                                                    * 
 *                Creating index on MODEL_RK,LOAD_END_DTTM columns            * 
 *============================================================================*/ 

/*---- Start of User Written Code  ----*/ 

/*Creating index on MODEL_RK and LOAD_END DTTM column */
PROC SQL NOPRINT;
  CREATE INDEX MODEL_RK_LOAD_END_DTTM
   ON martscr.APS_EXT(MODEL_RK,LOAD_END_DTTM);
QUIT;
/*---- End of User Written Code  ----*/ 

%rcSet(&syserr); 
%rcSet(&sqlrc); 

