/****************************************************************************** 
 * Job:           CBA_EXT                                   A5V75JN3.BN00000P * 
 * Description:   This job builds the CBA_EXT table by picking up data from   * 
 *                 CORE_BANKING_ACCOUNT                                       * 
 *                                                                            * 
 * Repository:    Foundation                                A0000001.A5V75JN3 * 
 * Server:        SASMain                                   A5V75JN3.AT000001 * 
 *                                                                            * 
 * Source Tables: LOAD_CONTROL - control.LOAD_CONTROL       A5V75JN3.BE0000I0 * 
 *                CORE_BANKING_ACCOUNT -                    A5V75JN3.BE00000Y * 
 *                 DDS.CORE_BANKING_ACCOUNT                                   * 
 * Target Table:  CBA_EXT - martscr.CBA_EXT                 A5V75JN3.BE0000IN * 
 *                                                                            * 
 * Generated on:  Wednesday, December 10, 2008 12:45:26 PM IST                * 
 * Generated by:  sasadm                                                      * 
 * Version:       9.1.20060626.51875                                          * 
 ******************************************************************************
 * Notes:                                                                     * 
 * CBA_EXT                                                                    * 
 * Job Name: CBA_EXTJob Desc Pre Process: NoneMain:a) Extract and load data   * 
 * from CORE_BANKING_ACCOUNT using SQL join on LOAD_CONTROL table based on    * 
 * following conditions:LOAD_CONTROL.LOAD_FLG = CHECK_FLAG_TRUEand            * 
 * LOAD_CONTROL.RUN_STATUS = RUNNING_STATUSand LOAD_CONTROL.LOAD_END_DTTM     * 
 * between CORE_BANKING_ACCOUNT.VALID_FROM_DTTMand                            * 
 * CORE_BANKING_ACCOUNT.VALID_TO_DTTMPost Process: An index is created on     * 
 * ACCOUNT_RK andLOAD_END_DTTM fields in CBA_EXT.Parameters:CHECK_FLAG_TRUE   * 
 * and RUNNING_STATUS are the user defined parameters. CHECK_FLAG_TRUE is     * 
 * set to 'Y' and RUNNING_STATUS is to 'Running' for each month of data       * 
 *  load.Developed by: singupReviewed by:Tested by:                           * 
 ******************************************************************************/ 



%let jobID = %quote(A5V75JN3.BN00000P);

/* Setup for capturing job status  */ 
data _null_; 
   call symput('etls_startTime',put(datetime(),datetime.));
run;

%let etls_jobName = CBA_EXT;
%let etls_recordsBefore = 0;
%let etls_recordsAfter = 0;
%let etls_lib = 0;
%let etls_table = 0;

/* Setup to capture return codes  */ 
%global job_rc trans_rc sqlrc; 
%let job_rc = 0;
%let trans_rc = 0;
%let sqlrc = 0;
%global syserr; 

%macro rcSet(error); 
   %if (&error gt &trans_rc) %then 
      %let trans_rc = &error;
   %if (&error gt &job_rc) %then 
      %let job_rc = &error;
%mend rcSet; 

%macro rcSetDS(error); 
   if &error gt input(symget('trans_rc'),12.) then 
      call symput('trans_rc',trim(left(put(&error,12.))));
   if &error gt input(symget('job_rc'),12.) then 
      call symput('job_rc',trim(left(put(&error,12.))));
%mend rcSetDS; 

%global etls_debug; 
%macro etls_setDebug; 
   %if %str(&etls_debug) ne 0 %then 
      OPTIONS MPRINT%str(;); 
%mend; 
%etls_setDebug; 

/*============================================================================* 
 * Pre-Process code for the job                             A5V75JN3.AY0004ND * 
 *                                                                            * 
 * User Written:  Oracle Date Problem Fix                   A5V75JN3.AF000PKK * 
 *                Oracle Date Problem Fix                                     * 
 *============================================================================*/ 

/*---- Start of User Written Code  ----*/ 

proc contents data=dds.core_banking_account out=_etlsEngine(keep=Engine) noprint;
run;

data _null_;
	set _etlsEngine;
	if _n_=1;
	  call symput('mEngine', kleft(kright(Engine)));
run;
/*---- End of User Written Code  ----*/ 

%rcSet(&syserr); 
%rcSet(&sqlrc); 

/*============================================================================* 
 * Step:          Extraction of data as per the loading     A5V75JN3.BO0006YG * 
 *                 period                                                     * 
 * Transform:     SQL Join (Version 2)                                        * 
 * Description:   Extract and load data based on load period mentioned in     * 
 *                 LOAD_CONTROL table                                         * 
 *                                                                            * 
 * Source Tables: LOAD_CONTROL - control.LOAD_CONTROL       A5V75JN3.BE0000I0 * 
 *                CORE_BANKING_ACCOUNT -                    A5V75JN3.BE00000Y * 
 *                 DDS.CORE_BANKING_ACCOUNT                                   * 
 * Target Table:  SQL Target - martscr.CBA_EXT              A5V75JN3.BP00066G * 
 *============================================================================*/ 

/* Access the data for Control  */ 
LIBNAME control BASE "Data/bisdata/control" ;
%rcSet(&syslibrc); 

/* Access the data for Detail Data Store  */ 
LIBNAME DDS BASE "Data/bisdata/dds" ;
%rcSet(&syslibrc); 

/* Access the data for Scratch for Mart  */ 
LIBNAME martscr BASE "Data/bisdata/scratch/mart" ;
%rcSet(&syslibrc); 

%let transformID = %quote(A5V75JN3.BO0006YG); 

%let trans_rc = 0; 

proc datasets lib = martscr nolist nowarn memtype = (data view);
   delete CBA_EXT;
quit;

proc sql;
   create table martscr.CBA_EXT as
      select
         CORE_BANKING_ACCOUNT.ACCOUNT_RK length = 8
                                         format = 12.
                                         informat = 12.
                                         label = "Account Key",
         LOAD_CONTROL.LOAD_END_DTTM length = 8
                                    format = NLDATM21.
                                    informat = NLDATM21.
                                    label = "Load End Datetime",
         CORE_BANKING_ACCOUNT.ACCOUNT_ID length = 32
                                         label = "Account Id",
         CORE_BANKING_ACCOUNT.ACCOUNT_RENEWAL_CNT length = 8
                                                  label = "Account Renewal Count",
         CORE_BANKING_ACCOUNT.ACCOUNT_RENEWAL_TYPE_CD length = 3
                                                      label = "Account Renewal Type Code",
         CORE_BANKING_ACCOUNT.ACTIVE_DIRECT_DEBITS_CNT length = 8
                                                       label = "Active Direct Debits Count",
         CORE_BANKING_ACCOUNT.ACTUAL_ACCOUNT_OPENING_AMT length = 8
                                                         format = NLNUM18.5
                                                         informat = NLNUM18.5
                                                         label = "Actual Account Opening Amount",
         CORE_BANKING_ACCOUNT.ADDITIONAL_SERVICES_FLG length = 1
                                                      label = "Additional Services Flag",
         CORE_BANKING_ACCOUNT.APR_RT length = 8
                                     format = NLNUM9.4
                                     informat = NLNUM9.4
                                     label = "APR Rate",
         CORE_BANKING_ACCOUNT.AUTHORIZED_USERS_CNT length = 8
                                                   label = "Authorized Users Count",
         CORE_BANKING_ACCOUNT.BASE_APR_RT length = 8
                                          format = NLNUM9.4
                                          informat = NLNUM9.4
                                          label = "Base APR Rate",
         CORE_BANKING_ACCOUNT.CALLABLE_FACILITY_USED_FLG length = 1
                                                         label = "Callable Facility Used Flag",
         CASE symget('mEngine')
         	WHEN "ORACLE" THEN datepart(CORE_BANKING_ACCOUNT.CHECKING_BOOK_DT)
         	ELSE CORE_BANKING_ACCOUNT.CHECKING_BOOK_DT
         END as CHECKING_BOOK_DT length = 8
                                 format = NLDATE10.
                                 informat = NLDATE10.
                                 label = "Checking Book Date",
         CORE_BANKING_ACCOUNT.CHECKING_BOOK_FLG length = 1
                                                label = "Checking Book Flag",
         CORE_BANKING_ACCOUNT.CHECKING_MAIN_FLG length = 1
                                                label = "Checking Main Flag",
         CORE_BANKING_ACCOUNT.CHG_DIRECT_DEPOSIT_MTH_NO length = 8
                                                        label = "Change Direct Deposit Month Number",
         CORE_BANKING_ACCOUNT.CORE_ACCOUNT_STATUS_CD length = 3
                                                     label = "Core Banking Account Status Code",
         CORE_BANKING_ACCOUNT.CORE_ACCOUNT_TYPE_CD length = 3
                                                   label = "Core Banking Account Type Code",
         CORE_BANKING_ACCOUNT.DIRECT_DEBITS_CNT length = 8
                                                label = "Direct Debits Count",
         CORE_BANKING_ACCOUNT.INTEREST_PAYOUT_FLG length = 1
                                                  label = "Interest Payout Flag",
         CORE_BANKING_ACCOUNT.INTEREST_PERIOD_CNT length = 8
                                                  label = "Interest Period Count",
         CORE_BANKING_ACCOUNT.INTEREST_TIER_NO length = 8
                                               label = "Interest Tier No",
         CORE_BANKING_ACCOUNT.INTERNAL_DIRECT_DEP_FLG length = 1
                                                      label = "Internal Direct Deposit Flag",
         CORE_BANKING_ACCOUNT.LINKED_ACCOUNT_FLG length = 1
                                                 label = "Linked Account Flag",
         CORE_BANKING_ACCOUNT.LINKED_DEPOSIT_ACCOUNT_FLG length = 1
                                                         label = "Linked Deposit Account Flag",
         CORE_BANKING_ACCOUNT.MANDATE_SINGLE_LIMIT_AMT length = 8
                                                       format = NLNUM18.5
                                                       informat = NLNUM18.5
                                                       label = "Mandate Single Limit Amount",
         CORE_BANKING_ACCOUNT.MIN_ACCOUNT_OPENING_AMT length = 8
                                                      format = NLNUM18.5
                                                      informat = NLNUM18.5
                                                      label = "Minimum Account Opening Amount",
         CORE_BANKING_ACCOUNT.OVERDRAFT_CHARGE_AMT length = 8
                                                   format = NLNUM18.5
                                                   informat = NLNUM18.5
                                                   label = "Overdraft Charge Amount",
         CASE symget('mEngine')
         	WHEN "ORACLE" THEN datepart(CORE_BANKING_ACCOUNT.OVERDRAFT_CHARGE_NOTIF_DT)
         	ELSE CORE_BANKING_ACCOUNT.OVERDRAFT_CHARGE_NOTIF_DT
         END as OVERDRAFT_CHARGE_NOTIF_DT length = 8
                                          format = NLDATE10.
                                          informat = NLDATE10.
                                          label = "Overdraft Charge Notification Date",
         CORE_BANKING_ACCOUNT.OVERDRAFT_CURRENT_AMT length = 8
                                                    format = NLNUM18.5
                                                    informat = NLNUM18.5
                                                    label = "Overdraft Current Amount",
         CORE_BANKING_ACCOUNT.OVERDRAFT_FLG length = 1
                                            label = "Overdraft Flag",
         CORE_BANKING_ACCOUNT.OVERDRAFT_LIMIT_AMT length = 8
                                                  format = NLNUM18.5
                                                  informat = NLNUM18.5
                                                  label = "Overdraft Limit Amount",
         CASE symget('mEngine')
         	WHEN "ORACLE" THEN datepart(CORE_BANKING_ACCOUNT.OVERDRAFT_LIMIT_DT)
         	ELSE CORE_BANKING_ACCOUNT.OVERDRAFT_LIMIT_DT
         END as OVERDRAFT_LIMIT_DT length = 8
                                   format = NLDATE10.
                                   informat = NLDATE10.
                                   label = "Overdraft Limit Date",
         CORE_BANKING_ACCOUNT.OVERDRAFT_PRIVILEGES_FLG length = 1
                                                       label = "Overdraft Privileges Flag",
         CORE_BANKING_ACCOUNT.OVERDRAFT_PROTECTION_FLG length = 1
                                                       label = "Overdraft Protection Flag",
         CORE_BANKING_ACCOUNT.PAYMENT_AMT length = 8
                                          format = NLNUM18.5
                                          informat = NLNUM18.5
                                          label = "Payment Amount",
         CORE_BANKING_ACCOUNT.PAYMENT_METHOD_CD length = 3,
         CORE_BANKING_ACCOUNT.PAYMENT_TIME_FREQUENCY_CD length = 3
                                                        label = "Time Frequency Code",
         CORE_BANKING_ACCOUNT.PREF_WITHDRAWAL_CHANNEL_CD length = 3
                                                         label = "Preferred Withdrawal Channel Code",
         CORE_BANKING_ACCOUNT.PREFERRED_DEPOSIT_CHANNEL_CD length = 3
                                                           label = "Preferred Deposit Channel Code",
         CORE_BANKING_ACCOUNT.PROTECTION_INS_FLG length = 1
                                                 label = "Protection Ins Flag",
         CORE_BANKING_ACCOUNT.PROTECTION_INS_STATUS_CD length = 3
                                                       label = "Protection Ins Status Code",
         CORE_BANKING_ACCOUNT.RECURRING_DEPOSIT_PLAN_FLG length = 1
                                                         label = "Recurring Deposit Plan Flag",
         CASE symget('mEngine')
         	WHEN "ORACLE" THEN datepart(CORE_BANKING_ACCOUNT.RENEWAL_DT)
         	ELSE CORE_BANKING_ACCOUNT.RENEWAL_DT
         END as RENEWAL_DT length = 8
                           format = NLDATE10.
                           informat = NLDATE10.
                           label = "Renewal Date",
         CORE_BANKING_ACCOUNT.REQUIRED_MIN_BALANCE_AMT length = 8
                                                       format = NLNUM18.5
                                                       informat = NLNUM18.5
                                                       label = "Required Minimum Balance Amount",
         CORE_BANKING_ACCOUNT.ROLLED_OVER_FLG length = 1
                                              label = "Rolled Over Flag",
         CORE_BANKING_ACCOUNT.SAFE_DEPOSIT_FLG length = 1
                                               label = "Safe Deposit Flag",
         CORE_BANKING_ACCOUNT.SOURCE_SYSTEM_CD length = 3
                                               label = "Source System Code",
         CORE_BANKING_ACCOUNT.STANDING_ORDERS_CNT length = 8
                                                  label = "Standing Orders Count",
         CORE_BANKING_ACCOUNT.STEP_UP_FACILITY_USED_FLG length = 1
                                                        label = "Step Up Facility Used Flag",
         CORE_BANKING_ACCOUNT.TERM length = 8
                                   label = "Term",
         CORE_BANKING_ACCOUNT.TERM_TIME_UOM_CD length = 3
                                               label = "UOM Code of Term Time",
         CORE_BANKING_ACCOUNT.WITHDRAWAL_NOTICE_DAYS_CNT length = 8
                                                         label = "Withdrawal Notice in Days",
         CORE_BANKING_ACCOUNT.WITHDRAWAL_PRIVILEGES_FLG length = 1
                                                        label = "Withdrawal Privileges Flag",
         CORE_BANKING_ACCOUNT.WITHDRAWL_NOTICE_FLG length = 1
                                                   label = "Withdrawal Notice Flag"
      from
         control.LOAD_CONTROL, 
         DDS.CORE_BANKING_ACCOUNT
      where
         LOAD_CONTROL.LOAD_FLG IN (&CHECK_FLAG_TRUE)
         and LOAD_CONTROL.RUN_STATUS IN (&RUNNING_STATUS)
         and LOAD_CONTROL.LOAD_END_DTTM >= CORE_BANKING_ACCOUNT.VALID_FROM_DTTM
         and LOAD_CONTROL.LOAD_END_DTTM <= CORE_BANKING_ACCOUNT.VALID_TO_DTTM
      ;
quit;

%rcSet(&sqlrc); 

%macro etls_completeTarget();
%mend etls_completeTarget;
%etls_completeTarget;

/*============================================================================* 
 * Step:          Dummy Loader                              A5V75JN3.BO0006YF * 
 * Transform:     Table Loader                                                * 
 * Description:                                                               * 
 *                                                                            * 
 * Source Table:  SQL Target - martscr.CBA_EXT              A5V75JN3.BP00066G * 
 * Target Table:  CBA_EXT - martscr.CBA_EXT                 A5V75JN3.BE0000IN * 
 *============================================================================*
 *                                                                            * 
 * Nothing will be generated for this process because the "Do not generate    * 
 *  code for this process" option is selected.                                * 
 *                                                                            * 
 *============================================================================*/ 

data _null_; 
   call symput('etls_endTime',put(datetime(),datetime.));
run;

/* Check return code for job  */ 
%macro etls_jobRCChk; 
   %if (&job_rc eq 4) %then
   %do; 
      %on_success(Job_nm=&etls_jobName..sas, param_table=&status_table);
   %end; 
%mend etls_jobRCChk; 
%etls_jobRCChk; 

/* Check return code for job  */ 
%macro etls_jobRCChk; 
   %if (&job_rc ge 5) %then
   %do; 
      %on_success(Job_nm=&etls_jobName..sas, param_table=&status_table);
   %end; 
%mend etls_jobRCChk; 
%etls_jobRCChk; 

/* Check return code for job  */ 
%macro etls_jobRCChk; 
   %if (&job_rc eq 0) %then
   %do; 
      %on_success(Job_nm=&etls_jobName..sas, param_table=&status_table);
   %end; 
%mend etls_jobRCChk; 
%etls_jobRCChk; 

/*---- Job status macro  ----*/ 
/*============================================================================* 
 * Post-Process code for the job                            A5V75JN3.AY0004NE * 
 *                                                                            * 
 * User Written:  Index creation code on ACCOUNT_RK and     A5V75JN3.AF000PKL * 
 *                 LOAD_END_DTTM  column                                      * 
 *                Index creation code on ACCOUNT_RK and LOAD_END_DTTM column  * 
 *============================================================================*/ 

/*---- Start of User Written Code  ----*/ 

/*creating index on ACCOUNT_RK  and LOAD_END_DTTM column */
PROC SQL NOPRINT;
           CREATE INDEX ACCOUNT_RK_LOAD_END_DTTM
            ON martscr.CBA_EXT(ACCOUNT_RK,LOAD_END_DTTM);
QUIT;
/*---- End of User Written Code  ----*/ 

%rcSet(&syserr); 
%rcSet(&sqlrc); 

