/****************************************************************************** 
 * Job:           CBI_EXT                                   A5V75JN3.BN00000R * 
 * Description:   This job picks up data from CREDIT_BUREAU_INFO.             * 
 *                                                                            * 
 * Repository:    Foundation                                A0000001.A5V75JN3 * 
 * Server:        SASMain                                   A5V75JN3.AT000001 * 
 *                                                                            * 
 * Source Tables: LOAD_CONTROL - control.LOAD_CONTROL       A5V75JN3.BE0000I0 * 
 *                CREDIT_BUREAU_INFO -                      A5V75JN3.BE00001H * 
 *                 DDS.CREDIT_BUREAU_INFO                                     * 
 * Target Table:  CBI_EXT - martscr.CBI_EXT                 A5V75JN3.BE0000IP * 
 *                                                                            * 
 * Generated on:  Wednesday, December 10, 2008 12:45:27 PM IST                * 
 * Generated by:  sasadm                                                      * 
 * Version:       9.1.20060626.51875                                          * 
 ******************************************************************************
 * Notes:                                                                     * 
 * CBI_EXT                                                                    * 
 * Job Name: CBI_EXTJob Desc Pre Process: NoneMain: Extract and load data     * 
 * from CREDIT_BUREAU_INFO using SQL join on LOAD_CONTROL based on            * 
 * following conditionsLOAD_CONTROL.LOAD_FLG = CHECK_FLAG_TRUEand             * 
 * LOAD_CONTROL.RUN_STATUS = RUNNING_STATUSand LOAD_CONTROL.LOAD_END_DTTM     * 
 * between CREDIT_BUREAU_INFO.VALID_FROM_DTTM and                             * 
 * CREDIT_BUREAU_INFO.VALID_TO_DTTMPost Process: Creating index on            * 
 * BUREAU_CD and on LOAD_END_DTTM.Parameters: CHECK_FLAG_TRUE and             * 
 * RUNNING_STATUS are the user defined parameters. CHECK_FLAG_TRUE is set     * 
 * to 'Y' and RUNNING_STATUS is to 'Running' for each month of data           * 
 *  load.Developed by: singupReviewed by:Tested by:                           * 
 ******************************************************************************/ 



%let jobID = %quote(A5V75JN3.BN00000R);

/* Setup for capturing job status  */ 
data _null_; 
   call symput('etls_startTime',put(datetime(),datetime.));
run;

%let etls_jobName = CBI_EXT;
%let etls_recordsBefore = 0;
%let etls_recordsAfter = 0;
%let etls_lib = 0;
%let etls_table = 0;

/* Setup to capture return codes  */ 
%global job_rc trans_rc sqlrc; 
%let job_rc = 0;
%let trans_rc = 0;
%let sqlrc = 0;
%global syserr; 

%macro rcSet(error); 
   %if (&error gt &trans_rc) %then 
      %let trans_rc = &error;
   %if (&error gt &job_rc) %then 
      %let job_rc = &error;
%mend rcSet; 

%macro rcSetDS(error); 
   if &error gt input(symget('trans_rc'),12.) then 
      call symput('trans_rc',trim(left(put(&error,12.))));
   if &error gt input(symget('job_rc'),12.) then 
      call symput('job_rc',trim(left(put(&error,12.))));
%mend rcSetDS; 

%global etls_debug; 
%macro etls_setDebug; 
   %if %str(&etls_debug) ne 0 %then 
      OPTIONS MPRINT%str(;); 
%mend; 
%etls_setDebug; 

/*============================================================================* 
 * Pre-Process code for the job                             A5V75JN3.AY0004NH * 
 *                                                                            * 
 * User Written:  Oracle Date Problem Fix                   A5V75JN3.AF000PLK * 
 *                Oracle Date Problem Fix                                     * 
 *============================================================================*/ 

/*---- Start of User Written Code  ----*/ 

proc contents data=dds.credit_bureau_info out=_etlsEngine(keep=Engine) noprint;
run;

data _null_;
	set _etlsEngine;
	if _n_=1;
	  call symput('mEngine', kleft(kright(Engine)));
run;
/*---- End of User Written Code  ----*/ 

%rcSet(&syserr); 
%rcSet(&sqlrc); 

/*============================================================================* 
 * Step:          Extraction of data as per the loading     A5V75JN3.BO0006YK * 
 *                 period                                                     * 
 * Transform:     SQL Join (Version 2)                                        * 
 * Description:   Extract and load data based on load period mentioned in     * 
 *                 LOAD_CONTROL table                                         * 
 *                                                                            * 
 * Source Tables: LOAD_CONTROL - control.LOAD_CONTROL       A5V75JN3.BE0000I0 * 
 *                CREDIT_BUREAU_INFO -                      A5V75JN3.BE00001H * 
 *                 DDS.CREDIT_BUREAU_INFO                                     * 
 * Target Table:  SQL Target - martscr.CBI_EXT              A5V75JN3.BP00066I * 
 *============================================================================*/ 

/* Access the data for Control  */ 
LIBNAME control BASE "Data/bisdata/control" ;
%rcSet(&syslibrc); 

/* Access the data for Detail Data Store  */ 
LIBNAME DDS BASE "Data/bisdata/dds" ;
%rcSet(&syslibrc); 

/* Access the data for Scratch for Mart  */ 
LIBNAME martscr BASE "Data/bisdata/scratch/mart" ;
%rcSet(&syslibrc); 

%let transformID = %quote(A5V75JN3.BO0006YK); 

%let trans_rc = 0; 

proc datasets lib = martscr nolist nowarn memtype = (data view);
   delete CBI_EXT;
quit;

proc sql;
   create table martscr.CBI_EXT as
      select
         CREDIT_BUREAU_INFO.APPLICANT_RK length = 8
                                         format = 12.
                                         informat = 12.
                                         label = "Applicant Key",
         LOAD_CONTROL.LOAD_END_DTTM length = 8
                                    format = NLDATM21.
                                    informat = NLDATM21.
                                    label = "Load End Datetime",
         CREDIT_BUREAU_INFO.BUREAU_CD length = 3
                                      label = "Bureau Code",
         CREDIT_BUREAU_INFO.DEROGATORY_ACCT_CNT length = 8
                                                label = "Derogatory Account Count",
         CREDIT_BUREAU_INFO.BUREAU_CLASS_CD length = 3
                                            label = "Bureau Class Code",
         CREDIT_BUREAU_INFO.OWNER_RK length = 8
                                     format = 12.
                                     informat = 12.
                                     label = "Owner Key",
         CASE symget('mEngine') 	
         	WHEN "ORACLE" THEN datepart(CREDIT_BUREAU_INFO.SCORE_DT)
         	ELSE CREDIT_BUREAU_INFO.SCORE_DT
         END as SCORE_DT length = 8
                         format = NLDATE10.
                         informat = NLDATE10.
                         label = "Score Date",
         CREDIT_BUREAU_INFO.GOOD_ACCT_CNT length = 8
                                          label = "Good Account Count",
         CREDIT_BUREAU_INFO.OPEN_ACCT_CNT length = 8
                                          label = "Open Account Count",
         CREDIT_BUREAU_INFO.FINANCIAL_APPLICATION_RK length = 8
                                                     format = 12.
                                                     informat = 12.
                                                     label = "Financial Application Key",
         CASE symget('mEngine') 	
         	WHEN "ORACLE" THEN datepart(CREDIT_BUREAU_INFO.CREDIT_ACTIVE_DT) 	
         	ELSE CREDIT_BUREAU_INFO.CREDIT_ACTIVE_DT
         END as CREDIT_ACTIVE_DT length = 8
                                 format = NLDATE10.
                                 informat = NLDATE10.
                                 label = "Credit Active Date",
         CASE symget('mEngine') 	
         	WHEN "ORACLE" THEN datepart(CREDIT_BUREAU_INFO.REQUEST_DT) 	
         	ELSE CREDIT_BUREAU_INFO.REQUEST_DT
         END as REQUEST_DT length = 8
                           format = NLDATE10.
                           informat = NLDATE10.
                           label = "Request Date",
         CREDIT_BUREAU_INFO.TOTAL_BALANCE_AMT length = 8
                                              format = NLNUM18.5
                                              informat = NLNUM18.5
                                              label = "Total Balance Amount",
         CREDIT_BUREAU_INFO.CURRENT_CREDIT_PCT length = 8
                                               format = NLNUM9.4
                                               informat = NLNUM9.4
                                               label = "Current Credit Percentage",
         CREDIT_BUREAU_INFO.DELINQUENT_ACCT_CNT length = 8
                                                label = "Delinquent Account Count",
         CREDIT_BUREAU_INFO.TOT_MTH_PAYMENT_AMT length = 8
                                                format = NLNUM18.5
                                                informat = NLNUM18.5
                                                label = "Total Monthly Payment Amount",
         CREDIT_BUREAU_INFO.CLOSED_ACCT_CNT length = 8
                                            label = "Closed Account count",
         CREDIT_BUREAU_INFO.CUSTOMER_RK length = 8
                                        format = 12.
                                        informat = 12.
                                        label = "Customer Key",
         CREDIT_BUREAU_INFO.BUREAU_INFO_RK length = 8
                                           format = 12.
                                           informat = 12.
                                           label = "Bureau Info Key",
         CREDIT_BUREAU_INFO.SCORE_NO length = 8
                                     format = NLNUM6.2
                                     informat = NLNUM6.2
                                     label = "Score No",
         CREDIT_BUREAU_INFO.REVOLVING_DEBT_AMT length = 8
                                               format = NLNUM18.5
                                               informat = NLNUM18.5
                                               label = "Revolving Debt Amount",
         CREDIT_BUREAU_INFO.REAL_ESTATE_DEBT_AMT length = 8
                                                 format = NLNUM18.5
                                                 informat = NLNUM18.5
                                                 label = "Real Estate Debt Amount",
         CREDIT_BUREAU_INFO.INSTALLMENT_DEBT_AMT length = 8
                                                 format = NLNUM18.5
                                                 informat = NLNUM18.5
                                                 label = "Installment Debt Amount",
         CREDIT_BUREAU_INFO.OTHER_DEBT_AMT length = 8
                                           format = NLNUM18.5
                                           informat = NLNUM18.5
                                           label = "Other Debt Amount",
         CREDIT_BUREAU_INFO.COLLECTION_DEBT_AMT length = 8
                                                format = NLNUM18.5
                                                informat = NLNUM18.5
                                                label = "Collection Debt Amount",
         CREDIT_BUREAU_INFO.TOT_PAST_DUE_SLOW_30_AMT length = 8
                                                     format = NLNUM18.5
                                                     informat = NLNUM18.5
                                                     label = "Total Amount Past Due for 30 days",
         CREDIT_BUREAU_INFO.TOT_PAST_DUE_SLOW_90_AMT length = 8
                                                     format = NLNUM18.5
                                                     informat = NLNUM18.5
                                                     label = "Total Amount Past Due for 90 days",
         CREDIT_BUREAU_INFO.HIGHEST_CREDIT_LIMIT_AMT length = 8
                                                     format = NLNUM18.5
                                                     informat = NLNUM18.5
                                                     label = "Highest Credit Limit Amount",
         CREDIT_BUREAU_INFO.CURRENT_CREDIT_LIMIT_AMT length = 8
                                                     format = NLNUM18.5
                                                     informat = NLNUM18.5
                                                     label = "Current Credit Limit Amount",
         CREDIT_BUREAU_INFO.OTHER_INQUIRY_BUREAU_CNT length = 8
                                                     label = "No of Inquiries by Other Bureaus",
         CASE symget('mEngine')
         	WHEN "ORACLE" THEN datepart(CREDIT_BUREAU_INFO.OTHER_LAST_INQUIRY_DT)
         	ELSE CREDIT_BUREAU_INFO.OTHER_LAST_INQUIRY_DT
         END as OTHER_LAST_INQUIRY_DT length = 8
                                      format = NLDATE10.
                                      informat = NLDATE10.
                                      label = "Last Inquiry Date by other Bureau",
         CREDIT_BUREAU_INFO.MONTHS_SINCE_AT_BUREAU length = 8
                                                   format = NLNUM6.2
                                                   informat = NLNUM6.2
                                                   label = "No of Months At Bureau",
         CREDIT_BUREAU_INFO.EVER_IN_COLLECTION_FLG length = 1
                                                   label = "Ever Into Collection Flag",
         CREDIT_BUREAU_INFO.CHARGE_OFF_CNT length = 8
                                           label = "Charge Off Count",
         CREDIT_BUREAU_INFO.LIENS_CNT length = 8
                                      label = "Liens Count",
         CASE symget('mEngine')
         	WHEN "ORACLE" THEN datepart(CREDIT_BUREAU_INFO.LAST_LIEN_DT)
         	ELSE CREDIT_BUREAU_INFO.LAST_LIEN_DT
         END as LAST_LIEN_DT length = 8
                             format = NLDATE10.
                             informat = NLDATE10.
                             label = "Last Lien Date",
         CASE symget('mEngine') 
         	WHEN "ORACLE" THEN datepart(CREDIT_BUREAU_INFO.BANKRUPTCY_FILED_DT) 
         	ELSE CREDIT_BUREAU_INFO.BANKRUPTCY_FILED_DT 
         END as BANKRUPTCY_FILED_DT length = 8
                                    format = NLDATE10.
                                    informat = NLDATE10.
                                    label = "Bankruptcy Filed Date",
         CREDIT_BUREAU_INFO.BANKRUPTCY_STATUS_CD length = 3
                                                 label = "Bankruptcy Status Code",
         CREDIT_BUREAU_INFO.BANKRUPTCY_CNT length = 8
                                           label = "Bankruptcy Count",
         CREDIT_BUREAU_INFO.WORST_RATING_12_MTH_NO length = 8
                                                   label = "Worst Rating No in Last 12 Months",
         CREDIT_BUREAU_INFO.FRAUD_FLG length = 1
                                      label = "Fraud Flag",
         CREDIT_BUREAU_INFO.JUDGEMENTS_CNT length = 8
                                           label = "Judgements Count",
         CASE symget('mEngine') 
         	WHEN "ORACLE" THEN datepart(CREDIT_BUREAU_INFO.LAST_JUDGEMENT_DT) 
         	ELSE CREDIT_BUREAU_INFO.LAST_JUDGEMENT_DT 
         END as LAST_JUDGEMENT_DT length = 8
                                  format = NLDATE10.
                                  informat = NLDATE10.
                                  label = "Last Judgement Date",
         CREDIT_BUREAU_INFO.PUBLIC_RECORD_CNT length = 8
                                              label = "Public Records Count"
      from
         control.LOAD_CONTROL, 
         DDS.CREDIT_BUREAU_INFO
      where
         LOAD_CONTROL.LOAD_FLG IN (&CHECK_FLAG_TRUE)
         and LOAD_CONTROL.RUN_STATUS IN (&RUNNING_STATUS)
         and LOAD_CONTROL.LOAD_END_DTTM >= CREDIT_BUREAU_INFO.VALID_FROM_DTTM
         and LOAD_CONTROL.LOAD_END_DTTM <= CREDIT_BUREAU_INFO.VALID_TO_DTTM
      ;
quit;

%rcSet(&sqlrc); 

%macro etls_completeTarget();
%mend etls_completeTarget;
%etls_completeTarget;

/*============================================================================* 
 * Step:          Dummy Loader                              A5V75JN3.BO0006YJ * 
 * Transform:     Table Loader                                                * 
 * Description:                                                               * 
 *                                                                            * 
 * Source Table:  SQL Target - martscr.CBI_EXT              A5V75JN3.BP00066I * 
 * Target Table:  CBI_EXT - martscr.CBI_EXT                 A5V75JN3.BE0000IP * 
 *============================================================================*
 *                                                                            * 
 * Nothing will be generated for this process because the "Do not generate    * 
 *  code for this process" option is selected.                                * 
 *                                                                            * 
 *============================================================================*/ 

data _null_; 
   call symput('etls_endTime',put(datetime(),datetime.));
run;

/* Check return code for job  */ 
%macro etls_jobRCChk; 
   %if (&job_rc eq 4) %then
   %do; 
      %on_success(Job_nm=&etls_jobName..sas, param_table=&status_table);
   %end; 
%mend etls_jobRCChk; 
%etls_jobRCChk; 

/* Check return code for job  */ 
%macro etls_jobRCChk; 
   %if (&job_rc ge 5) %then
   %do; 
      %on_success(Job_nm=&etls_jobName..sas, param_table=&status_table);
   %end; 
%mend etls_jobRCChk; 
%etls_jobRCChk; 

/* Check return code for job  */ 
%macro etls_jobRCChk; 
   %if (&job_rc eq 0) %then
   %do; 
      %on_success(Job_nm=&etls_jobName..sas, param_table=&status_table);
   %end; 
%mend etls_jobRCChk; 
%etls_jobRCChk; 

/*---- Job status macro  ----*/ 
/*============================================================================* 
 * Post-Process code for the job                            A5V75JN3.AY0004NI * 
 *                                                                            * 
 * User Written:  Index creation on BUREAU_CD and           A5V75JN3.AF000PLL * 
 *                 LOAD_END_DTTM                                              * 
 *                Index creation on BUREAU_CD and LOAD_END_DTTM               * 
 *============================================================================*/ 

/*---- Start of User Written Code  ----*/ 

/*creating index on BUREAU_CD and LOAD_END_DTTM column */
PROC SQL NOPRINT;
     CREATE INDEX BUREAU_CD_LOAD_END_DTTM
      ON martscr.CBI_EXT(BUREAU_CD, LOAD_END_DTTM);
QUIT;

/*---- End of User Written Code  ----*/ 

%rcSet(&syserr); 
%rcSet(&sqlrc); 

