/****************************************************************************** 
 * Job:           CCO_EXT                                   A5V75JN3.BN00000V * 
 * Description:   This job builds the CCO_EXT table by picking up data from   * 
 *                 CORPORATE_CUSTOMER_OWNER table.                            * 
 *                                                                            * 
 * Repository:    Foundation                                A0000001.A5V75JN3 * 
 * Server:        SASMain                                   A5V75JN3.AT000001 * 
 *                                                                            * 
 * Source Tables: LOAD_CONTROL - control.LOAD_CONTROL       A5V75JN3.BE0000I0 * 
 *                CORPORATE_CUSTOMER_OWNER -                A5V75JN3.BE000013 * 
 *                 DDS.CORPORATE_CUSTOMER_OWNER                               * 
 * Target Table:  CCO_EXT - martscr.CCO_EXT                 A5V75JN3.BE0000IT * 
 *                                                                            * 
 * Generated on:  Wednesday, December 10, 2008 12:45:28 PM IST                * 
 * Generated by:  sasadm                                                      * 
 * Version:       9.1.20060626.51875                                          * 
 ******************************************************************************
 * Notes:                                                                     * 
 * CCO_EXT                                                                    * 
 * Job Name: CCO_EXTJob Desc Pre Process: NoneMain:a) Extract and load data   * 
 * from CORPORATE_CUSTOMER_OWNER using SQL join on LOAD_CONTROL based on      * 
 * following conditions:LOAD_CONTROL.LOAD_FLG = CHECK_FLAG_TRUEand            * 
 * LOAD_CONTROL.RUN_STATUS = RUNNING_STATUSand LOAD_CONTROL.LOAD_END_DTTM     * 
 * between CORPORATE_CUSTOMER_OWNER.VALID_FROM_DTTM and                       * 
 * CORPORATE_CUSTOMER_OWNER.VALID_TO_DTTMPost Process: NoneParameters:        * 
 * CHECK_FLAG_TRUE and RUNNING_STATUS are the user defined parameters.        * 
 * CHECK_FLAG_TRUE is set to 'Y' and RUNNING_STATUS is to 'Running' for       * 
 *  each month of data load.Developed by: singupReviewed by:Tested by:        * 
 ******************************************************************************/ 



%let jobID = %quote(A5V75JN3.BN00000V);

/* Setup for capturing job status  */ 
data _null_; 
   call symput('etls_startTime',put(datetime(),datetime.));
run;

%let etls_jobName = CCO_EXT;
%let etls_recordsBefore = 0;
%let etls_recordsAfter = 0;
%let etls_lib = 0;
%let etls_table = 0;

/* Setup to capture return codes  */ 
%global job_rc trans_rc sqlrc; 
%let job_rc = 0;
%let trans_rc = 0;
%let sqlrc = 0;
%global syserr; 

%macro rcSet(error); 
   %if (&error gt &trans_rc) %then 
      %let trans_rc = &error;
   %if (&error gt &job_rc) %then 
      %let job_rc = &error;
%mend rcSet; 

%macro rcSetDS(error); 
   if &error gt input(symget('trans_rc'),12.) then 
      call symput('trans_rc',trim(left(put(&error,12.))));
   if &error gt input(symget('job_rc'),12.) then 
      call symput('job_rc',trim(left(put(&error,12.))));
%mend rcSetDS; 

%global etls_debug; 
%macro etls_setDebug; 
   %if %str(&etls_debug) ne 0 %then 
      OPTIONS MPRINT%str(;); 
%mend; 
%etls_setDebug; 

/*============================================================================* 
 * Pre-Process code for the job                             A5V75JN3.AY0004NL * 
 *                                                                            * 
 * User Written:  Oracle Date Problem Fix                   A5V75JN3.AF000PMH * 
 *                Oracle Date Problem Fix                                     * 
 *============================================================================*/ 

/*---- Start of User Written Code  ----*/ 

proc contents data=dds.corporate_customer_owner out=_etlsEngine(keep=Engine) noprint;
run;

data _null_;
	set _etlsEngine;
	if _n_=1;
	  call symput('mEngine', kleft(kright(Engine)));
run;
/*---- End of User Written Code  ----*/ 

%rcSet(&syserr); 
%rcSet(&sqlrc); 

/*============================================================================* 
 * Step:          Extraction of data as per the loading     A5V75JN3.BO0006YO * 
 *                 period                                                     * 
 * Transform:     SQL Join (Version 2)                                        * 
 * Description:   Extract and load data based on load period mentioned in     * 
 *                 LOAD_CONTROL table                                         * 
 *                                                                            * 
 * Source Tables: LOAD_CONTROL - control.LOAD_CONTROL       A5V75JN3.BE0000I0 * 
 *                CORPORATE_CUSTOMER_OWNER -                A5V75JN3.BE000013 * 
 *                 DDS.CORPORATE_CUSTOMER_OWNER                               * 
 * Target Table:  SQL Target - martscr.CCO_EXT              A5V75JN3.BP00066K * 
 *============================================================================*/ 

/* Access the data for Control  */ 
LIBNAME control BASE "Data/bisdata/control" ;
%rcSet(&syslibrc); 

/* Access the data for Detail Data Store  */ 
LIBNAME DDS BASE "Data/bisdata/dds" ;
%rcSet(&syslibrc); 

/* Access the data for Scratch for Mart  */ 
LIBNAME martscr BASE "Data/bisdata/scratch/mart" ;
%rcSet(&syslibrc); 

%let transformID = %quote(A5V75JN3.BO0006YO); 

%let trans_rc = 0; 

proc datasets lib = martscr nolist nowarn memtype = (data view);
   delete CCO_EXT;
quit;

proc sql;
   create table martscr.CCO_EXT as
      select
         CORPORATE_CUSTOMER_OWNER.OWNER_RK length = 8
                                           format = 12.
                                           informat = 12.
                                           label = "Owner Key",
         LOAD_CONTROL.LOAD_END_DTTM length = 8
                                    format = NLDATM21.
                                    informat = NLDATM21.
                                    label = "Load End Datetime",
         CORPORATE_CUSTOMER_OWNER.STATE_REGION_CD length = 4
                                                  label = "State/Region Code",
         CORPORATE_CUSTOMER_OWNER.LEGAL_JUDGEMENT_FLG length = 1
                                                      label = "Legal Judgement Flag",
         CORPORATE_CUSTOMER_OWNER.NET_WORTH_AMT length = 8
                                                format = NLNUM18.5
                                                informat = NLNUM18.5
                                                label = "Net Worth Amount",
         CORPORATE_CUSTOMER_OWNER.TIME_RESIDENCE_YEAR_CNT length = 8
                                                          label = "Time Residence Year Count",
         CORPORATE_CUSTOMER_OWNER.ANNUAL_INCOME_AMT length = 8
                                                    format = NLNUM18.5
                                                    informat = NLNUM18.5
                                                    label = "Annual Income Amount",
         CASE symget('mEngine')
         	WHEN "ORACLE" THEN datepart(CORPORATE_CUSTOMER_OWNER.BANKRUPTCY_FILED_DT)
         	ELSE CORPORATE_CUSTOMER_OWNER.BANKRUPTCY_FILED_DT
         END as BANKRUPTCY_FILED_DT length = 8
                                    format = NLDATE10.
                                    informat = NLDATE10.
                                    label = "Bankruptcy Filed Date",
         CORPORATE_CUSTOMER_OWNER.OWNER_ID length = 32
                                           label = "Owner Id",
         CORPORATE_CUSTOMER_OWNER.LIQUID_ASSETS_AMT length = 8
                                                    format = NLNUM18.5
                                                    informat = NLNUM18.5
                                                    label = "Liquid Assets Amount",
         CORPORATE_CUSTOMER_OWNER.HHOLD_INCOME_AMT length = 8
                                                   format = NLNUM18.5
                                                   informat = NLNUM18.5
                                                   label = "Household Income Amount",
         CORPORATE_CUSTOMER_OWNER.TAX_BRACKET_CD length = 3
                                                 label = "Tax Bracket Code",
         CORPORATE_CUSTOMER_OWNER.EMPLOYMENT_YEARS_CNT length = 8
                                                       label = "Employment Years Count",
         CORPORATE_CUSTOMER_OWNER.REAL_ESTATE_AMT length = 8
                                                  format = NLNUM18.5
                                                  informat = NLNUM18.5
                                                  label = "Real Estate Amount",
         CORPORATE_CUSTOMER_OWNER.CUSTOMER_RK length = 8
                                              format = 12.
                                              informat = 12.
                                              label = "Customer Key",
         CORPORATE_CUSTOMER_OWNER.FRAUD_FLG length = 1
                                            label = "Fraud Flag",
         CORPORATE_CUSTOMER_OWNER.EMPLOYMENT_STATUS_CD length = 3
                                                       label = "Employment Status Code",
         CORPORATE_CUSTOMER_OWNER.DEPENDENTS_CNT length = 8
                                                 label = "Dependents Count",
         CORPORATE_CUSTOMER_OWNER.PERCENT_OWNED length = 8
                                                format = NLNUM6.2
                                                informat = NLNUM6.2
                                                label = "Percent Owned",
         CORPORATE_CUSTOMER_OWNER.DELINQUENCY_FLG length = 1
                                                  label = "Delinquency Flag",
         CORPORATE_CUSTOMER_OWNER.GENDER_CD length = 3
                                            label = "Gender Code",
         CORPORATE_CUSTOMER_OWNER.LIQUID_NET_WORTH_AMT length = 8
                                                       format = NLNUM18.5
                                                       informat = NLNUM18.5
                                                       label = "Liquid Net Worth Amount",
         CORPORATE_CUSTOMER_OWNER.MONTHLY_HOUSING_AMT length = 8
                                                      format = NLNUM18.5
                                                      informat = NLNUM18.5
                                                      label = "Monthly Housing Amount",
         CORPORATE_CUSTOMER_OWNER.PENDING_LAWSUIT_FLG length = 1
                                                      label = "Pending Lawsuit Flag",
         CORPORATE_CUSTOMER_OWNER.STD_OCCUPATION_CD length = 3
                                                    label = "Std Occupation Code",
         CORPORATE_CUSTOMER_OWNER.OWNERSHIP_AMT length = 8
                                                format = NLNUM18.5
                                                informat = NLNUM18.5
                                                label = "Ownership Amount",
         CORPORATE_CUSTOMER_OWNER.TOTAL_LIABILITY_AMT length = 8
                                                      format = NLNUM18.5
                                                      informat = NLNUM18.5
                                                      label = "Total Liability Amount",
         CORPORATE_CUSTOMER_OWNER.MIDDLE_NM length = 40
                                            label = "Middle Name",
         CORPORATE_CUSTOMER_OWNER.ASSET_OTHER_AMT length = 8
                                                  format = NLNUM18.5
                                                  informat = NLNUM18.5
                                                  label = "Asset Other Amount",
         CORPORATE_CUSTOMER_OWNER.LAST_NM length = 40
                                          label = "Last Name",
         CORPORATE_CUSTOMER_OWNER.OTHER_CREDIT_CARDS_CNT length = 8
                                                         label = "Other Credit Cards Count",
         CORPORATE_CUSTOMER_OWNER.TAX_ID_TYPE_CD length = 3
                                                 label = "Tax Id Type Code",
         CORPORATE_CUSTOMER_OWNER.BANKRUPTCY_STATUS_CD length = 3
                                                       label = "Bankruptcy Status Code",
         CORPORATE_CUSTOMER_OWNER.FIRST_NM length = 40
                                           label = "First Name",
         CORPORATE_CUSTOMER_OWNER.LIABILITY_OTHER_AMT length = 8
                                                      format = NLNUM18.5
                                                      informat = NLNUM18.5
                                                      label = "Liability Other Amount",
         CORPORATE_CUSTOMER_OWNER.MAINTENANCE_FLG length = 1
                                                  label = "Maintenance Flag",
         CORPORATE_CUSTOMER_OWNER.RESIDENT_STATUS_CD length = 3
                                                     label = "Resident Status Code",
         CORPORATE_CUSTOMER_OWNER.TOTAL_ASSETS_AMT length = 8
                                                   format = NLNUM18.5
                                                   informat = NLNUM18.5
                                                   label = "Total Assets Amount",
         CORPORATE_CUSTOMER_OWNER.ANNUAL_SALARY_BUSINESS_AMT length = 8
                                                             format = NLNUM18.5
                                                             informat = NLNUM18.5
                                                             label = "Annual Salary Business Amount",
         CASE symget('mEngine') 
         	WHEN "ORACLE" THEN datepart(CORPORATE_CUSTOMER_OWNER.BIRTH_DT) 
         	ELSE CORPORATE_CUSTOMER_OWNER.BIRTH_DT 
         END as BIRTH_DT length = 8
                         format = NLDATE10.
                         informat = NLDATE10.
                         label = "Birth Date",
         CORPORATE_CUSTOMER_OWNER.EDUCATION_LEVEL_CD length = 10
                                                     label = "Education Code",
         CORPORATE_CUSTOMER_OWNER.FORECLOSED_FLG length = 1
                                                 label = "Foreclosed Flag",
         CORPORATE_CUSTOMER_OWNER.IND_CUSTOMER_RK length = 8
                                                  format = 12.
                                                  informat = 12.
                                                  label = "Customer Key",
         CORPORATE_CUSTOMER_OWNER.LIABILITY_REAL_ESTATE_AMT length = 8
                                                            format = NLNUM18.5
                                                            informat = NLNUM18.5
                                                            label = "Liability Real Estate Amount",
         CORPORATE_CUSTOMER_OWNER.MARITAL_STATUS_CD length = 3
                                                    label = "Marital Status Code",
         CORPORATE_CUSTOMER_OWNER.NO_OF_EMPLOYERS_CNT length = 8
                                                      label = "No Of Employers Count",
         CORPORATE_CUSTOMER_OWNER.OWNER_TYPE_CD length = 3
                                                label = "Owner Type Code",
         CORPORATE_CUSTOMER_OWNER.POSTAL_CD length = 20
                                            label = "Postal Code",
         CORPORATE_CUSTOMER_OWNER.TAX_ID length = 32
                                         label = "Tax Id",
         CORPORATE_CUSTOMER_OWNER.TOTAL_EMPLOYMENT_YEARS_CNT length = 8
                                                             label = "Total Employment Years Count",
         (CATX(' ',FIRST_NM,MIDDLE_NM,LAST_NM)) as CUSTOMER_NM length = 40
      from
         control.LOAD_CONTROL, 
         DDS.CORPORATE_CUSTOMER_OWNER
      where
         LOAD_CONTROL.LOAD_FLG IN (&CHECK_FLAG_TRUE)
         and LOAD_CONTROL.RUN_STATUS IN (&RUNNING_STATUS)
         and LOAD_CONTROL.LOAD_END_DTTM >= CORPORATE_CUSTOMER_OWNER.VALID_FROM_DTTM
         and LOAD_CONTROL.LOAD_END_DTTM <= CORPORATE_CUSTOMER_OWNER.VALID_TO_DTTM
      ;
quit;

%rcSet(&sqlrc); 

%macro etls_completeTarget();
%mend etls_completeTarget;
%etls_completeTarget;

/*============================================================================* 
 * Step:          Dummy Loader                              A5V75JN3.BO0006YN * 
 * Transform:     Table Loader                                                * 
 * Description:                                                               * 
 *                                                                            * 
 * Source Table:  SQL Target - martscr.CCO_EXT              A5V75JN3.BP00066K * 
 * Target Table:  CCO_EXT - martscr.CCO_EXT                 A5V75JN3.BE0000IT * 
 *============================================================================*
 *                                                                            * 
 * Nothing will be generated for this process because the "Do not generate    * 
 *  code for this process" option is selected.                                * 
 *                                                                            * 
 *============================================================================*/ 

data _null_; 
   call symput('etls_endTime',put(datetime(),datetime.));
run;

/* Check return code for job  */ 
%macro etls_jobRCChk; 
   %if (&job_rc eq 4) %then
   %do; 
      %on_success(Job_nm=&etls_jobName..sas, param_table=&status_table);
   %end; 
%mend etls_jobRCChk; 
%etls_jobRCChk; 

/* Check return code for job  */ 
%macro etls_jobRCChk; 
   %if (&job_rc ge 5) %then
   %do; 
      %on_success(Job_nm=&etls_jobName..sas, param_table=&status_table);
   %end; 
%mend etls_jobRCChk; 
%etls_jobRCChk; 

/* Check return code for job  */ 
%macro etls_jobRCChk; 
   %if (&job_rc eq 0) %then
   %do; 
      %on_success(Job_nm=&etls_jobName..sas, param_table=&status_table);
   %end; 
%mend etls_jobRCChk; 
%etls_jobRCChk; 

/*---- Job status macro  ----*/ 
