/****************************************************************************** 
 * Job:           CC_EXT                                    A5V75JN3.BN00000S * 
 * Description:   This job picks up data from CORPORATE_CUSTOMER              * 
 *                                                                            * 
 * Repository:    Foundation                                A0000001.A5V75JN3 * 
 * Server:        SASMain                                   A5V75JN3.AT000001 * 
 *                                                                            * 
 * Source Tables: LOAD_CONTROL - control.LOAD_CONTROL       A5V75JN3.BE0000I0 * 
 *                CORPORATE_CUSTOMER -                      A5V75JN3.BE000012 * 
 *                 DDS.CORPORATE_CUSTOMER                                     * 
 * Target Table:  CC_EXT - martscr.CC_EXT                   A5V75JN3.BE0000IQ * 
 *                                                                            * 
 * Generated on:  Wednesday, December 10, 2008 12:45:27 PM IST                * 
 * Generated by:  sasadm                                                      * 
 * Version:       9.1.20060626.51875                                          * 
 ******************************************************************************
 * Notes:                                                                     * 
 * CC_EXT                                                                     * 
 * Job Name: CC_EXTJob Desc Pre Process: NoneMain: a) Extract and load data   * 
 * from CORPORATE_CUSTOMER using SQL join on LOAD_CONTROL based on            * 
 * following conditions:LOAD_CONTROL.LOAD_FLG = CHECK_FLAG_TRUEand            * 
 * LOAD_CONTROL.RUN_STATUS = RUNNING_STATUSand LOAD_CONTROL.LOAD_END_DTTM     * 
 * between CORPORATE_CUSTOMER.VALID_FROM_DTTM and                             * 
 * CORPORATE_CUSTOMER.VALID_TO_DTTMPost Process: Creating index on            * 
 * CUSTOMER_RK and LOAD_END_DTTM.Parameters: CHECK_FLAG_TRUE and              * 
 * RUNNING_STATUS are the user defined parameters. CHECK_FLAG_TRUE is set     * 
 * to 'Y' and RUNNING_STATUS is to 'Running' for each month of data           * 
 *  load.Developed by: singupReviewed by:Tested by:                           * 
 ******************************************************************************/ 

/* Setup for capturing job status  */ 
data _null_; 
   call symput('etls_startTime',put(datetime(),datetime.));
run;

%let etls_jobName = CC_EXT;
%let etls_recordsBefore = 0;
%let etls_recordsAfter = 0;
%let etls_lib = 0;
%let etls_table = 0;

/* Setup to capture return codes  */ 
%global job_rc trans_rc sqlrc; 
%let job_rc = 0;
%let trans_rc = 0;
%let sqlrc = 0;
%global syserr; 

%macro rcSet(error); 
   %if (&error gt &trans_rc) %then 
      %let trans_rc = &error;
   %if (&error gt &job_rc) %then 
      %let job_rc = &error;
%mend rcSet; 

%macro rcSetDS(error); 
   if &error gt input(symget('trans_rc'),12.) then 
      call symput('trans_rc',trim(left(put(&error,12.))));
   if &error gt input(symget('job_rc'),12.) then 
      call symput('job_rc',trim(left(put(&error,12.))));
%mend rcSetDS; 

%global etls_debug; 
%macro etls_setDebug; 
   %if %str(&etls_debug) ne 0 %then 
      OPTIONS MPRINT%str(;); 
%mend; 
%etls_setDebug; 

/*============================================================================* 
 * Pre-Process code for the job                             A5V75JN3.AY0004NJ * 
 *                                                                            * 
 * User Written:  Oracle Date Problem Fix                   A5V75JN3.AF000PLZ * 
 *                Oracle Date Problem Fix                                     * 
 *============================================================================*/ 

/*---- Start of User Written Code  ----*/ 

proc contents data=dds.corporate_customer out=_etlsEngine(keep=Engine) noprint;
run;

data _null_;
	set _etlsEngine;
	if _n_=1;
	  call symput('mEngine', kleft(kright(Engine)));
run;
/*---- End of User Written Code  ----*/ 

%rcSet(&syserr); 
%rcSet(&sqlrc); 

/*============================================================================* 
 * Step:          Extraction of data as per the loading     A5V75JN3.BO0006YM * 
 *                 period                                                     * 
 * Transform:     SQL Join (Version 2)                                        * 
 * Description:   Extract and load data based on load period mentioned in     * 
 *                 LOAD_CONTROL table                                         * 
 *                                                                            * 
 * Source Tables: LOAD_CONTROL - control.LOAD_CONTROL       A5V75JN3.BE0000I0 * 
 *                CORPORATE_CUSTOMER -                      A5V75JN3.BE000012 * 
 *                 DDS.CORPORATE_CUSTOMER                                     * 
 * Target Table:  SQL Target - martscr.CC_EXT               A5V75JN3.BP00066J * 
 *============================================================================*/ 

/* Access the data for Control  */ 
LIBNAME control BASE "Data/bisdata/control" ;
%rcSet(&syslibrc); 

/* Access the data for Detail Data Store  */ 
LIBNAME DDS BASE "Data/bisdata/dds" ;
%rcSet(&syslibrc); 

/* Access the data for Scratch for Mart  */ 
LIBNAME martscr BASE "Data/bisdata/scratch/mart" ;
%rcSet(&syslibrc); 

%let trans_rc = 0; 

proc datasets lib = martscr nolist nowarn memtype = (data view);
   delete CC_EXT;
quit;

proc sql;
   create table martscr.CC_EXT as
      select
         CORPORATE_CUSTOMER.CUSTOMER_RK length = 8
                                        format = 12.
                                        informat = 12.
                                        label = "Customer Key",
         LOAD_CONTROL.LOAD_END_DTTM length = 8
                                    format = NLDATM21.
                                    informat = NLDATM21.
                                    label = "Load End Datetime",
         CORPORATE_CUSTOMER.AUDITOR_EXTERNAL_ORG_RK length = 8
                                                    format = 12.
                                                    informat = 12.
                                                    label = "Auditor External Organization Key",
         CORPORATE_CUSTOMER.ACCOUNTING_YEAR length = 8
                                            label = "Accounting Year",
         CORPORATE_CUSTOMER.AVERAGE_DIRECT_DEPOSIT_AMT length = 8
                                                       format = NLNUM18.5
                                                       informat = NLNUM18.5
                                                       label = "Average Direct Deposit Amount",
         CORPORATE_CUSTOMER.AVG_DIRECT_DEP_MONTH_NO length = 8
                                                    label = "Average Direct Deposit Month Number",
         CORPORATE_CUSTOMER.BUSINESS_NATURE_CD length = 3
                                               format = $3.
                                               informat = $3.
                                               label = "Code to indicate nature of business. For example: DIS (distribution), TRD (trading), MFG (manufacturing) , ITC (IT Consulting) etc.",
         CORPORATE_CUSTOMER.CENTRALIZATION_OF_DECISIONS_CD length = 3
                                                           label = "Centralization Of Decisions Code",
         CORPORATE_CUSTOMER.CORPORATE_ACCT_MGR_EMP_RK length = 8
                                                      format = 12.
                                                      informat = 12.
                                                      label = "Corporate Account Manager Emp Key",
         CORPORATE_CUSTOMER.COUNTRY_OF_BUSINESS_CD length = 3
                                                   label = "Country Of Business Code",
         CORPORATE_CUSTOMER.CUSTOMER_ID length = 32
                                        label = "Customer Id",
         CORPORATE_CUSTOMER.DEFAULT_STATUS_CD length = 3
                                              label = "Default Status Code",
         CORPORATE_CUSTOMER.DIRECT_DEPOSIT_EMP_CNT length = 8
                                                   label = "Direct Deposit Employee Count",
         CORPORATE_CUSTOMER.EMP_DIRECT_DEPOSIT_FLG length = 1
                                                   label = "Emp Direct Deposit Flag",
         CORPORATE_CUSTOMER.EXTERNAL_CREDIT_RATING1_CD length = 4
                                                       label = "External Credit Rating Code 1",
         CORPORATE_CUSTOMER.EXTERNAL_CREDIT_RATING2_CD length = 4
                                                       label = "External Credit Rating Code 2",
         CORPORATE_CUSTOMER.EXTERNAL_ORG_RK length = 8
                                            format = 12.
                                            informat = 12.
                                            label = "External Organization Key",
         CORPORATE_CUSTOMER.FOREIGN_TRADE_FINANCE_FLG length = 1
                                                      label = "Foreign Trade Finance Flag",
         CORPORATE_CUSTOMER.FRAUD_FLG length = 1
                                      label = "Fraud Flag",
         CASE symget('mEngine')
         	WHEN "ORACLE" THEN datepart(CORPORATE_CUSTOMER.INCORPORATION_DT)
         	ELSE CORPORATE_CUSTOMER.INCORPORATION_DT
         END as INCORPORATION_DT length = 8
                                 format = NLDATE10.
                                 informat = NLDATE10.
                                 label = "Incorporation Date",
         CORPORATE_CUSTOMER.INCORPORATION_TYPE_CD length = 3
                                                  label = "Incorporation Type Code",
         CORPORATE_CUSTOMER.INCORPORATION_YEAR length = 8
                                               label = "Incorporation Year",
         CORPORATE_CUSTOMER.INTERNAL_CREDIT_RATING_CD length = 4
                                                      label = "Internal Credit Rating Code",
         CORPORATE_CUSTOMER.NETTING_AGREEMENT_FLG length = 1
                                                  label = "Netting Agreement Flag",
         CORPORATE_CUSTOMER.NUM_EMPLOYEES_CNT length = 8
                                              label = "Number of Employees",
         CORPORATE_CUSTOMER.NUM_OFFICES_CNT length = 8
                                            label = "Number of Offices",
         CORPORATE_CUSTOMER.OPERATION_YEAR length = 8
                                           label = "Operation Year",
         CORPORATE_CUSTOMER.OTHER_BANK_DEBT_AMT length = 8
                                                format = NLNUM18.5
                                                informat = NLNUM18.5
                                                label = "Other Bank Debt Amount",
         CORPORATE_CUSTOMER.OWNERSHIP_CD length = 3
                                         label = "Ownership Code",
         CORPORATE_CUSTOMER.OWNERSHIP_CNT length = 8
                                          label = "Ownership Count",
         CORPORATE_CUSTOMER.PUBLIC_SECTOR_ENTITY_FLG length = 1
                                                     label = "Public Sector Entity Flag",
         CORPORATE_CUSTOMER.SALARY_DEPOSIT_FLG length = 1
                                               label = "Salary Deposit Flag",
         CORPORATE_CUSTOMER.SERVICING_ARRANGEMENT_CD length = 3
                                                     label = "Servicing Arrangement Code",
         CORPORATE_CUSTOMER.SHAREHOLDER_PATTERN_CD length = 3
                                                   label = "Shareholder Pattern Code",
         CORPORATE_CUSTOMER.SOURCE_SYSTEM_CD length = 3
                                             label = "Source System Code",
         CORPORATE_CUSTOMER.MULTILATERAL_DEV_BANK_FLG length = 1
                                                      label = "Multilateral Development Bank Flag"
      from
         control.LOAD_CONTROL, 
         DDS.CORPORATE_CUSTOMER
      where
         LOAD_CONTROL.LOAD_FLG IN (&CHECK_FLAG_TRUE)
         and LOAD_CONTROL.RUN_STATUS IN (&RUNNING_STATUS)
         and LOAD_CONTROL.LOAD_END_DTTM >= CORPORATE_CUSTOMER.VALID_FROM_DTTM
         and LOAD_CONTROL.LOAD_END_DTTM <= CORPORATE_CUSTOMER.VALID_TO_DTTM
      ;
quit;

%rcSet(&sqlrc); 

%macro etls_completeTarget();
%mend etls_completeTarget;
%etls_completeTarget;

/*============================================================================* 
 * Step:          Dummy Loader                              A5V75JN3.BO0006YL * 
 * Transform:     Table Loader                                                * 
 * Description:                                                               * 
 *                                                                            * 
 * Source Table:  SQL Target - martscr.CC_EXT               A5V75JN3.BP00066J * 
 * Target Table:  CC_EXT - martscr.CC_EXT                   A5V75JN3.BE0000IQ * 
 *============================================================================*
 *                                                                            * 
 * Nothing will be generated for this process because the "Do not generate    * 
 *  code for this process" option is selected.                                * 
 *                                                                            * 
 *============================================================================*/ 

data _null_; 
   call symput('etls_endTime',put(datetime(),datetime.));
run;

/* Check return code for job  */ 
%macro etls_jobRCChk; 
   %if (&job_rc eq 4) %then
   %do; 
      %on_success(Job_nm=&etls_jobName..sas, param_table=&status_table);
   %end; 
%mend etls_jobRCChk; 
%etls_jobRCChk; 

/* Check return code for job  */ 
%macro etls_jobRCChk; 
   %if (&job_rc ge 5) %then
   %do; 
      %on_success(Job_nm=&etls_jobName..sas, param_table=&status_table);
   %end; 
%mend etls_jobRCChk; 
%etls_jobRCChk; 

/* Check return code for job  */ 
%macro etls_jobRCChk; 
   %if (&job_rc eq 0) %then
   %do; 
      %on_success(Job_nm=&etls_jobName..sas, param_table=&status_table);
   %end; 
%mend etls_jobRCChk; 
%etls_jobRCChk; 

/*---- Job status macro  ----*/ 
/*============================================================================* 
 * Post-Process code for the job                            A5V75JN3.AY0004NK * 
 *                                                                            * 
 * User Written:  Index creation code on CUSTOMER_RK  and   A5V75JN3.AF000PM0 * 
 *                 LOAD_END_DTTM                                              * 
 *                Index creation code on CUSTOMER_RK  and LOAD_END_DTTM       * 
 *============================================================================*/ 

/*---- Start of User Written Code  ----*/ 

/*creating index on CUSTOMER_RK and LOAD_END_DTTM column */
PROC SQL NOPRINT;
     CREATE INDEX CUSTOMER_RK_LOAD_END_DTTM
      ON martscr.CC_EXT(CUSTOMER_RK,LOAD_END_DTTM);
QUIT;

/*---- End of User Written Code  ----*/ 

%rcSet(&syserr); 
%rcSet(&sqlrc); 

