/****************************************************************************** 
 * Job:           CON_EXT                                   A5V75JN3.BN000012 * 
 * Description:   This job picks up data from CONTACT                         * 
 *                                                                            * 
 * Repository:    Foundation                                A0000001.A5V75JN3 * 
 * Server:        SASMain                                   A5V75JN3.AT000001 * 
 *                                                                            * 
 * Source Tables: LOAD_CONTROL - control.LOAD_CONTROL       A5V75JN3.BE0000I0 * 
 *                CONTACT - DDS.CONTACT                     A5V75JN3.BE00000U * 
 * Target Table:  CON_EXT - martscr.CON_EXT                 A5V75JN3.BE0000J0 * 
 *                                                                            * 
 * Generated on:  Wednesday, December 10, 2008 12:45:30 PM IST                * 
 * Generated by:  sasadm                                                      * 
 * Version:       9.1.20060626.51875                                          * 
 ******************************************************************************
 * Notes:                                                                     * 
 * CON_EXT                                                                    * 
 * Job Name: CON_EXTJob Desc This extracts and loads data from CONTACT using  * 
 * SQL join on LOAD_CONTROL based on following                                * 
 * conditionsLOAD_CONTROL.LOAD_FLG = CHECK_FLAG_TRUEand                       * 
 * LOAD_CONTROL.RUN_STATUS = RUNNING_STATUSand CONTACT.COMMDATE between       * 
 * LOAD_CONTROL.LOAD_START_DTTM and LOAD_CONTROL.LOAD_END_DTTMand             * 
 * CONTACT.FINANCIAL_PRODUCT_TYPE_CD NOT IS NULLand CONTACT.LANGUAGE_CD IN    * 
 * (&LANGUAGE_FOR_DESC)Pre Process: NonePost Process: Creating index on       * 
 * CAMPAIGN_CD and LOAD_END_DTTMParameters:A) CHECK_FLAG_TRUE and             * 
 * RUNNING_STATUS are the user defined parameters. CHECK_FLAG_TRUE is set     * 
 * to 'Y' and RUNNING_STATUS is to 'Running' for each month of data           * 
 * load.B)LANGUAGE_FOR_DESC:Parameter to specify the language code to be      * 
 * used for picking up description for code fields from reference             * 
 *  tables.Developed by: singupReviewed by:Tested by:                         * 
 ******************************************************************************/ 



%let jobID = %quote(A5V75JN3.BN000012);

/* Setup for capturing job status  */ 
data _null_; 
   call symput('etls_startTime',put(datetime(),datetime.));
run;

%let etls_jobName = CON_EXT;
%let etls_recordsBefore = 0;
%let etls_recordsAfter = 0;
%let etls_lib = 0;
%let etls_table = 0;

/* Setup to capture return codes  */ 
%global job_rc trans_rc sqlrc; 
%let job_rc = 0;
%let trans_rc = 0;
%let sqlrc = 0;
%global syserr; 

%macro rcSet(error); 
   %if (&error gt &trans_rc) %then 
      %let trans_rc = &error;
   %if (&error gt &job_rc) %then 
      %let job_rc = &error;
%mend rcSet; 

%macro rcSetDS(error); 
   if &error gt input(symget('trans_rc'),12.) then 
      call symput('trans_rc',trim(left(put(&error,12.))));
   if &error gt input(symget('job_rc'),12.) then 
      call symput('job_rc',trim(left(put(&error,12.))));
%mend rcSetDS; 

%global etls_debug; 
%macro etls_setDebug; 
   %if %str(&etls_debug) ne 0 %then 
      OPTIONS MPRINT%str(;); 
%mend; 
%etls_setDebug; 

/*============================================================================* 
 * Pre-Process code for the job                             A5V75JN3.AY0004NU * 
 *                                                                            * 
 * User Written:  Oracle Date Problem Fix                   A5V75JN3.AF000PNZ * 
 *                Oracle Date Problem Fix                                     * 
 *============================================================================*/ 

/*---- Start of User Written Code  ----*/ 

proc contents data=DDS.CONTACT out=_etlsEngine(keep=Engine) noprint;
run;

data _null_;
	set _etlsEngine;
	if _n_=1;
	  call symput('mEngine', kleft(kright(Engine)));
run;
/*---- End of User Written Code  ----*/ 

%rcSet(&syserr); 
%rcSet(&sqlrc); 

/*============================================================================* 
 * Step:          Extraction of data as per the loading     A5V75JN3.BO0006YU * 
 *                 period                                                     * 
 * Transform:     SQL Join (Version 2)                                        * 
 * Description:   Extract and load data based on load period mentioned in     * 
 *                 LOAD_CONTROL table                                         * 
 *                                                                            * 
 * Source Tables: LOAD_CONTROL - control.LOAD_CONTROL       A5V75JN3.BE0000I0 * 
 *                CONTACT - DDS.CONTACT                     A5V75JN3.BE00000U * 
 * Target Table:  SQL Target - martscr.CON_EXT              A5V75JN3.BP00066N * 
 *============================================================================*/ 

/* Access the data for Control  */ 
LIBNAME control BASE "Data/bisdata/control" ;
%rcSet(&syslibrc); 

/* Access the data for Detail Data Store  */ 
LIBNAME DDS BASE "Data/bisdata/dds" ;
%rcSet(&syslibrc); 

/* Access the data for Scratch for Mart  */ 
LIBNAME martscr BASE "Data/bisdata/scratch/mart" ;
%rcSet(&syslibrc); 

%let transformID = %quote(A5V75JN3.BO0006YU); 

%let trans_rc = 0; 

proc datasets lib = martscr nolist nowarn memtype = (data view);
   delete CON_EXT;
quit;

proc sql;
   create table martscr.CON_EXT as
      select
         CONTACT.CUSTOMER_RK length = 8
                             format = 12.
                             informat = 12.
                             label = "Customer Key",
         LOAD_CONTROL.LOAD_END_DTTM length = 8
                                    format = NLDATM21.
                                    informat = NLDATM21.
                                    label = "Load End Datetime",
         CONTACT.HOUSEHOLD_RK length = 8
                              format = 12.
                              informat = 12.
                              label = "Household Key",
         CONTACT.PRODUCT_RK length = 8
                            format = 12.
                            informat = 12.
                            label = "Product Key",
         CONTACT.CAMPAIGN_CD length = 30
                             label = "Campaign code",
         CONTACT.CONTACT_ID length = 32
                            label = "Contact ID",
         CASE symget('mEngine')  
                 WHEN "ORACLE" THEN datepart(CONTACT.COMMDATE)
                 ELSE CONTACT.COMMDATE
         END as COMMDATE length = 8
                         format = NLDATE10.
                         informat = NLDATE10.
                         label = "Communication date",
         CASE symget('mEngine')  
                 WHEN "ORACLE" THEN datepart(CONTACT.EXPORTDATE)
                 ELSE CONTACT.EXPORTDATE
         END as EXPORTDATE length = 8
                           format = NLDATE10.
                           informat = NLDATE10.
                           label = "Export Date",
         CONTACT.CONTACT_REASON_TYPE_CD length = 3
                                        label = "Contact Reason Type Code",
         CONTACT.COMMSTATUS length = 5
                            label = "Communication status",
         CONTACT.FINANCIAL_PRODUCT_TYPE_CD length = 3
                                           label = "Financial Product Type Code",
         CONTACT.PAST_FLG length = 1
                          label = "Past Flag",
         CONTACT.CHANNEL_CD length = 3
                            label = "Channel Code",
         CONTACT.LANGUAGE_CD length = 3
                             label = "Language Code",
         CONTACT.COMMUNICATION_CD length = 30
                                  label = "Communication code",
         CONTACT.CAMPAIGN_COMMUNICATION_ID length = 32
                                           label = "Campaign Communication Id",
         CONTACT.CUSTOMER_MODEL_SCORE_ID length = 32
                                         label = "Customer Model Score Id",
         CONTACT.HOUSEHOLD_MODEL_SCORE_ID length = 32
                                          label = "Household Model Score Id",
         CONTACT.MARKETING_CAMPAIGN_ID length = 32
                                       label = "Campaign Id"
      from
         control.LOAD_CONTROL, 
         DDS.CONTACT
      where
         LOAD_CONTROL.LOAD_FLG IN (&CHECK_FLAG_TRUE)
         and LOAD_CONTROL.RUN_STATUS IN (&RUNNING_STATUS)
         and CASE symget('mEngine')  
                 WHEN "ORACLE" THEN datepart(CONTACT.COMMDATE)
                 ELSE CONTACT.COMMDATE
         END >= datepart(LOAD_CONTROL.LOAD_START_DTTM)
         and CASE symget('mEngine')  
                 WHEN "ORACLE" THEN datepart(CONTACT.COMMDATE)
                 ELSE CONTACT.COMMDATE
         END <= datepart(LOAD_CONTROL.LOAD_END_DTTM)
         and CONTACT.FINANCIAL_PRODUCT_TYPE_CD NOT IS NULL 
         and CONTACT.LANGUAGE_CD IN (&LANGUAGE_FOR_DESC)
      ;
quit;

%rcSet(&sqlrc); 

%macro etls_completeTarget();
   /*---- Create the integrity constraints for a table  ----*/ 
   %put %str(NOTE: Creating integrity constraints ...);
   proc datasets library=martscr nolist;
      modify CON_EXT;
         ic create not null (CUSTOMER_RK);
         ic create not null (LOAD_END_DTTM);
         ic create not null (CAMPAIGN_CD);
   quit;
   
   %rcSet(&syserr); 
   
%mend etls_completeTarget;
%etls_completeTarget;

/*============================================================================* 
 * Step:          Dummy Loader                              A5V75JN3.BO0006YT * 
 * Transform:     Table Loader                                                * 
 * Description:                                                               * 
 *                                                                            * 
 * Source Table:  SQL Target - martscr.CON_EXT              A5V75JN3.BP00066N * 
 * Target Table:  CON_EXT - martscr.CON_EXT                 A5V75JN3.BE0000J0 * 
 *============================================================================*
 *                                                                            * 
 * Nothing will be generated for this process because the "Do not generate    * 
 *  code for this process" option is selected.                                * 
 *                                                                            * 
 *============================================================================*/ 

data _null_; 
   call symput('etls_endTime',put(datetime(),datetime.));
run;

/* Check return code for job  */ 
%macro etls_jobRCChk; 
   %if (&job_rc eq 4) %then
   %do; 
      %on_success(Job_nm=&etls_jobName..sas, param_table=&status_table);
   %end; 
%mend etls_jobRCChk; 
%etls_jobRCChk; 

/* Check return code for job  */ 
%macro etls_jobRCChk; 
   %if (&job_rc ge 5) %then
   %do; 
      %on_success(Job_nm=&etls_jobName..sas, param_table=&status_table);
   %end; 
%mend etls_jobRCChk; 
%etls_jobRCChk; 

/* Check return code for job  */ 
%macro etls_jobRCChk; 
   %if (&job_rc eq 0) %then
   %do; 
      %on_success(Job_nm=&etls_jobName..sas, param_table=&status_table);
   %end; 
%mend etls_jobRCChk; 
%etls_jobRCChk; 

/*---- Job status macro  ----*/ 
/*============================================================================* 
 * Post-Process code for the job                            A5V75JN3.AY0004NV * 
 *                                                                            * 
 * User Written:  Creating index on CAMPAIGN_CD and         A5V75JN3.AF000PO0 * 
 *                 LOAD_END_DTTM                                              * 
 *                Creating index on CAMPAIGN_CD and LOAD_END_DTTM             * 
 *============================================================================*/ 

/*---- Start of User Written Code  ----*/ 

/*Creating index on CAMPAIGN_CD and LOAD_END_DTTM column */
PROC SQL NOPRINT;
  CREATE INDEX CAMPAIGN_CD_LOAD_END_DTTM
   ON martscr.CON_EXT(CAMPAIGN_CD, LOAD_END_DTTM);
QUIT;
/*---- End of User Written Code  ----*/ 

%rcSet(&syserr); 
%rcSet(&sqlrc); 

