/****************************************************************************** 
 * Job:           CRA_EXT                                   A5V75JN3.BN000016 * 
 * Description:   This job builds the CRA_EXT table by picking up data from   * 
 *                 CREDIT_CARD_ACCOUNT                                        * 
 *                                                                            * 
 * Repository:    Foundation                                A0000001.A5V75JN3 * 
 * Server:        SASMain                                   A5V75JN3.AT000001 * 
 *                                                                            * 
 * Source Tables: LOAD_CONTROL - control.LOAD_CONTROL       A5V75JN3.BE0000I0 * 
 *                CREDIT_CARD_ACCOUNT -                     A5V75JN3.BE00001I * 
 *                 DDS.CREDIT_CARD_ACCOUNT                                    * 
 * Target Table:  CRA_EXT - martscr.CRA_EXT                 A5V75JN3.BE0000J4 * 
 *                                                                            * 
 * Generated on:  Wednesday, December 10, 2008 12:47:25 PM IST                * 
 * Generated by:  sasadm                                                      * 
 * Version:       9.1.20060626.51875                                          * 
 ******************************************************************************
 * Notes:                                                                     * 
 * CRA_EXT                                                                    * 
 * Job Name: CRA_EXTJob Desc Pre Process: NoneMain:a) Extract and load data   * 
 * from CREDIT_CARD_ACCOUNT using SQL join on LOAD_CONTROL based on           * 
 * following conditions:LOAD_CONTROL.LOAD_FLG = CHECK_FLAG_TRUEand            * 
 * LOAD_CONTROL.RUN_STATUS = RUNNING_STATUSand LOAD_CONTROL.LOAD_END_DTTM     * 
 * between CREDIT_CARD_ACCOUNT.VALID_FROM_DTTM and                            * 
 * CREDIT_CARD_ACCOUNT.VALID_TO_DTTMPost Process: Index is created on         * 
 * ACCOUNT_RK and LOAD_END_DTTM fields in the CRA_EXT                         * 
 * tableParameters:CHECK_FLAG_TRUE and RUNNING_STATUS are the user defined    * 
 * parameters. CHECK_FLAG_TRUE is set to 'Y' and RUNNING_STATUS is to         * 
 * 'Running' for each month of data load.Developed by: singupReviewed         * 
 *  by:Tested by:                                                             * 
 ******************************************************************************/ 



%let jobID = %quote(A5V75JN3.BN000016);

/* Setup for capturing job status  */ 
data _null_; 
   call symput('etls_startTime',put(datetime(),datetime.));
run;

%let etls_jobName = CRA_EXT;
%let etls_recordsBefore = 0;
%let etls_recordsAfter = 0;
%let etls_lib = 0;
%let etls_table = 0;

/* Setup to capture return codes  */ 
%global job_rc trans_rc sqlrc; 
%let job_rc = 0;
%let trans_rc = 0;
%let sqlrc = 0;
%global syserr; 

%macro rcSet(error); 
   %if (&error gt &trans_rc) %then 
      %let trans_rc = &error;
   %if (&error gt &job_rc) %then 
      %let job_rc = &error;
%mend rcSet; 

%macro rcSetDS(error); 
   if &error gt input(symget('trans_rc'),12.) then 
      call symput('trans_rc',trim(left(put(&error,12.))));
   if &error gt input(symget('job_rc'),12.) then 
      call symput('job_rc',trim(left(put(&error,12.))));
%mend rcSetDS; 

%global etls_debug; 
%macro etls_setDebug; 
   %if %str(&etls_debug) ne 0 %then 
      OPTIONS MPRINT%str(;); 
%mend; 
%etls_setDebug; 

/*============================================================================* 
 * Pre-Process code for the job                             A5V75JN3.AY0004NW * 
 *                                                                            * 
 * User Written:  Oracle Date Problem Fix                   A5V75JN3.AF000POS * 
 *                Oracle Date Problem Fix                                     * 
 *============================================================================*/ 

/*---- Start of User Written Code  ----*/ 

proc contents data=dds.credit_card_account out=_etlsEngine(keep=Engine) noprint;
run;

data _null_;
	set _etlsEngine;
	if _n_=1;
	  call symput('mEngine', kleft(kright(Engine)));
run;
/*---- End of User Written Code  ----*/ 

%rcSet(&syserr); 
%rcSet(&sqlrc); 

/*============================================================================* 
 * Step:          Extraction of data as per the loading     A5V75JN3.BO0006YW * 
 *                 period                                                     * 
 * Transform:     SQL Join (Version 2)                                        * 
 * Description:   Extract and load data based on load period mentioned in     * 
 *                 LOAD_CONTROL table                                         * 
 *                                                                            * 
 * Source Tables: LOAD_CONTROL - control.LOAD_CONTROL       A5V75JN3.BE0000I0 * 
 *                CREDIT_CARD_ACCOUNT -                     A5V75JN3.BE00001I * 
 *                 DDS.CREDIT_CARD_ACCOUNT                                    * 
 * Target Table:  SQL Target - martscr.CRA_EXT              A5V75JN3.BP00066O * 
 *============================================================================*/ 

/* Access the data for Control  */ 
LIBNAME control BASE "Data/bisdata/control" ;
%rcSet(&syslibrc); 

/* Access the data for Detail Data Store  */ 
LIBNAME DDS BASE "Data/bisdata/dds" ;
%rcSet(&syslibrc); 

/* Access the data for Scratch for Mart  */ 
LIBNAME martscr BASE "Data/bisdata/scratch/mart" ;
%rcSet(&syslibrc); 

%let transformID = %quote(A5V75JN3.BO0006YW); 

%let trans_rc = 0; 

proc datasets lib = martscr nolist nowarn memtype = (data view);
   delete CRA_EXT;
quit;

proc sql;
   create table martscr.CRA_EXT as
      select
         CREDIT_CARD_ACCOUNT.ACCOUNT_RK length = 8
                                        format = 12.
                                        informat = 12.
                                        label = "Account Key",
         LOAD_CONTROL.LOAD_END_DTTM length = 8
                                    format = NLDATM21.
                                    informat = NLDATM21.
                                    label = "Load End Datetime",
         CREDIT_CARD_ACCOUNT.CASH_BACK_FLG length = 1
                                           label = "Cash Back Flag",
         CREDIT_CARD_ACCOUNT.CASH_BACK_PCT length = 8
                                           format = NLNUM9.4
                                           informat = NLNUM9.4
                                           label = "Cash Back Percentage",
         CREDIT_CARD_ACCOUNT.FINANCE_CHARGE_FLG length = 1
                                                label = "Finance Charge Flag",
         CREDIT_CARD_ACCOUNT.CREDIT_STATUS_CD length = 3
                                              label = "Credit Status Code",
         CASE symget('mEngine') 
         	WHEN "ORACLE" THEN datepart(CREDIT_CARD_ACCOUNT.CARD_EXPIRATION_DT) 
         	ELSE CREDIT_CARD_ACCOUNT.CARD_EXPIRATION_DT 
         END as CARD_EXPIRATION_DT length = 8
                                   format = NLDATE10.
                                   informat = NLDATE10.
                                   label = "Card Expiration Date",
         CASE symget('mEngine') 	 
         	WHEN "ORACLE" THEN datepart(CREDIT_CARD_ACCOUNT.CARD_ISSUE_DT) 	 
         	ELSE CREDIT_CARD_ACCOUNT.CARD_ISSUE_DT 
         END as CARD_ISSUE_DT length = 8
                              format = NLDATE10.
                              informat = NLDATE10.
                              label = "Card Issue Date",
         CASE symget('mEngine') 	 
         	WHEN "ORACLE" THEN datepart(CREDIT_CARD_ACCOUNT.CARD_REISSUE_DT) 
         	ELSE CREDIT_CARD_ACCOUNT.CARD_REISSUE_DT 
         END as CARD_REISSUE_DT length = 8
                                format = NLDATE10.
                                informat = NLDATE10.
                                label = "Card Reissue Date",
         CASE symget('mEngine') 
         	WHEN "ORACLE" THEN datepart(CREDIT_CARD_ACCOUNT.CARD_CANCEL_DT) 
         	ELSE CREDIT_CARD_ACCOUNT.CARD_CANCEL_DT 
         END as CARD_CANCEL_DT length = 8
                               format = NLDATE10.
                               informat = NLDATE10.
                               label = "Card Cancel Date",
         CASE symget('mEngine') 
         	WHEN "ORACLE" THEN datepart(CREDIT_CARD_ACCOUNT.CARD_LOSS_DT) 
         	ELSE CREDIT_CARD_ACCOUNT.CARD_LOSS_DT 
         END as CARD_LOSS_DT length = 8
                             format = NLDATE10.
                             informat = NLDATE10.
                             label = "Card Loss Date",
         CREDIT_CARD_ACCOUNT.CARD_LOSS_AMT length = 8
                                           format = NLNUM18.5
                                           informat = NLNUM18.5
                                           label = "Card Loss Amount",
         CREDIT_CARD_ACCOUNT.CREDIT_CYCLE_DAY_NO length = 8
                                                 label = "Credit Cycle Day",
         CREDIT_CARD_ACCOUNT.BASE_APR_RT length = 8
                                         format = NLNUM9.4
                                         informat = NLNUM9.4
                                         label = "Base Apr Rate",
         CREDIT_CARD_ACCOUNT.APR_RT length = 8
                                    format = NLNUM9.4
                                    informat = NLNUM9.4
                                    label = "Apr Rate",
         CREDIT_CARD_ACCOUNT.BALANCE_TRANSFER_RT length = 8
                                                 format = NLNUM9.4
                                                 informat = NLNUM9.4
                                                 label = "Balance Transfer Rate",
         CREDIT_CARD_ACCOUNT.PURCHASE_RT length = 8
                                         format = NLNUM9.4
                                         informat = NLNUM9.4
                                         label = "Purchase Rate",
         CREDIT_CARD_ACCOUNT.CASH_ADVANCE_RT length = 8
                                             format = NLNUM9.4
                                             informat = NLNUM9.4
                                             label = "Cash Advance Rate",
         CREDIT_CARD_ACCOUNT.INITIAL_LIMIT_AMT length = 8
                                               format = NLNUM18.5
                                               informat = NLNUM18.5
                                               label = "Initial Limit Amount",
         CREDIT_CARD_ACCOUNT.CURRENT_LIMIT_AMT length = 8
                                               format = NLNUM18.5
                                               informat = NLNUM18.5
                                               label = "Current Limit Amount",
         CASE symget('mEngine')
         	WHEN "ORACLE" THEN datepart(CREDIT_CARD_ACCOUNT.CURRENT_LIMIT_DT)
         	ELSE CREDIT_CARD_ACCOUNT.CURRENT_LIMIT_DT
         END as CURRENT_LIMIT_DT length = 8
                                 format = NLDATE10.
                                 informat = NLDATE10.
                                 label = "Current Limit Date",
         CREDIT_CARD_ACCOUNT.PROVISIONAL_CREDIT_LIMIT_AMT length = 8
                                                          format = NLNUM18.5
                                                          informat = NLNUM18.5
                                                          label = "Provisional Credit Limit Amount",
         CASE symget('mEngine') 
         	WHEN "ORACLE" THEN datepart(CREDIT_CARD_ACCOUNT.PROV_CREDIT_LIMIT_OPEN_DT) 
         	ELSE CREDIT_CARD_ACCOUNT.PROV_CREDIT_LIMIT_OPEN_DT 
         END as PROV_CREDIT_LIMIT_OPEN_DT length = 8
                                          format = NLDATE10.
                                          informat = NLDATE10.
                                          label = "Provisional Credit Limit start date",
         CASE symget('mEngine') 
         	WHEN "ORACLE" THEN datepart(CREDIT_CARD_ACCOUNT.PROV_CREDIT_LIMIT_CLOSE_DT) 
         	ELSE CREDIT_CARD_ACCOUNT.PROV_CREDIT_LIMIT_CLOSE_DT 
         END as PROV_CREDIT_LIMIT_CLOSE_DT length = 8
                                           format = NLDATE10.
                                           informat = NLDATE10.
                                           label = "Provisional Credit Limit end date",
         CREDIT_CARD_ACCOUNT.PAYMENT_METHOD_CD length = 3
                                               label = "Payment Method Code",
         CREDIT_CARD_ACCOUNT.COLLECTIONS_STATUS_CD length = 3
                                                   label = "Collections Status Code",
         CASE symget('mEngine') 
         	WHEN "ORACLE" THEN datepart(CREDIT_CARD_ACCOUNT.CREDIT_PAYMENT_PROTECTION_DT) 
         	ELSE CREDIT_CARD_ACCOUNT.CREDIT_PAYMENT_PROTECTION_DT 
         END as CREDIT_PAYMENT_PROTECTION_DT length = 8
                                             format = NLDATE10.
                                             informat = NLDATE10.
                                             label = "Credit Payment Protection Date",
         CREDIT_CARD_ACCOUNT.CARD_PROTECTION_INS_CD length = 3
                                                    label = "Card Protection Insurance Code",
         CREDIT_CARD_ACCOUNT.PROTECTION_INS_STATUS_CD length = 3
                                                      label = "Protection Insurance Status Code",
         CASE symget('mEngine') 
         	WHEN "ORACLE" THEN datepart(CREDIT_CARD_ACCOUNT.PROTECTION_INS_DT) 
         	ELSE CREDIT_CARD_ACCOUNT.PROTECTION_INS_DT 
         END as PROTECTION_INS_DT length = 8
                                  format = NLDATE10.
                                  informat = NLDATE10.
                                  label = "Protection Insurance Date",
         CREDIT_CARD_ACCOUNT.PAYMENT_PROTECT_STATUS_CD length = 3
                                                       label = "Payment Protect Status Code",
         CREDIT_CARD_ACCOUNT.CREDIT_PAYMENT_PROTECTION_CD length = 3
                                                          label = "Credit Payment Protection Code",
         CASE symget('mEngine') 
         	WHEN "ORACLE" THEN datepart(CREDIT_CARD_ACCOUNT.CHARGE_OFF_DT) 
         	ELSE CREDIT_CARD_ACCOUNT.CHARGE_OFF_DT 
         END as CHARGE_OFF_DT length = 8
                              format = NLDATE10.
                              informat = NLDATE10.
                              label = "Charge Off Date",
         CREDIT_CARD_ACCOUNT.CHARGE_OFF_AMT length = 8
                                            format = NLNUM18.5
                                            informat = NLNUM18.5
                                            label = "Charge Off Amount",
         CREDIT_CARD_ACCOUNT.OPEN_TO_BUY_AMT length = 8
                                             format = NLNUM18.5
                                             informat = NLNUM18.5
                                             label = "Open To Buy Amount",
         CREDIT_CARD_ACCOUNT.OPEN_TO_BUY_PCT length = 8
                                             format = NLNUM9.4
                                             informat = NLNUM9.4
                                             label = "Open To Buy Percent",
         CREDIT_CARD_ACCOUNT.BUREAU_CLASS_CD length = 3
                                             label = "Bureau Class Code",
         CREDIT_CARD_ACCOUNT.CUSTOMER_CLASS_CD length = 3
                                               label = "Customer Class Code",
         CREDIT_CARD_ACCOUNT.MONTHS_SINCE_AT_BUREAU_CNT length = 8
                                                        label = "No of Months At Bureau",
         CREDIT_CARD_ACCOUNT.INCENTIVE_TYPE_CD length = 3
                                               label = "Incentive Type Code",
         CASE symget('mEngine') 
         	WHEN "ORACLE" THEN datepart(CREDIT_CARD_ACCOUNT.INCENTIVE_END_DT) 
         	ELSE CREDIT_CARD_ACCOUNT.INCENTIVE_END_DT 
         END as INCENTIVE_END_DT length = 8
                                 format = NLDATE10.
                                 informat = NLDATE10.
                                 label = "Incentive End Date",
         CREDIT_CARD_ACCOUNT.AUTO_PAY_FLG length = 1
                                          label = "Auto Pay Flag",
         CREDIT_CARD_ACCOUNT.AUTO_DEBIT_ACCOUNT_NO length = 20
                                                   label = "Auto Debit Account Number",
         CREDIT_CARD_ACCOUNT.KEY_AUTO_DEBIT_ACCOUNT_NO length = 20
                                                       label = "Key to Auto Debit Account",
         CREDIT_CARD_ACCOUNT.ACCOUNT_RENEWAL_TYPE_CD length = 3
                                                     label = "Account Renewal Type Code",
         CREDIT_CARD_ACCOUNT.CARD_PAY_ACCOUNT_TYPE_CD length = 3
                                                      label = "Card Payment Account Type Code",
         CREDIT_CARD_ACCOUNT.CARD_PAYMENT_TYPE_CD length = 3
                                                  label = "Card Payment Type Code",
         CREDIT_CARD_ACCOUNT.TRAVEL_MILES_PGRM_FLG length = 1
                                                   label = "Travel Miles Program Flag",
         CREDIT_CARD_ACCOUNT.BONUS_POINT_PGRM_FLG length = 1
                                                  label = "Bonus Point Program Flag",
         CASE symget('mEngine') 
         	WHEN "ORACLE" THEN datepart(CREDIT_CARD_ACCOUNT.RENEWAL_FEE_DT) 
         	ELSE CREDIT_CARD_ACCOUNT.RENEWAL_FEE_DT 
         END as RENEWAL_FEE_DT length = 8
                               format = NLDATE10.
                               informat = NLDATE10.
                               label = "Renewal Fee Date",
         CASE symget('mEngine') 
         	WHEN "ORACLE" THEN datepart(CREDIT_CARD_ACCOUNT.MAX_DEBT_DT) 
         	ELSE CREDIT_CARD_ACCOUNT.MAX_DEBT_DT 
         END as MAX_DEBT_DT length = 8
                            format = NLDATE10.
                            informat = NLDATE10.
                            label = "Maximum Debt Date",
         CREDIT_CARD_ACCOUNT.ADDITIONAL_CARD_CNT length = 8
                                                 label = "Additional Card Count",
         CREDIT_CARD_ACCOUNT.INSURANCE_AMT length = 8
                                           format = NLNUM18.5
                                           informat = NLNUM18.5
                                           label = "Insurance Amount",
         CREDIT_CARD_ACCOUNT.CREDIT_LINE_USED_RNG_CD length = 3
                                                     label = "Credit Line Range Used Code",
         CREDIT_CARD_ACCOUNT.CASH_CREDIT_LINE_AMT length = 8
                                                  format = NLNUM18.5
                                                  informat = NLNUM18.5
                                                  label = "Cash Credit Line Amount",
         CREDIT_CARD_ACCOUNT.MAX_LATE_DAY_CNT length = 8
                                              label = "Maximum Late Days Count",
         CREDIT_CARD_ACCOUNT.CREDIT_DAYS_CNT length = 8
                                             label = "Credit Days Count",
         CREDIT_CARD_ACCOUNT.BALANCE_TRANSFER_FLG length = 1
                                                  label = "Balance Transfer Flag",
         CREDIT_CARD_ACCOUNT.ACCOUNT_ID length = 32
                                        label = "Account Id",
         CREDIT_CARD_ACCOUNT.SOURCE_SYSTEM_CD length = 3
                                              label = "Source System Code",
         CREDIT_CARD_ACCOUNT.CREDIT_CARD_ACCOUNT_TYPE_CD length = 3
                                                         label = "Credit Card Account Type Code",
         CREDIT_CARD_ACCOUNT.OFFSET_ACCOUNT_FLG length = 1
                                                label = "Offset Account Flag",
         CREDIT_CARD_ACCOUNT.REWARD_PROGRAM_FLG length = 1
                                                label = "Reward Program Flag",
         CREDIT_CARD_ACCOUNT.PAYMENT_PROTECTION_FLG length = 1
                                                    label = "Payment Protection Flag",
         CREDIT_CARD_ACCOUNT.ACTIVE_DIRECT_DEBITS_CNT length = 8
                                                      label = "Active Direct Debits Count",
         CASE symget('mEngine') 
         	WHEN "ORACLE" THEN datepart(CREDIT_CARD_ACCOUNT.RENEWAL_DT) 
         	ELSE CREDIT_CARD_ACCOUNT.RENEWAL_DT 
         END as RENEWAL_DT length = 8
                           format = NLDATE10.
                           informat = NLDATE10.
                           label = "Renewal Date",
         CREDIT_CARD_ACCOUNT.CARD_CANCEL_REASON_CD length = 3
                                                   label = "Card Cancel Reason Code"
      from
         control.LOAD_CONTROL, 
         DDS.CREDIT_CARD_ACCOUNT
      where
         LOAD_CONTROL.LOAD_FLG IN (&CHECK_FLAG_TRUE)
         and LOAD_CONTROL.RUN_STATUS IN (&RUNNING_STATUS)
         and LOAD_CONTROL.LOAD_END_DTTM >= CREDIT_CARD_ACCOUNT.VALID_FROM_DTTM
         and LOAD_CONTROL.LOAD_END_DTTM <= CREDIT_CARD_ACCOUNT.VALID_TO_DTTM
      ;
quit;

%rcSet(&sqlrc); 

%macro etls_completeTarget();
%mend etls_completeTarget;
%etls_completeTarget;

/*============================================================================* 
 * Step:          Dummy Loader                              A5V75JN3.BO0006YV * 
 * Transform:     Table Loader                                                * 
 * Description:                                                               * 
 *                                                                            * 
 * Source Table:  SQL Target - martscr.CRA_EXT              A5V75JN3.BP00066O * 
 * Target Table:  CRA_EXT - martscr.CRA_EXT                 A5V75JN3.BE0000J4 * 
 *============================================================================*
 *                                                                            * 
 * Nothing will be generated for this process because the "Do not generate    * 
 *  code for this process" option is selected.                                * 
 *                                                                            * 
 *============================================================================*/ 

data _null_; 
   call symput('etls_endTime',put(datetime(),datetime.));
run;

/* Check return code for job  */ 
%macro etls_jobRCChk; 
   %if (&job_rc eq 4) %then
   %do; 
      %on_success(Job_nm=&etls_jobName..sas, param_table=&status_table);
   %end; 
%mend etls_jobRCChk; 
%etls_jobRCChk; 

/* Check return code for job  */ 
%macro etls_jobRCChk; 
   %if (&job_rc ge 5) %then
   %do; 
      %on_success(Job_nm=&etls_jobName..sas, param_table=&status_table);
   %end; 
%mend etls_jobRCChk; 
%etls_jobRCChk; 

/* Check return code for job  */ 
%macro etls_jobRCChk; 
   %if (&job_rc eq 0) %then
   %do; 
      %on_success(Job_nm=&etls_jobName..sas, param_table=&status_table);
   %end; 
%mend etls_jobRCChk; 
%etls_jobRCChk; 

/*---- Job status macro  ----*/ 
/*============================================================================* 
 * Post-Process code for the job                            A5V75JN3.AY0004NX * 
 *                                                                            * 
 * User Written:  Index creation code on ACCOUNT_RK,        A5V75JN3.AF000POT * 
 *                 LOAD_END_DTTM column                                       * 
 *                Index creation code on ACCOUNT_RK,  LOAD_END_DTTM column    * 
 *============================================================================*/ 

/*---- Start of User Written Code  ----*/ 

/*creating index on ACCOUNT_RK AND LOAD_END_DTTM column */
PROC SQL NOPRINT;
           CREATE INDEX  ACCOUNT_RK_LOAD_END_DTTM
            ON martscr.CRA_EXT (ACCOUNT_RK, LOAD_END_DTTM);
QUIT;
/*---- End of User Written Code  ----*/ 

%rcSet(&syserr); 
%rcSet(&sqlrc); 

