/****************************************************************************** 
 * Job:           CS_MONITORING_MODEL                       A5V75JN3.BN0000VR * 
 * Description:   This job picks up information for model_input table and     * 
 *                 builds the staging area for monitoring models.             * 
 *                                                                            * 
 * Repository:    Foundation                                A0000001.A5V75JN3 * 
 * Server:        SASMain                                   A5V75JN3.AT000001 * 
 *                                                                            * 
 * Generated on:  Wednesday, December 10, 2008 12:48:59 PM IST                * 
 * Generated by:  sasadm                                                      * 
 * Version:       9.1.20060626.51875                                          * 
 ******************************************************************************/ 



%let jobID = %quote(A5V75JN3.BN0000VR);

/* Setup for capturing job status  */ 
data _null_; 
   call symput('etls_startTime',put(datetime(),datetime.));
run;

%let etls_jobName = CS_MONITORING_MODEL;
%let etls_recordsBefore = 0;
%let etls_recordsAfter = 0;
%let etls_lib = 0;
%let etls_table = 0;

/* Setup to capture return codes  */ 
%global job_rc trans_rc sqlrc; 
%let job_rc = 0;
%let trans_rc = 0;
%let sqlrc = 0;
%global syserr; 

%macro rcSet(error); 
   %if (&error gt &trans_rc) %then 
      %let trans_rc = &error;
   %if (&error gt &job_rc) %then 
      %let job_rc = &error;
%mend rcSet; 

%macro rcSetDS(error); 
   if &error gt input(symget('trans_rc'),12.) then 
      call symput('trans_rc',trim(left(put(&error,12.))));
   if &error gt input(symget('job_rc'),12.) then 
      call symput('job_rc',trim(left(put(&error,12.))));
%mend rcSetDS; 

%global etls_debug; 
%macro etls_setDebug; 
   %if %str(&etls_debug) ne 0 %then 
      OPTIONS MPRINT%str(;); 
%mend; 
%etls_setDebug; 

/*============================================================================* 
 * Step:          Creating input dataset for monitoring     A5V75JN3.BO0005NU * 
 *                 model                                                      * 
 * Transform:     User Written Code                                           * 
 * Description:   Creating input dataset for monitoring model                 * 
 *                                                                            * 
 * Target Table:  User Written Code Target - work.          A5V75JN3.BP0004SF * 
 *                                                                            * 
 * User Written:  Creating input dataset for monitoring     A5V75JN3.AF000MNA * 
 *                 model                                                      * 
 *                Creating input dataset for monitoring model                 * 
 *============================================================================*/ 

%let transformID = %quote(A5V75JN3.BO0005NU); 

%let trans_rc = 0; 

%let _OUTPUT = %nrquote(work.A5V75JN3_BP0004SF); 

/*---- Start of User Written Code  ----*/ 

/* 
1. The total count of models are obtained from MODEL_INPUT table where the STATUS is
 as given by the parameter CS_MODEL_STATUS and ABT_TYPE is as given by CS_MDL_TYPE,
 this parameter denotes that the type is monitoring model.
2. The table names are picked up from the MODEL_INPUT table for each model.
3. Check whether the dataset MODEL_INPUT contains all information for each model.
 If the table, SCR_CARD_ODDS_TABLE_NM, is not provided,
 or if the given datasets do not exist then information for that model is not
 included in the output dataset, and a message is written to the log.
4. If all information is provided and all dataset exist for a given model then,
 a) The dataset ACCOUNT_MODEL is created, containing the information provided in the
  dataset given by SCR_CARD_ODDS_TABLE_NM for each model
  by appending the data for PDO,LGD or CCF models provided.
 b) The dataset APPL_MODEL is created, containing the information provided in the
  dataset given by SCR_CARD_ODDS_TABLE_NM for each model
  by appending the data for PDA(Application PD) models provided.
*/
%let inlib = mdlmart;
%macro monitoring_model;

 data martscr.account_model;
  attrib ACCOUNT_RK length = 8 format = 12. informat = 12.;
  attrib MODEL_SK length = 8 format = 12. informat = 12.;
  attrib POOL_SCHEME_SK length = 8 format = 12. informat = 12.;
  attrib MODEL_TYPE_CD length = $3 format = $3. informat = $3.;
  attrib SCORE_POINTS length = 8;
  attrib ESTIMATED_ACCOUNT_PD length = 8;
  attrib ACTUAL_GOOD_BAD length = 8;
  attrib ESTIMATED_ACCOUNT_LGD length = 8;
  attrib ACTUAL_LGD length = 8;
  attrib ESTIMATED_ACCOUNT_CCF length = 8;
  attrib ACTUAL_CCF length = 8;
  attrib ABT_DT length = 8 format = NLDATE10. informat = NLDATE10.;
  attrib TARGET_DT length = 8 format = NLDATE10. informat = NLDATE10.;
  stop;
 run;

 data martscr.appl_model;
  attrib APPLICATION_RK length = 8 format = 12. informat = 12.;
  attrib MODEL_SK length = 8 format = 12. informat = 12.;
  attrib POOL_SCHEME_SK length = 8 format = 12. informat = 12.;
  attrib MODEL_TYPE_CD length = $3 format = $3. informat = $3.;
  attrib SCORE_POINTS length = 8;
  attrib ESTIMATED_APPL_PD length = 8;
  attrib ACTUAL_GOOD_BAD length = 8;
  attrib ABT_DT length = 8 format = NLDATE10. informat = NLDATE10.;
  attrib TARGET_DT length = 8 format = NLDATE10. informat = NLDATE10.;
  stop;
 run;

 %let tot_tbl = .;
 /* To obtain the count of models, where the status is as given by the parameter
  CS_MODEL_STATUS */
 proc sql noprint;
  select count(*) into :tot_tbl from &inlib..model_input
  where kupcase(status) IN (%sysfunc(kupcase(&CS_MODEL_STATUS)))
   and kupcase(ABT_TYPE) IN (%sysfunc(kupcase(&CS_ABT_TYPE_MDL)));
 quit;
 %let tot_tbl = %sysfunc(ktrim(%sysfunc(kleft(&tot_tbl))));

 %if (&tot_tbl > 0) %then %do;
  %do tbl_no=1 %to &tot_tbl;
   %let mdl_nm&tbl_no = .;
   %let odds_tbl_nm&tbl_no = .;
   %let abt_dt&tbl_no = .;
   %let abt_type&tbl_no = .;
  %end; 
 
  /* To obtain the table names and model names in array of macros, where the status is
   as given by the parameter CS_MODEL_STATUS */
  proc sql noprint;
   select MODEL_NM, SCR_CARD_ODDS_TABLE_NM, ABT_DT, ABT_TYPE
     into :mdl_nm1 - :mdl_nm&tot_tbl,
       :odds_tbl_nm1 - :odds_tbl_nm&tot_tbl,
       :abt_dt1 - :abt_dt&tot_tbl,
       :abt_type1 - :abt_type&tot_tbl
   from &inlib..model_input
   where kupcase(status) IN (%sysfunc(kupcase(&CS_MODEL_STATUS)))
    and kupcase(ABT_TYPE) IN (%sysfunc(kupcase(&CS_ABT_TYPE_MDL)));
  quit;
 
  %let acct_tbl_no = 0;
  %let appl_tbl_no = 0;
  %do tbl_no=1 %to &tot_tbl;
   %let mdl_nm&tbl_no = %sysfunc(ktrim(%sysfunc(kleft(&&mdl_nm&tbl_no))));
   %let odds_tbl_nm&tbl_no = %sysfunc(ktrim(%sysfunc(kleft(&&odds_tbl_nm&tbl_no))));
   %let abt_dt&tbl_no = %sysfunc(ktrim(%sysfunc(kleft(&&abt_dt&tbl_no))));
   %let abt_type&tbl_no = %sysfunc(ktrim(%sysfunc(kleft(&&abt_type&tbl_no))));
 
   %if (&&mdl_nm&tbl_no eq %str() or &&odds_tbl_nm&tbl_no eq %str()) %then %do;
    %if (&&mdl_nm&tbl_no eq %str()) %then %do;
     %put "ERROR: Provide MODEL_NM for Model&tbl_no";
    %end;
    %if (&&odds_tbl_nm&tbl_no eq %str()) %then %do;
     %put "ERROR: Provide SCR_CARD_ODDS_TABLE_NM for Model&tbl_no";
    %end;

    proc sql noprint;
    update &inlib..model_input
    set status = 'ERROR'
    where MODEL_NM = "&&mdl_nm&tbl_no"
      and ABT_TYPE = "&&abt_type&tbl_no";
    quit;

   %end;
   %else %do;
    %if (%sysfunc(exist(&inlib..&&odds_tbl_nm&tbl_no)) eq 0) %then %do;
     %put "ERROR: The dataset &inlib..&&odds_tbl_nm&tbl_no does not exist";

     proc sql noprint;
     update &inlib..model_input
     set status = 'ERROR'
     where MODEL_NM = "&&mdl_nm&tbl_no"
      and ABT_TYPE = "&&abt_type&tbl_no";
     quit;

    %end;
    %else %do;
     %let mdl_sk = .;
     %let mdl_type_cd =;
     %let pool_sch_sk = .;
     %let tgt_mths_cnt = .;

     proc sql noprint;
      select model_sk, model_type_cd, pool_scheme_sk,
         target_period_mths_cnt
        into :mdl_sk, :mdl_type_cd, :pool_sch_sk,
         :tgt_mths_cnt
      from martscr.ANALYTICAL_MODEL_DIM_EXT
      where ANALYTICAL_MODEL_DIM_EXT.model_nm = "&&mdl_nm&tbl_no";
     quit;
     %let mdl_sk = %sysfunc(ktrim(%sysfunc(kleft(&mdl_sk))));
     %let mdl_type_cd = %quote(%'%sysfunc(ktrim(%sysfunc(kleft(&mdl_type_cd))))%');
     %let pool_sch_sk = %sysfunc(ktrim(%sysfunc(kleft(&pool_sch_sk))));
     %let tgt_mths_cnt = %sysfunc(ktrim(%sysfunc(kleft(&tgt_mths_cnt))));
 
     %if (%sysfunc(kupcase(&mdl_type_cd)) eq %sysfunc(kupcase(&PD_ONG_MODEL)) or 
       %sysfunc(kupcase(&mdl_type_cd)) eq %sysfunc(kupcase(&LGD_MODEL)) or
       %sysfunc(kupcase(&mdl_type_cd)) eq %sysfunc(kupcase(&CCF_MODEL))) %then %do ;
      data work.acc_odds_table&tbl_no;
       length MODEL_TYPE_CD $3.;
       SCORE_POINTS = .;
       ESTIMATED_ACCOUNT_PD = .;
       ACTUAL_GOOD_BAD = .;
       ESTIMATED_ACCOUNT_LGD = .;
       ACTUAL_LGD = .;
       ESTIMATED_ACCOUNT_CCF = .;
       ACTUAL_CCF = .;
       set &inlib..&&odds_tbl_nm&tbl_no(rename=(
       %if (%sysfunc(kupcase(&mdl_type_cd)) eq %sysfunc(kupcase(&PD_ONG_MODEL))) %then %do ;
        scorecard_points= SCORE_POINTS 
        P_TGT_VAR1 = ESTIMATED_ACCOUNT_PD
        TGT_VAR = ACTUAL_GOOD_BAD
       %end;
       %if (%sysfunc(kupcase(&mdl_type_cd)) eq %sysfunc(kupcase(&LGD_MODEL))) %then %do ;
        P_TGT_VAR = ESTIMATED_ACCOUNT_LGD
        TGT_VAR = ACTUAL_LGD
       %end;
       %if (%sysfunc(kupcase(&mdl_type_cd)) eq %sysfunc(kupcase(&CCF_MODEL))) %then %do ;
        P_TGT_VAR = ESTIMATED_ACCOUNT_CCF
        TGT_VAR = ACTUAL_CCF
       %end;
       ));
       MODEL_SK = &mdl_sk;
       POOL_SCHEME_SK = &pool_sch_sk;
       MODEL_TYPE_CD = %unquote(&mdl_type_cd);
       ABT_DT = "&&abt_dt&tbl_no"D;
       TARGET_DT = INTNX('MONTH',"&&abt_dt&tbl_no"D,&tgt_mths_cnt,'END');
       keep ACCOUNT_RK MODEL_SK POOL_SCHEME_SK MODEL_TYPE_CD
        SCORE_POINTS ESTIMATED_ACCOUNT_PD ACTUAL_GOOD_BAD
        ESTIMATED_ACCOUNT_LGD ACTUAL_LGD ESTIMATED_ACCOUNT_CCF
        ACTUAL_CCF ABT_DT TARGET_DT;
      run;
      %let acct_tbl_no = %eval(&acct_tbl_no + 1);

/* Start of CS4.3 HF2 */ 
/* The if else condition - if (&acct_tbl_no = 1) is removed in CS4.3 HF2 */

       proc append base=martscr.account_model data=work.acc_odds_table&tbl_no force;
       run;
/* End of CS4.3 HF2 */
     %end;
     %else %if (%sysfunc(kupcase(&mdl_type_cd)) eq %sysfunc(kupcase(&PD_APP_MODEL))) %then %do;
      data work.appl_odds_table&tbl_no;
       SCORE_POINTS = .;
       ESTIMATED_APPL_PD = .;
       ACTUAL_GOOD_BAD = .;
       set &inlib..&&odds_tbl_nm&tbl_no(rename=(
        scorecard_points= SCORE_POINTS 
        P_TGT_VAR1 = ESTIMATED_APPL_PD
        TGT_VAR = ACTUAL_GOOD_BAD
       ));
       MODEL_SK = &mdl_sk;
       POOL_SCHEME_SK = &pool_sch_sk;
       MODEL_TYPE_CD = %unquote(&mdl_type_cd);
       ABT_DT = "&&abt_dt&tbl_no"D;
       TARGET_DT = INTNX('MONTH',"&&abt_dt&tbl_no"D,&tgt_mths_cnt,'END');
       keep APPLICATION_RK MODEL_SK POOL_SCHEME_SK MODEL_TYPE_CD
        SCORE_POINTS ESTIMATED_APPL_PD ACTUAL_GOOD_BAD
        ABT_DT TARGET_DT;
      run;
      %let appl_tbl_no = %eval(&appl_tbl_no + 1);

/* Start of CS4.3 HF2 */ 
/* The if else condition - if (&appl_tbl_no = 1) is removed in CS4.3 HF2 */

       proc append base=martscr.appl_model data=work.appl_odds_table&tbl_no force;
       run;

/* End of CS4.3 HF2 */

     %end;
    %end;
   %end;
  %end;
 %end;

%mend monitoring_model;
%monitoring_model;

/*---- End of User Written Code  ----*/ 

%rcSet(&syserr); 
%rcSet(&sqlrc); 

data _null_; 
   call symput('etls_endTime',put(datetime(),datetime.));
run;

/* Check return code for job  */ 
%macro etls_jobRCChk; 
   %if (&job_rc eq 0) %then
   %do; 
      %on_success(Job_nm=&etls_jobName..sas, param_table=&status_table);
   %end; 
%mend etls_jobRCChk; 
%etls_jobRCChk; 

/* Check return code for job  */ 
%macro etls_jobRCChk; 
   %if (&job_rc eq 4) %then
   %do; 
      %on_success(Job_nm=&etls_jobName..sas, param_table=&status_table);
   %end; 
%mend etls_jobRCChk; 
%etls_jobRCChk; 

/* Check return code for job  */ 
%macro etls_jobRCChk; 
   %if (&job_rc ge 5) %then
   %do; 
      %on_success(Job_nm=&etls_jobName..sas, param_table=&status_table);
   %end; 
%mend etls_jobRCChk; 
%etls_jobRCChk; 

/*---- Job status macro  ----*/ 
