/****************************************************************************** 
 * Job:           CUSTOMER_SCORE_PRE_DETAIL                 A5V75JN3.BN00003I * 
 * Description:   This job picks up data from CMS_EXT and AM_EXT  based on    * 
 *                MODEL_RK and LOAD_END_DTTM, for the CUSTOMER_SCORE          * 
 *                 pre-detail table.                                          * 
 *                                                                            * 
 * Repository:    Foundation                                A0000001.A5V75JN3 * 
 * Server:        SASMain                                   A5V75JN3.AT000001 * 
 *                                                                            * 
 * Source Tables: CMS_EXT - martscr.CMS_EXT                 A5V75JN3.BE0000IY * 
 *                AM_EXT - martscr.AM_EXT                   A5V75JN3.BE0000I8 * 
 * Target Table:  CUSTOMER_SCORE_PRE_DETAIL -               A5V75JN3.BE0000LG * 
 *                 martscr.CUSTOMER_SCORE_PRE_DETAIL                          * 
 *                                                                            * 
 * Generated on:  Wednesday, December 10, 2008 3:35:54 PM IST                 * 
 * Generated by:  sasadm                                                      * 
 * Version:       9.1.20060626.51875                                          * 
 ******************************************************************************
 * Notes:                                                                     * 
 * CUSTOMER_SCORE_PRE_DETAIL                                                  * 
 * Job Name: CUSTOMER_SCORE_PRE_DETAILJob Desc Pre Process: NoneMain: a)      * 
 * Score details of customers obtained by joining CMS_EXT and AM_EXT on       * 
 * MODEL_RK and LOAD_END_DTTM. This table acts as a pre-detail table for      * 
 * CUSTOMER_SCORE_DETAIL.Post Process: NoneParameters: NoneDeveloped by:      * 
 *  sinabcReviewed by:Tested by: sinabc                                       * 
 ******************************************************************************/ 



%let jobID = %quote(A5V75JN3.BN00003I);

/* Setup for capturing job status  */ 
data _null_; 
   call symput('etls_startTime',put(datetime(),datetime.));
run;

%let etls_jobName = CUSTOMER_SCORE_PRE_DETAIL;
%let etls_recordsBefore = 0;
%let etls_recordsAfter = 0;
%let etls_lib = 0;
%let etls_table = 0;

/* Setup to capture return codes  */ 
%global job_rc trans_rc sqlrc; 
%let job_rc = 0;
%let trans_rc = 0;
%let sqlrc = 0;
%global syserr; 

%macro rcSet(error); 
   %if (&error gt &trans_rc) %then 
      %let trans_rc = &error;
   %if (&error gt &job_rc) %then 
      %let job_rc = &error;
%mend rcSet; 

%macro rcSetDS(error); 
   if &error gt input(symget('trans_rc'),12.) then 
      call symput('trans_rc',trim(left(put(&error,12.))));
   if &error gt input(symget('job_rc'),12.) then 
      call symput('job_rc',trim(left(put(&error,12.))));
%mend rcSetDS; 

%global etls_debug; 
%macro etls_setDebug; 
   %if %str(&etls_debug) ne 0 %then 
      OPTIONS MPRINT%str(;); 
%mend; 
%etls_setDebug; 

/*============================================================================* 
 * Step:          Score details of customers                A5V75JN3.BO0005PQ * 
 * Transform:     SQL Join (Version 2)                                        * 
 * Description:   Score details of customers obtained by joining CMS_EXT and  * 
 *                 AM_EXT on MODEL_RK  and LOAD_END_DTTM                      * 
 *                                                                            * 
 * Source Tables: CMS_EXT - martscr.CMS_EXT                 A5V75JN3.BE0000IY * 
 *                AM_EXT - martscr.AM_EXT                   A5V75JN3.BE0000I8 * 
 * Target Table:  SQL Join Target -                         A5V75JN3.BP0004TI * 
 *                 martscr.CUSTOMER_SCORE_BEFORE_PRE_DETAIL                   * 
 *============================================================================*/ 

/* Access the data for Scratch for Mart  */ 
LIBNAME martscr BASE "Data/bisdata/scratch/mart" ;
%rcSet(&syslibrc); 

%let transformID = %quote(A5V75JN3.BO0005PQ); 

%let trans_rc = 0; 

proc datasets lib = martscr nolist nowarn memtype = (data view);
   delete CUSTOMER_SCORE_BEFORE_PRE_DETAIL;
quit;

proc sql;
   create table martscr.CUSTOMER_SCORE_BEFORE_PRE_DETAIL as
      select
         CMS_EXT.CUSTOMER_RK length = 8
                             format = 12.
                             informat = 12.
                             label = "Customer Key",
         CMS_EXT.LOAD_END_DTTM length = 8
                               format = NLDATM21.
                               informat = NLDATM21.
                               label = "Load End Datetime",
         CMS_EXT.MODEL_RK length = 8
                          format = 12.
                          informat = 12.
                          label = "Model Key",
         CMS_EXT.SCORE_DT as LATEST_SCORE_DT length = 8
                                             format = NLDATE10.
                                             informat = NLDATE10.
                                             label = "Score Date",
         CMS_EXT.CUSTOMER_MODEL_SCORE_NO as LATEST_SCORE_NO length = 8
                                                            format = NLNUM12.8
                                                            informat = NLNUM12.8
                                                            label = "Customer Model Score No",
         CMS_EXT.SCORE_POINTS_NO as LATEST_SCORE_POINTS_NO length = 8
                                                           label = "Score Points No"
      from
         martscr.CMS_EXT, 
         martscr.AM_EXT
      where
         CMS_EXT.LOAD_END_DTTM = AM_EXT.LOAD_END_DTTM
         and CMS_EXT.MODEL_RK = AM_EXT.MODEL_RK
         and AM_EXT.MODEL_DEPLOYMENT_CD IN (&PRD_MODEL_DEPLOYMENT, &DEV_MODEL_DEPLOYMENT)
         and AM_EXT.MODEL_TYPE_CD IN (&CUS_SCORE_MODEL)
      ;
quit;

%rcSet(&sqlrc); 

%macro etls_completeTarget();
   /*---- Create the integrity constraints for a table  ----*/ 
   %put %str(NOTE: Creating integrity constraints ...);
   proc datasets library=martscr nolist;
      modify CUSTOMER_SCORE_BEFORE_PRE_DETAIL;
         ic create not null (CUSTOMER_RK);
         ic create not null (MODEL_RK);
         ic create not null (LATEST_SCORE_DT);
   quit;
   
   %rcSet(&syserr); 
   
%mend etls_completeTarget;
%etls_completeTarget;

/*============================================================================* 
 * Step:          Code to Generate Customer Score Pre       A5V75JN3.BO0005PP * 
 *                 Detail                                                     * 
 * Transform:     User Written Code                                           * 
 * Description:                                                               * 
 *                                                                            * 
 * Source Table:  SQL Join Target -                         A5V75JN3.BP0004TI * 
 *                 martscr.CUSTOMER_SCORE_BEFORE_PRE_DETAIL                   * 
 * Target Table:  User Written Code Target -                A5V75JN3.BP0004TH * 
 *                 martscr.CUSTOMER_SCORE_PRE_DETAIL                          * 
 *                                                                            * 
 * User Written:  Code to Generate Customer Score Pre       A5V75JN3.AF000MVT * 
 *                 Detail                                                     * 
 *                Code to Generate Customer Score Pre Detail                  * 
 *============================================================================*/ 

%let SYSLAST = %nrquote(martscr.CUSTOMER_SCORE_BEFORE_PRE_DETAIL); 

%let transformID = %quote(A5V75JN3.BO0005PP); 

%let trans_rc = 0; 

%let _OUTPUT = %nrquote(martscr.CUSTOMER_SCORE_PRE_DETAIL); 

/*---- Start of User Written Code  ----*/ 

%let sort_col= CUSTOMER_RK MODEL_RK LOAD_END_DTTM;
%let etl_str=KTRIM(KLEFT(CUSTOMER_RK)) || KTRIM(KLEFT(MODEL_RK)) || KTRIM(KLEFT(LATEST_SCORE_DT)); 
%deduplicate(in_table=&SYSLAST,sort_col=&sort_col,out_table=&_OUTPUT,etls_str_in=&etl_str)
/*---- End of User Written Code  ----*/ 

%rcSet(&syserr); 
%rcSet(&sqlrc); 

/*============================================================================* 
 * Step:          Dummy Loader                              A5V75JN3.BO0005PO * 
 * Transform:     Table Loader (Version 2)                                    * 
 * Description:                                                               * 
 *                                                                            * 
 * Source Table:  User Written Code Target -                A5V75JN3.BP0004TH * 
 *                 martscr.CUSTOMER_SCORE_PRE_DETAIL                          * 
 * Target Table:  CUSTOMER_SCORE_PRE_DETAIL -               A5V75JN3.BE0000LG * 
 *                 martscr.CUSTOMER_SCORE_PRE_DETAIL                          * 
 *============================================================================*
 *                                                                            * 
 * Nothing will be generated for this process because the "Do not generate    * 
 *  code for this process" option is selected.                                * 
 *                                                                            * 
 *============================================================================*/ 

data _null_; 
   call symput('etls_endTime',put(datetime(),datetime.));
run;

/* Check return code for job  */ 
%macro etls_jobRCChk; 
   %if (&job_rc eq 4) %then
   %do; 
      %on_success(Job_nm=&etls_jobName..sas, param_table=&status_table);
   %end; 
%mend etls_jobRCChk; 
%etls_jobRCChk; 

/* Check return code for job  */ 
%macro etls_jobRCChk; 
   %if (&job_rc ge 5) %then
   %do; 
      %on_success(Job_nm=&etls_jobName..sas, param_table=&status_table);
   %end; 
%mend etls_jobRCChk; 
%etls_jobRCChk; 

/* Check return code for job  */ 
%macro etls_jobRCChk; 
   %if (&job_rc eq 0) %then
   %do; 
      %on_success(Job_nm=&etls_jobName..sas, param_table=&status_table);
   %end; 
%mend etls_jobRCChk; 
%etls_jobRCChk; 

/*---- Job status macro  ----*/ 
