/****************************************************************************** 
 * Job:           CUS_EXT                                   A5V75JN3.BN000019 * 
 * Description:   This job picks up data from CUSTOMER                        * 
 *                                                                            * 
 * Repository:    Foundation                                A0000001.A5V75JN3 * 
 * Server:        SASMain                                   A5V75JN3.AT000001 * 
 *                                                                            * 
 * Source Tables: LOAD_CONTROL - control.LOAD_CONTROL       A5V75JN3.BE0000I0 * 
 *                CUSTOMER - DDS.CUSTOMER                   A5V75JN3.BE00001W * 
 * Target Table:  CUS_EXT - martscr.CUS_EXT                 A5V75JN3.BE0000J7 * 
 *                                                                            * 
 * Generated on:  Wednesday, December 10, 2008 12:52:05 PM IST                * 
 * Generated by:  sasadm                                                      * 
 * Version:       9.1.20060626.51875                                          * 
 ******************************************************************************
 * Notes:                                                                     * 
 * CUS_EXT                                                                    * 
 * Job Name: CUS_EXTJob Desc Pre Process: NoneMain: Extract and load data     * 
 * from CUSTOMER using SQL join with LOAD_CONTROL table based on following    * 
 * conditionsLOAD_CONTROL.LOAD_FLG = CHECK_FLAG_TRUEand                       * 
 * LOAD_CONTROL.RUN_STATUS = RUNNING_STATUSand LOAD_CONTROL.LOAD_END_DTTM     * 
 * between CUSTOMER.VALID_FROM_DTTM and CUSTOMER.VALID_TO_DTTMPost Process:   * 
 * a) Creating index on CUSTOMER_RK,PRIM_BRANCH_FINANCIAL_UNIT_RK and         * 
 * LOAD_END_DTTMParameters:CHECK_FLAG_TRUE and RUNNING_STATUS are the user    * 
 * defined parameters. CHECK_FLAG_TRUE is set to Y and RUNNING_STATUS is to   * 
 * Running for each month of data load.Developed by: singupReviewed           * 
 *  by:Tested by:                                                             * 
 ******************************************************************************/ 

/* Setup for capturing job status  */ 
data _null_; 
   call symput('etls_startTime',put(datetime(),datetime.));
run;

%let etls_jobName = CUS_EXT;
%let etls_recordsBefore = 0;
%let etls_recordsAfter = 0;
%let etls_lib = 0;
%let etls_table = 0;

/* Setup to capture return codes  */ 
%global job_rc trans_rc sqlrc; 
%let job_rc = 0;
%let trans_rc = 0;
%let sqlrc = 0;
%global syserr; 

%macro rcSet(error); 
   %if (&error gt &trans_rc) %then 
      %let trans_rc = &error;
   %if (&error gt &job_rc) %then 
      %let job_rc = &error;
%mend rcSet; 

%macro rcSetDS(error); 
   if &error gt input(symget('trans_rc'),12.) then 
      call symput('trans_rc',trim(left(put(&error,12.))));
   if &error gt input(symget('job_rc'),12.) then 
      call symput('job_rc',trim(left(put(&error,12.))));
%mend rcSetDS; 

%global etls_debug; 
%macro etls_setDebug; 
   %if %str(&etls_debug) ne 0 %then 
      OPTIONS MPRINT%str(;); 
%mend; 
%etls_setDebug; 

/*============================================================================* 
 * Pre-Process code for the job                             A5V75JN3.AY0004NY * 
 *                                                                            * 
 * User Written:  Oracle Date Problem Fix                   A5V75JN3.AF000PPB * 
 *                Oracle Date Problem Fix                                     * 
 *============================================================================*/ 

/*---- Start of User Written Code  ----*/ 

proc contents data=dds.customer out=_etlsEngine(keep=Engine) noprint;
run;

data _null_;
	set _etlsEngine;
	if _n_=1;
	  call symput('mEngine', kleft(kright(Engine)));
run;
/*---- End of User Written Code  ----*/ 

%rcSet(&syserr); 
%rcSet(&sqlrc); 

/*============================================================================* 
 * Step:          Extraction and Loading data as per load   A5V75JN3.BO0006YY * 
 *                 period                                                     * 
 * Transform:     SQL Join (Version 2)                                        * 
 * Description:   Extraction and Loading data as per load period              * 
 *                                                                            * 
 * Source Tables: LOAD_CONTROL - control.LOAD_CONTROL       A5V75JN3.BE0000I0 * 
 *                CUSTOMER - DDS.CUSTOMER                   A5V75JN3.BE00001W * 
 * Target Table:  SQL Target - martscr.CUS_EXT              A5V75JN3.BP00066P * 
 *============================================================================*/ 

/* Access the data for Control  */ 
LIBNAME control BASE "Data/bisdata/control" ;
%rcSet(&syslibrc); 

/* Access the data for Detail Data Store  */ 
LIBNAME DDS BASE "Data/bisdata/dds" ;
%rcSet(&syslibrc); 

/* Access the data for Scratch for Mart  */ 
LIBNAME martscr BASE "Data/bisdata/scratch/mart" ;
%rcSet(&syslibrc); 

%let trans_rc = 0; 

proc datasets lib = martscr nolist nowarn memtype = (data view);
   delete CUS_EXT;
quit;

proc sql;
   create table martscr.CUS_EXT as
      select
         CUSTOMER.CUSTOMER_RK length = 8
                              format = 12.
                              informat = 12.
                              label = "Customer Key",
         LOAD_CONTROL.LOAD_END_DTTM length = 8
                                    format = NLDATM21.
                                    informat = NLDATM21.
                                    label = "Load End Datetime",
         CUSTOMER.MARKET_SEGMENT_CD length = 3
                                    label = "Market Segment Code",
         CUSTOMER.CUSTOMER_LIFECYCLE_CD length = 3
                                        label = "Customer Lifecycle Code",
         CUSTOMER.PREFERRED_CHANNEL_CD length = 3
                                       label = "Preferred Channel Code",
         CUSTOMER.SOURCE_SYSTEM_CD length = 3
                                   label = "Source System Code",
         CUSTOMER.COMMUNICATION_STATUS_CD length = 3
                                          label = "Communication Status Code",
         CUSTOMER.TAX_STATUS_CD length = 3
                                label = "Tax Status Code",
         CUSTOMER.CUSTOMER_ID length = 32
                              label = "Customer Id",
         CUSTOMER.SOURCE_CHANNEL_CD length = 3
                                    label = "Source Channel Code",
         CUSTOMER.CUSTOMER_ACTIVE_CD length = 3
                                     label = "Customer Active Code",
         CUSTOMER.TAX_ID_TYPE_CD length = 3
                                 label = "Tax Id Type Code",
         CUSTOMER.TAX_ID length = 32
                         label = "Tax Id",
         CUSTOMER.CUSTOMER_TYPE_CD length = 3
                                   label = "Customer Type Code",
         CUSTOMER.SOURCE_CD length = 5
                            label = "Source Code",
         CUSTOMER.BANK_CHANNEL_CD length = 3
                                  label = "Bank Channel Code",
         CUSTOMER.PROSPECT_ID length = 32
                              label = "Prospect ID",
         CUSTOMER.BANKRUPTCY_STATUS_CD length = 3
                                       label = "Bankruptcy Status Code",
         CASE symget('mEngine')
         	WHEN "ORACLE" THEN datepart(CUSTOMER.BANKRUPTCY_FILED_DT)
         	ELSE CUSTOMER.BANKRUPTCY_FILED_DT
         END as BANKRUPTCY_FILED_DT length = 8
                                    format = NLDATE10.
                                    informat = NLDATE10.
                                    label = "Bankruptcy Filed Date",
         CUSTOMER.COURT_JUDGEMENT_CNT length = 8
                                      label = "Count of court judgments.",
         CUSTOMER.RISK_FACTOR_ID length = 32
                                 label = "Risk Factor Id",
         CUSTOMER.CUSTOMER_RISK_FACTOR_CD length = 3
                                          label = "Customer Risk Factor Code",
         CUSTOMER.SERVICE_COST_CD length = 3
                                  label = "Service Cost Code",
         CUSTOMER.PROPERTY_TYPE_CD length = 3
                                   label = "Property Type Code",
         CUSTOMER.FORECLOSED_FLG length = 1
                                 label = "Foreclosed Flag",
         CUSTOMER.PENDING_LAWSUIT_FLG length = 1
                                      label = "Pending Lawsuit Flag",
         CUSTOMER.LEGAL_JUDGEMENT_FLG length = 1
                                      label = "Legal Judgement Flag",
         CUSTOMER.FINANCIAL_ASSOCIATE_RK length = 8
                                         format = 12.
                                         informat = 12.
                                         label = "Financial Associate Key",
         CUSTOMER.PRIM_BRANCH_FINANCIAL_UNIT_RK length = 8
                                                format = 12.
                                                informat = 12.
                                                label = "Primary Branch Financial Unit Key",
         CUSTOMER.SEC_BRANCH_FINANCIAL_UNIT_RK length = 8
                                               format = 12.
                                               informat = 12.
                                               label = "Secondary Branch Financial Unit Key",
         CUSTOMER.FIRST_FINANCIAL_ACCT_TYPE_CD as FIRST_ACCOUNT_TYPE_CD length = 3
                                                                        label = "First Financial Acct Type Code",
         CASE symget('mEngine')
         	WHEN "ORACLE" THEN datepart(CUSTOMER.FIRST_FINANCIAL_ACCOUNT_DT)
         	ELSE CUSTOMER.FIRST_FINANCIAL_ACCOUNT_DT
         END as FIRST_ACCOUNT_OPEN_DT length = 8
                                      format = NLDATE10.
                                      informat = NLDATE10.
                                      label = "First Financial Account Date",
         CUSTOMER.TV_REGION_CD length = 5
                               label = "TV Region Code",
         CUSTOMER.RADIO_REGION_CD length = 5
                                  label = "Radio Region Code",
         CUSTOMER.VALID_ADDRESS_FLG length = 1
                                    label = "Valid Address Flag",
         CUSTOMER.VALID_PHONE_FLG length = 1
                                  label = "Valid Phone Flag",
         CUSTOMER.VALID_MOBILE_FLG length = 1
                                   label = "Valid Mobile Flag",
         CUSTOMER.VALID_EMAIL_FLG length = 1
                                  label = "Valid Email Flag",
         CUSTOMER.DO_NOT_CONTACT_FLG length = 1
                                     label = "Do Not Contact Flag",
         CUSTOMER.MAILABLE_FLG length = 1
                               label = "Mailable Flag",
         CUSTOMER.TELEPHONABLE_FLG length = 1
                                   label = "Telephonable Flag",
         CUSTOMER.VALEDICTION_TXT length = 40
                                  label = "Valediction Text",
         CUSTOMER.CURRENCY_CD length = 3
                              label = "Currency Code",
         CUSTOMER.SOCIAL_AIM_CD length = 3
                                label = "Social Aim Type Code",
         CUSTOMER.MAX_DEBT_LIMIT_AMT length = 8
                                     format = NLNUM18.5
                                     informat = NLNUM18.5
                                     label = "Maximum debt limit amount",
         CUSTOMER.OWNER_TYPE_CD length = 3
                                label = "Owner Type Code",
         CUSTOMER.POLITICALLY_EXPOSED_FLG length = 1
                                          label = "Politically Exposed Flag",
         CASE symget('mEngine')
         	WHEN "ORACLE" THEN datepart(CUSTOMER.LAST_CASH_TRANS_REPORT_DT)
         	ELSE CUSTOMER.LAST_CASH_TRANS_REPORT_DT
         END as LAST_CASH_TRANS_REPORT_DT length = 8
                                          format = NLDATE10.
                                          informat = NLDATE10.
                                          label = "Last Cash Transaction Report Date",
         CASE symget('mEngine')
         	WHEN "ORACLE" THEN datepart(CUSTOMER.LAST_SUSP_ACTV_REPORT_DT)
         	ELSE CUSTOMER.LAST_SUSP_ACTV_REPORT_DT
         END as LAST_SUSP_ACTV_REPORT_DT length = 8
                                         format = NLDATE10.
                                         informat = NLDATE10.
                                         label = "Last Suspicious Activity Report Date",
         CASE symget('mEngine')
         	WHEN "ORACLE" THEN datepart(CUSTOMER.LAST_CONTACT_DT)
         	ELSE CUSTOMER.LAST_CONTACT_DT
         END as LAST_CONTACT_DT length = 8
                                format = NLDATE10.
                                informat = NLDATE10.
                                label = "Last Contact Date",
         CUSTOMER.DELINQUENT_FLG length = 1
                                 label = "Delinquent Flag",
         CUSTOMER.NET_WORTH_AT_APPLICATION_AMT length = 8
                                               format = NLNUM18.5
                                               informat = NLNUM18.5
                                               label = "Net Worth Amount At Application",
         CUSTOMER.CUSTOMER_CLASS_CD length = 3
                                    label = "Customer Class Code",
         CUSTOMER.EVER_IN_COLLECTION_FLG length = 1
                                         label = "Ever In Collection Flag",
         CUSTOMER.EFFECTIVE_FROM_DTTM length = 8
                                      format = NLDATM21.
                                      informat = NLDATM21.
                                      label = "Effective From Datetime",
         CUSTOMER.EFFECTIVE_TO_DTTM length = 8
                                    format = NLDATM21.
                                    informat = NLDATM21.
                                    label = "Effective To Datetime"
      from
         control.LOAD_CONTROL, 
         DDS.CUSTOMER
      where
         LOAD_CONTROL.LOAD_FLG IN (&CHECK_FLAG_TRUE)
         and LOAD_CONTROL.RUN_STATUS IN (&RUNNING_STATUS)
         and LOAD_CONTROL.LOAD_END_DTTM >= CUSTOMER.VALID_FROM_DTTM
         and LOAD_CONTROL.LOAD_END_DTTM <= CUSTOMER.VALID_TO_DTTM
      ;
quit;

%rcSet(&sqlrc); 

%macro etls_completeTarget();
%mend etls_completeTarget;
%etls_completeTarget;

/*============================================================================* 
 * Step:          Dummy Loader                              A5V75JN3.BO0006YX * 
 * Transform:     Table Loader                                                * 
 * Description:                                                               * 
 *                                                                            * 
 * Source Table:  SQL Target - martscr.CUS_EXT              A5V75JN3.BP00066P * 
 * Target Table:  CUS_EXT - martscr.CUS_EXT                 A5V75JN3.BE0000J7 * 
 *============================================================================*
 *                                                                            * 
 * Nothing will be generated for this process because the "Do not generate    * 
 *  code for this process" option is selected.                                * 
 *                                                                            * 
 *============================================================================*/ 

data _null_; 
   call symput('etls_endTime',put(datetime(),datetime.));
run;

/* Check return code for job  */ 
%macro etls_jobRCChk; 
   %if (&job_rc eq 4) %then
   %do; 
      %on_success(Job_nm=&etls_jobName..sas, param_table=&status_table);
   %end; 
%mend etls_jobRCChk; 
%etls_jobRCChk; 

/* Check return code for job  */ 
%macro etls_jobRCChk; 
   %if (&job_rc ge 5) %then
   %do; 
      %on_success(Job_nm=&etls_jobName..sas, param_table=&status_table);
   %end; 
%mend etls_jobRCChk; 
%etls_jobRCChk; 

/* Check return code for job  */ 
%macro etls_jobRCChk; 
   %if (&job_rc eq 0) %then
   %do; 
      %on_success(Job_nm=&etls_jobName..sas, param_table=&status_table);
   %end; 
%mend etls_jobRCChk; 
%etls_jobRCChk; 

/*---- Job status macro  ----*/ 
/*============================================================================* 
 * Post-Process code for the job                            A5V75JN3.AY0004NZ * 
 *                                                                            * 
 * User Written:  Index creation                            A5V75JN3.AF000PPC * 
 *                Index creation code on CUSTOMER_RK and                      * 
 *                 PRIM_BRANCH_FINANCIAL_UNIT_RK column with LOAD_END_DTTM    * 
 *============================================================================*/ 

/*---- Start of User Written Code  ----*/ 

/*creating index on CUSTOMER_RK and PRIM_BRANCH_FINANCIAL_UNIT_RK column */
PROC SQL NOPRINT;
  CREATE INDEX CUSTOMER_RK_LOAD_END_DTTM
   ON martscr.CUS_EXT(CUSTOMER_RK, LOAD_END_DTTM);

	CREATE INDEX PRIM_BRANCH_FINANCIAL_UNIT_RK_L
	ON martscr.CUS_EXT(PRIM_BRANCH_FINANCIAL_UNIT_RK, LOAD_END_DTTM);
QUIT;
/*---- End of User Written Code  ----*/ 

%rcSet(&syserr); 
%rcSet(&sqlrc); 

