/****************************************************************************** 
 * Job:           EOFD_EXT                                  A5V75JN3.BN00001I * 
 * Description:   This job builds the EOFD_EXT table by picking up data from  * 
 *                 EXTERNAL_ORG_FINANCIAL_DATA  table.                        * 
 *                                                                            * 
 * Repository:    Foundation                                A0000001.A5V75JN3 * 
 * Server:        SASMain                                   A5V75JN3.AT000001 * 
 *                                                                            * 
 * Source Tables: LOAD_CONTROL - control.LOAD_CONTROL       A5V75JN3.BE0000I0 * 
 *                EXTERNAL_ORG_FINANCIAL_DATA -             A5V75JN3.BE00002M * 
 *                 DDS.EXTERNAL_ORG_FINANCIAL_DATA                            * 
 * Target Table:  EOFD_EXT - martscr.EOFD_EXT               A5V75JN3.BE0000JG * 
 *                                                                            * 
 * Generated on:  Wednesday, December 10, 2008 2:05:29 PM IST                 * 
 * Generated by:  sasadm                                                      * 
 * Version:       9.1.20060626.51875                                          * 
 ******************************************************************************
 * Notes:                                                                     * 
 * EOFD_EXT                                                                   * 
 * Job Name: EOFD_EXTJob Desc Pre Process: NoneMain:Extract and load data     * 
 * from EXTERNAL_ORG_FINANCIAL_DATA using a SQL join with table               * 
 * LOAD_CONTROL based on conditionLOAD_CONTROL.LOAD_FLG = CHECK_FLAG_TRUE     * 
 * andLOAD_CONTROL.RUN_STATUS = RUNNING_STATUS                                * 
 * andLOAD_CONTROL.LOAD_END_DTTM betweenVALID_FROM_DTTM and                   * 
 * VALID_TO_DTTMPost Process: Index is created onEXTERNAL_ORG_RK              * 
 * ,LOAD_END_DTTMParameters: CHECK_FLAG_TRUE and RUNNING_STATUS are the       * 
 * user defined parameters. CHECK_FLAG_TRUE is set to 'Y' and                 * 
 * RUNNING_STATUS is to 'Running' for each month of data load.Developed by:   * 
 *  sinahkReviewed by:Tested by:                                              * 
 ******************************************************************************/ 



%let jobID = %quote(A5V75JN3.BN00001I);

/* Setup for capturing job status  */ 
data _null_; 
   call symput('etls_startTime',put(datetime(),datetime.));
run;

%let etls_jobName = EOFD_EXT;
%let etls_recordsBefore = 0;
%let etls_recordsAfter = 0;
%let etls_lib = 0;
%let etls_table = 0;

/* Setup to capture return codes  */ 
%global job_rc trans_rc sqlrc; 
%let job_rc = 0;
%let trans_rc = 0;
%let sqlrc = 0;
%global syserr; 

%macro rcSet(error); 
   %if (&error gt &trans_rc) %then 
      %let trans_rc = &error;
   %if (&error gt &job_rc) %then 
      %let job_rc = &error;
%mend rcSet; 

%macro rcSetDS(error); 
   if &error gt input(symget('trans_rc'),12.) then 
      call symput('trans_rc',trim(left(put(&error,12.))));
   if &error gt input(symget('job_rc'),12.) then 
      call symput('job_rc',trim(left(put(&error,12.))));
%mend rcSetDS; 

%global etls_debug; 
%macro etls_setDebug; 
   %if %str(&etls_debug) ne 0 %then 
      OPTIONS MPRINT%str(;); 
%mend; 
%etls_setDebug; 

/*============================================================================* 
 * Pre-Process code for the job                             A5V75JN3.AY0004O4 * 
 *                                                                            * 
 * User Written:  Oracle Date Problem Fix                   A5V75JN3.AF000PQP * 
 *                Oracle Date Problem Fix                                     * 
 *============================================================================*/ 

/*---- Start of User Written Code  ----*/ 

proc contents data=dds.external_org_financial_data out=_etlsEngine(keep=Engine) noprint;
run;

data _null_;
	set _etlsEngine;
	if _n_=1;
	  call symput('mEngine', kleft(kright(Engine)));
run;
/*---- End of User Written Code  ----*/ 

%rcSet(&syserr); 
%rcSet(&sqlrc); 

/*============================================================================* 
 * Step:          Extracting and Loading of data as per the A5V75JN3.BO0006Z4 * 
 *                 load period                                                * 
 * Transform:     SQL Join (Version 2)                                        * 
 * Description:   Join with LOAD_CONTROL table and extract appropriate data   * 
 *                 based  onVALID_FROM_DTTM and VALID_TO_DTTM                 * 
 *                                                                            * 
 * Source Tables: LOAD_CONTROL - control.LOAD_CONTROL       A5V75JN3.BE0000I0 * 
 *                EXTERNAL_ORG_FINANCIAL_DATA -             A5V75JN3.BE00002M * 
 *                 DDS.EXTERNAL_ORG_FINANCIAL_DATA                            * 
 * Target Table:  SQL Target - martscr.EOFD_EXT             A5V75JN3.BP00066S * 
 *============================================================================*/ 

/* Access the data for Control  */ 
LIBNAME control BASE "Data/bisdata/control" ;
%rcSet(&syslibrc); 

/* Access the data for Detail Data Store  */ 
LIBNAME DDS BASE "Data/bisdata/dds" ;
%rcSet(&syslibrc); 

/* Access the data for Scratch for Mart  */ 
LIBNAME martscr BASE "Data/bisdata/scratch/mart" ;
%rcSet(&syslibrc); 

%let transformID = %quote(A5V75JN3.BO0006Z4); 

%let trans_rc = 0; 

proc datasets lib = martscr nolist nowarn memtype = (data view);
   delete EOFD_EXT;
quit;

proc sql;
   create table martscr.EOFD_EXT as
      select
         LOAD_CONTROL.LOAD_END_DTTM length = 8
                                    format = NLDATM21.
                                    informat = NLDATM21.
                                    label = "Load End Datetime",
         EXTERNAL_ORG_FINANCIAL_DATA.EXTERNAL_ORG_RK length = 8
                                                     format = 12.
                                                     informat = 12.
                                                     label = "External Organization Key",
         EXTERNAL_ORG_FINANCIAL_DATA.ANNUAL_REVENUE_AMT length = 8
                                                        format = NLNUM18.5
                                                        informat = NLNUM18.5
                                                        label = "Annual Revenue Amount",
         EXTERNAL_ORG_FINANCIAL_DATA.REVENUE_GROWTH_AMT length = 8
                                                        format = NLNUM18.5
                                                        informat = NLNUM18.5
                                                        label = "Revenue Growth Amount",
         EXTERNAL_ORG_FINANCIAL_DATA.GROSS_ANNUAL_SALES_AMT length = 8
                                                            format = NLNUM18.5
                                                            informat = NLNUM18.5
                                                            label = "Gross Annual Sales Amount",
         EXTERNAL_ORG_FINANCIAL_DATA.NET_SALES_REVENUE_AMT length = 8
                                                           format = NLNUM18.5
                                                           informat = NLNUM18.5
                                                           label = "Net Sales Revenue Amount",
         EXTERNAL_ORG_FINANCIAL_DATA.ANNUAL_OPERATING_REVENUE_AMT length = 8
                                                                  format = NLNUM18.5
                                                                  informat = NLNUM18.5
                                                                  label = "Annual Operating Revenue Amount",
         EXTERNAL_ORG_FINANCIAL_DATA.CAGR_OPERATING_REVENUE_AMT length = 8
                                                                format = NLNUM18.5
                                                                informat = NLNUM18.5
                                                                label = "CAGR Operating Revenue Amount",
         EXTERNAL_ORG_FINANCIAL_DATA.NON_OPERATING_REVENUE_AMT length = 8
                                                               format = NLNUM18.5
                                                               informat = NLNUM18.5
                                                               label = "Non Operating Revenue Amount",
         EXTERNAL_ORG_FINANCIAL_DATA.COST_OF_GOODS_SOLD_AMT length = 8
                                                            format = NLNUM18.5
                                                            informat = NLNUM18.5
                                                            label = "Cost Of Goods Sold Amount",
         EXTERNAL_ORG_FINANCIAL_DATA.COST_OF_SALES_AMT length = 8
                                                       format = NLNUM18.5
                                                       informat = NLNUM18.5
                                                       label = "Cost Of Sales Amount",
         EXTERNAL_ORG_FINANCIAL_DATA.OPBDIT_AMT length = 8
                                                format = NLNUM18.5
                                                informat = NLNUM18.5
                                                label = "OPBDIT Amount",
         EXTERNAL_ORG_FINANCIAL_DATA.ANNUAL_INTEREST_CHARGES_AMT length = 8
                                                                 format = NLNUM18.5
                                                                 informat = NLNUM18.5
                                                                 label = "Annual Interest Charges Amount",
         EXTERNAL_ORG_FINANCIAL_DATA.INTEREST_FINANCE_CHARGES_AMT length = 8
                                                                  format = NLNUM18.5
                                                                  informat = NLNUM18.5
                                                                  label = "Interest Finance Charges Amount",
         EXTERNAL_ORG_FINANCIAL_DATA.TOTAL_TERM_DEBT_P_AND_I_AMT length = 8
                                                                 format = NLNUM18.5
                                                                 informat = NLNUM18.5
                                                                 label = "Total Term Debt Principal And Interest Amount",
         EXTERNAL_ORG_FINANCIAL_DATA.LONG_TERM_DEBT_INT_EXPENSE_AMT length = 8
                                                                    format = NLNUM18.5
                                                                    informat = NLNUM18.5
                                                                    label = "Long Term Debt Interest Expense Amount",
         EXTERNAL_ORG_FINANCIAL_DATA.DEPREC_NON_CASH_CHARGES_AMT length = 8
                                                                 format = NLNUM18.5
                                                                 informat = NLNUM18.5
                                                                 label = "Depreciation Non Cash Charges Amount",
         EXTERNAL_ORG_FINANCIAL_DATA.OWNER_COMP_DRAWING_AMT length = 8
                                                            format = NLNUM18.5
                                                            informat = NLNUM18.5
                                                            label = "Owner Compensation Drawing Amount",
         EXTERNAL_ORG_FINANCIAL_DATA.GENERAL_OTHER_EXPENSE_AMT length = 8
                                                               format = NLNUM18.5
                                                               informat = NLNUM18.5
                                                               label = "General Other Expenses Amount",
         EXTERNAL_ORG_FINANCIAL_DATA.EBIT_AMT length = 8
                                              format = NLNUM18.5
                                              informat = NLNUM18.5
                                              label = "EBIT Amount",
         EXTERNAL_ORG_FINANCIAL_DATA.PRIOR_PERIOD_ADJUSTMENTS_NO length = 8
                                                                 label = "Prior Period Adjustments No",
         EXTERNAL_ORG_FINANCIAL_DATA.EXTRA_ORDINARY_INCOME_AMT length = 8
                                                               format = NLNUM18.5
                                                               informat = NLNUM18.5
                                                               label = "Extra Ordinary Income Amount",
         EXTERNAL_ORG_FINANCIAL_DATA.EXTRA_ORDINARY_EXPENSES_AMT length = 8
                                                                 format = NLNUM18.5
                                                                 informat = NLNUM18.5
                                                                 label = "Extra Ordinary Expenses Amount",
         EXTERNAL_ORG_FINANCIAL_DATA.GROSS_PROFIT_AMT length = 8
                                                      format = NLNUM18.5
                                                      informat = NLNUM18.5
                                                      label = "Gross Profit Amount",
         EXTERNAL_ORG_FINANCIAL_DATA.PBT_AMT length = 8
                                             format = NLNUM18.5
                                             informat = NLNUM18.5
                                             label = "PBT Amount",
         EXTERNAL_ORG_FINANCIAL_DATA.PAT_AMT length = 8
                                             format = NLNUM18.5
                                             informat = NLNUM18.5
                                             label = "PAT Amount",
         EXTERNAL_ORG_FINANCIAL_DATA.ACCRETION_TO_RESERVES_AMT length = 8
                                                               format = NLNUM18.5
                                                               informat = NLNUM18.5
                                                               label = "Accretion To Reserves Amount",
         EXTERNAL_ORG_FINANCIAL_DATA.NET_CASH_ACCRUALS_AMT length = 8
                                                           format = NLNUM18.5
                                                           informat = NLNUM18.5
                                                           label = "Net Cash Accruals Amount",
         EXTERNAL_ORG_FINANCIAL_DATA.FREE_CASH_FLOW_AMT length = 8
                                                        format = NLNUM18.5
                                                        informat = NLNUM18.5
                                                        label = "Free Cash Flow Amount",
         EXTERNAL_ORG_FINANCIAL_DATA.GROSS_OPERATING_MARGINS_AMT length = 8
                                                                 format = NLNUM18.5
                                                                 informat = NLNUM18.5
                                                                 label = "Gross Operating Margins Amount",
         EXTERNAL_ORG_FINANCIAL_DATA.NET_INCOME_AMT length = 8
                                                    format = NLNUM18.5
                                                    informat = NLNUM18.5
                                                    label = "Net Income Amount",
         EXTERNAL_ORG_FINANCIAL_DATA.GROSS_MARGIN_AMT length = 8
                                                      format = NLNUM18.5
                                                      informat = NLNUM18.5
                                                      label = "Gross Margin Amount",
         EXTERNAL_ORG_FINANCIAL_DATA.NET_MARGIN_AMT length = 8
                                                    format = NLNUM18.5
                                                    informat = NLNUM18.5
                                                    label = "Net Margin Amount",
         EXTERNAL_ORG_FINANCIAL_DATA.RETURN_ON_CAPITAL_EMPLOYED_AMT length = 8
                                                                    format = NLNUM18.5
                                                                    informat = NLNUM18.5
                                                                    label = "Return On Capital Employed Amount",
         EXTERNAL_ORG_FINANCIAL_DATA.RETURN_ON_EQUITY_AMT length = 8
                                                          format = NLNUM18.5
                                                          informat = NLNUM18.5
                                                          label = "Return On Equity Amount",
         EXTERNAL_ORG_FINANCIAL_DATA.DEBT_SERVICE_COVERAGE_RT length = 8
                                                              format = NLNUM9.4
                                                              informat = NLNUM9.4
                                                              label = "Debt Service Coverage Ratio",
         EXTERNAL_ORG_FINANCIAL_DATA.AVG_DEBT_SERVICE_COVERAGE_RT length = 8
                                                                  format = NLNUM9.4
                                                                  informat = NLNUM9.4
                                                                  label = "Avg Debt Service Coverage Ratio",
         EXTERNAL_ORG_FINANCIAL_DATA.INTEREST_COVERAGE_RT length = 8
                                                          format = NLNUM9.4
                                                          informat = NLNUM9.4
                                                          label = "Interest Coverage Ratio",
         EXTERNAL_ORG_FINANCIAL_DATA.AVERAGE_INTEREST_COVERAGE_RT length = 8
                                                                  format = NLNUM9.4
                                                                  informat = NLNUM9.4
                                                                  label = "Average Interest Coverage Ratio",
         EXTERNAL_ORG_FINANCIAL_DATA.RENT_AMT length = 8
                                              format = NLNUM18.5
                                              informat = NLNUM18.5
                                              label = "Rent Amount",
         EXTERNAL_ORG_FINANCIAL_DATA.TOTAL_ASSETS_AMT length = 8
                                                      format = NLNUM18.5
                                                      informat = NLNUM18.5
                                                      label = "Total Assets Amount",
         EXTERNAL_ORG_FINANCIAL_DATA.FIXED_ASSETS_AMT length = 8
                                                      format = NLNUM18.5
                                                      informat = NLNUM18.5
                                                      label = "Fixed Assets Amount",
         EXTERNAL_ORG_FINANCIAL_DATA.CURRENT_ASSETS_AMT length = 8
                                                        format = NLNUM18.5
                                                        informat = NLNUM18.5
                                                        label = "Current Assets Amount",
         EXTERNAL_ORG_FINANCIAL_DATA.NET_TRADE_REC_AMT length = 8
                                                       format = NLNUM18.5
                                                       informat = NLNUM18.5
                                                       label = "Net Trade Receivables Amount",
         EXTERNAL_ORG_FINANCIAL_DATA.INVENTORY_AMT length = 8
                                                   format = NLNUM18.5
                                                   informat = NLNUM18.5
                                                   label = "Inventory Amount",
         EXTERNAL_ORG_FINANCIAL_DATA.OTHER_CURRENT_ASSETS_AMT length = 8
                                                              format = NLNUM18.5
                                                              informat = NLNUM18.5
                                                              label = "Other Current Assets Amount",
         EXTERNAL_ORG_FINANCIAL_DATA.MARKETABLE_SECURITIES_AMT length = 8
                                                               format = NLNUM18.5
                                                               informat = NLNUM18.5
                                                               label = "Marketable Securities Amount",
         EXTERNAL_ORG_FINANCIAL_DATA.ASSETS_SECURITIZED_AMT length = 8
                                                            format = NLNUM18.5
                                                            informat = NLNUM18.5
                                                            label = "Assets Securitized Amount",
         EXTERNAL_ORG_FINANCIAL_DATA.CASH_AND_BANK_BALANCES_AMT length = 8
                                                                format = NLNUM18.5
                                                                informat = NLNUM18.5
                                                                label = "Cash And Bank Balances Amount",
         EXTERNAL_ORG_FINANCIAL_DATA.INTANGIBLE_ASSETS_AMT length = 8
                                                           format = NLNUM18.5
                                                           informat = NLNUM18.5
                                                           label = "Intangible Assets Amount",
         EXTERNAL_ORG_FINANCIAL_DATA.REVALUATION_RESERVES_AMT length = 8
                                                              format = NLNUM18.5
                                                              informat = NLNUM18.5
                                                              label = "Revaluation Reserves Amount",
         EXTERNAL_ORG_FINANCIAL_DATA.OTHER_ASSETS_AMT length = 8
                                                      format = NLNUM18.5
                                                      informat = NLNUM18.5
                                                      label = "Other Assets Amount",
         EXTERNAL_ORG_FINANCIAL_DATA.TOTAL_LIABILITY_AMT length = 8
                                                         format = NLNUM18.5
                                                         informat = NLNUM18.5
                                                         label = "Total Liability Amount",
         EXTERNAL_ORG_FINANCIAL_DATA.TOTAL_DEBT_AMT length = 8
                                                    format = NLNUM18.5
                                                    informat = NLNUM18.5
                                                    label = "Total Debt Amount",
         EXTERNAL_ORG_FINANCIAL_DATA.LONG_TERM_DEBT_AMT length = 8
                                                        format = NLNUM18.5
                                                        informat = NLNUM18.5
                                                        label = "Long Term Debt Amount",
         EXTERNAL_ORG_FINANCIAL_DATA.LONG_TERM_DEBT_EXPO_AMT length = 8
                                                             format = NLNUM18.5
                                                             informat = NLNUM18.5
                                                             label = "Long Term Debt Exposure Amount",
         EXTERNAL_ORG_FINANCIAL_DATA.SHORT_TERM_DEBT_AMT length = 8
                                                         format = NLNUM18.5
                                                         informat = NLNUM18.5
                                                         label = "Short Term Debt Amount",
         EXTERNAL_ORG_FINANCIAL_DATA.SHORT_TERM_DEBT_EXPO_AMT length = 8
                                                              format = NLNUM18.5
                                                              informat = NLNUM18.5
                                                              label = "Short Term Debt Expo Amount",
         EXTERNAL_ORG_FINANCIAL_DATA.SECURED_DEBT_AMT length = 8
                                                      format = NLNUM18.5
                                                      informat = NLNUM18.5
                                                      label = "Secured Debt Amount",
         EXTERNAL_ORG_FINANCIAL_DATA.UNSECURED_DEBT_AMT length = 8
                                                        format = NLNUM18.5
                                                        informat = NLNUM18.5
                                                        label = "Unsecured Debt Amount",
         EXTERNAL_ORG_FINANCIAL_DATA.NOTES_PAYABLE_AMT length = 8
                                                       format = NLNUM18.5
                                                       informat = NLNUM18.5
                                                       label = "Notes Payable Amount",
         EXTERNAL_ORG_FINANCIAL_DATA.TRADE_PAYABLE_AMT length = 8
                                                       format = NLNUM18.5
                                                       informat = NLNUM18.5
                                                       label = "Trade Payable Amount",
         EXTERNAL_ORG_FINANCIAL_DATA.SHORT_TERM_PAYABLES_AMT length = 8
                                                             format = NLNUM18.5
                                                             informat = NLNUM18.5
                                                             label = "Short Term Payables Amount",
         EXTERNAL_ORG_FINANCIAL_DATA.CURRENT_LTD_AMT length = 8
                                                     format = NLNUM18.5
                                                     informat = NLNUM18.5
                                                     label = "Current Long Term Debt Amount",
         EXTERNAL_ORG_FINANCIAL_DATA.OTHER_CURRENT_LIABILITY_AMT length = 8
                                                                 format = NLNUM18.5
                                                                 informat = NLNUM18.5
                                                                 label = "Other Current Liability Amount",
         EXTERNAL_ORG_FINANCIAL_DATA.TOTAL_CURRENT_LIABILITY_AMT length = 8
                                                                 format = NLNUM18.5
                                                                 informat = NLNUM18.5
                                                                 label = "Total Current Liability Amount",
         EXTERNAL_ORG_FINANCIAL_DATA.OTHER_LIABILITY_AMT length = 8
                                                         format = NLNUM18.5
                                                         informat = NLNUM18.5
                                                         label = "Other Liability Amount",
         EXTERNAL_ORG_FINANCIAL_DATA.CONTINGENT_LIABILITIES_AMT length = 8
                                                                format = NLNUM18.5
                                                                informat = NLNUM18.5
                                                                label = "Contingent Liabilities Amount",
         EXTERNAL_ORG_FINANCIAL_DATA.TRADE_CREDITORS_AMT length = 8
                                                         format = NLNUM18.5
                                                         informat = NLNUM18.5
                                                         label = "Trade Creditors Amount",
         EXTERNAL_ORG_FINANCIAL_DATA.FOREIGN_CURR_EXPOS_TRANS_AMT length = 8
                                                                  format = NLNUM18.5
                                                                  informat = NLNUM18.5
                                                                  label = "Foreign Currency Exposure Amount",
         EXTERNAL_ORG_FINANCIAL_DATA.FOREIGN_CURR_TRANS_EXPOS_AMT length = 8
                                                                  format = NLNUM18.5
                                                                  informat = NLNUM18.5
                                                                  label = "Foreign Currency  Exposure Amount",
         EXTERNAL_ORG_FINANCIAL_DATA.FOREIGN_OTHER_EXPOS_AMT length = 8
                                                             format = NLNUM18.5
                                                             informat = NLNUM18.5
                                                             label = "Foreign Other Exposure Amount",
         EXTERNAL_ORG_FINANCIAL_DATA.CHARGED_OFF_AMT length = 8
                                                     format = NLNUM18.5
                                                     informat = NLNUM18.5
                                                     label = "Charge Off Amount",
         EXTERNAL_ORG_FINANCIAL_DATA.CURRENT_VALUE_SECURITY_AMT length = 8
                                                                format = NLNUM18.5
                                                                informat = NLNUM18.5
                                                                label = "Current Value Security Amount",
         EXTERNAL_ORG_FINANCIAL_DATA.NET_WORTH_AMT length = 8
                                                   format = NLNUM18.5
                                                   informat = NLNUM18.5
                                                   label = "Net Worth Amount",
         EXTERNAL_ORG_FINANCIAL_DATA.ADJUSTED_NET_WORTH_AMT length = 8
                                                            format = NLNUM18.5
                                                            informat = NLNUM18.5
                                                            label = "Adjusted Net Worth Amount",
         EXTERNAL_ORG_FINANCIAL_DATA.LIQUIDITY_RT length = 8
                                                  format = NLNUM9.4
                                                  informat = NLNUM9.4
                                                  label = "Liquidity Ratio",
         EXTERNAL_ORG_FINANCIAL_DATA.CURRENT_RT length = 8
                                                format = NLNUM9.4
                                                informat = NLNUM9.4
                                                label = "Current Ratio",
         EXTERNAL_ORG_FINANCIAL_DATA.TOTAL_EQUITY_NET_WORTH_AMT length = 8
                                                                format = NLNUM18.5
                                                                informat = NLNUM18.5
                                                                label = "Total Equity Net Worth Amount",
         EXTERNAL_ORG_FINANCIAL_DATA.RETAINED_EARNINGS_AMT length = 8
                                                           format = NLNUM18.5
                                                           informat = NLNUM18.5
                                                           label = "Retained Earnings Amount",
         EXTERNAL_ORG_FINANCIAL_DATA.ASSET_BETA_NO length = 8
                                                   label = "Asset Beta No",
         EXTERNAL_ORG_FINANCIAL_DATA.MARKET_CAPITALIZATION_AMT length = 8
                                                               format = NLNUM18.5
                                                               informat = NLNUM18.5
                                                               label = "Market Capitalization Amount",
         CASE symget('mEngine')
         	WHEN "ORACLE" THEN datepart(EXTERNAL_ORG_FINANCIAL_DATA.MARKET_CAPITALIZATION_DT)
         	ELSE EXTERNAL_ORG_FINANCIAL_DATA.MARKET_CAPITALIZATION_DT
         END as MARKET_CAPITALIZATION_DT length = 8
                                         format = NLDATE10.
                                         informat = NLDATE10.
                                         label = "Market Capitalization Date",
         EXTERNAL_ORG_FINANCIAL_DATA.DIVIDEND_PAYOUT_AMT length = 8
                                                         format = NLNUM18.5
                                                         informat = NLNUM18.5
                                                         label = "Dividend Payout Amount",
         EXTERNAL_ORG_FINANCIAL_DATA.DIVIDEND_PAYOUT_RATIO_PCT length = 8
                                                               format = NLNUM9.4
                                                               informat = NLNUM9.4
                                                               label = "Dividend Payout Ratio Percent",
         EXTERNAL_ORG_FINANCIAL_DATA.EARNINGS_PER_SHARE_AMT length = 8
                                                            format = NLNUM18.5
                                                            informat = NLNUM18.5
                                                            label = "Earnings Per Share Amount",
         EXTERNAL_ORG_FINANCIAL_DATA.PRICE_EARNINGS_RATIO_RT length = 8
                                                             format = NLNUM9.4
                                                             informat = NLNUM9.4
                                                             label = "Price Earnings Ratio Rate",
         EXTERNAL_ORG_FINANCIAL_DATA.DEBT_EQUITY_RT length = 8
                                                    format = NLNUM9.4
                                                    informat = NLNUM9.4
                                                    label = "Debt Equity Ratio",
         EXTERNAL_ORG_FINANCIAL_DATA.LT_DEBT_EQUITY_RT length = 8
                                                       format = NLNUM9.4
                                                       informat = NLNUM9.4
                                                       label = "Long Term Debt Equity Ratio",
         EXTERNAL_ORG_FINANCIAL_DATA.ST_DEBT_EQUITY_RT length = 8
                                                       format = NLNUM9.4
                                                       informat = NLNUM9.4
                                                       label = "Short Term Debt Equity Ratio",
         EXTERNAL_ORG_FINANCIAL_DATA.DAYS_PAYABLE_RT length = 8
                                                     format = NLNUM9.4
                                                     informat = NLNUM9.4
                                                     label = "Days Payable Ratio",
         EXTERNAL_ORG_FINANCIAL_DATA.DAYS_RECEIVABLE_RT length = 8
                                                        format = NLNUM9.4
                                                        informat = NLNUM9.4
                                                        label = "Days Receivable Ratio",
         EXTERNAL_ORG_FINANCIAL_DATA.DAYS_FINISHED_GOODS_INV_RT length = 8
                                                                format = NLNUM9.4
                                                                informat = NLNUM9.4
                                                                label = "Days Finished Goods Inventory Ratio",
         EXTERNAL_ORG_FINANCIAL_DATA.DAYS_WORK_IN_PROG_GOODS_RT length = 8
                                                                format = NLNUM9.4
                                                                informat = NLNUM9.4
                                                                label = "Days Work In Prog Goods Ratio",
         EXTERNAL_ORG_FINANCIAL_DATA.KNOWN_BANK_RELATIONS_CNT length = 8
                                                              label = "No of Known Bank Relations",
         EXTERNAL_ORG_FINANCIAL_DATA.CURRENCY_CD length = 3
                                                 label = "Currency Code",
         EXTERNAL_ORG_FINANCIAL_DATA.EQUITY_CAPITAL_AMT length = 8
                                                        format = NLNUM18.5
                                                        informat = NLNUM18.5
                                                        label = "Equity Capital Amount",
         EXTERNAL_ORG_FINANCIAL_DATA.CREDIT_BUREAU_SCORE_NO length = 8
                                                            label = "Credit Bureau Score No",
         CASE symget('mEngine')
         	WHEN "ORACLE" THEN datepart(EXTERNAL_ORG_FINANCIAL_DATA.CREDIT_BUREAU_SCORE_DT)
         	ELSE EXTERNAL_ORG_FINANCIAL_DATA.CREDIT_BUREAU_SCORE_DT
         END as CREDIT_BUREAU_SCORE_DT length = 8
                                       format = NLDATE10.
                                       informat = NLDATE10.
                                       label = "Credit Bureau Score Date",
         EXTERNAL_ORG_FINANCIAL_DATA.TAX_BRACKET_CD length = 3
                                                    label = "Tax Bracket Code",
         EXTERNAL_ORG_FINANCIAL_DATA.LIQUID_NET_WORTH_AMT length = 8
                                                          format = NLNUM18.5
                                                          informat = NLNUM18.5
                                                          label = "Liquid Net Worth Amount",
         CASE symget('mEngine')
         	WHEN "ORACLE" THEN datepart(EXTERNAL_ORG_FINANCIAL_DATA.BANKRUPTCY_FILED_DT)
         	ELSE EXTERNAL_ORG_FINANCIAL_DATA.BANKRUPTCY_FILED_DT
         END as BANKRUPTCY_FILED_DT length = 8
                                    format = NLDATE10.
                                    informat = NLDATE10.
                                    label = "Bankruptcy Filed Date",
         EXTERNAL_ORG_FINANCIAL_DATA.BANKRUPTCY_STATUS_CD length = 3
                                                          label = "Bankruptcy Status Code",
         CASE symget('mEngine')
         	WHEN "ORACLE" THEN datepart(EXTERNAL_ORG_FINANCIAL_DATA.REPORTED_ON_DT)
         	ELSE EXTERNAL_ORG_FINANCIAL_DATA.REPORTED_ON_DT
         END as REPORTED_ON_DT length = 8
                               format = NLDATE10.
                               informat = NLDATE10.
                               label = "REPORTED ON DATE",
         EXTERNAL_ORG_FINANCIAL_DATA.EFFECTIVE_FROM_DTTM length = 8
                                                         format = NLDATM21.
                                                         informat = NLDATM21.
                                                         label = "Effective From Datetime",
         EXTERNAL_ORG_FINANCIAL_DATA.EFFECTIVE_TO_DTTM length = 8
                                                       format = NLDATM21.
                                                       informat = NLDATM21.
                                                       label = "Effective To Datetime"
      from
         control.LOAD_CONTROL, 
         DDS.EXTERNAL_ORG_FINANCIAL_DATA
      where
         LOAD_CONTROL.LOAD_FLG IN (&CHECK_FLAG_TRUE)
         and LOAD_CONTROL.RUN_STATUS IN (&RUNNING_STATUS)
         and LOAD_CONTROL.LOAD_END_DTTM >= EXTERNAL_ORG_FINANCIAL_DATA.VALID_FROM_DTTM
         and LOAD_CONTROL.LOAD_END_DTTM <= EXTERNAL_ORG_FINANCIAL_DATA.VALID_TO_DTTM
      ;
quit;

%rcSet(&sqlrc); 

%macro etls_completeTarget();
%mend etls_completeTarget;
%etls_completeTarget;

/*============================================================================* 
 * Step:          Dummy Loader                              A5V75JN3.BO0006Z3 * 
 * Transform:     Table Loader                                                * 
 * Description:                                                               * 
 *                                                                            * 
 * Source Table:  SQL Target - martscr.EOFD_EXT             A5V75JN3.BP00066S * 
 * Target Table:  EOFD_EXT - martscr.EOFD_EXT               A5V75JN3.BE0000JG * 
 *============================================================================*
 *                                                                            * 
 * Nothing will be generated for this process because the "Do not generate    * 
 *  code for this process" option is selected.                                * 
 *                                                                            * 
 *============================================================================*/ 

data _null_; 
   call symput('etls_endTime',put(datetime(),datetime.));
run;

/* Check return code for job  */ 
%macro etls_jobRCChk; 
   %if (&job_rc eq 4) %then
   %do; 
      %on_success(Job_nm=&etls_jobName..sas, param_table=&status_table);
   %end; 
%mend etls_jobRCChk; 
%etls_jobRCChk; 

/* Check return code for job  */ 
%macro etls_jobRCChk; 
   %if (&job_rc ge 5) %then
   %do; 
      %on_success(Job_nm=&etls_jobName..sas, param_table=&status_table);
   %end; 
%mend etls_jobRCChk; 
%etls_jobRCChk; 

/* Check return code for job  */ 
%macro etls_jobRCChk; 
   %if (&job_rc eq 0) %then
   %do; 
      %on_success(Job_nm=&etls_jobName..sas, param_table=&status_table);
   %end; 
%mend etls_jobRCChk; 
%etls_jobRCChk; 

/*---- Job status macro  ----*/ 
/*============================================================================* 
 * Post-Process code for the job                            A5V75JN3.AY0004O5 * 
 *                                                                            * 
 * User Written:  Index creation  on                        A5V75JN3.AF000PQQ * 
 *                 EXTERNAL_ORG_RK,LOAD_END_DTTM column                       * 
 *                Index creation  on EXTERNAL_ORG_RK,LOAD_END_DTTM column     * 
 *============================================================================*/ 

/*---- Start of User Written Code  ----*/ 

/*creating index on EXTERNAL_ORG_RK & LOAD_END_DTTM column */
PROC SQL NOPRINT;
           CREATE INDEX EXTERNAL_ORG_RK_LOAD_END_DTTM
            ON martscr.EOFD_EXT(EXTERNAL_ORG_RK,LOAD_END_DTTM);
QUIT;
/*---- End of User Written Code  ----*/ 

%rcSet(&syserr); 
%rcSet(&sqlrc); 

