/****************************************************************************** 
 * Job:           FAC_EXT                                   A5V75JN3.BN00001N * 
 * Description:   This job picks up data from FINANCIAL_ACCOUNT_CHNG          * 
 *                                                                            * 
 * Repository:    Foundation                                A0000001.A5V75JN3 * 
 * Server:        SASMain                                   A5V75JN3.AT000001 * 
 *                                                                            * 
 * Source Tables: LOAD_CONTROL - control.LOAD_CONTROL       A5V75JN3.BE0000I0 * 
 *                FINANCIAL_ACCOUNT_CHNG -                  A5V75JN3.BE00002S * 
 *                 DDS.FINANCIAL_ACCOUNT_CHNG                                 * 
 * Target Table:  FAC_EXT - martscr.FAC_EXT                 A5V75JN3.BE0000JL * 
 *                                                                            * 
 * Generated on:  Wednesday, December 10, 2008 2:27:26 PM IST                 * 
 * Generated by:  sasadm                                                      * 
 * Version:       9.1.20060626.51875                                          * 
 ******************************************************************************
 * Notes:                                                                     * 
 * FAC_EXT                                                                    * 
 * Job Name: FAC_EXTJob Desc Pre Process: NoneMain:Extract and load data      * 
 * from FINANCIAL_ACCOUNT_CHNG using a SQL join with table LOAD_CONTROL       * 
 * based on conditionLOAD_CONTROL.LOAD_FLG = CHECK_FLAG_TRUE                  * 
 * andLOAD_CONTROL.RUN_STATUS = RUNNING_STATUS                                * 
 * andLOAD_CONTROL.LOAD_END_DTTM betweenVALID_FROM_DTTM and                   * 
 * VALID_TO_DTTMPost Process: Index is created                                * 
 * onACCOUNT_RK,LOAD_END_DTTMParameters: CHECK_FLAG_TRUE and RUNNING_STATUS   * 
 * are the user defined parameters. CHECK_FLAG_TRUE is set to 'Y' and         * 
 * RUNNING_STATUS is to 'Running' for each month of data load.Developed by:   * 
 *  sinahkReviewed by:Tested by:                                              * 
 ******************************************************************************/ 

/* Setup for capturing job status  */ 
data _null_; 
   call symput('etls_startTime',put(datetime(),datetime.));
run;

%let etls_jobName = FAC_EXT;
%let etls_recordsBefore = 0;
%let etls_recordsAfter = 0;
%let etls_lib = 0;
%let etls_table = 0;

/* Setup to capture return codes  */ 
%global job_rc trans_rc sqlrc; 
%let job_rc = 0;
%let trans_rc = 0;
%let sqlrc = 0;
%global syserr; 

%macro rcSet(error); 
   %if (&error gt &trans_rc) %then 
      %let trans_rc = &error;
   %if (&error gt &job_rc) %then 
      %let job_rc = &error;
%mend rcSet; 

%macro rcSetDS(error); 
   if &error gt input(symget('trans_rc'),12.) then 
      call symput('trans_rc',trim(left(put(&error,12.))));
   if &error gt input(symget('job_rc'),12.) then 
      call symput('job_rc',trim(left(put(&error,12.))));
%mend rcSetDS; 

%global etls_debug; 
%macro etls_setDebug; 
   %if %str(&etls_debug) ne 0 %then 
      OPTIONS MPRINT%str(;); 
%mend; 
%etls_setDebug; 

/*============================================================================* 
 * Pre-Process code for the job                             A5V75JN3.AY0004OC * 
 *                                                                            * 
 * User Written:  Oracle Date Problem Fix                   A5V75JN3.AF000PSY * 
 *                Oracle Date Problem Fix                                     * 
 *============================================================================*/ 

/*---- Start of User Written Code  ----*/ 

proc contents data=dds.financial_account_chng out=_etlsEngine(keep=Engine) noprint;
run;

data _null_;
	set _etlsEngine;
	if _n_=1;
	  call symput('mEngine', kleft(kright(Engine)));
run;
/*---- End of User Written Code  ----*/ 

%rcSet(&syserr); 
%rcSet(&sqlrc); 

/*============================================================================* 
 * Step:          Extracting and Loading of data as per the A5V75JN3.BO0006ZC * 
 *                 load period                                                * 
 * Transform:     SQL Join (Version 2)                                        * 
 * Description:   Join with LOAD_CONTROL table and extract appropriate data   * 
 *                 based  onVALID_FROM_DTTM and VALID_TO_DTTM                 * 
 *                                                                            * 
 * Source Tables: LOAD_CONTROL - control.LOAD_CONTROL       A5V75JN3.BE0000I0 * 
 *                FINANCIAL_ACCOUNT_CHNG -                  A5V75JN3.BE00002S * 
 *                 DDS.FINANCIAL_ACCOUNT_CHNG                                 * 
 * Target Table:  SQL Target - martscr.FAC_EXT              A5V75JN3.BP00066W * 
 *============================================================================*/ 

/* Access the data for Control  */ 
LIBNAME control BASE "Data/bisdata/control" ;
%rcSet(&syslibrc); 

/* Access the data for Detail Data Store  */ 
LIBNAME DDS BASE "Data/bisdata/dds" ;
%rcSet(&syslibrc); 

/* Access the data for Scratch for Mart  */ 
LIBNAME martscr BASE "Data/bisdata/scratch/mart" ;
%rcSet(&syslibrc); 

%let trans_rc = 0; 

proc datasets lib = martscr nolist nowarn memtype = (data view);
   delete FAC_EXT;
quit;

proc sql;
   create table martscr.FAC_EXT as
      select
         FINANCIAL_ACCOUNT_CHNG.ACCOUNT_RK length = 8
                                           format = 12.
                                           informat = 12.
                                           label = "Account Key",
         LOAD_CONTROL.LOAD_END_DTTM length = 8
                                    format = NLDATM21.
                                    informat = NLDATM21.
                                    label = "Load End Datetime",
         CASE symget('mEngine')
         	WHEN "ORACLE" THEN datepart(FINANCIAL_ACCOUNT_CHNG.STATEMENT_DT)
         	ELSE FINANCIAL_ACCOUNT_CHNG.STATEMENT_DT
         END as LAST_STATEMENT_DT length = 8
                                  format = NLDATE10.
                                  informat = NLDATE10.
                                  label = "Statement Date",
         FINANCIAL_ACCOUNT_CHNG.BILLED_AMT length = 8
                                           format = NLNUM18.5
                                           informat = NLNUM18.5
                                           label = "Billed Amount",
         FINANCIAL_ACCOUNT_CHNG.CURRENT_BILL_AMT length = 8
                                                 format = NLNUM18.5
                                                 informat = NLNUM18.5
                                                 label = "Current Bill Amount",
         FINANCIAL_ACCOUNT_CHNG.BALANCE_AMT length = 8
                                            format = NLNUM18.5
                                            informat = NLNUM18.5
                                            label = "Balance Amount",
         FINANCIAL_ACCOUNT_CHNG.INTEREST_BALANCE_AMT as INTEREST_EXPECTED_AMT length = 8
                                                                              format = NLNUM18.5
                                                                              informat = NLNUM18.5
                                                                              label = "Interest Balance Amount",
         FINANCIAL_ACCOUNT_CHNG.PRINCIPAL_BALANCE_AMT length = 8
                                                      format = NLNUM18.5
                                                      informat = NLNUM18.5
                                                      label = "Principal Balance Amount",
         FINANCIAL_ACCOUNT_CHNG.FEES_AMT length = 8
                                         format = NLNUM18.5
                                         informat = NLNUM18.5
                                         label = "Fees Amount",
         FINANCIAL_ACCOUNT_CHNG.PAST_DUE_AMT length = 8
                                             format = NLNUM18.5
                                             informat = NLNUM18.5
                                             label = "Past Due Amount",
         FINANCIAL_ACCOUNT_CHNG.DAYS_PAYMENT_PAST_DUE_CNT length = 8
                                                          label = "No of Days Payment Past Due",
         FINANCIAL_ACCOUNT_CHNG.TOTAL_BALANCE_AMT length = 8
                                                  format = NLNUM18.5
                                                  informat = NLNUM18.5
                                                  label = "Total Balance Amount",
         FINANCIAL_ACCOUNT_CHNG.AVG_DAILY_BALANCE_AMT as AVERAGE_DAILY_BALANCE_AMT length = 8
                                                                                   format = NLNUM18.5
                                                                                   informat = NLNUM18.5
                                                                                   label = "Average Daily Balance Amount",
         FINANCIAL_ACCOUNT_CHNG.MAX_ACCOUNT_VALUE_AMT length = 8
                                                      format = NLNUM18.5
                                                      informat = NLNUM18.5
                                                      label = "Maximum Account Value Amount",
         FINANCIAL_ACCOUNT_CHNG.MIN_ACCOUNT_VALUE_AMT length = 8
                                                      format = NLNUM18.5
                                                      informat = NLNUM18.5
                                                      label = "Minimum Account Value Amount",
         FINANCIAL_ACCOUNT_CHNG.MINIMUM_BILL_DUE_AMT as MIN_BILLING_AMT length = 8
                                                                        format = NLNUM18.5
                                                                        informat = NLNUM18.5
                                                                        label = "Minimum Due Amount",
         FINANCIAL_ACCOUNT_CHNG.LAST_PAYMENT_STATUS_CD length = 3
                                                       label = "Status of the last payment made by the customer. On time, late payment, differed payment, etc.",
         FINANCIAL_ACCOUNT_CHNG.CURTAILMENT_AMT length = 8
                                                format = NLNUM18.5
                                                informat = NLNUM18.5
                                                label = "Curtailment Amount"
      from
         control.LOAD_CONTROL, 
         DDS.FINANCIAL_ACCOUNT_CHNG
      where
         LOAD_CONTROL.LOAD_FLG IN (&CHECK_FLAG_TRUE)
         and LOAD_CONTROL.RUN_STATUS IN (&RUNNING_STATUS)
         and LOAD_CONTROL.LOAD_END_DTTM >= FINANCIAL_ACCOUNT_CHNG.VALID_FROM_DTTM
         and LOAD_CONTROL.LOAD_END_DTTM <= FINANCIAL_ACCOUNT_CHNG.VALID_TO_DTTM
      ;
quit;

%rcSet(&sqlrc); 

%macro etls_completeTarget();
   /*---- Create the integrity constraints for a table  ----*/ 
   %put %str(NOTE: Creating integrity constraints ...);
   proc datasets library=martscr nolist;
      modify FAC_EXT;
         ic create not null (ACCOUNT_RK);
         ic create not null (LOAD_END_DTTM);
   quit;
   
   %rcSet(&syserr); 
   
%mend etls_completeTarget;
%etls_completeTarget;

/*============================================================================* 
 * Step:          Dummy Loader                              A5V75JN3.BO0006ZB * 
 * Transform:     Table Loader                                                * 
 * Description:                                                               * 
 *                                                                            * 
 * Source Table:  SQL Target - martscr.FAC_EXT              A5V75JN3.BP00066W * 
 * Target Table:  FAC_EXT - martscr.FAC_EXT                 A5V75JN3.BE0000JL * 
 *============================================================================*
 *                                                                            * 
 * Nothing will be generated for this process because the "Do not generate    * 
 *  code for this process" option is selected.                                * 
 *                                                                            * 
 *============================================================================*/ 

data _null_; 
   call symput('etls_endTime',put(datetime(),datetime.));
run;

/* Check return code for job  */ 
%macro etls_jobRCChk; 
   %if (&job_rc eq 4) %then
   %do; 
      %on_success(Job_nm=&etls_jobName..sas, param_table=&status_table);
   %end; 
%mend etls_jobRCChk; 
%etls_jobRCChk; 

/* Check return code for job  */ 
%macro etls_jobRCChk; 
   %if (&job_rc ge 5) %then
   %do; 
      %on_success(Job_nm=&etls_jobName..sas, param_table=&status_table);
   %end; 
%mend etls_jobRCChk; 
%etls_jobRCChk; 

/* Check return code for job  */ 
%macro etls_jobRCChk; 
   %if (&job_rc eq 0) %then
   %do; 
      %on_success(Job_nm=&etls_jobName..sas, param_table=&status_table);
   %end; 
%mend etls_jobRCChk; 
%etls_jobRCChk; 

/*---- Job status macro  ----*/ 
/*============================================================================* 
 * Post-Process code for the job                            A5V75JN3.AY0004OD * 
 *                                                                            * 
 * User Written:  Index creation on ACCOUNT_RK &            A5V75JN3.AF000PSZ * 
 *                 LOAD_END_DTTM                                              * 
 *                Index creation on ACCOUNT_RK & LOAD_END_DTTM                * 
 *============================================================================*/ 

/*---- Start of User Written Code  ----*/ 

/*creating index on ACCOUNT_RK & LOAD_END_DTTM column */
PROC SQL NOPRINT;
     CREATE INDEX ACCOUNT_RK_LOAD_END_DTTM
      ON martscr.FAC_EXT(ACCOUNT_RK,LOAD_END_DTTM);
QUIT;
/*---- End of User Written Code  ----*/ 

%rcSet(&syserr); 
%rcSet(&sqlrc); 

