/****************************************************************************** 
 * Job:           FAR_EXT                                   A5V75JN3.BN00001P * 
 * Description:   This job picks up data from FINANCIAL_ACCOUNT_ROLE.         * 
 *                                                                            * 
 * Repository:    Foundation                                A0000001.A5V75JN3 * 
 * Server:        SASMain                                   A5V75JN3.AT000001 * 
 *                                                                            * 
 * Source Tables: LOAD_CONTROL - control.LOAD_CONTROL       A5V75JN3.BE0000I0 * 
 *                FINANCIAL_ACCOUNT_ROLE -                  A5V75JN3.BE00002X * 
 *                 DDS.FINANCIAL_ACCOUNT_ROLE                                 * 
 * Target Table:  FAR_EXT - martscr.FAR_EXT                 A5V75JN3.BE0000JN * 
 *                                                                            * 
 * Generated on:  Wednesday, December 10, 2008 2:28:34 PM IST                 * 
 * Generated by:  sasadm                                                      * 
 * Version:       9.1.20060626.51875                                          * 
 ******************************************************************************
 * Notes:                                                                     * 
 * FAR_EXT                                                                    * 
 * Job Name: FAR_EXTJob DescPre Process: NoneMain:Extract and load data from  * 
 * FINANCIAL_ACCOUNT_ROLE using a SQL join with table LOAD_CONTROL based on   * 
 * conditionLOAD_CONTROL.LOAD_FLG = CHECK_FLAG_TRUE                           * 
 * andLOAD_CONTROL.RUN_STATUS = RUNNING_STATUS                                * 
 * andLOAD_CONTROL.LOAD_END_DTTM betweenVALID_FROM_DTTM and                   * 
 * VALID_TO_DTTMPost Process: Index is created                                * 
 * onFAR_EXT.ACCOUNT_RK,FAR_EXT.LOAD_END_DTTMParameters: CHECK_FLAG_TRUE      * 
 * and RUNNING_STATUS are the user defined parameters. CHECK_FLAG_TRUE is     * 
 * set to 'Y' and RUNNING_STATUS is to 'Running' for each month of data       * 
 *  load.Developed by: sinahkReviewed by:Tested by:                           * 
 ******************************************************************************/ 



%let jobID = %quote(A5V75JN3.BN00001P);

/* Setup for capturing job status  */ 
data _null_; 
   call symput('etls_startTime',put(datetime(),datetime.));
run;

%let etls_jobName = FAR_EXT;
%let etls_recordsBefore = 0;
%let etls_recordsAfter = 0;
%let etls_lib = 0;
%let etls_table = 0;

/* Setup to capture return codes  */ 
%global job_rc trans_rc sqlrc; 
%let job_rc = 0;
%let trans_rc = 0;
%let sqlrc = 0;
%global syserr; 

%macro rcSet(error); 
   %if (&error gt &trans_rc) %then 
      %let trans_rc = &error;
   %if (&error gt &job_rc) %then 
      %let job_rc = &error;
%mend rcSet; 

%macro rcSetDS(error); 
   if &error gt input(symget('trans_rc'),12.) then 
      call symput('trans_rc',trim(left(put(&error,12.))));
   if &error gt input(symget('job_rc'),12.) then 
      call symput('job_rc',trim(left(put(&error,12.))));
%mend rcSetDS; 

%global etls_debug; 
%macro etls_setDebug; 
   %if %str(&etls_debug) ne 0 %then 
      OPTIONS MPRINT%str(;); 
%mend; 
%etls_setDebug; 

/*============================================================================* 
 * Pre-Process code for the job                             A5V75JN3.AY0004OE * 
 *                                                                            * 
 * User Written:  Oracle Date Problem Fix                   A5V75JN3.AF000PTE * 
 *                Oracle Date Problem Fix                                     * 
 *============================================================================*/ 

/*---- Start of User Written Code  ----*/ 

proc contents data=dds.financial_account_role out=_etlsEngine(keep=Engine) noprint;
run;

data _null_;
	set _etlsEngine;
	if _n_=1;
	  call symput('mEngine', kleft(kright(Engine)));
run;
/*---- End of User Written Code  ----*/ 

%rcSet(&syserr); 
%rcSet(&sqlrc); 

/*============================================================================* 
 * Step:          Extracting and Loading of data as per the A5V75JN3.BO0006ZE * 
 *                 load period                                                * 
 * Transform:     SQL Join (Version 2)                                        * 
 * Description:   Join with LOAD_CONTROL table and extract appropriate data   * 
 *                 based  onVALID_FROM_DTTM and VALID_TO_DTTM                 * 
 *                                                                            * 
 * Source Tables: LOAD_CONTROL - control.LOAD_CONTROL       A5V75JN3.BE0000I0 * 
 *                FINANCIAL_ACCOUNT_ROLE -                  A5V75JN3.BE00002X * 
 *                 DDS.FINANCIAL_ACCOUNT_ROLE                                 * 
 * Target Table:  Extract Target - martscr.FAR_EXT          A5V75JN3.BP00066X * 
 *============================================================================*/ 

/* Access the data for Control  */ 
LIBNAME control BASE "Data/bisdata/control" ;
%rcSet(&syslibrc); 

/* Access the data for Detail Data Store  */ 
LIBNAME DDS BASE "Data/bisdata/dds" ;
%rcSet(&syslibrc); 

/* Access the data for Scratch for Mart  */ 
LIBNAME martscr BASE "Data/bisdata/scratch/mart" ;
%rcSet(&syslibrc); 

%let transformID = %quote(A5V75JN3.BO0006ZE); 

%let trans_rc = 0; 

proc datasets lib = martscr nolist nowarn memtype = (data view);
   delete FAR_EXT;
quit;

proc sql;
   create table martscr.FAR_EXT as
      select
         LOAD_CONTROL.LOAD_END_DTTM length = 8
                                    format = NLDATM21.
                                    informat = NLDATM21.
                                    label = "Load End Datetime",
         FINANCIAL_ACCOUNT_ROLE.FINANCIAL_ACCOUNT_ROLE_RK length = 8
                                                          format = 12.
                                                          informat = 12.
                                                          label = "Financial Account Role Key",
         FINANCIAL_ACCOUNT_ROLE.FINANCIAL_ACCOUNT_ROLE_ID length = 32
                                                          label = "Financial Account Role Id",
         FINANCIAL_ACCOUNT_ROLE.ACCOUNT_RK length = 8
                                           format = 12.
                                           informat = 12.
                                           label = "Account Key",
         FINANCIAL_ACCOUNT_ROLE.RELATIONSHIP_TO_ACCOUNT_CD length = 3
                                                           label = "Relationship To Account Code",
         FINANCIAL_ACCOUNT_ROLE.FIRST_NM length = 40
                                         label = "First Name",
         FINANCIAL_ACCOUNT_ROLE.MIDDLE_NM length = 40
                                          label = "Middle Name",
         FINANCIAL_ACCOUNT_ROLE.LAST_NM length = 40
                                        label = "Last Name",
         CASE symget('mEngine') 
         	WHEN "ORACLE" THEN datepart(FINANCIAL_ACCOUNT_ROLE.BIRTH_DT) 
         	ELSE FINANCIAL_ACCOUNT_ROLE.BIRTH_DT 
         END as BIRTH_DT length = 8
                         format = NLDATE10.
                         informat = NLDATE10.
                         label = "Birth Date",
         FINANCIAL_ACCOUNT_ROLE.STD_OCCUPATION_CD length = 3
                                                  label = "Std Occupation Code",
         FINANCIAL_ACCOUNT_ROLE.PASSPORT_NO length = 32
                                            label = "Passport No",
         FINANCIAL_ACCOUNT_ROLE.PRIMARY_EMPLOYER_NM length = 100
                                                    label = "Primary Employer Name",
         FINANCIAL_ACCOUNT_ROLE.PRIMARY_EMPLOYER_PHONE_NO length = 20
                                                          label = "Primary Employer Phone No",
         FINANCIAL_ACCOUNT_ROLE.ANNUAL_INCOME_AMT length = 8
                                                  format = NLNUM18.5
                                                  informat = NLNUM18.5
                                                  label = "Annual Income Amount",
         FINANCIAL_ACCOUNT_ROLE.TAX_ID length = 32
                                       label = "Tax Id",
         FINANCIAL_ACCOUNT_ROLE.TAX_ID_TYPE_CD length = 3
                                               label = "Tax Id Type Code",
         FINANCIAL_ACCOUNT_ROLE.DRIVER_LICENSE_ID length = 32
                                                  label = "Driver License Id",
         FINANCIAL_ACCOUNT_ROLE.COUNTRY_OF_RESIDENCY_CD length = 3
                                                        label = "Country Of Residency Code",
         FINANCIAL_ACCOUNT_ROLE.PRIMARY_CITIZENSHIP_COUNTRY_CD length = 3
                                                               label = "Primary Citizenship Country Code",
         FINANCIAL_ACCOUNT_ROLE.COUNTRY_CD length = 3
                                           label = "Country Code",
         FINANCIAL_ACCOUNT_ROLE.HOME_PHONE_NO length = 20
                                              label = "Home Phone No",
         FINANCIAL_ACCOUNT_ROLE.DAYTIME_PHONE_NO length = 20
                                                 label = "Daytime Phone No",
         FINANCIAL_ACCOUNT_ROLE.INDIVIDUAL_ORG_FLG length = 1
                                                   label = "Individual Organization Flag",
         FINANCIAL_ACCOUNT_ROLE.EXTERNAL_ORG_RK length = 8
                                                format = 12.
                                                informat = 12.
                                                label = "External Organization",
         FINANCIAL_ACCOUNT_ROLE.EMPLOYER_RK length = 8
                                            format = 12.
                                            informat = 12.
                                            label = "External Organization",
         FINANCIAL_ACCOUNT_ROLE.EMPLOYEE_RK length = 8
                                            format = 12.
                                            informat = 12.
                                            label = "Employee Retained Key",
         FINANCIAL_ACCOUNT_ROLE.MARITAL_STATUS_CD length = 3
                                                  label = "Marital Status Code",
         FINANCIAL_ACCOUNT_ROLE.POLITICALLY_EXPOSED_FLG length = 1
                                                        label = "Politically Exposed Flag",
         CASE symget('mEngine')
         	WHEN "ORACLE" THEN datepart(FINANCIAL_ACCOUNT_ROLE.LAST_SUSP_ACTV_REPORT_DT)
         	ELSE FINANCIAL_ACCOUNT_ROLE.LAST_SUSP_ACTV_REPORT_DT
         END as LAST_SUSP_ACTV_REPORT_DT length = 8
                                         format = NLDATE10.
                                         informat = NLDATE10.
                                         label = "Last Suspicious Activity Report Date",
         FINANCIAL_ACCOUNT_ROLE.EMAIL_ADDRESS_TXT length = 100
                                                  label = "Email Address",
         FINANCIAL_ACCOUNT_ROLE.NET_WORTH_AT_APPLICATION_AMT length = 8
                                                             format = NLNUM18.5
                                                             informat = NLNUM18.5
                                                             label = "Net Worth Amount At Application",
         FINANCIAL_ACCOUNT_ROLE.SOURCE_SYSTEM_CD length = 3
                                                 label = "Source System Code"
      from
         control.LOAD_CONTROL, 
         DDS.FINANCIAL_ACCOUNT_ROLE
      where
         LOAD_CONTROL.LOAD_FLG IN (&CHECK_FLAG_TRUE)
         and LOAD_CONTROL.RUN_STATUS IN (&RUNNING_STATUS)
         and LOAD_CONTROL.LOAD_END_DTTM >= FINANCIAL_ACCOUNT_ROLE.VALID_FROM_DTTM
         and LOAD_CONTROL.LOAD_END_DTTM <= FINANCIAL_ACCOUNT_ROLE.VALID_TO_DTTM
      ;
quit;

%rcSet(&sqlrc); 

%macro etls_completeTarget();
   /*---- Create the integrity constraints for a table  ----*/ 
   %put %str(NOTE: Creating integrity constraints ...);
   proc datasets library=martscr nolist;
      modify FAR_EXT;
         ic create not null (ACCOUNT_RK);
   quit;
   
   %rcSet(&syserr); 
   
%mend etls_completeTarget;
%etls_completeTarget;

/*============================================================================* 
 * Step:          Dummy Loader                              A5V75JN3.BO0006ZD * 
 * Transform:     Table Loader                                                * 
 * Description:                                                               * 
 *                                                                            * 
 * Source Table:  Extract Target - martscr.FAR_EXT          A5V75JN3.BP00066X * 
 * Target Table:  FAR_EXT - martscr.FAR_EXT                 A5V75JN3.BE0000JN * 
 *============================================================================*
 *                                                                            * 
 * Nothing will be generated for this process because the "Do not generate    * 
 *  code for this process" option is selected.                                * 
 *                                                                            * 
 *============================================================================*/ 

data _null_; 
   call symput('etls_endTime',put(datetime(),datetime.));
run;

/* Check return code for job  */ 
%macro etls_jobRCChk; 
   %if (&job_rc eq 4) %then
   %do; 
      %on_success(Job_nm=&etls_jobName..sas, param_table=&status_table);
   %end; 
%mend etls_jobRCChk; 
%etls_jobRCChk; 

/* Check return code for job  */ 
%macro etls_jobRCChk; 
   %if (&job_rc ge 5) %then
   %do; 
      %on_success(Job_nm=&etls_jobName..sas, param_table=&status_table);
   %end; 
%mend etls_jobRCChk; 
%etls_jobRCChk; 

/* Check return code for job  */ 
%macro etls_jobRCChk; 
   %if (&job_rc eq 0) %then
   %do; 
      %on_success(Job_nm=&etls_jobName..sas, param_table=&status_table);
   %end; 
%mend etls_jobRCChk; 
%etls_jobRCChk; 

/*---- Job status macro  ----*/ 
/*============================================================================* 
 * Post-Process code for the job                            A5V75JN3.AY0004OF * 
 *                                                                            * 
 * User Written:  Index creation code on ACCOUNT_RK &       A5V75JN3.AF000PTF * 
 *                 LOAD_END_DTTM                                              * 
 *                Index creation code on ACCOUNT_RK & LOAD_END_DTTM           * 
 *============================================================================*/ 

/*---- Start of User Written Code  ----*/ 

/*creating index on ACCOUNT_RK & LOAD_END_DTTM column */
PROC SQL NOPRINT;
           CREATE INDEX ACCOUNT_RK_LOAD_END_DTTM
            ON martscr.FAR_EXT(ACCOUNT_RK,LOAD_END_DTTM);
           
QUIT;
/*---- End of User Written Code  ----*/ 

%rcSet(&syserr); 
%rcSet(&sqlrc); 

