/****************************************************************************** 
 * Job:           FA_APP_FOR_DIM_EXT                        A5V75JN3.BN00001K * 
 * Description:   This job picks up data from FINANCIAL_ACCOUNT_APPLICATION   * 
 *                based on the PROCESSED_DTTM. This job is not to be          * 
 *                 considered as other extract jobs.                          * 
 *                                                                            * 
 * Repository:    Foundation                                A0000001.A5V75JN3 * 
 * Server:        SASMain                                   A5V75JN3.AT000001 * 
 *                                                                            * 
 * Source Tables: LOAD_CONTROL - control.LOAD_CONTROL       A5V75JN3.BE0000I0 * 
 *                FINANCIAL_ACCOUNT_APPLICATION -           A5V75JN3.BE00002R * 
 *                 DDS.FINANCIAL_ACCOUNT_APPLICATION                          * 
 * Target Table:  FA_APP_FOR_DIM_EXT -                      A5V75JN3.BE0000JI * 
 *                 martscr.FA_APP_FOR_DIM_EXT                                 * 
 *                                                                            * 
 * Generated on:  Wednesday, December 10, 2008 2:12:06 PM IST                 * 
 * Generated by:  sasadm                                                      * 
 * Version:       9.1.20060626.51875                                          * 
 ******************************************************************************
 * Notes:                                                                     * 
 * FA_APP_FOR_DIM_EXT                                                         * 
 * Job Name: FA_APP_FOR_DIM_EXTJob Desc Pre Process: NoneMain:Extract and     * 
 * load data from FINANCIAL_ACCOUNT_APPLICATION using a SQL join with table   * 
 * LOAD_CONTROL based on conditionLOAD_CONTROL.LOAD_FLG = CHECK_FLAG_TRUE     * 
 * andLOAD_CONTROL.RUN_STATUS = RUNNING_STATUS andPROCESSED_DTTM >=           * 
 * LOAD_CONTROL.LOAD_START_DTTM andPROCESSED_DTTM <=                          * 
 * LOAD_CONTROL.LOAD_END_DTTMPost Process: Index is created                   * 
 * onAPPLICATION_RK,LOAD_END_DTTMParameters: CHECK_FLAG_TRUE and              * 
 * RUNNING_STATUS are the user defined parameters. CHECK_FLAG_TRUE is set     * 
 * to 'Y' and RUNNING_STATUS is to 'Running' for each month of data           * 
 *  load.Developed by: sinahkReviewed by:Tested by:                           * 
 ******************************************************************************/ 



%let jobID = %quote(A5V75JN3.BN00001K);

/* Setup for capturing job status  */ 
data _null_; 
   call symput('etls_startTime',put(datetime(),datetime.));
run;

%let etls_jobName = FA_APP_FOR_DIM_EXT;
%let etls_recordsBefore = 0;
%let etls_recordsAfter = 0;
%let etls_lib = 0;
%let etls_table = 0;

/* Setup to capture return codes  */ 
%global job_rc trans_rc sqlrc; 
%let job_rc = 0;
%let trans_rc = 0;
%let sqlrc = 0;
%global syserr; 

%macro rcSet(error); 
   %if (&error gt &trans_rc) %then 
      %let trans_rc = &error;
   %if (&error gt &job_rc) %then 
      %let job_rc = &error;
%mend rcSet; 

%macro rcSetDS(error); 
   if &error gt input(symget('trans_rc'),12.) then 
      call symput('trans_rc',trim(left(put(&error,12.))));
   if &error gt input(symget('job_rc'),12.) then 
      call symput('job_rc',trim(left(put(&error,12.))));
%mend rcSetDS; 

%global etls_debug; 
%macro etls_setDebug; 
   %if %str(&etls_debug) ne 0 %then 
      OPTIONS MPRINT%str(;); 
%mend; 
%etls_setDebug; 

/*============================================================================* 
 * Pre-Process code for the job                             A5V75JN3.AY0004O6 * 
 *                                                                            * 
 * User Written:  Oracle Date Problem Fix                   A5V75JN3.AF000PR7 * 
 *                Oracle Date Problem Fix                                     * 
 *============================================================================*/ 

/*---- Start of User Written Code  ----*/ 

proc contents data=dds.FINANCIAL_ACCOUNT_APPLICATION out=_etlsEngine(keep=Engine) noprint;
run;

data _null_;
	set _etlsEngine;
	if _n_=1;
	  call symput('mEngine', kleft(kright(Engine)));
run;
/*---- End of User Written Code  ----*/ 

%rcSet(&syserr); 
%rcSet(&sqlrc); 

/*============================================================================* 
 * Step:          Extracting and Loading of data as per the A5V75JN3.BO0006Z6 * 
 *                 load period                                                * 
 * Transform:     SQL Join (Version 2)                                        * 
 * Description:   Extract and load data based on load period mentioned in     * 
 *                 LOAD_CONTROL table                                         * 
 *                                                                            * 
 * Source Tables: LOAD_CONTROL - control.LOAD_CONTROL       A5V75JN3.BE0000I0 * 
 *                FINANCIAL_ACCOUNT_APPLICATION -           A5V75JN3.BE00002R * 
 *                 DDS.FINANCIAL_ACCOUNT_APPLICATION                          * 
 * Target Table:  SQL Target - martscr.FA_APP_FOR_DIM_EXT   A5V75JN3.BP00066T * 
 *============================================================================*/ 

/* Access the data for Control  */ 
LIBNAME control BASE "Data/bisdata/control" ;
%rcSet(&syslibrc); 

/* Access the data for Detail Data Store  */ 
LIBNAME DDS BASE "Data/bisdata/dds" ;
%rcSet(&syslibrc); 

/* Access the data for Scratch for Mart  */ 
LIBNAME martscr BASE "Data/bisdata/scratch/mart" ;
%rcSet(&syslibrc); 

%let transformID = %quote(A5V75JN3.BO0006Z6); 

%let trans_rc = 0; 

proc datasets lib = martscr nolist nowarn memtype = (data view);
   delete FA_APP_FOR_DIM_EXT;
quit;

proc sql;
   create table martscr.FA_APP_FOR_DIM_EXT as
      select
         CASE symget('mEngine')
         	WHEN "ORACLE" THEN datepart(FINANCIAL_ACCOUNT_APPLICATION.APPLICATION_DT)
         	ELSE FINANCIAL_ACCOUNT_APPLICATION.APPLICATION_DT
         END as APPLICATION_DT length = 8
                               format = NLDATE10.
                               informat = NLDATE10.
                               label = "Application Date",
         FINANCIAL_ACCOUNT_APPLICATION.FINANCIAL_APPLICATION_ID as APPLICATION_ID length = 32
                                                                                  label = "Financial Application Id",
         FINANCIAL_ACCOUNT_APPLICATION.FINANCIAL_APPLICATION_RK as APPLICATION_RK length = 8
                                                                                  format = 12.
                                                                                  informat = 12.
                                                                                  label = "Financial Application Key",
         FINANCIAL_ACCOUNT_APPLICATION.APPLIED_AMT length = 8
                                                   format = NLNUM18.5
                                                   informat = NLNUM18.5
                                                   label = "Applied Amount",
         FINANCIAL_ACCOUNT_APPLICATION.BORROWED_DOWNPAYMENT_FLG length = 1
                                                                label = "Borrowed Downpayment Flag",
         FINANCIAL_ACCOUNT_APPLICATION.BORROWED_DOWNPAYMENT_PCT length = 8
                                                                format = NLNUM9.4
                                                                informat = NLNUM9.4
                                                                label = "Borrowed Downpayment Percent",
         FINANCIAL_ACCOUNT_APPLICATION.CHANNEL_CD length = 3
                                                  label = "Channel Code",
         CASE symget('mEngine') 	
         	WHEN "ORACLE" THEN datepart(FINANCIAL_ACCOUNT_APPLICATION.CLLTRL_INS_END_DT)
         	ELSE FINANCIAL_ACCOUNT_APPLICATION.CLLTRL_INS_END_DT
         END as CLLTRL_INS_END_DT length = 8
                                  format = NLDATE10.
                                  informat = NLDATE10.
                                  label = "Collateranl Insurance End Date",
         CASE symget('mEngine') 	
         	WHEN "ORACLE" THEN datepart(FINANCIAL_ACCOUNT_APPLICATION.CLLTRL_INS_START_DT)
         	ELSE  FINANCIAL_ACCOUNT_APPLICATION.CLLTRL_INS_START_DT
         END as CLLTRL_INS_START_DT length = 8
                                    format = NLDATE10.
                                    informat = NLDATE10.
                                    label = "Collateral Insurance Start Date",
         FINANCIAL_ACCOUNT_APPLICATION.CLLTRL_MTHLY_INS_PREM_AMT length = 8
                                                                 format = NLNUM18.5
                                                                 informat = NLNUM18.5
                                                                 label = "Collateral Monthly Insurance Premium Amount",
         FINANCIAL_ACCOUNT_APPLICATION.CLLTRL_ONE_TIME_INS_PREM_AMT length = 8
                                                                    format = NLNUM18.5
                                                                    informat = NLNUM18.5
                                                                    label = "Collateral One Time Insurance Premium Amount",
         FINANCIAL_ACCOUNT_APPLICATION.EXTERNAL_BANK_CREDIT_AMT as COLLATERAL_AMT length = 8
                                                                                  format = NLNUM18.5
                                                                                  informat = NLNUM18.5
                                                                                  label = "Collateral Amount",
         FINANCIAL_ACCOUNT_APPLICATION.COLLATERAL_CD length = 3
                                                     label = "Collateral Code",
         FINANCIAL_ACCOUNT_APPLICATION.CREDIT_CARD_CONSOLIDATION_AMT length = 8
                                                                     format = NLNUM18.5
                                                                     informat = NLNUM18.5
                                                                     label = "Credit Card Consolidation Amount",
         FINANCIAL_ACCOUNT_APPLICATION.CREDIT_CARD_CONSOLIDATION_CNT length = 8
                                                                     label = "Credit Card Consolidation Count",
         FINANCIAL_ACCOUNT_APPLICATION.CUSTOMER_TYPE_CD length = 3
                                                        label = "Customer Type Code",
         FINANCIAL_ACCOUNT_APPLICATION.DECISION_CD length = 3
                                                   label = "Decision Code",
         FINANCIAL_ACCOUNT_APPLICATION.DECISION_OVERRIDE_FLG length = 1
                                                             label = "Decision Override Flag",
         FINANCIAL_ACCOUNT_APPLICATION.CORPORATE_APPLN_RK as EXTERNAL_ORG_RK length = 8
                                                                             format = 12.
                                                                             informat = 12.
                                                                             label = "External Organization",
         FINANCIAL_ACCOUNT_APPLICATION.FORECLOSED_FLG length = 1
                                                      label = "Foreclosed Flag",
         FINANCIAL_ACCOUNT_APPLICATION.LINKED_ACCOUNT_FLG length = 1
                                                          label = "Linked Account Flag",
         FINANCIAL_ACCOUNT_APPLICATION.LINKED_DEPOSIT_ACCOUNT_FLG length = 1
                                                                  label = "Linked Deposit Account Flag",
         LOAD_CONTROL.LOAD_END_DTTM length = 8
                                    format = NLDATM21.
                                    informat = NLDATM21.
                                    label = "Load End Datetime",
         FINANCIAL_ACCOUNT_APPLICATION.LOAN_CONSOLIDATION_AMT length = 8
                                                              format = NLNUM18.5
                                                              informat = NLNUM18.5
                                                              label = "Loan Consolidation Amount",
         FINANCIAL_ACCOUNT_APPLICATION.LOAN_CONSOLIDATION_CNT length = 8
                                                              label = "Loan Consolidation Count",
         FINANCIAL_ACCOUNT_APPLICATION.LOAN_SECURED_FLG length = 1
                                                        label = "Loan Secured Flag",
         FINANCIAL_ACCOUNT_APPLICATION.LOAN_TERM_MTHS_CNT length = 8
                                                          label = "Loan Term in Months",
         FINANCIAL_ACCOUNT_APPLICATION.MORTGAGE_CONSOLIDATION_AMT length = 8
                                                                  format = NLNUM18.5
                                                                  informat = NLNUM18.5
                                                                  label = "Mortgage Consolidation Amount",
         FINANCIAL_ACCOUNT_APPLICATION.MORTGAGE_CONSOLIDATION_CNT length = 8
                                                                  label = "Mortgage Consolidation Count",
         FINANCIAL_ACCOUNT_APPLICATION.OUTCOME_CD length = 3
                                                  label = "Outcome Code",
         CASE symget('mEngine')
         	WHEN "ORACLE" THEN datepart(FINANCIAL_ACCOUNT_APPLICATION.OUTCOME_DT)
         	ELSE FINANCIAL_ACCOUNT_APPLICATION.OUTCOME_DT
         END as OUTCOME_DT length = 8
                           format = NLDATE10.
                           informat = NLDATE10.
                           label = "Outcome Date",
         FINANCIAL_ACCOUNT_APPLICATION.OVERRIDE_REASON_CD length = 3
                                                          label = "Override Reason Code",
         FINANCIAL_ACCOUNT_APPLICATION.PRIOR_MORTGAGE_CNT length = 8
                                                          label = "Prior Mortgage Count",
         FINANCIAL_ACCOUNT_APPLICATION.PROCESSING_CHARGES_AMT length = 8
                                                              format = NLNUM18.5
                                                              informat = NLNUM18.5
                                                              label = "Processing Charges Amount",
         FINANCIAL_ACCOUNT_APPLICATION.PRODUCT_RK length = 8
                                                  format = 12.
                                                  informat = 12.
                                                  label = "Product Key",
         FINANCIAL_ACCOUNT_APPLICATION.PURPOSE_CD length = 3
                                                  label = "Purpose Code",
         FINANCIAL_ACCOUNT_APPLICATION.SAVINGS_IN_CONSOLIDATION_AMT length = 8
                                                                    format = NLNUM18.5
                                                                    informat = NLNUM18.5
                                                                    label = "Savings in Consolidation Amount",
         FINANCIAL_ACCOUNT_APPLICATION.SOURCE_CD length = 5
                                                 label = "Source Code",
         FINANCIAL_ACCOUNT_APPLICATION.SOURCE_SYSTEM_CD length = 3
                                                        label = "Source System Code"
      from
         control.LOAD_CONTROL, 
         DDS.FINANCIAL_ACCOUNT_APPLICATION
      where
         LOAD_CONTROL.LOAD_FLG IN (&CHECK_FLAG_TRUE)
         and LOAD_CONTROL.RUN_STATUS IN (&RUNNING_STATUS)
         and FINANCIAL_ACCOUNT_APPLICATION.PROCESSED_DTTM >= LOAD_CONTROL.LOAD_START_DTTM
         and FINANCIAL_ACCOUNT_APPLICATION.PROCESSED_DTTM <= LOAD_CONTROL.LOAD_END_DTTM
      ;
quit;

%rcSet(&sqlrc); 

%macro etls_completeTarget();
   /*---- Create the integrity constraints for a table  ----*/ 
   %put %str(NOTE: Creating integrity constraints ...);
   proc datasets library=martscr nolist;
      modify FA_APP_FOR_DIM_EXT;
         ic create not null (APPLICATION_ID);
   quit;
   
   %rcSet(&syserr); 
   
%mend etls_completeTarget;
%etls_completeTarget;

/*============================================================================* 
 * Step:          Dummy Loader                              A5V75JN3.BO0006Z5 * 
 * Transform:     Table Loader (Version 2)                                    * 
 * Description:                                                               * 
 *                                                                            * 
 * Source Table:  SQL Target - martscr.FA_APP_FOR_DIM_EXT   A5V75JN3.BP00066T * 
 * Target Table:  FA_APP_FOR_DIM_EXT -                      A5V75JN3.BE0000JI * 
 *                 martscr.FA_APP_FOR_DIM_EXT                                 * 
 *============================================================================*
 *                                                                            * 
 * Nothing will be generated for this process because the "Do not generate    * 
 *  code for this process" option is selected.                                * 
 *                                                                            * 
 *============================================================================*/ 

data _null_; 
   call symput('etls_endTime',put(datetime(),datetime.));
run;

/* Check return code for job  */ 
%macro etls_jobRCChk; 
   %if (&job_rc eq 4) %then
   %do; 
      %on_success(Job_nm=&etls_jobName..sas, param_table=&status_table);
   %end; 
%mend etls_jobRCChk; 
%etls_jobRCChk; 

/* Check return code for job  */ 
%macro etls_jobRCChk; 
   %if (&job_rc ge 5) %then
   %do; 
      %on_success(Job_nm=&etls_jobName..sas, param_table=&status_table);
   %end; 
%mend etls_jobRCChk; 
%etls_jobRCChk; 

/* Check return code for job  */ 
%macro etls_jobRCChk; 
   %if (&job_rc eq 0) %then
   %do; 
      %on_success(Job_nm=&etls_jobName..sas, param_table=&status_table);
   %end; 
%mend etls_jobRCChk; 
%etls_jobRCChk; 

/*---- Job status macro  ----*/ 
/*============================================================================* 
 * Post-Process code for the job                            A5V75JN3.AY0004O7 * 
 *                                                                            * 
 * User Written:  Index creation on APPLICATION_RK &        A5V75JN3.AF000PR8 * 
 *                 LOAD_END_DTTM column                                       * 
 *                Index creation on APPLICATION_RK & LOAD_END_DTTM column     * 
 *============================================================================*/ 

/*---- Start of User Written Code  ----*/ 

/*creating index on APPLICATION_RK & LOAD_END_DTTM column */
PROC SQL NOPRINT;
     CREATE INDEX APPLICATION_RK_LOAD_END_DTTM
      ON martscr.FA_APP_FOR_DIM_EXT(APPLICATION_RK,LOAD_END_DTTM);
QUIT;
/*---- End of User Written Code  ----*/ 

%rcSet(&syserr); 
%rcSet(&sqlrc); 

