/****************************************************************************** 
 * Job:           FA_EXT                                    A5V75JN3.BN00001M * 
 * Description:   This job builds the FA_EXT by picking up data from          * 
 *                 FINANCIAL_ACCOUNT                                          * 
 *                                                                            * 
 * Repository:    Foundation                                A0000001.A5V75JN3 * 
 * Server:        SASMain                                   A5V75JN3.AT000001 * 
 *                                                                            * 
 * Source Tables: LOAD_CONTROL - control.LOAD_CONTROL       A5V75JN3.BE0000I0 * 
 *                FINANCIAL_ACCOUNT - DDS.FINANCIAL_ACCOUNT A5V75JN3.BE00002O * 
 * Target Table:  FA_EXT - martscr.FA_EXT                   A5V75JN3.BE0000JK * 
 *                                                                            * 
 * Generated on:  Wednesday, December 10, 2008 2:27:25 PM IST                 * 
 * Generated by:  sasadm                                                      * 
 * Version:       9.1.20060626.51875                                          * 
 ******************************************************************************
 * Notes:                                                                     * 
 * FA_EXT                                                                     * 
 * Job Name: FA_EXTJob Desc Pre Process: NoneMain:Extract and load data from  * 
 * FINANCIAL_ACCOUNT using a SQL join with table LOAD_CONTROL based on        * 
 * conditionLOAD_CONTROL.LOAD_FLG = CHECK_FLAG_TRUE                           * 
 * andLOAD_CONTROL.RUN_STATUS = RUNNING_STATUS                                * 
 * andLOAD_CONTROL.LOAD_END_DTTM betweenVALID_FROM_DTTM and                   * 
 * VALID_TO_DTTMPost Process: Indexes are created                             * 
 * onACCOUNT_RK,LOAD_END_DTTM andFINANCIAL_APPLICATION_RK,LOAD_END_DTTM       * 
 * andCAMPAIGN_CD,LOAD_END_DTTMParameters: CHECK_FLAG_TRUE and                * 
 * RUNNING_STATUS are the user defined parameters. CHECK_FLAG_TRUE is set     * 
 * to 'Y' and RUNNING_STATUS is to 'Running' for each month of data           * 
 *  load.Developed by: sinahkReviewed by:Tested by:                           * 
 ******************************************************************************/ 



%let jobID = %quote(A5V75JN3.BN00001M);

/* Setup for capturing job status  */ 
data _null_; 
   call symput('etls_startTime',put(datetime(),datetime.));
run;

%let etls_jobName = FA_EXT;
%let etls_recordsBefore = 0;
%let etls_recordsAfter = 0;
%let etls_lib = 0;
%let etls_table = 0;

/* Setup to capture return codes  */ 
%global job_rc trans_rc sqlrc; 
%let job_rc = 0;
%let trans_rc = 0;
%let sqlrc = 0;
%global syserr; 

%macro rcSet(error); 
   %if (&error gt &trans_rc) %then 
      %let trans_rc = &error;
   %if (&error gt &job_rc) %then 
      %let job_rc = &error;
%mend rcSet; 

%macro rcSetDS(error); 
   if &error gt input(symget('trans_rc'),12.) then 
      call symput('trans_rc',trim(left(put(&error,12.))));
   if &error gt input(symget('job_rc'),12.) then 
      call symput('job_rc',trim(left(put(&error,12.))));
%mend rcSetDS; 

%global etls_debug; 
%macro etls_setDebug; 
   %if %str(&etls_debug) ne 0 %then 
      OPTIONS MPRINT%str(;); 
%mend; 
%etls_setDebug; 

/*============================================================================* 
 * Pre-Process code for the job                             A5V75JN3.AY0004OA * 
 *                                                                            * 
 * User Written:  Oracle Date Problem Fix                   A5V75JN3.AF000PSJ * 
 *                Oracle Date Problem Fix                                     * 
 *============================================================================*/ 

/*---- Start of User Written Code  ----*/ 

proc contents data=dds.financial_account out=_etlsEngine(keep=Engine) noprint;
run;

data _null_;
	set _etlsEngine;
	if _n_=1;
	  call symput('mEngine', kleft(kright(Engine)));
run;
/*---- End of User Written Code  ----*/ 

%rcSet(&syserr); 
%rcSet(&sqlrc); 

/*============================================================================* 
 * Step:          Extracting and Loading of data as per the A5V75JN3.BO0006ZA * 
 *                 load period                                                * 
 * Transform:     SQL Join (Version 2)                                        * 
 * Description:   Join with LOAD_CONTROL table and extract appropriate data   * 
 *                 based  onVALID_FROM_DTTM and VALID_TO_DTTM                 * 
 *                                                                            * 
 * Source Tables: LOAD_CONTROL - control.LOAD_CONTROL       A5V75JN3.BE0000I0 * 
 *                FINANCIAL_ACCOUNT - DDS.FINANCIAL_ACCOUNT A5V75JN3.BE00002O * 
 * Target Table:  SQL Target - martscr.FA_EXT               A5V75JN3.BP00066V * 
 *============================================================================*/ 

/* Access the data for Control  */ 
LIBNAME control BASE "Data/bisdata/control" ;
%rcSet(&syslibrc); 

/* Access the data for Detail Data Store  */ 
LIBNAME DDS BASE "Data/bisdata/dds" ;
%rcSet(&syslibrc); 

/* Access the data for Scratch for Mart  */ 
LIBNAME martscr BASE "Data/bisdata/scratch/mart" ;
%rcSet(&syslibrc); 

%let transformID = %quote(A5V75JN3.BO0006ZA); 

%let trans_rc = 0; 

proc datasets lib = martscr nolist nowarn memtype = (data view);
   delete FA_EXT;
quit;

proc sql;
   create table martscr.FA_EXT as
      select
         LOAD_CONTROL.LOAD_END_DTTM length = 8
                                    format = NLDATM21.
                                    informat = NLDATM21.
                                    label = "Load End Datetime",
         FINANCIAL_ACCOUNT.ACCOUNT_RK length = 8
                                      format = 12.
                                      informat = 12.
                                      label = "Account Key",
         FINANCIAL_ACCOUNT.ACCOUNT_ID length = 32
                                      label = "Account Id",
         FINANCIAL_ACCOUNT.SOURCE_SYSTEM_CD length = 3
                                            label = "Source System Code",
         FINANCIAL_ACCOUNT.ACCOUNT_REGISTRATION_NM length = 100
                                                   label = "Account Registration Name",
         FINANCIAL_ACCOUNT.ALTERNATE_ACCOUNT_NM length = 40
                                                label = "Alternate Account Name",
         FINANCIAL_ACCOUNT.FINANCIAL_ACCOUNT_TYPE_CD length = 3
                                                     label = "Financial Account Type Code",
         FINANCIAL_ACCOUNT.AUTO_DEBIT_ACCOUNT_TYPE_CD length = 3
                                                      label = "Auto Debit Account Type Code",
         FINANCIAL_ACCOUNT.ACCOUNT_REGISTRATION_TYPE_CD length = 3
                                                        label = "Account Registration Type Code",
         FINANCIAL_ACCOUNT.ACCOUNT_STATUS_CD length = 3
                                             label = "Account Status Code",
         CASE symget('mEngine')
         	WHEN "ORACLE" THEN datepart(FINANCIAL_ACCOUNT.OPEN_DT)
         	ELSE FINANCIAL_ACCOUNT.OPEN_DT
         END as OPEN_DT length = 8
                        format = NLDATE10.
                        informat = NLDATE10.
                        label = "Open Date",
         CASE symget('mEngine')
         	WHEN "ORACLE" THEN datepart(FINANCIAL_ACCOUNT.CLOSE_DT)
         	ELSE FINANCIAL_ACCOUNT.CLOSE_DT
         END as CLOSE_DT length = 8
                         format = NLDATE10.
                         informat = NLDATE10.
                         label = "Close Date",
         FINANCIAL_ACCOUNT.CLOSE_REASON_CD length = 3
                                           label = "Account Close Reason Code",
         FINANCIAL_ACCOUNT.ACCOUNT_TAX_ID length = 32
                                          label = "Account Tax Id",
         FINANCIAL_ACCOUNT.EXPECTED_LOSS_PCT length = 8
                                             format = NLNUM9.4
                                             informat = NLNUM9.4
                                             label = "Expected Loss Percentage",
         FINANCIAL_ACCOUNT.INDIVIDUAL_ORGANIZATION_CD length = 3
                                                      label = "Individual Organization Code",
         FINANCIAL_ACCOUNT.SOURCE_CD length = 5
                                     label = "Source Code",
         FINANCIAL_ACCOUNT.OPENING_CHANNEL_CD length = 3
                                              label = "Opening Channel Code",
         FINANCIAL_ACCOUNT.PREFERRED_CHANNEL_CD length = 3
                                                label = "Preferred Channel Code",
         FINANCIAL_ACCOUNT.CURRENCY_CD length = 3
                                       label = "Currency Code",
         FINANCIAL_ACCOUNT.PRIMARY_PHONE_NO length = 20
                                            label = "Primary Phone No",
         FINANCIAL_ACCOUNT.PRIMARY_PHONE_TYPE_CD length = 3
                                                 label = "Primary Phone Type Code",
         FINANCIAL_ACCOUNT.SECONDARY_PHONE_NO length = 20
                                              label = "Secondary Phone No",
         FINANCIAL_ACCOUNT.SECONDARY_PHONE_TYPE_CD length = 3
                                                   label = "Secondary Phone Type Code",
         FINANCIAL_ACCOUNT.MAILABLE_FLG length = 1
                                        label = "Mailable Flag",
         FINANCIAL_ACCOUNT.TELEPHONABLE_FLG length = 1
                                            label = "Telephonable Flag",
         FINANCIAL_ACCOUNT.EMAIL_FLG length = 1
                                     label = "Email Flag",
         FINANCIAL_ACCOUNT.SMS_FLG length = 1
                                   label = "SMS Flag",
         FINANCIAL_ACCOUNT.DO_NOT_CONTACT_FLG length = 1
                                              label = "Do Not Contact Flag",
         FINANCIAL_ACCOUNT.EMPLOYEE_RK length = 8
                                       format = 12.
                                       informat = 12.
                                       label = "Employee Key",
         FINANCIAL_ACCOUNT.CURRENCY_BASED_ACCOUNT_FLG length = 1
                                                      label = "Currency Based Account Flag",
         FINANCIAL_ACCOUNT.FEE_BASED_FLG length = 1
                                         label = "Fee Based Flag",
         FINANCIAL_ACCOUNT.ANNUAL_FEES_AMT length = 8
                                           format = NLNUM18.5
                                           informat = NLNUM18.5
                                           label = "Annual Fees Amount",
         FINANCIAL_ACCOUNT.MONTHLY_FEES_AMT length = 8
                                            format = NLNUM18.5
                                            informat = NLNUM18.5
                                            label = "Monthly Fees Amount",
         FINANCIAL_ACCOUNT.CAMPAIGN_CD length = 30
                                       label = "Campaign Code",
         FINANCIAL_ACCOUNT.COMMUNICATION_CD length = 30
                                            label = "Communication Code",
         CASE symget('mEngine')
         	WHEN "ORACLE" THEN datepart(FINANCIAL_ACCOUNT.REGISTERED_ONLINE_DT)
         	ELSE FINANCIAL_ACCOUNT.REGISTERED_ONLINE_DT
         END as REGISTERED_ONLINE_DT length = 8
                                     format = NLDATE10.
                                     informat = NLDATE10.
                                     label = "Registered Online Date",
         CASE symget('mEngine')
         	WHEN "ORACLE" THEN datepart(FINANCIAL_ACCOUNT.FIRST_LOGIN_DT)
         	ELSE FINANCIAL_ACCOUNT.FIRST_LOGIN_DT
         END as FIRST_LOGIN_DT length = 8
                               format = NLDATE10.
                               informat = NLDATE10.
                               label = "First Login Date",
         FINANCIAL_ACCOUNT.ONLINE_BILL_PAYMENT_FLG length = 1
                                                   label = "Online Bill Payment Flag",
         FINANCIAL_ACCOUNT.ID_VERIFICATION_TYPE_CD length = 3
                                                   label = "ID Verification Type Code",
         FINANCIAL_ACCOUNT.PREVIOUS_ACCOUNT_ID length = 32
                                               label = "Previous Account Id",
         FINANCIAL_ACCOUNT.OPEN_BRANCH_FINANCIAL_UNIT_RK length = 8
                                                         format = 12.
                                                         informat = 12.
                                                         label = "Open Branch Financial Unit Key",
         FINANCIAL_ACCOUNT.PRIM_BRANCH_FINANCIAL_UNIT_RK length = 8
                                                         format = 12.
                                                         informat = 12.
                                                         label = "Primary Branch Financial Unit Key",
         FINANCIAL_ACCOUNT.FINANCIAL_APPLICATION_RK length = 8
                                                    format = 12.
                                                    informat = 12.
                                                    label = "Financial Application Key",
         FINANCIAL_ACCOUNT.CREDIT_FACILITY_RK length = 8
                                              format = 12.
                                              informat = 12.
                                              label = "Credit Facility Key",
         FINANCIAL_ACCOUNT.FUTURE_MARGIN_INCOME_AMT length = 8
                                                    format = NLNUM18.5
                                                    informat = NLNUM18.5
                                                    label = "Future Margin Income Amount",
         FINANCIAL_ACCOUNT.IN_DEFAULT_FLG length = 1
                                          label = "Already In Default Flag",
         FINANCIAL_ACCOUNT.FINANCIAL_BOOK_RK length = 8
                                             format = 12.
                                             informat = 12.
                                             label = "Financial Book Key",
         FINANCIAL_ACCOUNT.IRRECOVERABLE_FLG length = 1
                                             label = "Irrecoverable Flag",
         FINANCIAL_ACCOUNT.OWNED_BY_INTERNAL_ORG_RK length = 8
                                                    format = 12.
                                                    informat = 12.
                                                    label = "Internal Organization Retained Key",
         FINANCIAL_ACCOUNT.PREVIOUS_BANK_EXTERNAL_ORG_RK length = 8
                                                         format = 12.
                                                         informat = 12.
                                                         label = "Previous Bank External Organization",
         FINANCIAL_ACCOUNT.NETTING_SET_RK length = 8
                                          format = 12.
                                          informat = 12.
                                          label = "Netting Set Key",
         FINANCIAL_ACCOUNT.REVOLVING_FLG length = 1
                                         label = "Revolving Flag",
         FINANCIAL_ACCOUNT.SOURCE_CHANNEL_CD length = 3
                                             label = "Source Channel Code",
         FINANCIAL_ACCOUNT.GRACE_PERIOD_DAYS_CNT length = 8
                                                 label = "Grace Period Days Count",
         FINANCIAL_ACCOUNT.REGULATORY_PRODUCT_CD length = 3
                                                 label = "Equity Instrument Type Code",
         FINANCIAL_ACCOUNT.HOLDING_PERIOD_DAYS_CNT length = 8
                                                   label = "Holding Period Days Count",
         FINANCIAL_ACCOUNT.HAIRCUT_VALUE_RT length = 8
                                            format = NLNUM9.4
                                            informat = NLNUM9.4
                                            label = "Haircut Value Rate",
         FINANCIAL_ACCOUNT.REMARGINING_DAYS_CNT length = 8
                                                label = "Remargining Days Count",
         FINANCIAL_ACCOUNT.FINANCIAL_CALENDAR_RK length = 8
                                                 format = 12.
                                                 informat = 12.
                                                 label = "Financial Calendar Key",
         FINANCIAL_ACCOUNT.DAY_BASIS_CD length = 10
                                        label = "Day Basis Code",
         FINANCIAL_ACCOUNT.PORTFOLIO_ID length = 32
                                        label = "Portfolio Id",
         FINANCIAL_ACCOUNT.RISK_WEIGHT_PCT length = 8
                                           format = NLNUM9.4
                                           informat = NLNUM9.4
                                           label = "Risk Weight Percent",
         FINANCIAL_ACCOUNT.SECURITIZATION_POOL_RK length = 8
                                                  format = 12.
                                                  informat = 12.
                                                  label = "Securitization Pool Key",
         FINANCIAL_ACCOUNT.RECEIVABLES_POOL_RK length = 8
                                               format = 12.
                                               informat = 12.
                                               label = "Receivables Pool Key",
         FINANCIAL_ACCOUNT.HAIRCUT_SET_ID length = 32
                                          label = "Haircut Set Id",
         FINANCIAL_ACCOUNT.ACCOUNT_USAGE_TYPE_CD length = 3
                                                 label = "Account Usage Type Code",
         FINANCIAL_ACCOUNT.RISK_ALARM_FLG length = 1
                                          label = "Risk Alarm Flag",
         FINANCIAL_ACCOUNT.LOW_PROFITABILITY_FLG length = 1
                                                 label = "Low Profitability Flag",
         FINANCIAL_ACCOUNT.ACCOUNT_LIFECYCLE_STG_CD length = 3
                                                    label = "Account Lifecycle Code",
         FINANCIAL_ACCOUNT.ATTRITION_ALARM_FLG length = 1
                                               label = "Attrition Alarm Flag",
         FINANCIAL_ACCOUNT.BALANCE_FROZEN_FLG length = 1
                                              label = "Balance Frozen Flag",
         CASE symget('mEngine')
         	WHEN "ORACLE" THEN datepart(FINANCIAL_ACCOUNT.BALANCE_FROZEN_DT)
         	ELSE FINANCIAL_ACCOUNT.BALANCE_FROZEN_DT
         END as BALANCE_FROZEN_DT length = 8
                                  format = NLDATE10.
                                  informat = NLDATE10.
                                  label = "Balance Frozen Date",
         FINANCIAL_ACCOUNT.ACCOUNT_BLOCK_REASON_CD length = 3
                                                   label = "Account Blocking Reason Code",
         FINANCIAL_ACCOUNT.TAXATION_STATE_CD length = 4
                                             label = "State/Region Code",
         FINANCIAL_ACCOUNT.EFFECTIVE_MATURITY_YEAR_NO length = 8
                                                      label = "Effective Maturity Year",
         FINANCIAL_ACCOUNT.GL_ACCOUNT_RK length = 8
                                         format = 12.
                                         informat = 12.
                                         label = "Account Retained Key",
         FINANCIAL_ACCOUNT.REFERENCED_BY_INSTRUMENT_RK length = 8
                                                       format = 12.
                                                       informat = 12.
                                                       label = "Financial Instrument Key",
         FINANCIAL_ACCOUNT.FROM_OTHER_INSTITUTION_FLG length = 1
                                                      label = "From Other Institution Flag",
         FINANCIAL_ACCOUNT.ACCOUNT_RENEWAL_CNT length = 8
                                               label = "Account Renewal Count",
         CASE symget('mEngine')
         	WHEN "ORACLE" THEN datepart(FINANCIAL_ACCOUNT.BALANCE_TRANSFER_DT)
         	ELSE FINANCIAL_ACCOUNT.BALANCE_TRANSFER_DT
         END as BALANCE_TRANSFER_DT length = 8
                                    format = NLDATE10.
                                    informat = NLDATE10.
                                    label = "Balance Transfer Date",
         FINANCIAL_ACCOUNT.BALANCE_TRANSFER_AMT length = 8
                                                format = NLNUM18.5
                                                informat = NLNUM18.5
                                                label = "Balance Transfer Amount",
         FINANCIAL_ACCOUNT.BALANCE_TRANSFER_CNT length = 8
                                                label = "Balance Transfer Count",
         FINANCIAL_ACCOUNT.BASE_LONG_TERM_APR_RT length = 8
                                                 format = NLNUM9.4
                                                 informat = NLNUM9.4
                                                 label = "Base Long Term APR Rate",
         FINANCIAL_ACCOUNT.BROKER_FLG length = 1
                                      label = "Broker Flag",
         FINANCIAL_ACCOUNT.MULT_RATE_FLG length = 1
                                         label = "Multi Rate Flag",
         FINANCIAL_ACCOUNT.AUTO_DEBIT_ACCOUNT_NO length = 32
                                                 label = "Auto Debit Account No",
         FINANCIAL_ACCOUNT.WORST_STATUS_LAST_12_MTH_CD length = 3
                                                       label = "Worst Status Last 12 Mth Code",
         CASE symget('mEngine')
         	WHEN "ORACLE" THEN datepart(FINANCIAL_ACCOUNT.WORST_STATUS_LAST_12_MTH_DT)
         	ELSE FINANCIAL_ACCOUNT.WORST_STATUS_LAST_12_MTH_DT
         END as WORST_STATUS_LAST_12_MTH_DT length = 8
                                            format = NLDATE10.
                                            informat = NLDATE10.
                                            label = "Worst Status Last 12 Mth Date",
         FINANCIAL_ACCOUNT.BALANCE_TRNSF_OTHER_ACCT_CNT length = 8
                                                        label = "Balance Transfer Other Acct Count",
         FINANCIAL_ACCOUNT.EFFECTIVE_FROM_DTTM length = 8
                                               format = NLDATM21.
                                               informat = NLDATM21.
                                               label = "Effective From Datetime",
         FINANCIAL_ACCOUNT.EFFECTIVE_TO_DTTM length = 8
                                             format = NLDATM21.
                                             informat = NLDATM21.
                                             label = "Effective To Datetime",
         FINANCIAL_ACCOUNT.COUNTERPARTY_RK length = 8
                                           format = 12.
                                           informat = 12.
                                           label = "Counterparty Key",
         FINANCIAL_ACCOUNT.STATEMENT_FREQUENCY_CD length = 3
                                                  label = "Time Frequency Code",
         FINANCIAL_ACCOUNT.SECURITY_DEPOSIT_AMT length = 8
                                                format = NLNUM18.5
                                                informat = NLNUM18.5
                                                label = "Security Deposit Amount if applicable for loan, mortgage and credit card accounts",
         FINANCIAL_ACCOUNT.SECURITY_DEPOSIT_REFUND_AMT length = 8
                                                       format = NLNUM18.5
                                                       informat = NLNUM18.5
                                                       label = "If the security deposit amount was refunded then the amount of refund"
      from
         control.LOAD_CONTROL, 
         DDS.FINANCIAL_ACCOUNT
      where
         LOAD_CONTROL.LOAD_FLG IN (&CHECK_FLAG_TRUE)
         and LOAD_CONTROL.RUN_STATUS IN (&RUNNING_STATUS)
         and LOAD_CONTROL.LOAD_END_DTTM >= FINANCIAL_ACCOUNT.VALID_FROM_DTTM
         and LOAD_CONTROL.LOAD_END_DTTM <= FINANCIAL_ACCOUNT.VALID_TO_DTTM
      ;
quit;

%rcSet(&sqlrc); 

%macro etls_completeTarget();
   /*---- Create the integrity constraints for a table  ----*/ 
   %put %str(NOTE: Creating integrity constraints ...);
   proc datasets library=martscr nolist;
      modify FA_EXT;
         ic create not null (ACCOUNT_ID);
         ic create not null (FINANCIAL_ACCOUNT_TYPE_CD);
   quit;
   
   %rcSet(&syserr); 
   
%mend etls_completeTarget;
%etls_completeTarget;

/*============================================================================* 
 * Step:          Dummy Loader                              A5V75JN3.BO0006Z9 * 
 * Transform:     Table Loader                                                * 
 * Description:                                                               * 
 *                                                                            * 
 * Source Table:  SQL Target - martscr.FA_EXT               A5V75JN3.BP00066V * 
 * Target Table:  FA_EXT - martscr.FA_EXT                   A5V75JN3.BE0000JK * 
 *============================================================================*
 *                                                                            * 
 * Nothing will be generated for this process because the "Do not generate    * 
 *  code for this process" option is selected.                                * 
 *                                                                            * 
 *============================================================================*/ 

data _null_; 
   call symput('etls_endTime',put(datetime(),datetime.));
run;

/* Check return code for job  */ 
%macro etls_jobRCChk; 
   %if (&job_rc eq 4) %then
   %do; 
      %on_success(Job_nm=&etls_jobName..sas, param_table=&status_table);
   %end; 
%mend etls_jobRCChk; 
%etls_jobRCChk; 

/* Check return code for job  */ 
%macro etls_jobRCChk; 
   %if (&job_rc ge 5) %then
   %do; 
      %on_success(Job_nm=&etls_jobName..sas, param_table=&status_table);
   %end; 
%mend etls_jobRCChk; 
%etls_jobRCChk; 

/* Check return code for job  */ 
%macro etls_jobRCChk; 
   %if (&job_rc eq 0) %then
   %do; 
      %on_success(Job_nm=&etls_jobName..sas, param_table=&status_table);
   %end; 
%mend etls_jobRCChk; 
%etls_jobRCChk; 

/*---- Job status macro  ----*/ 
/*============================================================================* 
 * Post-Process code for the job                            A5V75JN3.AY0004OB * 
 *                                                                            * 
 * User Written:  Index creation code on  columns           A5V75JN3.AF000PSK * 
 *                Index creation code on ACCOUNT_RK,FINANCIAL_APPLICATION_RK  * 
 *                 and CAMPAIGN_CD columns with LOAD_END_DTTM                 * 
 *============================================================================*/ 

/*---- Start of User Written Code  ----*/ 

/*creating indexes on ACCOUNT_RK ,FINANCIAL_APPLICATION_RK and
CAMPAIGN_CD with LOAD_END_DTTM column */

PROC SQL NOPRINT;
           CREATE INDEX ACCOUNT_RK_LOAD_END_DTTM
            ON martscr.FA_EXT(ACCOUNT_RK,LOAD_END_DTTM);

           CREATE INDEX FINANCIAL_APPLICATION_RK_LOAD
            ON martscr.FA_EXT(FINANCIAL_APPLICATION_RK,LOAD_END_DTTM);

           CREATE INDEX CAMPAIGN_CD_LOAD_END_DTTM
            ON martscr.FA_EXT(CAMPAIGN_CD,LOAD_END_DTTM);
QUIT;
/*---- End of User Written Code  ----*/ 

%rcSet(&syserr); 
%rcSet(&sqlrc); 

