/****************************************************************************** 
 * Job:           FA_UP_SELL_L                              A5V75JN3.BN00005W * 
 * Description:   This job picks up data from FA_FARST_L and                  * 
 *                UP_SELL_FOR_ALL_ACCT by performing left join on             * 
 *                 FA_FARST_L.                                                * 
 *                                                                            * 
 * Repository:    Foundation                                A0000001.A5V75JN3 * 
 * Server:        SASMain                                   A5V75JN3.AT000001 * 
 *                                                                            * 
 * Source Tables: UP_SELL_FOR_ALL_ACCT -                    A5V75JN3.BE0000NL * 
 *                 martscr.UP_SELL_FOR_ALL_ACCT                               * 
 *                FA_FARST_L - martscr.FA_FARST_L           A5V75JN3.BE0000NX * 
 * Target Table:  FA_UP_SELL_L - martscr.FA_UP_SELL_L       A5V75JN3.BE0000O1 * 
 *                                                                            * 
 * Generated on:  Wednesday, December 10, 2008 2:26:28 PM IST                 * 
 * Generated by:  sasadm                                                      * 
 * Version:       9.1.20060626.51875                                          * 
 ******************************************************************************
 * Notes:                                                                     * 
 * FA_UP_SELL_L                                                               * 
 * Job Name: FA_UP_SELL_LJob Desc Pre Process: NoneMain: a) Up sell event     * 
 * for all accounts obtained by joining FA_FARST_L and UP_SELL_FOR_ALL_ACCT   * 
 * on ACCOUNT_RK by performing left join on FA_FARST_L.ACTIVE_ACCOUNT_CNT     * 
 * is obtained by applying the condition that if ACCOUNT_STATUS_CD is         * 
 * active, i.e. in the user defined parameter ACCT_STATUS_ACT then the        * 
 * count is 1 else it is 0.INACTIVE_ACCOUNT_CNT is obtained by applying the   * 
 * condition that if ACCOUNT_STATUS_CD is inactive, i.e. in the user          * 
 * defined parameter ACCT_STATUS_INA then the count is 1 else it is           * 
 * 0.CLOSED_ACCOUNT_CNT is obtained by applying the condition that if         * 
 * ACCOUNT_STATUS_CD is closed, i.e. in the user defined parameter            * 
 * ACCT_STATUS_CLO then the count is 1 else it is 0.OPEN_ACCOUNT_CNT is       * 
 * obtained by applying the condition that if ACCOUNT_STATUS_CD is open,      * 
 * i.e. in the user defined parameter ACCT_STATUS_OPN then the count is 1     * 
 * else it is 0.DELINQUENCY_CNT is obtained by applying the condition that    * 
 * if DAYS_PAYMENT_PAST_DUE_CNT is greater than 0 then the count is 1 else    * 
 * it is 0.DIFFER_PAYMENT_CNT is obtained by applying the condition that if   * 
 * LAST_PAYMENT_STATUS_CD is differ, i.e. in the user defined parameter       * 
 * DIFFER_PAYMENT_STATUS then the count is 1 else it is 0.DEFAULT_CNT is      * 
 * obtained by applying the condition that if DEFAULT_STATUS_CD is default,   * 
 * i.e. in the user defined parameter DEFAULT_STATUS_CD then the count is 1   * 
 * else it is 0.NEW_ACCOUNT_CNT is obtained by applying the condition that    * 
 * if OPEN_DT is in the current load then the count is 1 else it is           * 
 * 0.CROSS_SELL_CAMPAIGN_IND is obtained by applying the condition that if    * 
 * CAMPAIGN_TYPE_CD is of type cross sell, i.e. in the user defined           * 
 * parameter CROSS_SELL_CAMPAIGN_TYPE then the count is 1 else 0.Post         * 
 * Process: NoneParameters: a) ACCT_STATUS_ACT: This parameter is used to     * 
 * check whether the acount is active.b) ACCT_STATUS_INA: This parameter is   * 
 * used to check whether the account is inactive.c) ACCT_STATUS_CLO: This     * 
 * parameter is used to check whether the account is closed.d)                * 
 * ACCT_STATUS_OPN: This parameter is used to check whether the account is    * 
 * open.e ) DIFFER_PAYMENT_STATUS: This parameter is used to check whether    * 
 * the last payment made is a differ payment i.e. the payment made on or      * 
 * before the bill due date is greater than the minimum due amount and less   * 
 * than the bill amount.f) DEFAULT_STATUS_CD: This parameter is used to       * 
 * check whether the account delinquency status is default.g)                 * 
 * CROSS_SELL_CAMPAIGN_TYPE: This parameter is used to check whether the      * 
 * campaign is for cross sell.The SQL join source code is user written to     * 
 * satisfy CASE statement condition in &DEFAULT_STATUS_CD                     * 
 *  parameter.Developed by: singupReviewed by:Tested by:                      * 
 ******************************************************************************/ 



%let jobID = %quote(A5V75JN3.BN00005W);

/* Setup for capturing job status  */ 
data _null_; 
   call symput('etls_startTime',put(datetime(),datetime.));
run;

%let etls_jobName = FA_UP_SELL_L;
%let etls_recordsBefore = 0;
%let etls_recordsAfter = 0;
%let etls_lib = 0;
%let etls_table = 0;

/* Setup to capture return codes  */ 
%global job_rc trans_rc sqlrc; 
%let job_rc = 0;
%let trans_rc = 0;
%let sqlrc = 0;
%global syserr; 

%macro rcSet(error); 
   %if (&error gt &trans_rc) %then 
      %let trans_rc = &error;
   %if (&error gt &job_rc) %then 
      %let job_rc = &error;
%mend rcSet; 

%macro rcSetDS(error); 
   if &error gt input(symget('trans_rc'),12.) then 
      call symput('trans_rc',trim(left(put(&error,12.))));
   if &error gt input(symget('job_rc'),12.) then 
      call symput('job_rc',trim(left(put(&error,12.))));
%mend rcSetDS; 

%global etls_debug; 
%macro etls_setDebug; 
   %if %str(&etls_debug) ne 0 %then 
      OPTIONS MPRINT%str(;); 
%mend; 
%etls_setDebug; 

/*============================================================================* 
 * Step:          SQL Join - USER DEFINED                   A5V75JN3.BO0005QC * 
 * Transform:     SQL Join (Version 2)                                        * 
 * Description:   Note that this is user defined code                         * 
 *                                                                            * 
 * Source Tables: UP_SELL_FOR_ALL_ACCT -                    A5V75JN3.BE0000NL * 
 *                 martscr.UP_SELL_FOR_ALL_ACCT                               * 
 *                FA_FARST_L - martscr.FA_FARST_L           A5V75JN3.BE0000NX * 
 * Target Table:  SQL Target - martscr.FA_UP_SELL_L         A5V75JN3.BP0004TT * 
 *                                                                            * 
 * User Written:  SQL Source Code                           A5V75JN3.AF000MYF * 
 *                User defined SQL code                                       * 
 *============================================================================*/ 

/* Access the data for Scratch for Mart  */ 
LIBNAME martscr BASE "Data/bisdata/scratch/mart" ;
%rcSet(&syslibrc); 

%let transformID = %quote(A5V75JN3.BO0005QC); 

%let trans_rc = 0; 

%let _OUTPUT = %nrquote(martscr.FA_UP_SELL_L); 

/*---- Start of User Written Code  ----*/ 

proc datasets lib = martscr nolist nowarn memtype = (data view);
   delete FA_UP_SELL_L;
quit;

proc sql;
   create table martscr.FA_UP_SELL_L as
      select
	    FA_FARST_L.ACCOUNT_RK length = 8
                                         format = 12.
                                         informat = 12.
                                         label = "Account Key",
         FA_FARST_L.LOAD_END_DTTM length = 8
                                            format = NLDATM21.
                                            informat = NLDATM21.
                                            label = "Load End Datetime",

         FA_FARST_L.OWNED_BY_INTERNAL_ORG_RK length = 8
                                             format = 12.
                                             informat = 12.
                                             label = "Internal Organization Retained Key",

         FA_FARST_L.CUSTOMER_RK length = 8
                                          format = 12.
                                          informat = 12.
                                          label = "Customer Key",
         FA_FARST_L.PRODUCT_RK length = 8
                                         format = 12.
                                         informat = 12.
                                         label = "Product Key",
         FA_FARST_L.EMPLOYEE_RK length = 8
                                format = 12.
                                informat = 12.
                                label = "Employee Key",


         CASE  WHEN FA_FARST_L.DAYS_PAYMENT_PAST_DUE_CNT  > 0 THEN 1 ELSE 0 END as DELINQUENCY_CNT length = 8
                                                                                                   format = 8.
                                                                                                   informat = 8.,
         FA_FARST_L.OVERDRAFT_CURRENT_AMT length = 8
                                          format = NLNUM18.5
                                          informat = NLNUM18.5
                                          label = "Overdraft Current Amount",
         FA_FARST_L.CLEARED_BALANCE_AMT length = 8
                                        format = NLNUM18.5
                                        informat = NLNUM18.5
                                        label = "Cleared Balance Amount",

         FA_FARST_L.LAST_PAYMENT_STATUS_CD length = 3,
         FA_FARST_L.CCD_POINTS_BALANCE length = 8
                                       format = NLNUM18.5
                                       informat = NLNUM18.5
                                       label = "Credit Card Points Balance",
         FA_FARST_L.CCD_TOT_POINTS_EARNED length = 8
                                          format = NLNUM6.2
                                          informat = NLNUM6.2
                                          label = "Total No Points Earned",
         FA_FARST_L.MIN_BILLING_AMT length = 8
                                    format = NLNUM18.5
                                    informat = NLNUM18.5
                                    label = "Minimum Due Amount",
         FA_FARST_L.LATE_PAYMENT_CNT length = 8
                                     label = "Number of late payment transactions, performed by all the Sk's.",
         CASE  WHEN FA_FARST_L.ACCOUNT_STATUS_CD IN (&ACCT_STATUS_OPN) THEN 1 ELSE 0 END as OPEN_ACCOUNT_CNT length = 8
                                                                                                             format = 8.
                                                                                                             informat = 8.,
         CASE  WHEN FA_FARST_L.ACCOUNT_STATUS_CD IN (&ACCT_STATUS_CLO) THEN 1 ELSE 0 END as CLOSED_ACCOUNT_CNT length = 8
                                                                                                               format = 8.
                                                                                                               informat = 8.,
         FA_FARST_L.AVERAGE_DAILY_BALANCE_AMT length = 8
                                              format = NLNUM18.5
                                              informat = NLNUM18.5
                                              label = "Average Daily Balance Amount",
         CASE  WHEN FA_FARST_L.DEFAULT_STATUS_CD IN (&DEFAULT_STATUS_CD) THEN 1 ELSE 0 END as DEFAULT_CNT length = 8
                                                                                                                     format = 8.
                                                                                                                     informat = 8.,
         FA_FARST_L.PRINCIPAL_BALANCE_AMT length = 8
                                          format = NLNUM18.5
                                          informat = NLNUM18.5
                                          label = "Principal Balance Amount",
         FA_FARST_L.NEXT_INTEREST_PAYMENT_DT length = 8
                                             format = NLDATE10.
                                             informat = NLDATE10.
                                             label = "Next Interest Payment Date",
         FA_FARST_L.BILLED_AMT length = 8
                               format = NLNUM18.5
                               informat = NLNUM18.5
                               label = "Billed Amount",
         FA_FARST_L.OPEN_DT length = 8
                            format = NLDATE10.
                            informat = NLDATE10.
                            label = "Open Date",
         CASE WHEN UP_SELL_FOR_ALL_ACCT.UP_SELL_ACCOUNT_CNT  > 0 THEN 1 ELSE 0 END as UP_SELL_ACCOUNT_CNT length = 8
                                                                                                          format = 8.
                                                                                                          informat = 8.,
         CASE  WHEN FA_FARST_L.OPEN_DT  between INTNX('MONTH',datepart(FA_FARST_L.LOAD_END_DTTM) ,0,'BEGINNING') and datepart(FA_FARST_L.LOAD_END_DTTM)  THEN 1 ELSE 0 END as NEW_ACCOUNT_CNT length = 8
                                                                                                                                                                          format = 8.
                                                                                                                                                                          informat = 8.,
         FA_FARST_L.MIN_ACCOUNT_VALUE_AMT length = 8
                                          format = NLNUM18.5
                                          informat = NLNUM18.5
                                          label = "Minimum Account Value Amount",
         FA_FARST_L.CURRENT_BILL_AMT length = 8
                                     format = NLNUM18.5
                                     informat = NLNUM18.5
                                     label = "Current Bill Amount",
         FA_FARST_L.FEES_AMT length = 8
                             format = NLNUM18.5
                             informat = NLNUM18.5
                             label = "Fees Amount",
         FA_FARST_L.MAX_ACCOUNT_VALUE_AMT length = 8
                                          format = NLNUM18.5
                                          informat = NLNUM18.5
                                          label = "Maximum Account Value Amount",
         FA_FARST_L.TOTAL_BALANCE_AMT length = 8
                                      format = NLNUM18.5
                                      informat = NLNUM18.5
                                      label = "Total Balance Amount",
         FA_FARST_L.PAST_DUE_AMT length = 8
                                 format = NLNUM18.5
                                 informat = NLNUM18.5
                                 label = "Past Due Amount",
         FA_FARST_L.DAYS_PAYMENT_PAST_DUE_CNT length = 8
                                              label = "No of Days Payment Past Due",
         FA_FARST_L.OPENING_CHANNEL_CD length = 3
                                       label = "Opening Channel Code",
         CASE  WHEN FA_FARST_L.ACCOUNT_STATUS_CD  IN (&ACCT_STATUS_ACT) THEN 1 ELSE 0 END as ACTIVE_ACCOUNT_CNT length = 8
                                                                                                                format = 8.
                                                                                                                informat = 8.,
         CASE  WHEN FA_FARST_L.CAMPAIGN_TYPE_CD  IN (&CROSS_SELL_CAMPAIGN_TYPE) THEN 1 ELSE 0 END as CROSS_SELL_CAMPAIGN_IND length = 8
                                                                                                                             format = 8.
                                                                                                                             informat = 8.,
         FA_FARST_L.CURTAILMENT_AMT length = 8
                                    format = NLNUM18.5
                                    informat = NLNUM18.5
                                    label = "Curtailment Amount",
         FA_FARST_L.BALANCE_AMT length = 8
                                format = NLNUM18.5
                                informat = NLNUM18.5
                                label = "Balance Amount",
         FA_FARST_L.INTEREST_EXPECTED_AMT length = 8
                                          format = NLNUM18.5
                                          informat = NLNUM18.5
                                          label = "Interest Balance Amount",
         FA_FARST_L.LAST_STATEMENT_DT length = 8
                                      format = NLDATE10.
                                      informat = NLDATE10.
                                      label = "Statement Date",
         FA_FARST_L.CCD_TOT_POINTS_REDEEMED length = 8
                                            format = NLNUM6.2
                                            informat = NLNUM6.2
                                            label = "Total No Points Redeemed",
         FA_FARST_L.ESCROW_AMT length = 8
                               format = NLNUM18.5
                               informat = NLNUM18.5
                               label = "Escrow Amount",
         FA_FARST_L.TOTAL_SUSPENSIONS_CNT length = 8,
         CASE  WHEN FA_FARST_L.ACCOUNT_STATUS_CD  IN (&ACCT_STATUS_INA) THEN 1 ELSE 0 END as INACTIVE_ACCOUNT_CNT length = 8
                                                                                                                  format = 8.
                                                                                                                  informat = 8.,
         CASE  WHEN FA_FARST_L.LAST_PAYMENT_STATUS_CD  IN (&DIFFER_PAYMENT_STATUS) THEN 1 ELSE 0 END as DIFFER_PAYMENT_CNT length = 8
                                                                                                                           format = 8.
                                                                                                                           informat = 8.
      from
			martscr.FA_FARST_L left join 
         martscr.UP_SELL_FOR_ALL_ACCT 
         
            on
            (
               UP_SELL_FOR_ALL_ACCT.ACCOUNT_RK = FA_FARST_L.ACCOUNT_RK
               and UP_SELL_FOR_ALL_ACCT.LOAD_END_DTTM = FA_FARST_L.LOAD_END_DTTM
            )
      ;
quit;


%macro etls_completeTarget();
   /*---- Create the integrity constraints for a table  ----*/ 
   %put %str(NOTE: Creating integrity constraints ...);
   proc datasets library=martscr nolist;
      modify FA_UP_SELL_L;
			ic create not null (ACCOUNT_RK);
			ic create not null (LOAD_END_DTTM);
         ic create not null (OWNED_BY_INTERNAL_ORG_RK);
         ic create not null (CUSTOMER_RK);
         ic create not null (PRODUCT_RK);
    quit;
   
%mend etls_completeTarget;
%etls_completeTarget;


/*---- End of User Written Code  ----*/ 

%rcSet(&syserr); 
%rcSet(&sqlrc); 

/*============================================================================* 
 * Step:          Dummy Loader                              A5V75JN3.BO0005QB * 
 * Transform:     Table Loader                                                * 
 * Description:                                                               * 
 *                                                                            * 
 * Source Table:  SQL Target - martscr.FA_UP_SELL_L         A5V75JN3.BP0004TT * 
 * Target Table:  FA_UP_SELL_L - martscr.FA_UP_SELL_L       A5V75JN3.BE0000O1 * 
 *============================================================================*
 *                                                                            * 
 * Nothing will be generated for this process because the "Do not generate    * 
 *  code for this process" option is selected.                                * 
 *                                                                            * 
 *============================================================================*/ 

data _null_; 
   call symput('etls_endTime',put(datetime(),datetime.));
run;

/* Check return code for job  */ 
%macro etls_jobRCChk; 
   %if (&job_rc eq 4) %then
   %do; 
      %on_success(Job_nm=&etls_jobName..sas, param_table=&status_table);
   %end; 
%mend etls_jobRCChk; 
%etls_jobRCChk; 

/* Check return code for job  */ 
%macro etls_jobRCChk; 
   %if (&job_rc ge 5) %then
   %do; 
      %on_success(Job_nm=&etls_jobName..sas, param_table=&status_table);
   %end; 
%mend etls_jobRCChk; 
%etls_jobRCChk; 

/* Check return code for job  */ 
%macro etls_jobRCChk; 
   %if (&job_rc eq 0) %then
   %do; 
      %on_success(Job_nm=&etls_jobName..sas, param_table=&status_table);
   %end; 
%mend etls_jobRCChk; 
%etls_jobRCChk; 

/*---- Job status macro  ----*/ 
