/****************************************************************************** 
 * Job:           FIN_ACCT_RST_EXT                          A5V75JN3.BN00001R * 
 * Description:   This job picks up data from FINANCIAL_ACCOUNT_RESTRICTION   * 
 *                                                                            * 
 * Repository:    Foundation                                A0000001.A5V75JN3 * 
 * Server:        SASMain                                   A5V75JN3.AT000001 * 
 *                                                                            * 
 * Source Tables: LOAD_CONTROL - control.LOAD_CONTROL       A5V75JN3.BE0000I0 * 
 *                FINANCIAL_ACCOUNT_RESTRICTION -           A5V75JN3.BE00002W * 
 *                 DDS.FINANCIAL_ACCOUNT_RESTRICTION                          * 
 * Target Table:  FIN_ACCT_RST_EXT -                        A5V75JN3.BE0000JP * 
 *                 martscr.FIN_ACCT_RST_EXT                                   * 
 *                                                                            * 
 * Generated on:  Wednesday, December 10, 2008 2:28:35 PM IST                 * 
 * Generated by:  sasadm                                                      * 
 * Version:       9.1.20060626.51875                                          * 
 ******************************************************************************
 * Notes:                                                                     * 
 * FIN_ACCT_RST_EXT                                                           * 
 * Job Name: FIN_ACCT_RST_EXTJob Desc Pre Process: NoneMain:Main:Extract and  * 
 * load data from FINANCIAL_ACCOUNT_RESTRICTION using a SQL join with table   * 
 * LOAD_CONTROL based on conditionLOAD_CONTROL.LOAD_FLG = CHECK_FLAG_TRUE     * 
 * andLOAD_CONTROL.RUN_STATUS = RUNNING_STATUS andRESTRICTION_DT              * 
 * >=DATEPART(LOAD_START_DTTM) and RESTRICTION_DT <=                          * 
 * DATEPART(LOAD_END_DTTM)Post Process: Index is created                      * 
 * onACCOUNT_RK,LOAD_END_DTTMParameters: CHECK_FLAG_TRUE and RUNNING_STATUS   * 
 * are the user defined parameters. CHECK_FLAG_TRUE is set to 'Y' and         * 
 * RUNNING_STATUS is to 'Running' for each month of data load.Developed by:   * 
 *  sinahkReviewed by:Tested by:                                              * 
 ******************************************************************************/ 



%let jobID = %quote(A5V75JN3.BN00001R);

/* Setup for capturing job status  */ 
data _null_; 
   call symput('etls_startTime',put(datetime(),datetime.));
run;

%let etls_jobName = FIN_ACCT_RST_EXT;
%let etls_recordsBefore = 0;
%let etls_recordsAfter = 0;
%let etls_lib = 0;
%let etls_table = 0;

/* Setup to capture return codes  */ 
%global job_rc trans_rc sqlrc; 
%let job_rc = 0;
%let trans_rc = 0;
%let sqlrc = 0;
%global syserr; 

%macro rcSet(error); 
   %if (&error gt &trans_rc) %then 
      %let trans_rc = &error;
   %if (&error gt &job_rc) %then 
      %let job_rc = &error;
%mend rcSet; 

%macro rcSetDS(error); 
   if &error gt input(symget('trans_rc'),12.) then 
      call symput('trans_rc',trim(left(put(&error,12.))));
   if &error gt input(symget('job_rc'),12.) then 
      call symput('job_rc',trim(left(put(&error,12.))));
%mend rcSetDS; 

%global etls_debug; 
%macro etls_setDebug; 
   %if %str(&etls_debug) ne 0 %then 
      OPTIONS MPRINT%str(;); 
%mend; 
%etls_setDebug; 

/*============================================================================* 
 * Pre-Process code for the job                             A5V75JN3.AY0004OG * 
 *                                                                            * 
 * User Written:  Oracle Date Problem Fix                   A5V75JN3.AF000PTT * 
 *                Oracle Date Problem Fix                                     * 
 *============================================================================*/ 

/*---- Start of User Written Code  ----*/ 

proc contents data=DDS.FINANCIAL_ACCOUNT_RESTRICTION out=_etlsEngine(keep=Engine) noprint;
run;

data _null_;
	set _etlsEngine;
	if _n_=1;
	  call symput('mEngine', kleft(kright(Engine)));
run;
/*---- End of User Written Code  ----*/ 

%rcSet(&syserr); 
%rcSet(&sqlrc); 

/*============================================================================* 
 * Step:          Extracting and Loading of data as per the A5V75JN3.BO0006ZG * 
 *                 load period                                                * 
 * Transform:     SQL Join (Version 2)                                        * 
 * Description:   Join with LOAD_CONTROL table and extract appropriate data   * 
 *                 based  onLOAD_START_DTTM and LOAD_END_DTTM                 * 
 *                                                                            * 
 * Source Tables: LOAD_CONTROL - control.LOAD_CONTROL       A5V75JN3.BE0000I0 * 
 *                FINANCIAL_ACCOUNT_RESTRICTION -           A5V75JN3.BE00002W * 
 *                 DDS.FINANCIAL_ACCOUNT_RESTRICTION                          * 
 * Target Table:  Extract Target - martscr.FIN_ACCT_RST_EXT A5V75JN3.BP00066Y * 
 *============================================================================*/ 

/* Access the data for Control  */ 
LIBNAME control BASE "Data/bisdata/control" ;
%rcSet(&syslibrc); 

/* Access the data for Detail Data Store  */ 
LIBNAME DDS BASE "Data/bisdata/dds" ;
%rcSet(&syslibrc); 

/* Access the data for Scratch for Mart  */ 
LIBNAME martscr BASE "Data/bisdata/scratch/mart" ;
%rcSet(&syslibrc); 

%let transformID = %quote(A5V75JN3.BO0006ZG); 

%let trans_rc = 0; 

proc datasets lib = martscr nolist nowarn memtype = (data view);
   delete FIN_ACCT_RST_EXT;
quit;

proc sql;
   create table martscr.FIN_ACCT_RST_EXT as
      select
         FINANCIAL_ACCOUNT_RESTRICTION.ACCOUNT_RK length = 8
                                                  format = 12.
                                                  informat = 12.
                                                  label = "Account Key",
         LOAD_CONTROL.LOAD_END_DTTM length = 8
                                    format = NLDATM21.
                                    informat = NLDATM21.
                                    label = "Load End Datetime",
         FINANCIAL_ACCOUNT_RESTRICTION.ACCOUNT_RESTRICTION_TYPE_CD length = 3
                                                                   label = "Account Restriction Type Code"
      from
         control.LOAD_CONTROL, 
         DDS.FINANCIAL_ACCOUNT_RESTRICTION
      where
         LOAD_CONTROL.LOAD_FLG IN (&CHECK_FLAG_TRUE)
         and LOAD_CONTROL.RUN_STATUS IN (&RUNNING_STATUS)
         and CASE symget('mEngine')  
                 WHEN "ORACLE" THEN datepart(FINANCIAL_ACCOUNT_RESTRICTION.RESTRICTION_DT)
                 ELSE FINANCIAL_ACCOUNT_RESTRICTION.RESTRICTION_DT
         END >= DATEPART(LOAD_CONTROL.LOAD_START_DTTM)
         and CASE symget('mEngine')  
                 WHEN "ORACLE" THEN datepart(FINANCIAL_ACCOUNT_RESTRICTION.RESTRICTION_DT)
                 ELSE FINANCIAL_ACCOUNT_RESTRICTION.RESTRICTION_DT
         END <= DATEPART(LOAD_CONTROL.LOAD_END_DTTM)
      ;
quit;

%rcSet(&sqlrc); 

%macro etls_completeTarget();
   /*---- Create the integrity constraints for a table  ----*/ 
   %put %str(NOTE: Creating integrity constraints ...);
   proc datasets library=martscr nolist;
      modify FIN_ACCT_RST_EXT;
         ic create not null (ACCOUNT_RK);
         ic create not null (LOAD_END_DTTM);
   quit;
   
   %rcSet(&syserr); 
   
%mend etls_completeTarget;
%etls_completeTarget;

/*============================================================================* 
 * Step:          Dummy Loader                              A5V75JN3.BO0006ZF * 
 * Transform:     Table Loader                                                * 
 * Description:                                                               * 
 *                                                                            * 
 * Source Table:  Extract Target - martscr.FIN_ACCT_RST_EXT A5V75JN3.BP00066Y * 
 * Target Table:  FIN_ACCT_RST_EXT -                        A5V75JN3.BE0000JP * 
 *                 martscr.FIN_ACCT_RST_EXT                                   * 
 *============================================================================*
 *                                                                            * 
 * Nothing will be generated for this process because the "Do not generate    * 
 *  code for this process" option is selected.                                * 
 *                                                                            * 
 *============================================================================*/ 

data _null_; 
   call symput('etls_endTime',put(datetime(),datetime.));
run;

/* Check return code for job  */ 
%macro etls_jobRCChk; 
   %if (&job_rc eq 4) %then
   %do; 
      %on_success(Job_nm=&etls_jobName..sas, param_table=&status_table);
   %end; 
%mend etls_jobRCChk; 
%etls_jobRCChk; 

/* Check return code for job  */ 
%macro etls_jobRCChk; 
   %if (&job_rc ge 5) %then
   %do; 
      %on_success(Job_nm=&etls_jobName..sas, param_table=&status_table);
   %end; 
%mend etls_jobRCChk; 
%etls_jobRCChk; 

/* Check return code for job  */ 
%macro etls_jobRCChk; 
   %if (&job_rc eq 0) %then
   %do; 
      %on_success(Job_nm=&etls_jobName..sas, param_table=&status_table);
   %end; 
%mend etls_jobRCChk; 
%etls_jobRCChk; 

/*---- Job status macro  ----*/ 
/*============================================================================* 
 * Post-Process code for the job                            A5V75JN3.AY0004OH * 
 *                                                                            * 
 * User Written:  Index creation on ACCOUNT_RK &            A5V75JN3.AF000PTU * 
 *                 LOAD_END_DTTM                                              * 
 *                Index creation on ACCOUNT_RK & LOAD_END_DTTM                * 
 *============================================================================*/ 

/*---- Start of User Written Code  ----*/ 

/*creating index on ACCOUNT_RK * LOAD_END_DTTM column */
PROC SQL NOPRINT;
     CREATE INDEX ACCOUNT_RK_LOAD_END_DTTM
      ON martscr.FIN_ACCT_RST_EXT(ACCOUNT_RK,LOAD_END_DTTM);
QUIT;
/*---- End of User Written Code  ----*/ 

%rcSet(&syserr); 
%rcSet(&sqlrc); 

