/****************************************************************************** 
 * Job:           FPA_EXT                                   A5V75JN3.BN00001T * 
 * Description:   This job picks up data from  FINANCIAL_PRODUCT_ACCOUNT      * 
 *                                                                            * 
 * Repository:    Foundation                                A0000001.A5V75JN3 * 
 * Server:        SASMain                                   A5V75JN3.AT000001 * 
 *                                                                            * 
 * Source Tables: LOAD_CONTROL - control.LOAD_CONTROL       A5V75JN3.BE0000I0 * 
 *                FINANCIAL_PRODUCT_ACCOUNT -               A5V75JN3.BE00003D * 
 *                 DDS.FINANCIAL_PRODUCT_ACCOUNT                              * 
 * Target Table:  FPA_EXT - martscr.FPA_EXT                 A5V75JN3.BE0000JR * 
 *                                                                            * 
 * Generated on:  Wednesday, December 10, 2008 2:39:32 PM IST                 * 
 * Generated by:  sasadm                                                      * 
 * Version:       9.1.20060626.51875                                          * 
 ******************************************************************************
 * Notes:                                                                     * 
 * FPA_EXT                                                                    * 
 * Job Name: FPA_EXTJob Desc Pre Process: NoneMain:Extract and load data      * 
 * from FINANCIAL_PRODUCT_ACCOUNT using a SQL join with table LOAD_CONTROL    * 
 * based on conditionLOAD_CONTROL.LOAD_FLG = CHECK_FLAG_TRUE                  * 
 * andLOAD_CONTROL.RUN_STATUS = RUNNING_STATUS                                * 
 * andLOAD_CONTROL.LOAD_END_DTTM betweenSTART_DT and END_DT and               * 
 * PRIMARY_PROD_FLG IN (&CHECK_FLAG_TRUE.)Post Process: Index is created      * 
 * onACCOUNT_RK,LOAD_END_DTTMParameters: CHECK_FLAG_TRUE and RUNNING_STATUS   * 
 * are the user defined parameters. CHECK_FLAG_TRUE is set to 'Y' and         * 
 * RUNNING_STATUS is to 'Running' for each month of data load.Developed by:   * 
 *  sinahkReviewed by:Tested by:                                              * 
 ******************************************************************************/ 



%let jobID = %quote(A5V75JN3.BN00001T);

/* Setup for capturing job status  */ 
data _null_; 
   call symput('etls_startTime',put(datetime(),datetime.));
run;

%let etls_jobName = FPA_EXT;
%let etls_recordsBefore = 0;
%let etls_recordsAfter = 0;
%let etls_lib = 0;
%let etls_table = 0;

/* Setup to capture return codes  */ 
%global job_rc trans_rc sqlrc; 
%let job_rc = 0;
%let trans_rc = 0;
%let sqlrc = 0;
%global syserr; 

%macro rcSet(error); 
   %if (&error gt &trans_rc) %then 
      %let trans_rc = &error;
   %if (&error gt &job_rc) %then 
      %let job_rc = &error;
%mend rcSet; 

%macro rcSetDS(error); 
   if &error gt input(symget('trans_rc'),12.) then 
      call symput('trans_rc',trim(left(put(&error,12.))));
   if &error gt input(symget('job_rc'),12.) then 
      call symput('job_rc',trim(left(put(&error,12.))));
%mend rcSetDS; 

%global etls_debug; 
%macro etls_setDebug; 
   %if %str(&etls_debug) ne 0 %then 
      OPTIONS MPRINT%str(;); 
%mend; 
%etls_setDebug; 

/*============================================================================* 
 * Pre-Process code for the job                             A5V75JN3.AY0004OK * 
 *                                                                            * 
 * User Written:  Oracle Date Problem Fix                   A5V75JN3.AF000PUQ * 
 *                Oracle Date Problem Fix                                     * 
 *============================================================================*/ 

/*---- Start of User Written Code  ----*/ 

proc contents data=DDS.FINANCIAL_PRODUCT_ACCOUNT out=_etlsEngine(keep=Engine) noprint;
run;

data _null_;
	set _etlsEngine;
	if _n_=1;
	  call symput('mEngine', kleft(kright(Engine)));
run;
/*---- End of User Written Code  ----*/ 

%rcSet(&syserr); 
%rcSet(&sqlrc); 

/*============================================================================* 
 * Step:          Extracting and Loading of data as per the A5V75JN3.BO0006ZK * 
 *                 load period                                                * 
 * Transform:     SQL Join (Version 2)                                        * 
 * Description:   Join with LOAD_CONTROL table and extract appropriate data   * 
 *                 based  onSTART_DT and END_DT                               * 
 *                                                                            * 
 * Source Tables: LOAD_CONTROL - control.LOAD_CONTROL       A5V75JN3.BE0000I0 * 
 *                FINANCIAL_PRODUCT_ACCOUNT -               A5V75JN3.BE00003D * 
 *                 DDS.FINANCIAL_PRODUCT_ACCOUNT                              * 
 * Target Table:  SQL Target - martscr.FPA_EXT              A5V75JN3.BP000670 * 
 *============================================================================*/ 

/* Access the data for Control  */ 
LIBNAME control BASE "Data/bisdata/control" ;
%rcSet(&syslibrc); 

/* Access the data for Detail Data Store  */ 
LIBNAME DDS BASE "Data/bisdata/dds" ;
%rcSet(&syslibrc); 

/* Access the data for Scratch for Mart  */ 
LIBNAME martscr BASE "Data/bisdata/scratch/mart" ;
%rcSet(&syslibrc); 

%let transformID = %quote(A5V75JN3.BO0006ZK); 

%let trans_rc = 0; 

proc datasets lib = martscr nolist nowarn memtype = (data view);
   delete FPA_EXT;
quit;

proc sql;
   create table martscr.FPA_EXT as
      select
         LOAD_CONTROL.LOAD_END_DTTM length = 8
                                    format = NLDATM21.
                                    informat = NLDATM21.
                                    label = "Load End Datetime",
         FINANCIAL_PRODUCT_ACCOUNT.ACCOUNT_RK length = 8
                                              format = 12.
                                              informat = 12.
                                              label = "Account Key",
         FINANCIAL_PRODUCT_ACCOUNT.PRODUCT_RK length = 8
                                              format = 12.
                                              informat = 12.
                                              label = "Product Key",
         FINANCIAL_PRODUCT_ACCOUNT.PRIMARY_PROD_FLG length = 1
                                                    label = "Primary Product Flag",
         FINANCIAL_PRODUCT_ACCOUNT.REINVEST_FLG length = 1
                                                label = "Reinvest Flag",
         FINANCIAL_PRODUCT_ACCOUNT.INVEST_REGULAR_AMT length = 8
                                                      format = NLNUM18.5
                                                      informat = NLNUM18.5
                                                      label = "Invest Regular Amount",
         FINANCIAL_PRODUCT_ACCOUNT.INVEST_LAST_LUMP_SUM_AMT length = 8
                                                            format = NLNUM18.5
                                                            informat = NLNUM18.5
                                                            label = "Invest Last Lump Sum Amount",
         FINANCIAL_PRODUCT_ACCOUNT.FUND_UNITS_CNT length = 8
                                                  format = NLNUM6.2
                                                  informat = NLNUM6.2
                                                  label = "Fund Units Count",
         FINANCIAL_PRODUCT_ACCOUNT.TOT_CURR_FUND_VAL length = 8
                                                     format = NLNUM18.5
                                                     informat = NLNUM18.5
                                                     label = "Total Current Fund Value"
      from
         control.LOAD_CONTROL, 
         DDS.FINANCIAL_PRODUCT_ACCOUNT
      where
         LOAD_CONTROL.LOAD_FLG IN (&CHECK_FLAG_TRUE)
         and LOAD_CONTROL.RUN_STATUS IN (&RUNNING_STATUS)
         and datepart(LOAD_CONTROL.LOAD_END_DTTM) >= CASE symget('mEngine')  
                 WHEN "ORACLE" THEN datepart(FINANCIAL_PRODUCT_ACCOUNT.START_DT)
                 ELSE FINANCIAL_PRODUCT_ACCOUNT.START_DT
         END
         and datepart(LOAD_CONTROL.LOAD_END_DTTM) <= CASE symget('mEngine')  
                 WHEN "ORACLE" THEN datepart(FINANCIAL_PRODUCT_ACCOUNT.END_DT)
                 ELSE FINANCIAL_PRODUCT_ACCOUNT.END_DT
         END
         and FINANCIAL_PRODUCT_ACCOUNT.PRIMARY_PROD_FLG IN (&CHECK_FLAG_TRUE.)
      ;
quit;

%rcSet(&sqlrc); 

%macro etls_completeTarget();
%mend etls_completeTarget;
%etls_completeTarget;

/*============================================================================* 
 * Step:          Dummy Loader                              A5V75JN3.BO0006ZJ * 
 * Transform:     Table Loader                                                * 
 * Description:                                                               * 
 *                                                                            * 
 * Source Table:  SQL Target - martscr.FPA_EXT              A5V75JN3.BP000670 * 
 * Target Table:  FPA_EXT - martscr.FPA_EXT                 A5V75JN3.BE0000JR * 
 *============================================================================*
 *                                                                            * 
 * Nothing will be generated for this process because the "Do not generate    * 
 *  code for this process" option is selected.                                * 
 *                                                                            * 
 *============================================================================*/ 

data _null_; 
   call symput('etls_endTime',put(datetime(),datetime.));
run;

/* Check return code for job  */ 
%macro etls_jobRCChk; 
   %if (&job_rc eq 4) %then
   %do; 
      %on_success(Job_nm=&etls_jobName..sas, param_table=&status_table);
   %end; 
%mend etls_jobRCChk; 
%etls_jobRCChk; 

/* Check return code for job  */ 
%macro etls_jobRCChk; 
   %if (&job_rc ge 5) %then
   %do; 
      %on_success(Job_nm=&etls_jobName..sas, param_table=&status_table);
   %end; 
%mend etls_jobRCChk; 
%etls_jobRCChk; 

/* Check return code for job  */ 
%macro etls_jobRCChk; 
   %if (&job_rc eq 0) %then
   %do; 
      %on_success(Job_nm=&etls_jobName..sas, param_table=&status_table);
   %end; 
%mend etls_jobRCChk; 
%etls_jobRCChk; 

/*---- Job status macro  ----*/ 
/*============================================================================* 
 * Post-Process code for the job                            A5V75JN3.AY0004OL * 
 *                                                                            * 
 * User Written:  Creating index on ACCOUNT_RK &            A5V75JN3.AF000PUR * 
 *                 LOAD_END_DTTM column.                                      * 
 *                Creating index on ACCOUNT_RK & LOAD_END_DTTM column.        * 
 *============================================================================*/ 

/*---- Start of User Written Code  ----*/ 

/*Creating index on ACCOUNT_RK & LOAD_END_DTTM column */
PROC SQL NOPRINT;
  CREATE INDEX ACCOUNT_RK_LOAD_END_DTTM
   ON martscr.FPA_EXT(ACCOUNT_RK,LOAD_END_DTTM);
QUIT;
/*---- End of User Written Code  ----*/ 

%rcSet(&syserr); 
%rcSet(&sqlrc); 

