/****************************************************************************** 
 * Job:           FP_APPND_PRD_TYPE_L                       A5V75JN3.BN00007F * 
 * Description:   This job picks up the data from   FP_EXT and                * 
 *                 APPEND_PRODUCTS .                                          * 
 *                                                                            * 
 * Repository:    Foundation                                A0000001.A5V75JN3 * 
 * Server:        SASMain                                   A5V75JN3.AT000001 * 
 *                                                                            * 
 * Source Tables: FP_EXT - martscr.FP_EXT                   A5V75JN3.BE0000JQ * 
 *                APPEND_PRODUCTS - martscr.APPEND_PRODUCTS A5V75JN3.BE0000ID * 
 * Target Table:  FP_APPND_PRD_TYPE_L -                     A5V75JN3.BE0000Q3 * 
 *                 martscr.FP_APPND_PRD_TYPE_L                                * 
 *                                                                            * 
 * Generated on:  Wednesday, December 10, 2008 2:34:55 PM IST                 * 
 * Generated by:  sasadm                                                      * 
 * Version:       9.1.20060626.51875                                          * 
 ******************************************************************************
 * Notes:                                                                     * 
 * FP_APPND_PRD_TYPE_L                                                        * 
 * Job Name: FP_APPND_PRD_TYPE_LJob Desc :Pre Process: NoneMain: Finding      * 
 * product type code for all product type by left joining the table FP_EXT    * 
 * and APPEND_PRODUCTS on PRODUCT_RK and LOAD_END_DTTM .Post Process:         * 
 * creating index on PRODUCT_CATEGORY_CD andLOAD_END_DTTM                     * 
 *  columns.Parameters: NoneDeveloped by: sinahkReviewed by:Tested by:        * 
 ******************************************************************************/ 



%let jobID = %quote(A5V75JN3.BN00007F);

/* Setup for capturing job status  */ 
data _null_; 
   call symput('etls_startTime',put(datetime(),datetime.));
run;

%let etls_jobName = FP_APPND_PRD_TYPE_L;
%let etls_recordsBefore = 0;
%let etls_recordsAfter = 0;
%let etls_lib = 0;
%let etls_table = 0;

/* Setup to capture return codes  */ 
%global job_rc trans_rc sqlrc; 
%let job_rc = 0;
%let trans_rc = 0;
%let sqlrc = 0;
%global syserr; 

%macro rcSet(error); 
   %if (&error gt &trans_rc) %then 
      %let trans_rc = &error;
   %if (&error gt &job_rc) %then 
      %let job_rc = &error;
%mend rcSet; 

%macro rcSetDS(error); 
   if &error gt input(symget('trans_rc'),12.) then 
      call symput('trans_rc',trim(left(put(&error,12.))));
   if &error gt input(symget('job_rc'),12.) then 
      call symput('job_rc',trim(left(put(&error,12.))));
%mend rcSetDS; 

%global etls_debug; 
%macro etls_setDebug; 
   %if %str(&etls_debug) ne 0 %then 
      OPTIONS MPRINT%str(;); 
%mend; 
%etls_setDebug; 

/*============================================================================* 
 * Step:          Finding the product type code for all     A5V75JN3.BO0005QU * 
 *                 product.                                                   * 
 * Transform:     SQL Join (Version 2)                                        * 
 * Description:   Finding product type code for all product type by left      * 
 *                joining the table FP_EXT and APPEND_PRODUCTS on             * 
 *                 PRODUCT_RK and LOAD_END_DTTM.                              * 
 *                                                                            * 
 * Source Tables: FP_EXT - martscr.FP_EXT                   A5V75JN3.BE0000JQ * 
 *                APPEND_PRODUCTS - martscr.APPEND_PRODUCTS A5V75JN3.BE0000ID * 
 * Target Table:  SQL Target - martscr.FP_APPND_PRD_TYPE_L  A5V75JN3.BP0004U2 * 
 *============================================================================*/ 

/* Access the data for Scratch for Mart  */ 
LIBNAME martscr BASE "Data/bisdata/scratch/mart" ;
%rcSet(&syslibrc); 

%let transformID = %quote(A5V75JN3.BO0005QU); 

%let trans_rc = 0; 

proc datasets lib = martscr nolist nowarn memtype = (data view);
   delete FP_APPND_PRD_TYPE_L;
quit;

proc sql;
   create table martscr.FP_APPND_PRD_TYPE_L as
      select
         FP_EXT.FINANCIAL_PRODUCT_TYPE_CD length = 3
                                          label = "Financial Product Type Code",
         FP_EXT.PRODUCT_RK length = 8
                           format = 12.
                           informat = 12.
                           label = "Product Key",
         FP_EXT.MARKETING_RELATIVE_LEVEL_NO as PRODUCT_LEVEL_NO length = 8
                                                                label = "product Relative Level No",
         FP_EXT.PRODUCT_ID length = 32
                           label = "Product ID",
         FP_EXT.PRODUCT_NM length = 40
                           label = "Product Name",
         FP_EXT.EFFECTIVE_DT length = 8
                             format = NLDATE10.
                             informat = NLDATE10.
                             label = "Effective Date",
         FP_EXT.SOURCE_SYSTEM_CD length = 3
                                 label = "Source System Code",
         FP_EXT.EXPIRATION_DT length = 8
                              format = NLDATE10.
                              informat = NLDATE10.
                              label = "Expiration Date",
         APPEND_PRODUCTS.PRODUCT_SUB_TYPE_CD length = 3,
         FP_EXT.PRODUCT_CATEGORY_CD length = 3
                                    label = "Product Category Code",
         FP_EXT.LOAD_END_DTTM length = 8
                              format = NLDATM21.
                              informat = NLDATM21.
                              label = "Load End Datetime"
      from
         martscr.FP_EXT left join 
         martscr.APPEND_PRODUCTS
            on
            (
               FP_EXT.PRODUCT_RK = APPEND_PRODUCTS.PRODUCT_RK
               and FP_EXT.LOAD_END_DTTM = APPEND_PRODUCTS.LOAD_END_DTTM
            )
      ;
quit;

%rcSet(&sqlrc); 

%macro etls_completeTarget();
   /*---- Create the integrity constraints for a table  ----*/ 
   %put %str(NOTE: Creating integrity constraints ...);
   proc datasets library=martscr nolist;
      modify FP_APPND_PRD_TYPE_L;
         ic create not null (PRODUCT_RK);
         ic create not null (LOAD_END_DTTM);
   quit;
   
   %rcSet(&syserr); 
   
%mend etls_completeTarget;
%etls_completeTarget;

/*============================================================================* 
 * Step:          Dummy Loader                              A5V75JN3.BO0005QT * 
 * Transform:     Table Loader                                                * 
 * Description:                                                               * 
 *                                                                            * 
 * Source Table:  SQL Target - martscr.FP_APPND_PRD_TYPE_L  A5V75JN3.BP0004U2 * 
 * Target Table:  FP_APPND_PRD_TYPE_L -                     A5V75JN3.BE0000Q3 * 
 *                 martscr.FP_APPND_PRD_TYPE_L                                * 
 *============================================================================*
 *                                                                            * 
 * Nothing will be generated for this process because the "Do not generate    * 
 *  code for this process" option is selected.                                * 
 *                                                                            * 
 *============================================================================*/ 

data _null_; 
   call symput('etls_endTime',put(datetime(),datetime.));
run;

/* Check return code for job  */ 
%macro etls_jobRCChk; 
   %if (&job_rc eq 4) %then
   %do; 
      %on_success(Job_nm=&etls_jobName..sas, param_table=&status_table);
   %end; 
%mend etls_jobRCChk; 
%etls_jobRCChk; 

/* Check return code for job  */ 
%macro etls_jobRCChk; 
   %if (&job_rc ge 5) %then
   %do; 
      %on_success(Job_nm=&etls_jobName..sas, param_table=&status_table);
   %end; 
%mend etls_jobRCChk; 
%etls_jobRCChk; 

/* Check return code for job  */ 
%macro etls_jobRCChk; 
   %if (&job_rc eq 0) %then
   %do; 
      %on_success(Job_nm=&etls_jobName..sas, param_table=&status_table);
   %end; 
%mend etls_jobRCChk; 
%etls_jobRCChk; 

/*---- Job status macro  ----*/ 
/*============================================================================* 
 * Post-Process code for the job                            A5V75JN3.AY00043S * 
 *                                                                            * 
 * User Written:  creating index on PRODUCT_CATEGORY_CD and A5V75JN3.AF000N02 * 
 *                 LOAD_END_DTTM                                              * 
 *                creating index on PRODUCT_CATEGORY_CD and LOAD_END_DTTM     * 
 *============================================================================*/ 

/*---- Start of User Written Code  ----*/ 

/*creating index on PRODUCT_CATEGORY_CD & LOAD_END_DTTM column */
PROC SQL NOPRINT;
     CREATE INDEX PRODUCT_CATEGORY_CD_L
      ON martscr.FP_APPND_PRD_TYPE_L(PRODUCT_CATEGORY_CD,LOAD_END_DTTM);
QUIT;

/*---- End of User Written Code  ----*/ 

%rcSet(&syserr); 
%rcSet(&sqlrc); 

