/****************************************************************************** 
 * Job:           FP_EXT                                    A5V75JN3.BN00001S * 
 * Description:   This job picks up data from  FINANCIAL_PRODUCT              * 
 *                                                                            * 
 * Repository:    Foundation                                A0000001.A5V75JN3 * 
 * Server:        SASMain                                   A5V75JN3.AT000001 * 
 *                                                                            * 
 * Source Tables: LOAD_CONTROL - control.LOAD_CONTROL       A5V75JN3.BE0000I0 * 
 *                FINANCIAL_PRODUCT - DDS.FINANCIAL_PRODUCT A5V75JN3.BE00003C * 
 * Target Table:  FP_EXT - martscr.FP_EXT                   A5V75JN3.BE0000JQ * 
 *                                                                            * 
 * Generated on:  Wednesday, December 10, 2008 2:36:13 PM IST                 * 
 * Generated by:  sasadm                                                      * 
 * Version:       9.1.20060626.51875                                          * 
 ******************************************************************************
 * Notes:                                                                     * 
 * FP_EXT                                                                     * 
 * Job Name: FP_EXTJob Desc Pre Process: NoneMain:Extract and load data from  * 
 * FINANCIAL_PRODUCT using a SQL join with table LOAD_CONTROL based on        * 
 * conditionLOAD_CONTROL.LOAD_FLG = CHECK_FLAG_TRUE                           * 
 * andLOAD_CONTROL.RUN_STATUS = RUNNING_STATUS                                * 
 * andLOAD_CONTROL.LOAD_END_DTTM betweenVALID_FROM_DTTM and                   * 
 * VALID_TO_DTTMPost Process: Index is created                                * 
 * onFP_EXT.PRODUCT_RK,FP_EXT.LOAD_END_DTTMParameters: CHECK_FLAG_TRUE and    * 
 * RUNNING_STATUS are the user defined parameters. CHECK_FLAG_TRUE is set     * 
 * to 'Y' and RUNNING_STATUS is to 'Running' for each month of data           * 
 *  load.Developed by: sinahkReviewed by:Tested by:                           * 
 ******************************************************************************/ 



%let jobID = %quote(A5V75JN3.BN00001S);

/* Setup for capturing job status  */ 
data _null_; 
   call symput('etls_startTime',put(datetime(),datetime.));
run;

%let etls_jobName = FP_EXT;
%let etls_recordsBefore = 0;
%let etls_recordsAfter = 0;
%let etls_lib = 0;
%let etls_table = 0;

/* Setup to capture return codes  */ 
%global job_rc trans_rc sqlrc; 
%let job_rc = 0;
%let trans_rc = 0;
%let sqlrc = 0;
%global syserr; 

%macro rcSet(error); 
   %if (&error gt &trans_rc) %then 
      %let trans_rc = &error;
   %if (&error gt &job_rc) %then 
      %let job_rc = &error;
%mend rcSet; 

%macro rcSetDS(error); 
   if &error gt input(symget('trans_rc'),12.) then 
      call symput('trans_rc',trim(left(put(&error,12.))));
   if &error gt input(symget('job_rc'),12.) then 
      call symput('job_rc',trim(left(put(&error,12.))));
%mend rcSetDS; 

%global etls_debug; 
%macro etls_setDebug; 
   %if %str(&etls_debug) ne 0 %then 
      OPTIONS MPRINT%str(;); 
%mend; 
%etls_setDebug; 

/*============================================================================* 
 * Pre-Process code for the job                             A5V75JN3.AY0004OI * 
 *                                                                            * 
 * User Written:  Oracle Date Problem Fix                   A5V75JN3.AF000PU9 * 
 *                Oracle Date Problem Fix                                     * 
 *============================================================================*/ 

/*---- Start of User Written Code  ----*/ 

proc contents data=dds.financial_product out=_etlsEngine(keep=Engine) noprint;
run;

data _null_;
	set _etlsEngine;
	if _n_=1;
	  call symput('mEngine', kleft(kright(Engine)));
run;
/*---- End of User Written Code  ----*/ 

%rcSet(&syserr); 
%rcSet(&sqlrc); 

/*============================================================================* 
 * Step:          Extracting and Loading of data as per the A5V75JN3.BO0006ZI * 
 *                 load period                                                * 
 * Transform:     SQL Join (Version 2)                                        * 
 * Description:   Join with LOAD_CONTROL table and extract appropriate data   * 
 *                 based  onVALID_FROM_DTTM and VALID_TO_DTTM                 * 
 *                                                                            * 
 * Source Tables: LOAD_CONTROL - control.LOAD_CONTROL       A5V75JN3.BE0000I0 * 
 *                FINANCIAL_PRODUCT - DDS.FINANCIAL_PRODUCT A5V75JN3.BE00003C * 
 * Target Table:  Extract Target - martscr.FP_EXT           A5V75JN3.BP00066Z * 
 *============================================================================*/ 

/* Access the data for Control  */ 
LIBNAME control BASE "Data/bisdata/control" ;
%rcSet(&syslibrc); 

/* Access the data for Detail Data Store  */ 
LIBNAME DDS BASE "Data/bisdata/dds" ;
%rcSet(&syslibrc); 

/* Access the data for Scratch for Mart  */ 
LIBNAME martscr BASE "Data/bisdata/scratch/mart" ;
%rcSet(&syslibrc); 

%let transformID = %quote(A5V75JN3.BO0006ZI); 

%let trans_rc = 0; 

proc datasets lib = martscr nolist nowarn memtype = (data view);
   delete FP_EXT;
quit;

proc sql;
   create table martscr.FP_EXT as
      select
         LOAD_CONTROL.LOAD_END_DTTM length = 8
                                    format = NLDATM21.
                                    informat = NLDATM21.
                                    label = "Load End Datetime",
         FINANCIAL_PRODUCT.PRODUCT_RK length = 8
                                      format = 12.
                                      informat = 12.
                                      label = "Product Key",
         FINANCIAL_PRODUCT.PRODUCT_ID length = 32
                                      label = "Product ID",
         FINANCIAL_PRODUCT.PRODUCT_NM length = 40
                                      label = "Product Name",
         FINANCIAL_PRODUCT.FINANCIAL_PRODUCT_TYPE_CD length = 3
                                                     label = "Financial Product Type Code",
         FINANCIAL_PRODUCT.PRODUCT_CATEGORY_CD length = 3
                                               label = "Product Category Code",
         CASE symget('mEngine')
         	WHEN "ORACLE" THEN datepart(FINANCIAL_PRODUCT.EFFECTIVE_DT)
         	ELSE FINANCIAL_PRODUCT.EFFECTIVE_DT
         END as EFFECTIVE_DT length = 8
                             format = NLDATE10.
                             informat = NLDATE10.
                             label = "Effective Date",
         CASE symget('mEngine')
         	WHEN "ORACLE" THEN datepart(FINANCIAL_PRODUCT.EXPIRATION_DT)
         	ELSE FINANCIAL_PRODUCT.EXPIRATION_DT
         END as EXPIRATION_DT length = 8
                              format = NLDATE10.
                              informat = NLDATE10.
                              label = "Expiration Date",
         FINANCIAL_PRODUCT.SOURCE_SYSTEM_CD length = 3
                                            label = "Source System Code",
         FINANCIAL_PRODUCT.MARKETING_RELATIVE_LEVEL_NO length = 8
                                                       label = "Marketing Relative Level No"
      from
         control.LOAD_CONTROL, 
         DDS.FINANCIAL_PRODUCT
      where
         LOAD_CONTROL.LOAD_FLG IN (&CHECK_FLAG_TRUE)
         and LOAD_CONTROL.RUN_STATUS IN (&RUNNING_STATUS)
         and LOAD_CONTROL.LOAD_END_DTTM >= FINANCIAL_PRODUCT.VALID_FROM_DTTM
         and LOAD_CONTROL.LOAD_END_DTTM <= FINANCIAL_PRODUCT.VALID_TO_DTTM
      ;
quit;

%rcSet(&sqlrc); 

%macro etls_completeTarget();
   /*---- Create the integrity constraints for a table  ----*/ 
   %put %str(NOTE: Creating integrity constraints ...);
   proc datasets library=martscr nolist;
      modify FP_EXT;
         ic create not null (PRODUCT_ID);
   quit;
   
   %rcSet(&syserr); 
   
%mend etls_completeTarget;
%etls_completeTarget;

/*============================================================================* 
 * Step:          Dummy Loader                              A5V75JN3.BO0006ZH * 
 * Transform:     Table Loader                                                * 
 * Description:                                                               * 
 *                                                                            * 
 * Source Table:  Extract Target - martscr.FP_EXT           A5V75JN3.BP00066Z * 
 * Target Table:  FP_EXT - martscr.FP_EXT                   A5V75JN3.BE0000JQ * 
 *============================================================================*
 *                                                                            * 
 * Nothing will be generated for this process because the "Do not generate    * 
 *  code for this process" option is selected.                                * 
 *                                                                            * 
 *============================================================================*/ 

data _null_; 
   call symput('etls_endTime',put(datetime(),datetime.));
run;

/* Check return code for job  */ 
%macro etls_jobRCChk; 
   %if (&job_rc eq 4) %then
   %do; 
      %on_success(Job_nm=&etls_jobName..sas, param_table=&status_table);
   %end; 
%mend etls_jobRCChk; 
%etls_jobRCChk; 

/* Check return code for job  */ 
%macro etls_jobRCChk; 
   %if (&job_rc ge 5) %then
   %do; 
      %on_success(Job_nm=&etls_jobName..sas, param_table=&status_table);
   %end; 
%mend etls_jobRCChk; 
%etls_jobRCChk; 

/* Check return code for job  */ 
%macro etls_jobRCChk; 
   %if (&job_rc eq 0) %then
   %do; 
      %on_success(Job_nm=&etls_jobName..sas, param_table=&status_table);
   %end; 
%mend etls_jobRCChk; 
%etls_jobRCChk; 

/*---- Job status macro  ----*/ 
/*============================================================================* 
 * Post-Process code for the job                            A5V75JN3.AY0004OJ * 
 *                                                                            * 
 * User Written:  Index creation code on PRODUCT_RK &       A5V75JN3.AF000PUA * 
 *                 LOAD_END_DTTM column                                       * 
 *                Index creation code on PRODUCT_RK & LOAD_END_DTTM column    * 
 *============================================================================*/ 

/*---- Start of User Written Code  ----*/ 

/*creating index on PRODUCT_RK & LOAD_END_DTTM column */
PROC SQL NOPRINT;
           CREATE INDEX PRODUCT_RK_LOAD_END_DTTM
            ON martscr.FP_EXT(PRODUCT_RK,LOAD_END_DTTM);
QUIT;
/*---- End of User Written Code  ----*/ 

%rcSet(&syserr); 
%rcSet(&sqlrc); 

