/****************************************************************************** 
 * Job:           IC_EXT                                    A5V75JN3.BN000021 * 
 * Description:   This job picks up data from INDIVIDUAL_CUSTOMER             * 
 *                                                                            * 
 * Repository:    Foundation                                A0000001.A5V75JN3 * 
 * Server:        SASMain                                   A5V75JN3.AT000001 * 
 *                                                                            * 
 * Source Tables: LOAD_CONTROL - control.LOAD_CONTROL       A5V75JN3.BE0000I0 * 
 *                INDIVIDUAL_CUSTOMER -                     A5V75JN3.BE000044 * 
 *                 DDS.INDIVIDUAL_CUSTOMER                                    * 
 * Target Table:  IC_EXT - martscr.IC_EXT                   A5V75JN3.BE0000JZ * 
 *                                                                            * 
 * Generated on:  Wednesday, December 10, 2008 2:39:32 PM IST                 * 
 * Generated by:  sasadm                                                      * 
 * Version:       9.1.20060626.51875                                          * 
 ******************************************************************************
 * Notes:                                                                     * 
 * IC_EXT                                                                     * 
 * Job Name: IC_EXTJob Desc Pre Process: NoneMain:Extract and load data from  * 
 * INDIVIDUAL_CUSTOMER using a SQL join with table LOAD_CONTROL based on      * 
 * conditionLOAD_CONTROL.LOAD_FLG = CHECK_FLAG_TRUE                           * 
 * andLOAD_CONTROL.RUN_STATUS = RUNNING_STATUS                                * 
 * andLOAD_CONTROL.LOAD_END_DTTM betweenVALID_FROM_DTTM and                   * 
 * VALID_TO_DTTMLength is changed from 3 to 10 character in target table      * 
 * for EMPLOYMENT_INDUSTRY_CD and MONTHLY_PRI_INCOME_SOURCE_CDPost Process:   * 
 * Index is created onIC_EXT.CUSTOMER_RK,IC_EXT.LOAD_END_DTTMParameters:      * 
 * CHECK_FLAG_TRUE and RUNNING_STATUS are the user defined parameters.        * 
 * CHECK_FLAG_TRUE is set to 'Y' and RUNNING_STATUS is to 'Running' for       * 
 *  each month of data load.Developed by: sinahkReviewed by:Tested by:        * 
 ******************************************************************************/ 

/* Setup for capturing job status  */ 
data _null_; 
   call symput('etls_startTime',put(datetime(),datetime.));
run;

%let etls_jobName = IC_EXT;
%let etls_recordsBefore = 0;
%let etls_recordsAfter = 0;
%let etls_lib = 0;
%let etls_table = 0;

/* Setup to capture return codes  */ 
%global job_rc trans_rc sqlrc; 
%let job_rc = 0;
%let trans_rc = 0;
%let sqlrc = 0;
%global syserr; 

%macro rcSet(error); 
   %if (&error gt &trans_rc) %then 
      %let trans_rc = &error;
   %if (&error gt &job_rc) %then 
      %let job_rc = &error;
%mend rcSet; 

%macro rcSetDS(error); 
   if &error gt input(symget('trans_rc'),12.) then 
      call symput('trans_rc',trim(left(put(&error,12.))));
   if &error gt input(symget('job_rc'),12.) then 
      call symput('job_rc',trim(left(put(&error,12.))));
%mend rcSetDS; 

%global etls_debug; 
%macro etls_setDebug; 
   %if %str(&etls_debug) ne 0 %then 
      OPTIONS MPRINT%str(;); 
%mend; 
%etls_setDebug; 

/*============================================================================* 
 * Pre-Process code for the job                             A5V75JN3.AY0004OM * 
 *                                                                            * 
 * User Written:  Oracle Date Problem Fix                   A5V75JN3.AF000PVL * 
 *                Oracle Date Problem Fix                                     * 
 *============================================================================*/ 

/*---- Start of User Written Code  ----*/ 

proc contents data=dds.individual_customer out=_etlsEngine(keep=Engine) noprint;
run;

data _null_;
	set _etlsEngine;
	if _n_=1;
	  call symput('mEngine', kleft(kright(Engine)));
run;
/*---- End of User Written Code  ----*/ 

%rcSet(&syserr); 
%rcSet(&sqlrc); 

/*============================================================================* 
 * Step:          Extracting and Loading of data as per the A5V75JN3.BO0006ZM * 
 *                 load period                                                * 
 * Transform:     SQL Join (Version 2)                                        * 
 * Description:   Join with LOAD_CONTROL table and extract appropriate data   * 
 *                 based  onVALID_FROM_DTTM and VALID_TO_DTTM                 * 
 *                                                                            * 
 * Source Tables: LOAD_CONTROL - control.LOAD_CONTROL       A5V75JN3.BE0000I0 * 
 *                INDIVIDUAL_CUSTOMER -                     A5V75JN3.BE000044 * 
 *                 DDS.INDIVIDUAL_CUSTOMER                                    * 
 * Target Table:  Extract Target - martscr.IC_EXT           A5V75JN3.BP000671 * 
 *============================================================================*/ 

/* Access the data for Control  */ 
LIBNAME control BASE "Data/bisdata/control" ;
%rcSet(&syslibrc); 

/* Access the data for Detail Data Store  */ 
LIBNAME DDS BASE "Data/bisdata/dds" ;
%rcSet(&syslibrc); 

/* Access the data for Scratch for Mart  */ 
LIBNAME martscr BASE "Data/bisdata/scratch/mart" ;
%rcSet(&syslibrc); 

%let trans_rc = 0; 

proc datasets lib = martscr nolist nowarn memtype = (data view);
   delete IC_EXT;
quit;

proc sql;
   create table martscr.IC_EXT as
      select
         INDIVIDUAL_CUSTOMER.ANNUAL_INCOME_AMT length = 8
                                               format = NLNUM18.5
                                               informat = NLNUM18.5
                                               label = "Annual Income Amount",
         INDIVIDUAL_CUSTOMER.ASSET_OTHER_AMT length = 8
                                             format = NLNUM18.5
                                             informat = NLNUM18.5
                                             label = "Asset Other Amount",
         CASE symget('mEngine')
         	WHEN "ORACLE" THEN datepart(INDIVIDUAL_CUSTOMER.BANKRUPTCY_FILED_DT)
         	ELSE INDIVIDUAL_CUSTOMER.BANKRUPTCY_FILED_DT
         END as BANKRUPTCY_FILED_DT length = 8
                                    format = NLDATE10.
                                    informat = NLDATE10.
                                    label = "Bankruptcy Filed Date",
         INDIVIDUAL_CUSTOMER.BANKRUPTCY_STATUS_CD length = 3
                                                  label = "Bankruptcy Status Code",
         INDIVIDUAL_CUSTOMER.BEST_DAY_OF_WK_TO_CNTCT_NO length = 8
                                                        label = "Best Day of Week to Contact",
         INDIVIDUAL_CUSTOMER.BEST_TIME_TO_CONTACT_CD length = 3
                                                     label = "Time of Day to Contact Code",
         INDIVIDUAL_CUSTOMER.BILL_PAY_SERVICE_FLG length = 1
                                                  label = "Bill Pay Service Flag",
         CASE symget('mEngine')
         	WHEN "ORACLE" THEN datepart(INDIVIDUAL_CUSTOMER.BIRTH_DT)
         	ELSE INDIVIDUAL_CUSTOMER.BIRTH_DT
         END as BIRTH_DT length = 8
                         format = NLDATE10.
                         informat = NLDATE10.
                         label = "Birth Date",
         INDIVIDUAL_CUSTOMER.BRANCH_FREQ_REASON_CD length = 3
                                                   label = "Branch Frequency Reason Code",
         INDIVIDUAL_CUSTOMER.CHILDREN_CNT length = 8
                                          label = "Children Count",
         INDIVIDUAL_CUSTOMER.CLIENT_TYPE_CD length = 3
                                            label = "Client Type Code",
         INDIVIDUAL_CUSTOMER.COSIGNER_FLG length = 1
                                          label = "Cosigner Flag",
         INDIVIDUAL_CUSTOMER.COUNTRY_OF_RESIDENCY_CD length = 3
                                                     label = "Country Of Residency Code",
         INDIVIDUAL_CUSTOMER.CREDIT_BUREAU_SCORE length = 8
                                                 format = NLNUM8.2
                                                 informat = NLNUM8.2
                                                 label = "Credit Bureau Score",
         CASE symget('mEngine')
         	WHEN "ORACLE" THEN datepart(INDIVIDUAL_CUSTOMER.CREDIT_BUREAU_SCORE_DT)
         	ELSE INDIVIDUAL_CUSTOMER.CREDIT_BUREAU_SCORE_DT
         END as CREDIT_BUREAU_SCORE_DT length = 8
                                       format = NLDATE10.
                                       informat = NLDATE10.
                                       label = "Credit Bureau Score Date",
         INDIVIDUAL_CUSTOMER.CURRENCY_CD length = 3
                                         label = "Currency Code",
         CASE symget('mEngine')
         	WHEN "ORACLE" THEN datepart(INDIVIDUAL_CUSTOMER.CURRENT_ADDR_START_DT)
         	ELSE INDIVIDUAL_CUSTOMER.CURRENT_ADDR_START_DT
         END as CURRENT_ADDRESS_START_DT length = 8
                                         format = NLDATE10.
                                         informat = NLDATE10.
                                         label = "Current Address Start Date",
         CASE symget('mEngine')
         	WHEN "ORACLE" THEN datepart(INDIVIDUAL_CUSTOMER.CURRENT_COUNTRY_START_DT)
         	ELSE INDIVIDUAL_CUSTOMER.CURRENT_COUNTRY_START_DT
         END as CURRENT_COUNTRY_START_DT length = 8
                                         format = NLDATE10.
                                         informat = NLDATE10.
                                         label = "Current Country Start Date",
         CASE symget('mEngine')
         	WHEN "ORACLE" THEN datepart(INDIVIDUAL_CUSTOMER.CURRENT_EMP_START_DT)
         	ELSE INDIVIDUAL_CUSTOMER.CURRENT_EMP_START_DT
         END as CURRENT_EMP_START_DT length = 8
                                     format = NLDATE10.
                                     informat = NLDATE10.
                                     label = "Current Employment Start Date",
         INDIVIDUAL_CUSTOMER.CUSTOMER_ID length = 32
                                         label = "Customer ID",
         INDIVIDUAL_CUSTOMER.CUSTOMER_RK length = 8
                                         format = 12.
                                         informat = 12.
                                         label = "Customer Key",
         INDIVIDUAL_CUSTOMER.DAYTIME_TELEPHONE_NO length = 20
                                                  label = "Daytime Telephone No",
         INDIVIDUAL_CUSTOMER.DEBT_COLLECTION_FLG length = 1
                                                 label = "Debt Collection Flag",
         INDIVIDUAL_CUSTOMER.DECEASED_FLG length = 1
                                          label = "Deceased Flag",
         INDIVIDUAL_CUSTOMER.DIRECT_DEPOSIT_FLG length = 1
                                                label = "Direct Deposit Flag",
         INDIVIDUAL_CUSTOMER.DRIVER_LICENSE_ID length = 32
                                               label = "Driver License ID",
         CASE symget('mEngine')
         	WHEN "ORACLE" THEN datepart(INDIVIDUAL_CUSTOMER.DRIVERS_LIC_EXPIRATION_DT)
         	ELSE INDIVIDUAL_CUSTOMER.DRIVERS_LIC_EXPIRATION_DT
         END as DRIVERS_LIC_EXPIRATION_DT length = 8
                                          format = NLDATE10.
                                          informat = NLDATE10.
                                          label = "Drivers License Expiration Date",
         INDIVIDUAL_CUSTOMER.DRIVERS_LIC_STATE_REGION_CD length = 4
                                                         label = "Drivers License State Region Code",
         INDIVIDUAL_CUSTOMER.EDUCATION_LEVEL_CD length = 10
                                                label = "Education Level Code",
         CASE symget('mEngine')
         	WHEN "ORACLE" THEN datepart(INDIVIDUAL_CUSTOMER.ELDEST_CHILD_BIRTH_DT)
         	ELSE INDIVIDUAL_CUSTOMER.ELDEST_CHILD_BIRTH_DT
         END as ELDEST_CHILD_BIRTH_DT length = 8
                                      format = NLDATE10.
                                      informat = NLDATE10.
                                      label = "Eldest Child Birth Date",
         INDIVIDUAL_CUSTOMER.EMAIL_ADDRESS_TXT length = 100
                                               label = "Email Address",
         INDIVIDUAL_CUSTOMER.EMPLOYEE_RK length = 8
                                         format = 12.
                                         informat = 12.
                                         label = "Employee Key",
         INDIVIDUAL_CUSTOMER.EMPLOYER_INDUSTRY_CD length = 10
                                                  label = "Industry Code",
         INDIVIDUAL_CUSTOMER.EMPLOYMENT_BUSINESS_NATURE_CD length = 3
                                                           label = "Business Nature Code",
         INDIVIDUAL_CUSTOMER.EMPLOYMENT_INDUSTRY_CD length = 10
                                                    label = "Industry Code",
         INDIVIDUAL_CUSTOMER.EMPLOYMENT_POSITION_STATUS_CD length = 3
                                                           label = "Employment Position Status Code",
         CASE symget('mEngine')
         	WHEN "ORACLE" THEN datepart(INDIVIDUAL_CUSTOMER.EMPLOYMENT_START_DT)
         	ELSE INDIVIDUAL_CUSTOMER.EMPLOYMENT_START_DT
         END as EMPLOYMENT_START_DT length = 8
                                    format = NLDATE10.
                                    informat = NLDATE10.
                                    label = "Employment Start Date",
         INDIVIDUAL_CUSTOMER.EMPLOYMENT_STATUS_CD length = 3
                                                  label = "Employment Status Code",
         INDIVIDUAL_CUSTOMER.EMPLOYMENT_YEARS_CNT length = 8
                                                  format = NLNUM6.2
                                                  informat = NLNUM6.2
                                                  label = "Employment Years Count",
         INDIVIDUAL_CUSTOMER.FAX_NO length = 20
                                    label = "Fax No",
         INDIVIDUAL_CUSTOMER.FIRST_NM length = 40
                                      label = "First Name",
         INDIVIDUAL_CUSTOMER.FRAUD_FLG length = 1
                                       label = "Fraud Flag",
         INDIVIDUAL_CUSTOMER.GENDER_CD length = 3
                                       label = "Gender Code",
         INDIVIDUAL_CUSTOMER.GEO_DEMOGRAPHIC_CD length = 5
                                                label = "Geography Demographic Code",
         INDIVIDUAL_CUSTOMER.GONEAWAY_FLG length = 1
                                          label = "Goneaway Flag",
         INDIVIDUAL_CUSTOMER.HEAD_OF_HOUSEHOLD_FLG length = 1
                                                   label = "Head Of Household Flag",
         INDIVIDUAL_CUSTOMER.HOME_TELEPHONE_NO length = 20
                                               label = "Home Telephone No",
         INDIVIDUAL_CUSTOMER.HOUSE_APPRAISED_VAL_AMT length = 8
                                                     format = NLNUM18.5
                                                     informat = NLNUM18.5
                                                     label = "Appraised House Value Amount",
         INDIVIDUAL_CUSTOMER.HOUSEHOLD_RK as HHOLD_RK length = 8
                                                      format = 12.
                                                      informat = 12.
                                                      label = "Household Key",
         INDIVIDUAL_CUSTOMER.ID_VERIFICATION_TYPE_CD length = 3
                                                     label = "Id Verification Type Code",
         INDIVIDUAL_CUSTOMER.INCOME_CATEGORY_CD length = 3
                                                label = "Income Category Code",
         CASE symget('mEngine')
         	WHEN "ORACLE" THEN datepart(INDIVIDUAL_CUSTOMER.INCOME_STATED_DT)
         	ELSE INDIVIDUAL_CUSTOMER.INCOME_STATED_DT
         END as INCOME_STATED_DT length = 8
                                 format = NLDATE10.
                                 informat = NLDATE10.
                                 label = "Income Stated Date",
         INDIVIDUAL_CUSTOMER.INSURANCE_FLG length = 1
                                           label = "Insurance Flag",
         INDIVIDUAL_CUSTOMER.CREDIT_RATING_CD as INTERNAL_CREDIT_RATING_CD length = 20
                                                                           label = "Credit Rating Code",
         INDIVIDUAL_CUSTOMER.INTERNET_FLG length = 1
                                          label = "Internet Flag",
         INDIVIDUAL_CUSTOMER.INVESTMENT_EXP_YEARS_NO length = 8
                                                     label = "Investment Experience Years No",
         INDIVIDUAL_CUSTOMER.INVESTMENT_OBJECTIVE_CD length = 3
                                                     label = "Investment Objective Code",
         INDIVIDUAL_CUSTOMER.INVESTMENT_SRVC_SUBSCRIBED_FLG length = 1
                                                            label = "Investment Service Subscribed Flag",
         CASE symget('mEngine')
         	WHEN "ORACLE" THEN datepart(INDIVIDUAL_CUSTOMER.JOB_TITLE_START_DT)
         	ELSE INDIVIDUAL_CUSTOMER.JOB_TITLE_START_DT
         END as JOB_TITLE_START_DT length = 8
                                   format = NLDATE10.
                                   informat = NLDATE10.
                                   label = "Job Title Start Date",
         INDIVIDUAL_CUSTOMER.JOB_TITLE_TXT length = 40
                                           label = "Job Title",
         INDIVIDUAL_CUSTOMER.LANGUAGE_PREFERENCE_CD length = 3
                                                    label = "Language Preference Code",
         INDIVIDUAL_CUSTOMER.LAST_NM length = 40
                                     label = "Last Name",
         INDIVIDUAL_CUSTOMER.LEGAL_JUDGEMENT_FLG length = 1
                                                 label = "Legal Judgement Flag",
         INDIVIDUAL_CUSTOMER.LIABILITY_OTHER_AMT length = 8
                                                 format = NLNUM18.5
                                                 informat = NLNUM18.5
                                                 label = "Liability Other Amount",
         INDIVIDUAL_CUSTOMER.LIABILITY_REAL_ESTATE_AMT length = 8
                                                       format = NLNUM18.5
                                                       informat = NLNUM18.5
                                                       label = "Liability Real Estate Amount",
         INDIVIDUAL_CUSTOMER.LIFESTAGE_CD length = 3
                                          label = "Life Stage Code",
         INDIVIDUAL_CUSTOMER.LIQUID_ASSETS_AMT length = 8
                                               format = NLNUM18.5
                                               informat = NLNUM18.5
                                               label = "Liquid Assets Amount",
         INDIVIDUAL_CUSTOMER.LIQUID_NET_WORTH_AMT length = 8
                                                  format = NLNUM18.5
                                                  informat = NLNUM18.5
                                                  label = "Liquid Net Worth Amount",
         LOAD_CONTROL.LOAD_END_DTTM length = 8
                                    format = NLDATM21.
                                    informat = NLDATM21.
                                    label = "Load End Datetime",
         INDIVIDUAL_CUSTOMER.MAINTENANCE_FLG length = 1
                                             label = "Maintenance Flag",
         INDIVIDUAL_CUSTOMER.MARITAL_STATUS_CD length = 3
                                               label = "Marital Status Code",
         INDIVIDUAL_CUSTOMER.MIDDLE_NM length = 40
                                       label = "Middle Name",
         INDIVIDUAL_CUSTOMER.MOBILE_TELEPHONE_NO length = 20
                                                 label = "Mobile Telephone No",
         INDIVIDUAL_CUSTOMER.MONTHLY_HOUSING_AMT length = 8
                                                 format = NLNUM18.5
                                                 informat = NLNUM18.5
                                                 label = "Monthly Housing Amount",
         INDIVIDUAL_CUSTOMER.MONTHLY_PRI_INCOME_SOURCE_CD length = 10
                                                          label = "Cash Flow Source Code",
         INDIVIDUAL_CUSTOMER.NET_WORTH_AMT length = 8
                                           format = NLNUM18.5
                                           informat = NLNUM18.5
                                           label = "Net Worth Amount",
         INDIVIDUAL_CUSTOMER.NET_WORTH_CD length = 3
                                          label = "Net Worth Code",
         INDIVIDUAL_CUSTOMER.NM_SUFFIX_TXT length = 40
                                           label = "Name Suffix",
         INDIVIDUAL_CUSTOMER.NO_OF_EMPLOYERS_CNT as EMPLOYERS_CNT length = 8
                                                                  label = "No Of Employers Count",
         CASE symget('mEngine')
         	WHEN "ORACLE" THEN datepart(INDIVIDUAL_CUSTOMER.OCCUPATION_START_DT)
         	ELSE INDIVIDUAL_CUSTOMER.OCCUPATION_START_DT
         END as OCCUPATION_START_DT length = 8
                                    format = NLDATE10.
                                    informat = NLDATE10.
                                    label = "Occupation Start Date",
         INDIVIDUAL_CUSTOMER.ONLINE_BANKING_FLG length = 1
                                                label = "Online Banking Flag",
         INDIVIDUAL_CUSTOMER.OTHER_CREDIT_CARDS_CNT length = 8
                                                    label = "Other Credit Cards Count",
         INDIVIDUAL_CUSTOMER.OTHER_INST_CLIENT_CNT length = 8
                                                   label = "Other Institute Client Count",
         INDIVIDUAL_CUSTOMER.OWN_AUTOMOBILE_FLG length = 1
                                                label = "Own Automobile Flag",
         INDIVIDUAL_CUSTOMER.OWN_MOTORCYCLE_FLG length = 1
                                                label = "Own Motorcycle Flag",
         CASE symget('mEngine')
         	WHEN "ORACLE" THEN datepart(INDIVIDUAL_CUSTOMER.PASSPORT_EXPIRATION_DT)
         	ELSE INDIVIDUAL_CUSTOMER.PASSPORT_EXPIRATION_DT
         END as PASSPORT_EXPIRATION_DT length = 8
                                       format = NLDATE10.
                                       informat = NLDATE10.
                                       label = "Passport Expiration Date",
         INDIVIDUAL_CUSTOMER.PASSPORT_ISSUE_COUNTRY_CD length = 3
                                                       label = "Country Code",
         INDIVIDUAL_CUSTOMER.PASSPORT_NO length = 32
                                         label = "Passport No",
         INDIVIDUAL_CUSTOMER.PENDING_LAWSUIT_FLG length = 1
                                                 label = "Pending Lawsuit Flag",
         INDIVIDUAL_CUSTOMER.PREFERRED_TELEPHONE_NO length = 20
                                                    label = "Preferred Telephone No",
         INDIVIDUAL_CUSTOMER.PRIMARY_CITIZENSHIP_COUNTRY_CD length = 3
                                                            label = "Country Code",
         INDIVIDUAL_CUSTOMER.PRIMARY_ECONOM_ACTIV_CD length = 3
                                                     label = "Primary Economic Activity Code",
         INDIVIDUAL_CUSTOMER.PRIMARY_EMPLOYER_NM length = 100
                                                 label = "Primary Employer Name",
         INDIVIDUAL_CUSTOMER.PRIMARY_EMPLOYER_PHONE_NO length = 20
                                                       label = "Primary Employer Phone No",
         INDIVIDUAL_CUSTOMER.PUBLIC_RECORDS_CNT length = 8
                                                label = "Public Records Count",
         INDIVIDUAL_CUSTOMER.REAL_ESTATE_AMT length = 8
                                             format = NLNUM18.5
                                             informat = NLNUM18.5
                                             label = "Real Estate Amount",
         INDIVIDUAL_CUSTOMER.RESIDENT_FLG length = 1
                                          label = "RESIDENT_FLG",
         INDIVIDUAL_CUSTOMER.RESIDENT_STATUS_CD as RESIDENCE_STATUS_CD length = 3
                                                                       label = "Resident Status Code",
         CASE symget('mEngine')
         	WHEN "ORACLE" THEN datepart(INDIVIDUAL_CUSTOMER.RESIDENCE_STATUS_DT)
         	ELSE INDIVIDUAL_CUSTOMER.RESIDENCE_STATUS_DT
         END as RESIDENCE_STATUS_DT length = 8
                                    format = NLDATE10.
                                    informat = NLDATE10.
                                    label = "Residence Status Date",
         CASE symget('mEngine')
         	WHEN "ORACLE" THEN datepart(INDIVIDUAL_CUSTOMER.SALARY_ESTIMATE_DT)
         	ELSE INDIVIDUAL_CUSTOMER.SALARY_ESTIMATE_DT
         END as SALARY_ESTIMATE_DT length = 8
                                   format = NLDATE10.
                                   informat = NLDATE10.
                                   label = "Salary Estimate Date",
         INDIVIDUAL_CUSTOMER.SALARY_RANGE_CD length = 3
                                             label = "Salary Range Code",
         INDIVIDUAL_CUSTOMER.SALUTATION_NM length = 20
                                           label = "Salutation Name",
         INDIVIDUAL_CUSTOMER.SECNDRY_CITIZENSHIP_COUNTRY_CD length = 3
                                                            label = "Country Code",
         INDIVIDUAL_CUSTOMER.SHAREHOLDER_FLG length = 1
                                             label = "Shareholder Flag",
         INDIVIDUAL_CUSTOMER.SIBLING_CNT length = 8
                                         label = "Sibling Count",
         INDIVIDUAL_CUSTOMER.SOCIAL_SECURITY_NO length = 20
                                                label = "Social Security No",
         INDIVIDUAL_CUSTOMER.SOURCE_SYSTEM_CD length = 3
                                              label = "Source System Code",
         INDIVIDUAL_CUSTOMER.SPECIAL_NEEDS_CD length = 3
                                              label = "Special Needs Code",
         INDIVIDUAL_CUSTOMER.STD_OCCUPATION_CD length = 3
                                               label = "Standard Occupation Code",
         INDIVIDUAL_CUSTOMER.TAX_BRACKET_CD length = 3
                                            label = "Tax Bracket Code",
         CASE symget('mEngine')
         	WHEN "ORACLE" THEN datepart(INDIVIDUAL_CUSTOMER.TEMPORARY_EMPLOYMENT_END_DT)
         	ELSE INDIVIDUAL_CUSTOMER.TEMPORARY_EMPLOYMENT_END_DT
         END as TEMPORARY_EMPLOYMENT_END_DT length = 8
                                            format = NLDATE10.
                                            informat = NLDATE10.
                                            label = "Temporary Employment End Date",
         INDIVIDUAL_CUSTOMER.TIME_RESIDENCE_YEAR_CNT length = 8
                                                     format = NLNUM6.2
                                                     informat = NLNUM6.2
                                                     label = "Time at Residence in Years",
         INDIVIDUAL_CUSTOMER.TITLE_TXT length = 20
                                       label = "Title Text",
         INDIVIDUAL_CUSTOMER.TOTAL_ASSET_AMT length = 8
                                             format = NLNUM18.5
                                             informat = NLNUM18.5
                                             label = "Total Asset Amount",
         INDIVIDUAL_CUSTOMER.TOTAL_DEPENDENTS_CNT length = 8
                                                  label = "Total Dependents Count",
         INDIVIDUAL_CUSTOMER.TOTAL_EMPLOYMENT_YEARS_CNT length = 8
                                                        format = NLNUM6.2
                                                        informat = NLNUM6.2
                                                        label = "Total Employment Years Count",
         INDIVIDUAL_CUSTOMER.TOTAL_LIABILITY_AMT length = 8
                                                 format = NLNUM18.5
                                                 informat = NLNUM18.5
                                                 label = "Total Liability Amount",
         CASE symget('mEngine')
         	WHEN "ORACLE" THEN datepart(INDIVIDUAL_CUSTOMER.YOUNGEST_CHILD_BIRTH_DT)
         	ELSE INDIVIDUAL_CUSTOMER.YOUNGEST_CHILD_BIRTH_DT
         END as YOUNGEST_CHILD_BIRTH_DT length = 8
                                        format = NLDATE10.
                                        informat = NLDATE10.
                                        label = "Youngest Child Birth Date"
      from
         control.LOAD_CONTROL, 
         DDS.INDIVIDUAL_CUSTOMER
      where
         LOAD_CONTROL.LOAD_FLG IN (&CHECK_FLAG_TRUE)
         and LOAD_CONTROL.RUN_STATUS IN (&RUNNING_STATUS)
         and LOAD_CONTROL.LOAD_END_DTTM >= INDIVIDUAL_CUSTOMER.VALID_FROM_DTTM
         and LOAD_CONTROL.LOAD_END_DTTM <= INDIVIDUAL_CUSTOMER.VALID_TO_DTTM
      ;
quit;

%rcSet(&sqlrc); 

%macro etls_completeTarget();
%mend etls_completeTarget;
%etls_completeTarget;

/*============================================================================* 
 * Step:          Dummy Loader                              A5V75JN3.BO0006ZL * 
 * Transform:     Table Loader                                                * 
 * Description:                                                               * 
 *                                                                            * 
 * Source Table:  Extract Target - martscr.IC_EXT           A5V75JN3.BP000671 * 
 * Target Table:  IC_EXT - martscr.IC_EXT                   A5V75JN3.BE0000JZ * 
 *============================================================================*
 *                                                                            * 
 * Nothing will be generated for this process because the "Do not generate    * 
 *  code for this process" option is selected.                                * 
 *                                                                            * 
 *============================================================================*/ 

data _null_; 
   call symput('etls_endTime',put(datetime(),datetime.));
run;

/* Check return code for job  */ 
%macro etls_jobRCChk; 
   %if (&job_rc eq 4) %then
   %do; 
      %on_success(Job_nm=&etls_jobName..sas, param_table=&status_table);
   %end; 
%mend etls_jobRCChk; 
%etls_jobRCChk; 

/* Check return code for job  */ 
%macro etls_jobRCChk; 
   %if (&job_rc ge 5) %then
   %do; 
      %on_success(Job_nm=&etls_jobName..sas, param_table=&status_table);
   %end; 
%mend etls_jobRCChk; 
%etls_jobRCChk; 

/* Check return code for job  */ 
%macro etls_jobRCChk; 
   %if (&job_rc eq 0) %then
   %do; 
      %on_success(Job_nm=&etls_jobName..sas, param_table=&status_table);
   %end; 
%mend etls_jobRCChk; 
%etls_jobRCChk; 

/*---- Job status macro  ----*/ 
/*============================================================================* 
 * Post-Process code for the job                            A5V75JN3.AY0004ON * 
 *                                                                            * 
 * User Written:  Index creation code on CUSTOMER_RK &      A5V75JN3.AF000PVM * 
 *                 LOAD_END_DTTM column                                       * 
 *                Index creation code on CUSTOMER_RK & LOAD_END_DTTM column   * 
 *============================================================================*/ 

/*---- Start of User Written Code  ----*/ 

/*creating index on CUSTOMER_RK & LOAD_END_DTTM column */
PROC SQL NOPRINT;
           CREATE INDEX CUSTOMER_RK_LOAD_END_DTTM
            ON martscr.IC_EXT(CUSTOMER_RK,LOAD_END_DTTM);
QUIT;
/*---- End of User Written Code  ----*/ 

%rcSet(&syserr); 
%rcSet(&sqlrc); 

