/****************************************************************************** 
 * Job:           IO_EXT                                    A5V75JN3.BN000025 * 
 * Description:   This job builds the IO_EXT table by picking up data from    * 
 *                 INTERNAL_ORG.                                              * 
 *                                                                            * 
 * Repository:    Foundation                                A0000001.A5V75JN3 * 
 * Server:        SASMain                                   A5V75JN3.AT000001 * 
 *                                                                            * 
 * Source Tables: LOAD_CONTROL - control.LOAD_CONTROL       A5V75JN3.BE0000I0 * 
 *                INTERNAL_ORG - DDS.INTERNAL_ORG           A5V75JN3.BE00004C * 
 * Target Table:  IO_EXT - martscr.IO_EXT                   A5V75JN3.BE0000K3 * 
 *                                                                            * 
 * Generated on:  Wednesday, December 10, 2008 2:39:34 PM IST                 * 
 * Generated by:  sasadm                                                      * 
 * Version:       9.1.20060626.51875                                          * 
 ******************************************************************************
 * Notes:                                                                     * 
 * IO_EXT                                                                     * 
 * Job Name: IO_EXTJob Desc Pre Process: NoneMain:Extract and load data from  * 
 * INTERNAL_ORG using a SQL join with table LOAD_CONTROL based on             * 
 * conditionLOAD_CONTROL.LOAD_FLG = CHECK_FLAG_TRUE                           * 
 * andLOAD_CONTROL.RUN_STATUS = RUNNING_STATUS                                * 
 * andLOAD_CONTROL.LOAD_END_DTTM betweenVALID_FROM_DTTM and                   * 
 * VALID_TO_DTTM;Post Process: Index is created                               * 
 * on(INTERNAL_ORG_RK,LOAD_END_DTTM)Parameters:a)CHECK_FLAG_TRUE and          * 
 * RUNNING_STATUS are the user defined parameters. CHECK_FLAG_TRUE is set     * 
 * to 'Y' and RUNNING_STATUS is to 'Running' for each month of data           * 
 *  load.Developed by: sinahkReviewed by:Tested by:                           * 
 ******************************************************************************/ 



%let jobID = %quote(A5V75JN3.BN000025);

/* Setup for capturing job status  */ 
data _null_; 
   call symput('etls_startTime',put(datetime(),datetime.));
run;

%let etls_jobName = IO_EXT;
%let etls_recordsBefore = 0;
%let etls_recordsAfter = 0;
%let etls_lib = 0;
%let etls_table = 0;

/* Setup to capture return codes  */ 
%global job_rc trans_rc sqlrc; 
%let job_rc = 0;
%let trans_rc = 0;
%let sqlrc = 0;
%global syserr; 

%macro rcSet(error); 
   %if (&error gt &trans_rc) %then 
      %let trans_rc = &error;
   %if (&error gt &job_rc) %then 
      %let job_rc = &error;
%mend rcSet; 

%macro rcSetDS(error); 
   if &error gt input(symget('trans_rc'),12.) then 
      call symput('trans_rc',trim(left(put(&error,12.))));
   if &error gt input(symget('job_rc'),12.) then 
      call symput('job_rc',trim(left(put(&error,12.))));
%mend rcSetDS; 

%global etls_debug; 
%macro etls_setDebug; 
   %if %str(&etls_debug) ne 0 %then 
      OPTIONS MPRINT%str(;); 
%mend; 
%etls_setDebug; 

/*============================================================================* 
 * Step:          Extracting and Loading of data as per the A5V75JN3.BO0005P5 * 
 *                 load period                                                * 
 * Transform:     SQL Join (Version 2)                                        * 
 * Description:   Join with LOAD_CONTROL table and extract appropriate data   * 
 *                 based  onVALID_FROM_DTTM and VALID_TO_DTTM                 * 
 *                                                                            * 
 * Source Tables: LOAD_CONTROL - control.LOAD_CONTROL       A5V75JN3.BE0000I0 * 
 *                INTERNAL_ORG - DDS.INTERNAL_ORG           A5V75JN3.BE00004C * 
 * Target Table:  SQL Target - martscr.IO_EXT               A5V75JN3.BP0004T7 * 
 *============================================================================*/ 

/* Access the data for Control  */ 
LIBNAME control BASE "Data/bisdata/control" ;
%rcSet(&syslibrc); 

/* Access the data for Detail Data Store  */ 
LIBNAME DDS BASE "Data/bisdata/dds" ;
%rcSet(&syslibrc); 

/* Access the data for Scratch for Mart  */ 
LIBNAME martscr BASE "Data/bisdata/scratch/mart" ;
%rcSet(&syslibrc); 

%let transformID = %quote(A5V75JN3.BO0005P5); 

%let trans_rc = 0; 

proc datasets lib = martscr nolist nowarn memtype = (data view);
   delete IO_EXT;
quit;

proc sql;
   create table martscr.IO_EXT as
      select
         LOAD_CONTROL.LOAD_END_DTTM length = 8
                                    format = NLDATM21.
                                    informat = NLDATM21.
                                    label = "Load End Datetime",
         INTERNAL_ORG.INTERNAL_ORG_RK length = 8
                                      format = 12.
                                      informat = 12.
                                      label = "Internal Organization Retained Key",
         INTERNAL_ORG.INTERNAL_ORG_ID length = 32
                                      label = "Internal Organization",
         INTERNAL_ORG.SOURCE_SYSTEM_CD length = 3
                                       label = "Source System Code",
         INTERNAL_ORG.ORGANIZATION_NM length = 40
                                      label = "Organization Name",
         INTERNAL_ORG.ORGANIZATION_DESC length = 100
                                        label = "Organization Description",
         INTERNAL_ORG.ORGANIZATION_TYPE_CD length = 3
                                           label = "Organization Type Code",
         INTERNAL_ORG.LEGAL_ENTITY_FLG length = 1
                                       label = "Legal Entity Flag",
         INTERNAL_ORG.LINE_OF_BUSINESS_NM length = 40
                                          label = "Line Of Business Name",
         INTERNAL_ORG.MANAGING_EMPLOYEE_RK length = 8
                                           format = 12.
                                           informat = 12.
                                           label = "Managing Employee Retained Key",
         INTERNAL_ORG.ADDRESS_LINE_1_TXT length = 100
                                         label = "Address Line 1",
         INTERNAL_ORG.ADDRESS_LINE_2_TXT length = 100
                                         label = "Address Line 2",
         INTERNAL_ORG.ADDRESS_LINE_3_TXT length = 100
                                         label = "Address Line 3",
         INTERNAL_ORG.ADDRESS_LINE_4_TXT length = 100
                                         label = "Address Line 4",
         INTERNAL_ORG.CITY_NM length = 100
                              label = "City Name",
         INTERNAL_ORG.POSTAL_CD length = 20
                                label = "Postal Code",
         INTERNAL_ORG.STATE_REGION_CD length = 4
                                      label = "State/Region code",
         INTERNAL_ORG.COUNTY_NM length = 40
                                label = "County Name",
         INTERNAL_ORG.COUNTRY_CD length = 3
                                 label = "Country Code",
         INTERNAL_ORG.BOOK_OF_RECORD_CURRENCY_CD length = 3
                                                 label = "Book of Record Currency Code",
         INTERNAL_ORG.REPORTING_CURRENCY_CD length = 3
                                            label = "Reporting Currency Code",
         INTERNAL_ORG.EXTERNAL_TRADER_FLG length = 1
                                          label = "External Trader Flag",
         INTERNAL_ORG.DIVISION_TYPE_CD length = 3
                                       label = "Division Type Code",
         INTERNAL_ORG.EFFECTIVE_FROM_DTTM length = 8
                                          format = NLDATM21.
                                          informat = NLDATM21.
                                          label = "Effective From Datetime",
         INTERNAL_ORG.EFFECTIVE_TO_DTTM length = 8
                                        format = NLDATM21.
                                        informat = NLDATM21.
                                        label = "Effective To Datetime",
         INTERNAL_ORG.COST_CENTER_RK length = 8
                                     format = 12.
                                     informat = 12.
                                     label = "This the cost center to which this internal organization belongs to"
      from
         control.LOAD_CONTROL, 
         DDS.INTERNAL_ORG
      where
         LOAD_CONTROL.LOAD_FLG IN (&CHECK_FLAG_TRUE)
         and LOAD_CONTROL.RUN_STATUS IN (&RUNNING_STATUS)
         and LOAD_CONTROL.LOAD_END_DTTM >= INTERNAL_ORG.VALID_FROM_DTTM
         and LOAD_CONTROL.LOAD_END_DTTM <= INTERNAL_ORG.VALID_TO_DTTM
      ;
quit;

%rcSet(&sqlrc); 

%macro etls_completeTarget();
   /*---- Create the integrity constraints for a table  ----*/ 
   %put %str(NOTE: Creating integrity constraints ...);
   proc datasets library=martscr nolist;
      modify IO_EXT;
         ic create not null (LOAD_END_DTTM);
         ic create not null (INTERNAL_ORG_RK);
         ic create not null (ORGANIZATION_TYPE_CD);
   quit;
   
   %rcSet(&syserr); 
   
%mend etls_completeTarget;
%etls_completeTarget;

/*============================================================================* 
 * Step:          Dummy Loader                              A5V75JN3.BO0005P6 * 
 * Transform:     Table Loader                                                * 
 * Description:                                                               * 
 *                                                                            * 
 * Source Table:  SQL Target - martscr.IO_EXT               A5V75JN3.BP0004T7 * 
 * Target Table:  IO_EXT - martscr.IO_EXT                   A5V75JN3.BE0000K3 * 
 *============================================================================*
 *                                                                            * 
 * Nothing will be generated for this process because the "Do not generate    * 
 *  code for this process" option is selected.                                * 
 *                                                                            * 
 *============================================================================*/ 

data _null_; 
   call symput('etls_endTime',put(datetime(),datetime.));
run;

/* Check return code for job  */ 
%macro etls_jobRCChk; 
   %if (&job_rc eq 4) %then
   %do; 
      %on_success(Job_nm=&etls_jobName..sas, param_table=&status_table);
   %end; 
%mend etls_jobRCChk; 
%etls_jobRCChk; 

/* Check return code for job  */ 
%macro etls_jobRCChk; 
   %if (&job_rc ge 5) %then
   %do; 
      %on_success(Job_nm=&etls_jobName..sas, param_table=&status_table);
   %end; 
%mend etls_jobRCChk; 
%etls_jobRCChk; 

/* Check return code for job  */ 
%macro etls_jobRCChk; 
   %if (&job_rc eq 0) %then
   %do; 
      %on_success(Job_nm=&etls_jobName..sas, param_table=&status_table);
   %end; 
%mend etls_jobRCChk; 
%etls_jobRCChk; 

/*---- Job status macro  ----*/ 
/*============================================================================* 
 * Post-Process code for the job                            A5V75JN3.AY00042R * 
 *                                                                            * 
 * User Written:  Index creation code on INTERNAL_ORG_RK &  A5V75JN3.AF000MTF * 
 *                 LOAD_END_DTTM                                              * 
 *                Index creation code on INTERNAL_ORG_RK & LOAD_END_DTTM      * 
 *                 column                                                     * 
 *============================================================================*/ 

/*---- Start of User Written Code  ----*/ 

/*creating index on INTERNAL_ORG_RK & LOAD_END_DTTM column */
PROC SQL NOPRINT;
           CREATE INDEX INTERNAL_ORG_RK_LOAD_END_DTTM
            ON martscr.IO_EXT (INTERNAL_ORG_RK,LOAD_END_DTTM);
QUIT;
/*---- End of User Written Code  ----*/ 

%rcSet(&syserr); 
%rcSet(&sqlrc); 

