/****************************************************************************** 
 * Job:           LA_EXT                                    A5V75JN3.BN000029 * 
 * Description:   This job builds the LA_EXT by picking up data extracted     * 
 *                 from LOAN_ACCOUNT                                          * 
 *                                                                            * 
 * Repository:    Foundation                                A0000001.A5V75JN3 * 
 * Server:        SASMain                                   A5V75JN3.AT000001 * 
 *                                                                            * 
 * Source Tables: LOAD_CONTROL - control.LOAD_CONTROL       A5V75JN3.BE0000I0 * 
 *                LOAN_ACCOUNT - DDS.LOAN_ACCOUNT           A5V75JN3.BE00004P * 
 * Target Table:  LA_EXT - martscr.LA_EXT                   A5V75JN3.BE0000K7 * 
 *                                                                            * 
 * Generated on:  Wednesday, December 10, 2008 2:39:34 PM IST                 * 
 * Generated by:  sasadm                                                      * 
 * Version:       9.1.20060626.51875                                          * 
 ******************************************************************************
 * Notes:                                                                     * 
 * LA_EXT                                                                     * 
 * Job Name: LA_EXTJob Desc Pre Process: NoneMain:Extract and load data from  * 
 * LOAN_ACCOUNT using a SQL join with table LOAD_CONTROL based on             * 
 * conditionLOAD_CONTROL.LOAD_FLG = CHECK_FLAG_TRUE                           * 
 * andLOAD_CONTROL.RUN_STATUS = RUNNING_STATUS                                * 
 * andLOAD_CONTROL.LOAD_END_DTTM betweenVALID_FROM_DTTM and                   * 
 * VALID_TO_DTTMPost Process: Index is created on(LA_EXT.ACCOUNT_RK,LA_EXT    * 
 * .LOAD_END_DTTM)Parameters: CHECK_FLAG_TRUE and RUNNING_STATUS are the      * 
 * user defined parameters. CHECK_FLAG_TRUE is set to 'Y' and                 * 
 * RUNNING_STATUS is to 'Running' for each month of data load.Developed by:   * 
 *  sinahkReviewed by:Tested by:                                              * 
 ******************************************************************************/ 



%let jobID = %quote(A5V75JN3.BN000029);

/* Setup for capturing job status  */ 
data _null_; 
   call symput('etls_startTime',put(datetime(),datetime.));
run;

%let etls_jobName = LA_EXT;
%let etls_recordsBefore = 0;
%let etls_recordsAfter = 0;
%let etls_lib = 0;
%let etls_table = 0;

/* Setup to capture return codes  */ 
%global job_rc trans_rc sqlrc; 
%let job_rc = 0;
%let trans_rc = 0;
%let sqlrc = 0;
%global syserr; 

%macro rcSet(error); 
   %if (&error gt &trans_rc) %then 
      %let trans_rc = &error;
   %if (&error gt &job_rc) %then 
      %let job_rc = &error;
%mend rcSet; 

%macro rcSetDS(error); 
   if &error gt input(symget('trans_rc'),12.) then 
      call symput('trans_rc',trim(left(put(&error,12.))));
   if &error gt input(symget('job_rc'),12.) then 
      call symput('job_rc',trim(left(put(&error,12.))));
%mend rcSetDS; 

%global etls_debug; 
%macro etls_setDebug; 
   %if %str(&etls_debug) ne 0 %then 
      OPTIONS MPRINT%str(;); 
%mend; 
%etls_setDebug; 

/*============================================================================* 
 * Pre-Process code for the job                             A5V75JN3.AY0004OQ * 
 *                                                                            * 
 * User Written:  Oracle Date Problem Fix                   A5V75JN3.AF000PWT * 
 *                Oracle Date Problem Fix                                     * 
 *============================================================================*/ 

/*---- Start of User Written Code  ----*/ 

proc contents data=dds.loan_account out=_etlsEngine(keep=Engine) noprint;
run;

data _null_;
	set _etlsEngine;
	if _n_=1;
	  call symput('mEngine', kleft(kright(Engine)));
run;
/*---- End of User Written Code  ----*/ 

%rcSet(&syserr); 
%rcSet(&sqlrc); 

/*============================================================================* 
 * Step:          Extracting and Loading of data as per the A5V75JN3.BO0006ZQ * 
 *                 load period                                                * 
 * Transform:     SQL Join (Version 2)                                        * 
 * Description:   Join with LOAD_CONTROL table and extract appropriate data   * 
 *                 based  onVALID_FROM_DTTM and VALID_TO_DTTM                 * 
 *                                                                            * 
 * Source Tables: LOAD_CONTROL - control.LOAD_CONTROL       A5V75JN3.BE0000I0 * 
 *                LOAN_ACCOUNT - DDS.LOAN_ACCOUNT           A5V75JN3.BE00004P * 
 * Target Table:  SQL Target - martscr.LA_EXT               A5V75JN3.BP000673 * 
 *============================================================================*/ 

/* Access the data for Control  */ 
LIBNAME control BASE "Data/bisdata/control" ;
%rcSet(&syslibrc); 

/* Access the data for Detail Data Store  */ 
LIBNAME DDS BASE "Data/bisdata/dds" ;
%rcSet(&syslibrc); 

/* Access the data for Scratch for Mart  */ 
LIBNAME martscr BASE "Data/bisdata/scratch/mart" ;
%rcSet(&syslibrc); 

%let transformID = %quote(A5V75JN3.BO0006ZQ); 

%let trans_rc = 0; 

proc datasets lib = martscr nolist nowarn memtype = (data view);
   delete LA_EXT;
quit;

proc sql;
   create table martscr.LA_EXT as
      select
         LOAD_CONTROL.LOAD_END_DTTM length = 8
                                    format = NLDATM21.
                                    informat = NLDATM21.
                                    label = "Load End Datetime",
         LOAN_ACCOUNT.ACCOUNT_RK length = 8
                                 format = 12.
                                 informat = 12.
                                 label = "Account Key",
         LOAN_ACCOUNT.LOAN_TYPE_CD length = 3
                                   label = "Loan Type Code",
         LOAN_ACCOUNT.LOAN_STATUS_CD length = 3
                                     label = "Loan Status Code",
         LOAN_ACCOUNT.LOAN_CYCLE_NO length = 8
                                    label = "Loan Cycle No",
         LOAN_ACCOUNT.APPLIED_AMT length = 8
                                  format = NLNUM18.5
                                  informat = NLNUM18.5
                                  label = "Applied Amount",
         LOAN_ACCOUNT.ADVANCE_REQUIRED_AMT length = 8
                                           format = NLNUM18.5
                                           informat = NLNUM18.5
                                           label = "Advance Required Amount",
         LOAN_ACCOUNT.ADVANCE_APPROVED_AMT length = 8
                                           format = NLNUM18.5
                                           informat = NLNUM18.5
                                           label = "Advance Approved Amount",
         LOAN_ACCOUNT.ACTUAL_ADVANCE_AMT length = 8
                                         format = NLNUM18.5
                                         informat = NLNUM18.5
                                         label = "Actual Advance Amount",
         LOAN_ACCOUNT.DOWN_PAYMENT_AMT length = 8
                                       format = NLNUM18.5
                                       informat = NLNUM18.5
                                       label = "Down Payment Amount",
         CASE symget('mEngine')
         	WHEN "ORACLE" THEN datepart(LOAN_ACCOUNT.MATURITY_DT)
         	ELSE LOAN_ACCOUNT.MATURITY_DT
         END as MATURITY_DT length = 8
                            format = NLDATE10.
                            informat = NLDATE10.
                            label = "Maturity Date",
         LOAN_ACCOUNT.PURPOSE_CD length = 3
                                 label = "Purpose Code",
         LOAN_ACCOUNT.PAYMENT_METHOD_CD length = 3
                                        label = "Payment Method Code",
         LOAN_ACCOUNT.MONTHLY_PAYMENT_AMT length = 8
                                          format = NLNUM18.5
                                          informat = NLNUM18.5
                                          label = "Monthly Payment Amount",
         LOAN_ACCOUNT.AUTO_PAY_FLG length = 1
                                   label = "Auto Pay Flag",
         LOAN_ACCOUNT.INTEREST_TIER_NO length = 8
                                       label = "Interest Tier No",
         LOAN_ACCOUNT.APR_RT length = 8
                             format = NLNUM9.4
                             informat = NLNUM9.4
                             label = "APR Rate",
         LOAN_ACCOUNT.BASE_APR_RT length = 8
                                  format = NLNUM9.4
                                  informat = NLNUM9.4
                                  label = "Base APR Rate",
         LOAN_ACCOUNT.INTEREST_PAYABLE_AMT length = 8
                                           format = NLNUM18.5
                                           informat = NLNUM18.5
                                           label = "Interest Payable Amount",
         CASE symget('mEngine')
         	WHEN "ORACLE" THEN datepart(LOAN_ACCOUNT.CHARGE_OFF_DT)
         	ELSE LOAN_ACCOUNT.CHARGE_OFF_DT
         END as CHARGE_OFF_DT length = 8
                              format = NLDATE10.
                              informat = NLDATE10.
                              label = "Charge Off Date",
         LOAN_ACCOUNT.CHARGE_OFF_AMT length = 8
                                     format = NLNUM18.5
                                     informat = NLNUM18.5
                                     label = "Charge Off Amount",
         LOAN_ACCOUNT.PREPAY_PENALTY_AMT length = 8
                                         format = NLNUM18.5
                                         informat = NLNUM18.5
                                         label = "Prepayment Penalty Amount",
         CASE symget('mEngine')
         	WHEN "ORACLE" THEN datepart(LOAN_ACCOUNT.PREPAY_PENALTY_DT)
         	ELSE LOAN_ACCOUNT.PREPAY_PENALTY_DT
         END as PREPAY_PENALTY_DT length = 8
                                  format = NLDATE10.
                                  informat = NLDATE10.
                                  label = "Prepayment Penalty Date",
         LOAN_ACCOUNT.COLLATERAL_CD length = 3
                                    label = "Collateral Code",
         LOAN_ACCOUNT.COLLATERAL_AMT length = 8
                                     format = NLNUM18.5
                                     informat = NLNUM18.5
                                     label = "Collateral Amount",
         LOAN_ACCOUNT.GUARANTEE_CD length = 3
                                   label = "Guarantee Code",
         LOAN_ACCOUNT.GUARANTEE_AMT length = 8
                                    format = NLNUM18.5
                                    informat = NLNUM18.5
                                    label = "Guarantee Amount",
         LOAN_ACCOUNT.LOAN_SECURED_FLG length = 1
                                       label = "Loan Secured Flag",
         LOAN_ACCOUNT.SECURITY_CD length = 3
                                  label = "Security Code",
         LOAN_ACCOUNT.LOAN_SECURITY_TYPE_CD length = 3
                                            label = "Loan Security Type Code",
         LOAN_ACCOUNT.PROPERTY_RK length = 8
                                  format = 12.
                                  informat = 12.
                                  label = "Property Key",
         LOAN_ACCOUNT.DOCUMENTATION_TYPE_CD length = 3
                                            label = "Documentation Type Code",
         LOAN_ACCOUNT.OVERPAY_TO_PRINCIPAL_FLG length = 1
                                               label = "Overpay To Principal Flag",
         LOAN_ACCOUNT.LOAN_INSURED_FLG length = 1
                                       label = "Loan Insured Flag",
         LOAN_ACCOUNT.PPI_FLG length = 1
                              label = "PPI Flag",
         LOAN_ACCOUNT.PPI_NO length = 20
                             label = "PPI No",
         CASE symget('mEngine')
         	WHEN "ORACLE" THEN datepart(LOAN_ACCOUNT.PPI_START_DT)
         	ELSE LOAN_ACCOUNT.PPI_START_DT
         END as PPI_START_DT length = 8
                             format = NLDATE10.
                             informat = NLDATE10.
                             label = "PPI Start Date",
         LOAN_ACCOUNT.PPI_PREMIUM_RT length = 8
                                     format = NLNUM9.4
                                     informat = NLNUM9.4
                                     label = "PPI Premium Rate",
         CASE symget('mEngine')
         	WHEN "ORACLE" THEN datepart(LOAN_ACCOUNT.PREMIUM_FIRST_DUE_DT)
         	ELSE LOAN_ACCOUNT.PREMIUM_FIRST_DUE_DT
         END as PREMIUM_FIRST_DUE_DT length = 8
                                     format = NLDATE10.
                                     informat = NLDATE10.
                                     label = "Premium First Due Date",
         LOAN_ACCOUNT.APP_LIFE_COVERAGE_FLG length = 1
                                            label = "Life Coverage Flag At Application",
         LOAN_ACCOUNT.LIEN_INDICATOR_FLG length = 1
                                         label = "Lien Indicator Flag",
         LOAN_ACCOUNT.SPECIALIZED_LENDING_CD length = 3
                                             label = "Specialized Lending Code",
         LOAN_ACCOUNT.LATE_PAYMENT_DAYS_LATE_NO length = 8
                                                label = "No of Late Payment Days",
         LOAN_ACCOUNT.LATE_PAYMENT_STATUS_CD length = 3
                                             label = "Late Payment Status Code",
         LOAN_ACCOUNT.CURRENT_LIMIT_AMT length = 8
                                        format = NLNUM18.5
                                        informat = NLNUM18.5
                                        label = "Current Limit Amount",
         CASE symget('mEngine')
         	WHEN "ORACLE" THEN datepart(LOAN_ACCOUNT.CURRENT_LIMIT_DT)
         	ELSE LOAN_ACCOUNT.CURRENT_LIMIT_DT
         END as CURRENT_LIMIT_DT length = 8
                                 format = NLDATE10.
                                 informat = NLDATE10.
                                 label = "Current Limit Date",
         LOAN_ACCOUNT.BUREAU_CLASS_CD length = 3
                                      label = "Bureau Class Code",
         LOAN_ACCOUNT.INQUIRY_BUREAU_CNT length = 8
                                         label = "Inquiry Bureau Count",
         LOAN_ACCOUNT.MONTHS_SINCE_AT_BUREAU_CNT length = 8
                                                 label = "Months Since At Bureau",
         LOAN_ACCOUNT.COLLECTIONS_STATUS_CD length = 3
                                            label = "Collections Status Code",
         LOAN_ACCOUNT.PROT_INS_EXTERNAL_ORG_RK length = 8
                                               format = 12.
                                               informat = 12.
                                               label = "External Organization",
         LOAN_ACCOUNT.SENIORITY_CD length = 3
                                   label = "Seniority Code",
         LOAN_ACCOUNT.PAYMENT_AMT length = 8
                                  format = NLNUM18.5
                                  informat = NLNUM18.5
                                  label = "Payment Amount",
         LOAN_ACCOUNT.PAYMENT_TIME_FREQUENCY_CD length = 3
                                                label = "Time Frequency Code",
         LOAN_ACCOUNT.CASH_ADVANCE_FLG length = 1
                                       label = "Cash Advance Flag",
         LOAN_ACCOUNT.AUTO_DEBIT_ACCOUNT_NO length = 20
                                            label = "Auto Debit Account Number",
         LOAN_ACCOUNT.KEY_AUTO_DEBIT_ACCOUNT_NO length = 20
                                                label = "Key Auto Debit Account Number",
         CASE symget('mEngine')
         	WHEN "ORACLE" THEN datepart(LOAN_ACCOUNT.LOAN_DISBURSED_DT)
         	ELSE LOAN_ACCOUNT.LOAN_DISBURSED_DT
         END as LOAN_DISBURSED_DT length = 8
                                  format = NLDATE10.
                                  informat = NLDATE10.
                                  label = "Loan Disbursed Date",
         CASE symget('mEngine')
         	WHEN "ORACLE" THEN datepart(LOAN_ACCOUNT.LOAN_APPROVAL_DT)
         	ELSE LOAN_ACCOUNT.LOAN_APPROVAL_DT
         END as LOAN_APPROVAL_DT length = 8
                                 format = NLDATE10.
                                 informat = NLDATE10.
                                 label = "Loan Approval Date",
         LOAN_ACCOUNT.AUTO_DEBIT_ACCT_TYPE_CD length = 3
                                              label = "Auto Debit Account Type Code",
         LOAN_ACCOUNT.REFINANCE_AMT length = 8
                                    format = NLNUM18.5
                                    informat = NLNUM18.5
                                    label = "REFINANCE_AMT",
         LOAN_ACCOUNT.APR_TYPE_CD length = 10
                                  label = "Commodity Type Code",
         LOAN_ACCOUNT.ACCOUNT_ID length = 32
                                 label = "Account ID",
         LOAN_ACCOUNT.SOURCE_SYSTEM_CD length = 3
                                       label = "Source System Code",
         LOAN_ACCOUNT.HONEYMOON_FLG length = 1
                                    label = "Honeymoon Flag",
         CASE symget('mEngine')
         	WHEN "ORACLE" THEN datepart(LOAN_ACCOUNT.HONEYMOON_START_DT)
         	ELSE LOAN_ACCOUNT.HONEYMOON_START_DT
         END as HONEYMOON_START_DT length = 8
                                   format = NLDATE10.
                                   informat = NLDATE10.
                                   label = "Honeymoon Period Start Date",
         CASE symget('mEngine') 	
         	WHEN "ORACLE" THEN datepart( LOAN_ACCOUNT.HONEYMOON_END_DT) 	
         	ELSE  LOAN_ACCOUNT.HONEYMOON_END_DT
         END as HONEYMOON_END_DT length = 8
                                 format = NLDATE10.
                                 informat = NLDATE10.
                                 label = "Honeymoon End Date",
         LOAN_ACCOUNT.OFFSET_ACCOUNT_FLG length = 1
                                         label = "Offset Account Flag",
         LOAN_ACCOUNT.PORTABILITY_FLG length = 1
                                      label = "Portability Flag",
         LOAN_ACCOUNT.PPI_STATUS_CD length = 3
                                    label = "PPI Status Code",
         LOAN_ACCOUNT.SPLIT_LOAN_FLG length = 1
                                     label = "Split Loan Flag",
         CASE symget('mEngine')
         	WHEN "ORACLE" THEN datepart(LOAN_ACCOUNT.FIXED_INT_END_DT)
         	ELSE LOAN_ACCOUNT.FIXED_INT_END_DT
         END as FIXED_INT_END_DT length = 8
                                 format = NLDATE10.
                                 informat = NLDATE10.
                                 label = "Fixed Interest End Date",
         LOAN_ACCOUNT.CONVERTIBLE_CD length = 3
                                     label = "Convertible Code",
         LOAN_ACCOUNT.REPAYMENT_HOLIDAY_FLG length = 1
                                            label = "Repayment Holiday Flag",
         CASE symget('mEngine')
         	WHEN "ORACLE" THEN datepart(LOAN_ACCOUNT.REPAYMENT_HOLIDAY_START_DT)
         	ELSE LOAN_ACCOUNT.REPAYMENT_HOLIDAY_START_DT
         END as REPAYMENT_HOLIDAY_START_DT length = 8
                                           format = NLDATE10.
                                           informat = NLDATE10.
                                           label = "Repayment Holiday Start Date",
         CASE symget('mEngine') 	
         	WHEN "ORACLE" THEN datepart(LOAN_ACCOUNT.REPAYMENT_HOLIDAY_END_DT) 	
         	ELSE  LOAN_ACCOUNT.REPAYMENT_HOLIDAY_END_DT
         END as REPAYMENT_HOLIDAY_END_DT length = 8
                                         format = NLDATE10.
                                         informat = NLDATE10.
                                         label = "Repayment Holiday End Date",
         LOAN_ACCOUNT.SPECIAL_INTEREST_RT length = 8
                                          format = NLNUM9.4
                                          informat = NLNUM9.4
                                          label = "Special Interest Rate",
         CASE symget('mEngine')
         	WHEN "ORACLE" THEN datepart(LOAN_ACCOUNT.SPECIAL_RATE_START_DT)
         	ELSE LOAN_ACCOUNT.SPECIAL_RATE_START_DT
         END as SPECIAL_RATE_START_DT length = 8
                                      format = NLDATE10.
                                      informat = NLDATE10.
                                      label = "Special Rate Start Date",
         CASE symget('mEngine') 	
         	WHEN "ORACLE" THEN datepart(LOAN_ACCOUNT.SPECIAL_RATE_END_DT) 	
         	ELSE  LOAN_ACCOUNT.SPECIAL_RATE_END_DT
         END as SPECIAL_RATE_END_DT length = 8
                                    format = NLDATE10.
                                    informat = NLDATE10.
                                    label = "Special Rate End Date",
         LOAN_ACCOUNT.SPECIAL_RATE_TYPE_CD length = 3
                                           label = "Special Rate Type Code",
         LOAN_ACCOUNT.MATURITY_CHANGE_REASON_CD length = 3
                                                label = "Marital Status Code",
         LOAN_ACCOUNT.DISBURSEMENT_TYPE_CD length = 3
                                           label = "Disbursement Type Code",
         LOAN_ACCOUNT.APR_RT_CHANGE_REASON_CD length = 3
                                              label = "Interest Rate Change Reason Code"
      from
         control.LOAD_CONTROL, 
         DDS.LOAN_ACCOUNT
      where
         LOAD_CONTROL.LOAD_FLG IN (&CHECK_FLAG_TRUE)
         and LOAD_CONTROL.RUN_STATUS IN (&RUNNING_STATUS)
         and LOAD_CONTROL.LOAD_END_DTTM >= LOAN_ACCOUNT.VALID_FROM_DTTM
         and LOAD_CONTROL.LOAD_END_DTTM <= LOAN_ACCOUNT.VALID_TO_DTTM
      ;
quit;

%rcSet(&sqlrc); 

%macro etls_completeTarget();
%mend etls_completeTarget;
%etls_completeTarget;

/*============================================================================* 
 * Step:          Dummy Loader                              A5V75JN3.BO0006ZP * 
 * Transform:     Table Loader                                                * 
 * Description:                                                               * 
 *                                                                            * 
 * Source Table:  SQL Target - martscr.LA_EXT               A5V75JN3.BP000673 * 
 * Target Table:  LA_EXT - martscr.LA_EXT                   A5V75JN3.BE0000K7 * 
 *============================================================================*
 *                                                                            * 
 * Nothing will be generated for this process because the "Do not generate    * 
 *  code for this process" option is selected.                                * 
 *                                                                            * 
 *============================================================================*/ 

data _null_; 
   call symput('etls_endTime',put(datetime(),datetime.));
run;

/* Check return code for job  */ 
%macro etls_jobRCChk; 
   %if (&job_rc eq 4) %then
   %do; 
      %on_success(Job_nm=&etls_jobName..sas, param_table=&status_table);
   %end; 
%mend etls_jobRCChk; 
%etls_jobRCChk; 

/* Check return code for job  */ 
%macro etls_jobRCChk; 
   %if (&job_rc ge 5) %then
   %do; 
      %on_success(Job_nm=&etls_jobName..sas, param_table=&status_table);
   %end; 
%mend etls_jobRCChk; 
%etls_jobRCChk; 

/* Check return code for job  */ 
%macro etls_jobRCChk; 
   %if (&job_rc eq 0) %then
   %do; 
      %on_success(Job_nm=&etls_jobName..sas, param_table=&status_table);
   %end; 
%mend etls_jobRCChk; 
%etls_jobRCChk; 

/*---- Job status macro  ----*/ 
/*============================================================================* 
 * Post-Process code for the job                            A5V75JN3.AY0004OR * 
 *                                                                            * 
 * User Written:  Index creation code on ACCOUNT_RK,        A5V75JN3.AF000PWU * 
 *                 LOAD_END_DTTM column                                       * 
 *                Index creation code on ACCOUNT_RK, LOAD_END_DTTM column     * 
 *============================================================================*/ 

/*---- Start of User Written Code  ----*/ 

/*creating index on ACCOUNT_RK column */
PROC SQL NOPRINT;
           CREATE INDEX ACCOUNT_RK_LOAD_END_DTTM
            ON martscr.LA_EXT(ACCOUNT_RK,LOAD_END_DTTM);
QUIT;
/*---- End of User Written Code  ----*/ 

%rcSet(&syserr); 
%rcSet(&sqlrc); 

