/****************************************************************************** 
 * Job:           MA_EXT                                    A5V75JN3.BN00002E * 
 * Description:   This job picks up data from MORTGAGE_ACCOUNT based  on      * 
 *                 join with LOAD_CONTROL table .                             * 
 *                                                                            * 
 * Repository:    Foundation                                A0000001.A5V75JN3 * 
 * Server:        SASMain                                   A5V75JN3.AT000001 * 
 *                                                                            * 
 * Source Tables: LOAD_CONTROL - control.LOAD_CONTROL       A5V75JN3.BE0000I0 * 
 *                MORTGAGE_ACCOUNT - DDS.MORTGAGE_ACCOUNT   A5V75JN3.BE00004W * 
 * Target Table:  MA_EXT - martscr.MA_EXT                   A5V75JN3.BE0000KC * 
 *                                                                            * 
 * Generated on:  Tuesday, December 16, 2008 5:26:38 PM GMT+05:30             * 
 * Generated by:  sasadm                                                      * 
 * Version:       9.1.20060626.51875                                          * 
 ******************************************************************************
 * Notes:                                                                     * 
 * MA_EXT                                                                     * 
 * Job Name: MA_EXTJob Desc Pre Process: NoneMain:Extract and load data from  * 
 * MORTGAGE_ACCOUNT using a SQL join with table LOAD_CONTROL based on         * 
 * conditionLOAD_CONTROL.LOAD_FLG = CHECK_FLAG_TRUE                           * 
 * andLOAD_CONTROL.RUN_STATUS = RUNNING_STATUS                                * 
 * andLOAD_CONTROL.LOAD_END_DTTM betweenVALID_FROM_DTTM and                   * 
 * VALID_TO_DTTMPost Process: Index is created                                * 
 * on(ACCOUNT_RK,LOAD_END_DTTM)Parameters: CHECK_FLAG_TRUE and                * 
 * RUNNING_STATUS are the user defined parameters. CHECK_FLAG_TRUE is set     * 
 * to 'Y' and RUNNING_STATUS is to 'Running' for each month of data           * 
 *  load.Developed by: sinahkReviewed by:Tested by:                           * 
 ******************************************************************************/ 

/* Setup for capturing job status  */ 
data _null_; 
   call symput('etls_startTime',put(datetime(),datetime.));
run;

%let etls_jobName = MA_EXT;
%let etls_recordsBefore = 0;
%let etls_recordsAfter = 0;
%let etls_lib = 0;
%let etls_table = 0;

/* Setup to capture return codes  */ 
%global job_rc trans_rc sqlrc; 
%let job_rc = 0;
%let trans_rc = 0;
%let sqlrc = 0;
%global syserr; 

%macro rcSet(error); 
   %if (&error gt &trans_rc) %then 
      %let trans_rc = &error;
   %if (&error gt &job_rc) %then 
      %let job_rc = &error;
%mend rcSet; 

%macro rcSetDS(error); 
   if &error gt input(symget('trans_rc'),12.) then 
      call symput('trans_rc',trim(left(put(&error,12.))));
   if &error gt input(symget('job_rc'),12.) then 
      call symput('job_rc',trim(left(put(&error,12.))));
%mend rcSetDS; 

%global etls_debug; 
%macro etls_setDebug; 
   %if %str(&etls_debug) ne 0 %then 
      OPTIONS MPRINT%str(;); 
%mend; 
%etls_setDebug; 

/*============================================================================* 
 * Pre-Process code for the job                             A5V75JN3.AY0004OS * 
 *                                                                            * 
 * User Written:  Oracle Date Problem Fix                   A5V75JN3.AF000PXT * 
 *                Oracle Date Problem Fix                                     * 
 *============================================================================*/ 

/*---- Start of User Written Code  ----*/ 

proc contents data=dds.MORTGAGE_ACCOUNT out=_etlsEngine(keep=Engine) noprint;
run;

data _null_;
	set _etlsEngine;
	if _n_=1;
	  call symput('mEngine', kleft(kright(Engine)));
run;
/*---- End of User Written Code  ----*/ 

%rcSet(&syserr); 
%rcSet(&sqlrc); 

/*============================================================================* 
 * Step:          Extracting and Loading of data as per the A5V75JN3.BO0006ZS * 
 *                 load period                                                * 
 * Transform:     SQL Join (Version 2)                                        * 
 * Description:   Join with LOAD_CONTROL table and extract appropriate data   * 
 *                 based  onVALID_FROM_DTTM and VALID_TO_DTTM                 * 
 *                                                                            * 
 * Source Tables: LOAD_CONTROL - control.LOAD_CONTROL       A5V75JN3.BE0000I0 * 
 *                MORTGAGE_ACCOUNT - DDS.MORTGAGE_ACCOUNT   A5V75JN3.BE00004W * 
 * Target Table:  SQL Target - martscr.MA_EXT               A5V75JN3.BP000674 * 
 *============================================================================*/ 

/* Access the data for Control  */ 
LIBNAME control BASE "Data/bisdata/control" ;
%rcSet(&syslibrc); 

/* Access the data for Detail Data Store  */ 
LIBNAME DDS BASE "Data/bisdata/dds" ;
%rcSet(&syslibrc); 

/* Access the data for Scratch for Mart  */ 
LIBNAME martscr BASE "Data/bisdata/scratch/mart" ;
%rcSet(&syslibrc); 

%let trans_rc = 0; 

proc datasets lib = martscr nolist nowarn memtype = (data view);
   delete MA_EXT;
quit;

proc sql;
   create table martscr.MA_EXT as
      select
         MORTGAGE_ACCOUNT.ACCOUNT_ID length = 32
                                     label = "Account Id",
         MORTGAGE_ACCOUNT.ACCOUNT_RK length = 8
                                     format = 12.
                                     informat = 12.
                                     label = "Account Key",
         MORTGAGE_ACCOUNT.ACTUAL_ADVANCE_AMT length = 8
                                             format = NLNUM18.5
                                             informat = NLNUM18.5
                                             label = "Actual Advance Amount",
         MORTGAGE_ACCOUNT.ADVANCE_PCT length = 8
                                      format = NLNUM9.4
                                      informat = NLNUM9.4
                                      label = "Advance Percent",
         MORTGAGE_ACCOUNT.ADVANCE_REQ_AMT length = 8
                                          format = NLNUM18.5
                                          informat = NLNUM18.5
                                          label = "Advance Required Amount",
         MORTGAGE_ACCOUNT.ANNUAL_REPAYMENT_PCT length = 8
                                               format = NLNUM9.4
                                               informat = NLNUM9.4
                                               label = "Annual Repayment Percent",
         MORTGAGE_ACCOUNT.APPROVED_ADVANCE_AMT length = 8
                                               format = NLNUM18.5
                                               informat = NLNUM18.5
                                               label = "Approved Advance Amount",
         MORTGAGE_ACCOUNT.APR_RT length = 8
                                 format = NLNUM9.4
                                 informat = NLNUM9.4
                                 label = "APR Rate",
         MORTGAGE_ACCOUNT.APR_RT_CHANGE_REASON_CD length = 3
                                                  label = "Interest Rate Change Reason Code",
         MORTGAGE_ACCOUNT.APR_TYPE_CD length = 10
                                      label = "Annual Percentage Rate (APR) Type code.",
         MORTGAGE_ACCOUNT.AUTO_PAY_FLG length = 1
                                       label = "Auto Pay Flag",
         MORTGAGE_ACCOUNT.BASE_APR_RT length = 8
                                      format = NLNUM9.4
                                      informat = NLNUM9.4
                                      label = "Base APR Rate",
         MORTGAGE_ACCOUNT.BLDG_INS_PROOF_FLG length = 1
                                             label = "Building Insurance Proof Flag",
         MORTGAGE_ACCOUNT.BORROWED_DOWNPAYMENT_FLG length = 1
                                                   label = "Borrowed Downpayment Flag",
         MORTGAGE_ACCOUNT.BORROWED_DOWNPAYMENT_PCT length = 8
                                                   format = NLNUM9.4
                                                   informat = NLNUM9.4
                                                   label = "Borrowed Downpayment Percent",
         MORTGAGE_ACCOUNT.BUILDING_INS_EXTERNAL_ORG_RK length = 8
                                                       format = 12.
                                                       informat = 12.
                                                       label = "Building Insurance External Organization Key",
         MORTGAGE_ACCOUNT.BUILDINGS_INS_FLG length = 1
                                            label = "Buildings Insurance Flag",
         MORTGAGE_ACCOUNT.BUREAU_CLASS_CD length = 3
                                          label = "Bureau Class Code",
         MORTGAGE_ACCOUNT.CASH_ADVANCE_FLG length = 1
                                           label = "Cash Advance Flag",
         MORTGAGE_ACCOUNT.CASHBACK_AMT length = 8
                                       format = NLNUM18.5
                                       informat = NLNUM18.5
                                       label = "Cashback Amount",
         MORTGAGE_ACCOUNT.CASHBACK_PCT length = 8
                                       format = NLNUM9.4
                                       informat = NLNUM9.4
                                       label = "Cashback Percent",
         MORTGAGE_ACCOUNT.CHARGE_OFF_AMT length = 8
                                         format = NLNUM18.5
                                         informat = NLNUM18.5
                                         label = "Charge Off Amount",
         CASE symget('mEngine') 
         	WHEN "ORACLE" THEN datepart(MORTGAGE_ACCOUNT.CHARGE_OFF_DT) 
         	ELSE MORTGAGE_ACCOUNT.CHARGE_OFF_DT 
         END as CHARGE_OFF_DT length = 8
                              format = NLDATE10.
                              informat = NLDATE10.
                              label = "Charge Off Date",
         MORTGAGE_ACCOUNT.CLOSING_COST_AMT length = 8
                                           format = NLNUM18.5
                                           informat = NLNUM18.5
                                           label = "Closing Cost Amount",
         MORTGAGE_ACCOUNT.COLLECTIONS_STATUS_CD length = 3
                                                label = "Collections Status Code",
         CASE symget('mEngine') 
         	WHEN "ORACLE" THEN datepart(MORTGAGE_ACCOUNT.CONVERSION_TO_FIXED_END_DT) 
         	ELSE MORTGAGE_ACCOUNT.CONVERSION_TO_FIXED_END_DT 
         END as CONVERSION_TO_FIXED_END_DT length = 8
                                           format = NLDATE10.
                                           informat = NLDATE10.
                                           label = "Conversion To Fixed End Date",
         MORTGAGE_ACCOUNT.CONVERT_TO_SPLIT_OPTION_FLG length = 1
                                                      label = "Convert to Split Option Flag",
         MORTGAGE_ACCOUNT.CONVERTIBLE_CD length = 3
                                         label = "Convertible Code",
         MORTGAGE_ACCOUNT.CURRENT_LIMIT_AMT length = 8
                                            format = NLNUM18.5
                                            informat = NLNUM18.5
                                            label = "Current Limit Amount",
         CASE symget('mEngine') 
         	WHEN "ORACLE" THEN datepart(MORTGAGE_ACCOUNT.CURRENT_LIMIT_DT) 
         	ELSE MORTGAGE_ACCOUNT.CURRENT_LIMIT_DT 
         END as CURRENT_LIMIT_DT length = 8
                                 format = NLDATE10.
                                 informat = NLDATE10.
                                 label = "Current Limit Date",
         MORTGAGE_ACCOUNT.DEBT_PAYMENT_AMT length = 8
                                           format = NLNUM18.5
                                           informat = NLNUM18.5
                                           label = "Debt Payment Amount",
         MORTGAGE_ACCOUNT.DISBURSEMENT_TYPE_CD length = 3
                                               label = "Disbursement Type Code",
         MORTGAGE_ACCOUNT.DOCUMENTATION_TYPE_CD length = 3
                                                label = "Documentation Type Code",
         MORTGAGE_ACCOUNT.DOWN_PAYMENT_AMT length = 8
                                           format = NLNUM18.5
                                           informat = NLNUM18.5
                                           label = "Down Payment Amount",
         CASE symget('mEngine')  
                 WHEN "ORACLE" THEN datepart(MORTGAGE_ACCOUNT.EXCHANGE_DT)
                 ELSE MORTGAGE_ACCOUNT.EXCHANGE_DT
         END as EXCHANGE_DT length = 8
                            format = NLDATE10.
                            informat = NLDATE10.
                            label = "Exchange Date",
         MORTGAGE_ACCOUNT.FIRST_MORTGAGE_FLG length = 1
                                             label = "First Mortgage Flag",
         MORTGAGE_ACCOUNT.FIRST_TIME_BUYER_FLG length = 1
                                               label = "First Time Buyer Flag",
         MORTGAGE_ACCOUNT.FIXED_APR_RT length = 8
                                       format = NLNUM9.4
                                       informat = NLNUM9.4
                                       label = "Fixed APR Rate",
         CASE symget('mEngine') 
         	WHEN "ORACLE" THEN datepart(MORTGAGE_ACCOUNT.FIXED_INT_END_DT) 
         	ELSE MORTGAGE_ACCOUNT.FIXED_INT_END_DT 
         END as FIXED_INT_END_DT length = 8
                                 format = NLDATE10.
                                 informat = NLDATE10.
                                 label = "Fixed Interest End Date",
         MORTGAGE_ACCOUNT.FIXED_PERIOD_MONTHS length = 8
                                              label = "Fixed Period Months",
         CASE symget('mEngine') 
         	WHEN "ORACLE" THEN datepart(MORTGAGE_ACCOUNT.FIXED_VARIABLE_DT) 
         	ELSE MORTGAGE_ACCOUNT.FIXED_VARIABLE_DT 
         END as FIXED_VARIABLE_DT length = 8
                                  format = NLDATE10.
                                  informat = NLDATE10.
                                  label = "Fixed Variable Date",
         MORTGAGE_ACCOUNT.GUARANTEE_AMT length = 8
                                        format = NLNUM18.5
                                        informat = NLNUM18.5
                                        label = "Guarantee Amount",
         MORTGAGE_ACCOUNT.HOME_EQUITY_LOAN_FLG length = 1
                                               label = "Home Equity Loan Flag",
         MORTGAGE_ACCOUNT.HOME_STATUS_CD length = 3
                                         label = "Social Aim Type Code",
         CASE symget('mEngine') 
         	WHEN "ORACLE" THEN datepart(MORTGAGE_ACCOUNT.HONEYMOON_END_DT) 
         	ELSE MORTGAGE_ACCOUNT.HONEYMOON_END_DT 
         END as HONEYMOON_END_DT length = 8
                                 format = NLDATE10.
                                 informat = NLDATE10.
                                 label = "Honeymoon End Date",
         MORTGAGE_ACCOUNT.HONEYMOON_FLG length = 1
                                        label = "Honeymoon Flag",
         CASE symget('mEngine') 
         	WHEN "ORACLE" THEN datepart(MORTGAGE_ACCOUNT.HONEYMOON_START_DT) 
         	ELSE MORTGAGE_ACCOUNT.HONEYMOON_START_DT 
         END as HONEYMOON_START_DT length = 8
                                   format = NLDATE10.
                                   informat = NLDATE10.
                                   label = "Honeymoon Period Start Date",
         MORTGAGE_ACCOUNT.IMPROVEMENTS_ALLOCATION_AMT length = 8
                                                      format = NLNUM18.5
                                                      informat = NLNUM18.5
                                                      label = "Improvements Allocation Amount",
         MORTGAGE_ACCOUNT.INQUIRY_BUREAU_CNT length = 8
                                             label = "Inquiry Bureau Count",
         MORTGAGE_ACCOUNT.INTEREST_PAYABLE_AMT length = 8
                                               format = NLNUM18.5
                                               informat = NLNUM18.5
                                               label = "Interest Payable Amount",
         MORTGAGE_ACCOUNT.INTEREST_RATE_CAP_RT length = 8
                                               format = NLNUM9.4
                                               informat = NLNUM9.4
                                               label = "Maximum Interest Rate",
         MORTGAGE_ACCOUNT.INTEREST_TIER_NO length = 18
                                           label = "Interest Tier No",
         MORTGAGE_ACCOUNT.INTRODUCER_CD length = 3
                                        label = "Introducer Code",
         CASE symget('mEngine')
         	WHEN "ORACLE" THEN datepart(MORTGAGE_ACCOUNT.LAST_STATEMENT_DT)
         	ELSE MORTGAGE_ACCOUNT.LAST_STATEMENT_DT
         END as LAST_STATEMENT_DT length = 8
                                  format = NLDATE10.
                                  informat = NLDATE10.
                                  label = "Last Statement Date",
         MORTGAGE_ACCOUNT.LATEST_MTH_PREM_AMT length = 8
                                              format = NLNUM18.5
                                              informat = NLNUM18.5
                                              label = "Latest Month Premium Amount",
         MORTGAGE_ACCOUNT.LIEN_INDICATOR_FLG length = 1
                                             label = "Lien Indicator Flag",
         MORTGAGE_ACCOUNT.LIFE_INSURANCE_FLG length = 1
                                             label = "Life Insurance Flag",
         LOAD_CONTROL.LOAD_END_DTTM length = 8
                                    format = NLDATM21.
                                    informat = NLDATM21.
                                    label = "Load End Datetime",
         MORTGAGE_ACCOUNT.MAINTENANCE_FLG length = 1
                                          label = "Maintenance Flag",
         MORTGAGE_ACCOUNT.MATURITY_CHANGE_REASON_CD length = 3
                                                    label = "Maturity Change Reason Code",
         CASE symget('mEngine') 	
         	WHEN "ORACLE" THEN datepart(MORTGAGE_ACCOUNT.MATURITY_DT) 	
         	ELSE  MORTGAGE_ACCOUNT.MATURITY_DT
         END as MATURITY_DT length = 8
                            format = NLDATE10.
                            informat = NLDATE10.
                            label = "Maturity Date",
         MORTGAGE_ACCOUNT.MAXIMUM_MONTHLY_PAYMENT_AMT length = 8
                                                      format = NLNUM18.5
                                                      informat = NLNUM18.5
                                                      label = "Maximum Monthly Payment Amount",
         MORTGAGE_ACCOUNT.MINIMUM_PAYMENT_FLG length = 1
                                              label = "Minimum Payment Flag",
         MORTGAGE_ACCOUNT.MINIMUM_REDRAW_AMT length = 8
                                             format = NLNUM18.5
                                             informat = NLNUM18.5
                                             label = "Minimum Redraw Amount",
         MORTGAGE_ACCOUNT.MONTHLY_PAYMENT_AMT length = 8
                                              format = NLNUM18.5
                                              informat = NLNUM18.5
                                              label = "Monthly Payment Amount",
         MORTGAGE_ACCOUNT.MONTHS_SINCE_AT_BUREAU_CNT length = 8
                                                     label = "Months Since At Bureau",
         MORTGAGE_ACCOUNT.MORTGAGE_CYCLE_DAY_NO length = 8
                                                label = "Mortgage Cycle No Date",
         MORTGAGE_ACCOUNT.MORTGAGE_STATUS_CD length = 3
                                             label = "Mortgage Status Code",
         MORTGAGE_ACCOUNT.MORTGAGE_TYPE_CD length = 3
                                           label = "Mortgage Type Code",
         CASE symget('mEngine') 
         	WHEN "ORACLE" THEN datepart(MORTGAGE_ACCOUNT.NEXT_PI_ADJUSTMENT_DT) 
         	ELSE MORTGAGE_ACCOUNT.NEXT_PI_ADJUSTMENT_DT 
         END as NEXT_PI_ADJUSTMENT_DT length = 8
                                      format = NLDATE10.
                                      informat = NLDATE10.
                                      label = "Next PI Adjustment Date",
         MORTGAGE_ACCOUNT.OFFSET_ACCOUNT_FLG length = 1
                                             label = "Offset Account Flag",
         MORTGAGE_ACCOUNT.OPEN_TO_BUY_AMT length = 8
                                          format = NLNUM18.5
                                          informat = NLNUM18.5
                                          label = "Open To Buy Amount",
         MORTGAGE_ACCOUNT.ORIGIN_CHANNEL_CD length = 3
                                            label = "Origin Channel Code",
         MORTGAGE_ACCOUNT.PAYMENT_ADJUSTABLE_CAP_AMT length = 8
                                                     format = NLNUM18.5
                                                     informat = NLNUM18.5
                                                     label = "Maximum Payment Adjustable  Amount",
         MORTGAGE_ACCOUNT.PAYMENT_AMT length = 8
                                      format = NLNUM18.5
                                      informat = NLNUM18.5
                                      label = "Payment Amount",
         MORTGAGE_ACCOUNT.PAYMENT_METHOD_CD length = 3
                                            label = "Payment Method Code",
         MORTGAGE_ACCOUNT.PAYMENT_PROTECTION_FLG length = 1
                                                 label = "Payment Protection Flag",
         MORTGAGE_ACCOUNT.PAYMENT_PROTECTION_STATUS_CD length = 3
                                                       label = "Payment Protect Status Code",
         MORTGAGE_ACCOUNT.PAYMENT_TIME_FREQUENCY_CD length = 3
                                                    label = "Payment Time Frequency Code",
         MORTGAGE_ACCOUNT.PERIOD_CAP_PERCENTAGE_RT length = 8
                                                   format = NLNUM9.4
                                                   informat = NLNUM9.4
                                                   label = "Period Maximum Percentage Rate",
         MORTGAGE_ACCOUNT.PORTABILITY_FLG length = 1
                                          label = "Portability Flag",
         CASE symget('mEngine') 
         	WHEN "ORACLE" THEN datepart(MORTGAGE_ACCOUNT.PPI_PREMIUM_FIRST_DUE_DT) 
         	ELSE MORTGAGE_ACCOUNT.PPI_PREMIUM_FIRST_DUE_DT 
         END as PPI_PREMIUM_FIRST_DUE_DT length = 8
                                         format = NLDATE10.
                                         informat = NLDATE10.
                                         label = "Protection insurance first premium due date",
         MORTGAGE_ACCOUNT.PRE_CREDIT_CD length = 3
                                        label = "Pre Credit Code",
         CASE symget('mEngine') 	
         	WHEN "ORACLE" THEN datepart(MORTGAGE_ACCOUNT.PRE_CREDIT_END_DT)
         	ELSE  MORTGAGE_ACCOUNT.PRE_CREDIT_END_DT
         END as PRE_CREDIT_END_DT length = 8
                                  format = NLDATE10.
                                  informat = NLDATE10.
                                  label = "Pre Credit End Date",
         MORTGAGE_ACCOUNT.PREPAYMENT_PENALTY_AMT length = 8
                                                 format = NLNUM18.5
                                                 informat = NLNUM18.5
                                                 label = "Prepayment Penalty Amount",
         CASE symget('mEngine') 
         	WHEN "ORACLE" THEN datepart(MORTGAGE_ACCOUNT.PREPAYMENT_PENALTY_DT ) 
         	ELSE MORTGAGE_ACCOUNT.PREPAYMENT_PENALTY_DT  
         END as PREPAYMENT_PENALTY_DT length = 8
                                      format = NLDATE10.
                                      informat = NLDATE10.
                                      label = "Prepayment Penalty Date",
         MORTGAGE_ACCOUNT.PRINCIPAL_REPAYMENT_FLG length = 1
                                                  label = "Principal Repayment Flag",
         MORTGAGE_ACCOUNT.PROPERTY_RK length = 8
                                      format = 12.
                                      informat = 12.
                                      label = "Property Key",
         CASE symget('mEngine') 
         	WHEN "ORACLE" THEN datepart(MORTGAGE_ACCOUNT.PROT_PREM_START_DT) 
         	ELSE MORTGAGE_ACCOUNT.PROT_PREM_START_DT 
         END as PROT_PREM_START_DT length = 8
                                   format = NLDATE10.
                                   informat = NLDATE10.
                                   label = "Protection Prem Start Date",
         MORTGAGE_ACCOUNT.PROT_TERM_CONDITION_CD length = 3
                                                 label = "Protection Term Condition Code",
         MORTGAGE_ACCOUNT.PROTECTION_FLG length = 1
                                         label = "Protection Flag",
         MORTGAGE_ACCOUNT.PROTECTION_INS_EXTERNAL_ORG_RK length = 8
                                                         format = 12.
                                                         informat = 12.
                                                         label = "Protection Insurance External Organization Key",
         MORTGAGE_ACCOUNT.PROTECTION_POLICY_NO length = 20
                                               label = "Protection Policy No",
         MORTGAGE_ACCOUNT.PROTECTION_PREM_RT length = 8
                                             format = NLNUM9.4
                                             informat = NLNUM9.4
                                             label = "Protection Premium Rate",
         CASE symget('mEngine') 
         	WHEN "ORACLE" THEN datepart(MORTGAGE_ACCOUNT.PROTECTION_START_DT) 
         	ELSE MORTGAGE_ACCOUNT.PROTECTION_START_DT 
         END as PROTECTION_START_DT length = 8
                                    format = NLDATE10.
                                    informat = NLDATE10.
                                    label = "Protection Start Date",
         MORTGAGE_ACCOUNT.PROTECTION_STATUS_CD length = 3
                                               label = "Protection Status Code",
         MORTGAGE_ACCOUNT.PURPOSE_CD length = 3
                                     label = "Purpose Code",
         CASE symget('mEngine') 
         	WHEN "ORACLE" THEN datepart(MORTGAGE_ACCOUNT.REDEEMED_DT) 
         	ELSE MORTGAGE_ACCOUNT.REDEEMED_DT 
         END as REDEEMED_DT length = 8
                            format = NLDATE10.
                            informat = NLDATE10.
                            label = "Redeemed Date",
         MORTGAGE_ACCOUNT.REDEMPTION_CHARGES_CD length = 3
                                                label = "Redemption Charges Code",
         MORTGAGE_ACCOUNT.REDRAW_FLG length = 1
                                     label = "Redraw Flag",
         MORTGAGE_ACCOUNT.REFINANCE_AMT length = 8
                                        format = NLNUM18.5
                                        informat = NLNUM18.5
                                        label = "Refinance Amount",
         CASE symget('mEngine') 
         	WHEN "ORACLE" THEN datepart(MORTGAGE_ACCOUNT.REPAYMENT_HOLIDAY_END_DT) 
         	ELSE MORTGAGE_ACCOUNT.REPAYMENT_HOLIDAY_END_DT 
         END as REPAYMENT_HOLIDAY_END_DT length = 8
                                         format = NLDATE10.
                                         informat = NLDATE10.
                                         label = "Repayment Holiday End Date",
         MORTGAGE_ACCOUNT.REPAYMENT_HOLIDAY_FLG length = 1
                                                label = "Repayment Holiday Flag",
         CASE symget('mEngine') 
         	WHEN "ORACLE" THEN datepart(MORTGAGE_ACCOUNT.REPAYMENT_HOLIDAY_START_DT) 
         	ELSE MORTGAGE_ACCOUNT.REPAYMENT_HOLIDAY_START_DT 
         END as REPAYMENT_HOLIDAY_START_DT length = 8
                                           format = NLDATE10.
                                           informat = NLDATE10.
                                           label = "Repayment Holiday Start Date",
         CASE symget('mEngine') 
         	WHEN "ORACLE" THEN datepart(MORTGAGE_ACCOUNT.REVIEW_DT) 
         	ELSE MORTGAGE_ACCOUNT.REVIEW_DT 
         END as REVIEW_DT length = 8
                          format = NLDATE10.
                          informat = NLDATE10.
                          label = "Review Date",
         MORTGAGE_ACCOUNT.SENIORITY_CD length = 3
                                       label = "Seniority Code",
         MORTGAGE_ACCOUNT.SET_UP_FEES_AMT length = 8
                                          format = NLNUM18.5
                                          informat = NLNUM18.5
                                          label = "Set Up Fees Amount",
         MORTGAGE_ACCOUNT.SOURCE_SYSTEM_CD length = 3
                                           label = "Source System Code",
         MORTGAGE_ACCOUNT.SPECIAL_INTEREST_RT length = 8
                                              format = NLNUM9.4
                                              informat = NLNUM9.4
                                              label = "Special Interest Rate",
         CASE symget('mEngine') 
         	WHEN "ORACLE" THEN datepart(MORTGAGE_ACCOUNT.SPECIAL_RATE_END_DT) 
         	ELSE MORTGAGE_ACCOUNT.SPECIAL_RATE_END_DT 
         END as SPECIAL_RATE_END_DT length = 8
                                    format = NLDATE10.
                                    informat = NLDATE10.
                                    label = "Special Rate End Date",
         CASE symget('mEngine') 
         	WHEN "ORACLE" THEN datepart(MORTGAGE_ACCOUNT.SPECIAL_RATE_START_DT) 
         	ELSE MORTGAGE_ACCOUNT.SPECIAL_RATE_START_DT 
         END as SPECIAL_RATE_START_DT length = 8
                                      format = NLDATE10.
                                      informat = NLDATE10.
                                      label = "Special Rate Start Date",
         MORTGAGE_ACCOUNT.SPECIAL_RATE_TYPE_CD length = 3
                                               label = "Special Rate Type Code",
         MORTGAGE_ACCOUNT.SPECIALIZED_LENDING_CD length = 3
                                                 label = "Specialized Lending Code",
         MORTGAGE_ACCOUNT.SPLIT_LOAN_FLG length = 1
                                         label = "Split Loan Flag",
         MORTGAGE_ACCOUNT.TAX_YEAR_INTEREST_AMT length = 8
                                                format = NLNUM18.5
                                                informat = NLNUM18.5
                                                label = "Tax Year Interest Amount",
         MORTGAGE_ACCOUNT.VRBLE_CHNG_TIME_FREQUENCY_CD length = 3
                                                       label = "Variable Change Time Frequency Code"
      from
         control.LOAD_CONTROL, 
         DDS.MORTGAGE_ACCOUNT
      where
         LOAD_CONTROL.LOAD_FLG IN (&CHECK_FLAG_TRUE)
         and LOAD_CONTROL.RUN_STATUS IN (&RUNNING_STATUS)
         and LOAD_CONTROL.LOAD_END_DTTM >= MORTGAGE_ACCOUNT.VALID_FROM_DTTM
         and LOAD_CONTROL.LOAD_END_DTTM <= MORTGAGE_ACCOUNT.VALID_TO_DTTM
      ;
quit;

%rcSet(&sqlrc); 

%macro etls_completeTarget();
%mend etls_completeTarget;
%etls_completeTarget;

/*============================================================================* 
 * Step:          Dummy Loader                              A5V75JN3.BO0006ZR * 
 * Transform:     Table Loader                                                * 
 * Description:                                                               * 
 *                                                                            * 
 * Source Table:  SQL Target - martscr.MA_EXT               A5V75JN3.BP000674 * 
 * Target Table:  MA_EXT - martscr.MA_EXT                   A5V75JN3.BE0000KC * 
 *============================================================================*
 *                                                                            * 
 * Nothing will be generated for this process because the "Do not generate    * 
 *  code for this process" option is selected.                                * 
 *                                                                            * 
 *============================================================================*/ 

data _null_; 
   call symput('etls_endTime',put(datetime(),datetime.));
run;

/* Check return code for job  */ 
%macro etls_jobRCChk; 
   %if (&job_rc eq 4) %then
   %do; 
      %on_success(Job_nm=&etls_jobName..sas, param_table=&status_table);
   %end; 
%mend etls_jobRCChk; 
%etls_jobRCChk; 

/* Check return code for job  */ 
%macro etls_jobRCChk; 
   %if (&job_rc ge 5) %then
   %do; 
      %on_success(Job_nm=&etls_jobName..sas, param_table=&status_table);
   %end; 
%mend etls_jobRCChk; 
%etls_jobRCChk; 

/* Check return code for job  */ 
%macro etls_jobRCChk; 
   %if (&job_rc eq 0) %then
   %do; 
      %on_success(Job_nm=&etls_jobName..sas, param_table=&status_table);
   %end; 
%mend etls_jobRCChk; 
%etls_jobRCChk; 

/*---- Job status macro  ----*/ 
/*============================================================================* 
 * Post-Process code for the job                            A5V75JN3.AY0004OT * 
 *                                                                            * 
 * User Written:  Index creation code on ACCOUNT_RK column, A5V75JN3.AF000PXU * 
 *                 LOAD_END_DTTM                                              * 
 *                Index creation code on ACCOUNT_RK column, LOAD_END_DTTM     * 
 *============================================================================*/ 

/*---- Start of User Written Code  ----*/ 

/*creating index on ACCOUNT_RK column */
PROC SQL NOPRINT;
           CREATE INDEX  ACCOUNT_RK_LOAD_END_DTTM
            ON martscr.MA_EXT (ACCOUNT_RK,LOAD_END_DTTM);

QUIT;
/*---- End of User Written Code  ----*/ 

%rcSet(&syserr); 
%rcSet(&sqlrc); 

