/****************************************************************************** 
 * Job:           MasterLoopStarSchemaJob                   A5V75JN3.BN000003 * 
 * Description:                                                               * 
 *                                                                            * 
 * Repository:    Foundation                                A0000001.A5V75JN3 * 
 * Server:        SASMain                                   A5V75JN3.AT000001 * 
 *                                                                            * 
 * Source Table:  PARAMETER_LIST_STAR_SCHEMA -              A5V75JN3.BE0000I1 * 
 *                 control.PARAMETER_LIST_STAR_SCHEMA                         * 
 *                                                                            * 
 * Generated on:  Wednesday, December 10, 2008 2:42:19 PM IST                 * 
 * Generated by:  sasadm                                                      * 
 * Version:       9.1.20060626.51875                                          * 
 ******************************************************************************/ 

/* Setup to capture return codes  */ 
%global job_rc trans_rc sqlrc; 
%let job_rc = 0;
%let trans_rc = 0;
%let sqlrc = 0;
%global syserr; 

%macro rcSet(error); 
   %if (&error gt &trans_rc) %then 
      %let trans_rc = &error;
   %if (&error gt &job_rc) %then 
      %let job_rc = &error;
%mend rcSet; 

%macro rcSetDS(error); 
   if &error gt input(symget('trans_rc'),12.) then 
      call symput('trans_rc',trim(left(put(&error,12.))));
   if &error gt input(symget('job_rc'),12.) then 
      call symput('job_rc',trim(left(put(&error,12.))));
%mend rcSetDS; 

%global etls_debug; 
%macro etls_setDebug; 
   %if %str(&etls_debug) ne 0 %then 
      OPTIONS MPRINT%str(;); 
%mend; 
%etls_setDebug; 

/*============================================================================* 
 * Pre-Process code for the job                             A5V75JN3.AY000410 * 
 *                                                                            * 
 * User Written:  Log the start of job                      A5V75JN3.AF000MJJ * 
 *============================================================================*/ 

/*---- Start of User Written Code  ----*/ 

 

%macro initial_verify;

%let max_load_dttm=;
%let error_cnt=;
%let month_cnt=;


/* This code checks for any existing erroneous loading periods with LOAD_FLG having value of CHECK_FLAG_TRUE.
If such records exist, this job will abort. */

proc sql noprint;
  select count(*)
  into :error_cnt
  from control.LOAD_CONTROL
  where RUN_STATUS = &ERROR_STATUS.
  and LOAD_FLG = &CHECK_FLAG_TRUE.;
quit;

%if &error_cnt gt 1 %then %do;
   %put &LOADING_ERROR;
	%abort ABEND;
%end;

/* This code checks the count of loading periods having LOAD_FLG = CHECK_FLAG_TRUE.
It checks the value of MULTI_MONTH_LOAD parameter and the number of months that are intended for loading.
MULTI_MONTH_LOAD parameter should have value CHECK_FLAG_TRUE, if there are multiple months to be loaded at 
the same time. Otherwise of a single month is to be loaded, the MULTI_MONTH_LOAD parameter should have 
value CHECK_FLAG_FALSE. 
If there is a mismatch between the loading periods count and MULTI_MONTH_LOAD parameter this job will abort. */

proc sql noprint;
  select count(*)
  into :month_cnt
  from control.LOAD_CONTROL
  where LOAD_FLG = &CHECK_FLAG_TRUE. 
  and RUN_STATUS = &WAITING_STATUS.;
quit;

%if &month_cnt. gt 1 and &MULTI_MONTH_LOAD. eq &CHECK_FLAG_FALSE. %then %do;
   %put &MISMATCH_ERROR;
	proc sql;
		update control.LOAD_CONTROL set RUN_STATUS = &ERROR_STATUS. 
		where LOAD_FLG = &CHECK_FLAG_TRUE. and RUN_STATUS = &WAITING_STATUS.;
	quit;
   %abort ABEND;
%end;

%if &month_cnt. eq 1 and &MULTI_MONTH_LOAD. eq &CHECK_FLAG_TRUE. %then %do;
   %put &MISMATCH_ERROR;
	proc sql;
		update control.LOAD_CONTROL set RUN_STATUS = &ERROR_STATUS. 
		where LOAD_FLG = &CHECK_FLAG_TRUE. and RUN_STATUS = &WAITING_STATUS.;
	quit;
   %abort ABEND;
%end;

/* If the earlier run of this job had some errors, this code updates the return_code to '.'.
This is done so that the erroneous jobs are run again. */
/* return_cd value in the &status_table is greater than 4 in case of errors. 
Customise this statement, if the even the warnings should not be allowed. */

proc sql;
		update &status_table.
		set return_cd = .
		where return_cd > 4;
quit;

proc sql;
		select count(*) 
		into :run_cnt
		from &status_table.
		where return_cd = .;
quit;

%if &run_cnt eq 0 %then %do;
   %put &NO_JOBS_ERROR;
	proc sql;
		update control.LOAD_CONTROL set RUN_STATUS = &ERROR_STATUS. 
		where LOAD_FLG = &CHECK_FLAG_TRUE. and RUN_STATUS = &WAITING_STATUS.;
	quit;
   %abort ABEND;
%end;


/* If the initial verification is correct, the RUN_STATUS in the LOAD_CONTROL table is updated to
RUNNING_STATUS. */

proc sql;
		update control.LOAD_CONTROL
		set RUN_STATUS = &RUNNING_STATUS.
		where LOAD_FLG = &CHECK_FLAG_TRUE.
		and RUN_STATUS = &WAITING_STATUS.;
quit;

/* set the value of parameters - LOAD_STAR_USER_INPUT_DTTM and LOAD_STAR_USER_INPUT_DATE */

proc sql;
      select max(LOAD_END_DTTM) format=NLDATM21. 
		into :max_end_dttm 
		from control.LOAD_CONTROL 
		where RUN_STATUS = &RUNNING_STATUS.;
quit;

%let max_end_dttm = &max_end_dttm.;
data _null_;
	ld=input("&max_end_dttm"dt,32.);
	dp=datepart(ld);
	call symput('ld1',put(ld,NLDATM21.));
	call symput('dp1',dp);
run;

proc sql;
	update custpara.parameter
	set parameter_value = "'&ld1'"||'dt'
	where parameter_nm = 'LOAD_STAR_USER_INPUT_DTTM';

	update custpara.parameter
	set parameter_value = "'&ld1'"||'dt'
	where parameter_nm = 'MAX_LOAD_END_DTTM';

	update custpara.parameter
	set parameter_value = "&dp1"
	where parameter_nm = 'LOAD_STAR_USER_INPUT_DATE';
quit;


%mend;


options symbolgen;

proc printto log='Data/bisdata/log/schedule_credit_scoring/MasterLoopStarSchemaJob.log';
run;

%let status_table=control.parameter_list_star_schema;
%initial_verify;

options nosymbolgen;

proc printto ;
run;
/*---- End of User Written Code  ----*/ 

%rcSet(&syserr); 
%rcSet(&sqlrc); 

/*============================================================================* 
 * Step:          SQL Join                                  A5V75JN3.BO0005MU * 
 * Transform:     SQL Join (Version 2)                                        * 
 * Description:                                                               * 
 *                                                                            * 
 * Source Table:  PARAMETER_LIST_STAR_SCHEMA -              A5V75JN3.BE0000I1 * 
 *                 control.PARAMETER_LIST_STAR_SCHEMA                         * 
 * Target Table:  SQL Target - work.W5D8EMYG                A5V75JN3.BP0004RV * 
 *============================================================================*/ 

/* Access the data for Control  */ 
LIBNAME control BASE "Data/bisdata/control" ;
%rcSet(&syslibrc); 

%let SYSLAST = %nrquote(control.PARAMETER_LIST_STAR_SCHEMA); 

%let trans_rc = 0; 

proc datasets lib = work nolist nowarn memtype = (data view);
   delete W5D8EMYG;
quit;

proc sql;
   create table work.W5D8EMYG as
      select distinct
         PARAMETER_LIST_STAR_SCHEMA.LEVEL_NO as master_level_no length = 8
      from
         control.PARAMETER_LIST_STAR_SCHEMA
      order by
         master_level_no
      ;
quit;

%rcSet(&sqlrc); 

%macro etls_completeTarget();
%mend etls_completeTarget;
%etls_completeTarget;

/*============================================================================* 
 * Step:          Loop                                      A5V75JN3.BR00034C * 
 * Transform:     Loop                                                        * 
 * Description:                                                               * 
 *                                                                            * 
 * Source Table:  SQL Target - work.W5D8EMYG                A5V75JN3.BP0004RV * 
 * Target Table:  Status Table - work.W5AR0VBB              A5V75JN3.BP0004RW * 
 *============================================================================*/ 

%let SYSLAST = %nrquote(work.W5D8EMYG); 

%let trans_rc = 0; 

%macro etls_getHandle(statusTable=, handleVariable=, row=); 
   %let etls_dsid = %sysfunc(open(&statusTable)); 
   %if (&etls_dsid = 0) %then 
      %put %sysfunc(sysmsg()); 
   %else 
   %do; 
      %let rc = %sysfunc(fetchobs(&etls_dsid, &row)); 
      %if (&rc ne 0) %then 
         %put %sysfunc(sysmsg()); 
      %else 
      %do; 
         %let etls_varnum = %sysfunc(varnum(&etls_dsid,&handleVariable)); 
         %if (&etls_varnum > 0) %then 
            %sysfunc(getvarc(&etls_dsid,&etls_varnum)); 
         %else 
            %put %sysfunc(sysmsg()); 
      %end; 
      %let rc = %sysfunc(close(&etls_dsid)); 
   %end; 
%mend etls_getHandle; 

%macro etls_freeHandle(statusTable=, statusVariable=, handleVariable=, 
   handleName=, statusSetting="Finished", 
   endTimeVariable=endTime, startTimeVariable=startTime, signoff=1, 
   returnCodeVariable=, returnCodeMacroVariable=, setMainJobRC=1, 
   statusUnknownReturnCode=., startTimeMacroVariable=, endTimeMacroVariable= ); 

   %if ("&statusTable" ne "") %then 
   %do; 
      %local etls_rcMacroVarExisted; 
      %let etls_rcMacroVarExisted = 0; 
      %if ("&returnCodeMacroVariable" ne "") %then 
      %do; 
         proc sql noprint; 
            select '1' into: etls_rcMacroVarExisted from dictionary.macros 
            where name=upcase("&returnCodeMacroVariable"); 
         quit; 

         %rcSet(&sqlrc); 
         %if (&etls_rcMacroVarExisted = 0) %then 
         %do; 
            %put WARNING: Return code from inner job not found.  Setting status to Unknown.;
            %let &returnCodeMacroVariable=&statusUnknownReturnCode; 
         %end; 
         %if (&setMainJobRC eq 1) %then 
            %rcSet(&&&returnCodeMacroVariable); 
      %end; 
      %else 
      %do; 
         %let returnCodeMacroVariable=etls_rcmacvar; 
         %let &returnCodeMacroVariable=&statusUnknownReturnCode; 
      %end; 

      %local etls_startTimeMacroVarExisted; 
      %let etls_startTimeMacroVarExisted = 0; 
      %if ("&startTimeMacroVariable" ne "") %then 
      %do; 
         proc sql noprint; 
            select '1' into: etls_startTimeMacroVarExisted from dictionary.macros 
            where name=upcase("&startTimeMacroVariable"); 
         quit; 

         %rcSet(&sqlrc); 
         %if (&etls_startTimeMacroVarExisted = 0) %then 
         %do; 
            %put WARNING: Start time from inner job not found.  No value will be set.;
            %let &startTimeMacroVariable=; 
         %end; 
      %end; 

      %local etls_endTimeMacroVarExisted; 
      %let etls_endTimeMacroVarExisted = 0; 
      %if ("&endTimeMacroVariable" ne "") %then 
      %do; 
         proc sql noprint; 
            select '1' into: etls_endTimeMacroVarExisted from dictionary.macros 
            where name=upcase("&endTimeMacroVariable"); 
         quit; 

         %rcSet(&sqlrc); 
         %if (&etls_endTimeMacroVarExisted = 0) %then 
         %do; 
            %put WARNING: End time from inner job not found.  Setting end time to current time.;
            %let &endTimeMacroVariable=%sysfunc(datetime()); 
         %end; 
      %end; 

      data &statusTable; 
         modify &statusTable(where=(&handleVariable = &handleName)); 
         %if ("&startTimeMacroVariable" ne "") %then 
         %do; 
            &startTimeVariable = input(symget("&startTimeMacroVariable"),32.);; 
         %end; 
         %if ("&endTimeVariable" ne "") %then 
         %do; 
            %if ("&endTimeMacroVariable" ne "") %then 
            %do; 
               &endTimeVariable = input(symget("&endTimeMacroVariable"),32.);; 
            %end; 
            %else 
               &endTimeVariable = datetime();; 
         %end; 
         %if ("&returnCodeVariable" ne "") %then 
            &returnCodeVariable = input(symget("&returnCodeMacroVariable"),32.);; 
         %if ("&statusVariable" ne "") %then 
         %do; 
            if (symget("etls_rcMacroVarExisted") eq "0") then 
               &statusVariable = "Unknown Status"; 
            else
               &statusVariable = &statusSetting;
         %end;
         call symput('handle',&handleVariable); 
         replace; 
         stop; 
      run; 

      %rcSet(&syserr); 

      %if (&signoff eq 1) %then 
         %etls_signoff(handleName=&handle); 
   %end; 
%mend etls_freeHandle; 

%macro etls_createHandle(statusTable=, statusVariable=, 
   handleVariable=, handlePrefix=rmt, 
   workloadMacroVariable=, row=, machineVariable=, 
   statusSetting="Running", startTimeVariable=startTime, 
   signon=1, useGrid=1, log=, output=, gridRC=, cmacvar=etls_signonStatus, 
   additionalSignonOptions=, signonRetries= ); 

   %local remoteSessionId; 
   %let remoteSessionId = &handlePrefix.&row; 
   %let &cmacvar = 1; 
   %local etls_machineId; 
   %if (&signon eq 1) %then  
      %etls_signon(handleName=&remoteSessionId, useGrid=&useGrid, 
         machineIdMacroVariable=etls_machineId, workloadMacroVariable=&workloadMacroVariable, 
         log=&log, output=&output, cmacvar=&cmacvar, gridRC=&gridRC, 
         additionalSignonOptions=&additionalSignonOptions,signonRetries=&signonRetries); 
   %else %let &cmacvar=0; 

   data &statusTable; 
      retain ptr &row; 
      modify &statusTable point = ptr; 
      &handleVariable = "&remoteSessionId"; 
      %if (&signon eq 1) %then 
         &machineVariable = "&etls_machineId";; 
      %if (&&&cmacvar ne 0) %then 
      %do; 
         &statusVariable = "Failed Signon"; 
      %end; 
      %else 
         &statusVariable = &statusSetting;; 
      %if (&startTimeVariable ne ) %then 
         &startTimeVariable = datetime();; 
      replace; 
      stop; 
   run; 

   %rcSet(&syserr); 
%mend etls_createHandle; 

%macro etls_getParameterNames(parameterTable=, parameterVariableMacro=, startingColumnNumber=1);
   %let &parameterVariableMacro = ;
   %let dsid = %sysfunc(open(&parameterTable));
   %if (&dsid gt 0) %then 
   %do; 
      %do i=&startingColumnNumber %to %sysfunc(attrn(&dsid,nvars)); 
         %let &parameterVariableMacro = &&&parameterVariableMacro %sysfunc(varname(&dsid,&i)); 
      %end; 
      %let dsid = %sysfunc(close(&dsid)); 
   %end; 
   %else 
      %put %sysfunc(sysmsg()); 
   %rcSet(&syserr); 
%mend etls_getParameterNames; 

%macro etls_getParameters(parameterTable=, row=, startingColumnNumber=1 , handleName=); 
   data _null_; 
      length vname $256 vtype $1 value $3200; 
      dsid = open("&parameterTable"); 
      if (dsid > 0) then 
      do; 
         do _i = 1 to &row; 
            fetchrc = fetch(dsid); 
         end; 
         do _i=&startingColumnNumber to attrn(dsid,'nvars'); 
            vname = varname(dsid,_i); 
            vtype = vartype(dsid,_i); 
            if (fetchrc = 0) then 
            do; 
               if (vtype = 'C') then 
               do; 
                  value = getvarc(dsid,_i); 
                  value = tranwrd(value,"%","%%"); 
                  value = tranwrd(value,"(","%("); 
                  value = tranwrd(value,")","%)"); 
                  value = tranwrd(value,'"','%"'); 
               end; 
               else 
                  value = left(put(getvarn(dsid,_i),best32.)); 
            end; /* fetchrc = 0 */ 
            
            put ;
            if indexc(trimn(value),"+-*/<>=^~;, '()&%",'"')>0 then 
            do; 
               value='%str('||trim(value)||')'; 
               put "NOTE: Special characters encountered; References may require: %nrbquote(%)UNQUOTE(&" vname+(-1)').';
            end; 
            %if %str(&handlename) ne %str() %then 
            %do; 
               value = '%syslput '||trim(vname)||'= '||trim(value)||" / remote = &handleName;"; 
            %end; 
            %else 
            %do; 
               value = '%let '||trim(vname)||'= '||trim(value)||';'; 
            %end; 
            
            put "NOTE: Setting macro variable " vname "with statement:" value ;
            call execute(value); 
         end; /* do i= */ 
         dsid = close(dsid); 
      end; /* dsid > 0 */ 
      else 
      do; 
         put "ERROR" ": Parameter table, &parameterTable, could not be opened.";
         abort; 
      end; 
      stop; 
   run; 
   
   %rcSet(&syserr); 
%mend etls_getParameters; 

%macro etls_loopW5N8JZPH; 
   %local etls_filePrefix; 
   %let etls_filePrefix = ; 
   
   %macro etls_processToLoopW5N8JZPR(parameterTable=, row=, handleName=rmt);
      %local etls_parmvars; 
      %etls_getParameterNames(parameterTable=&parameterTable, 
         parameterVariableMacro=etls_parmvars, 
         startingColumnNumber=1); 
      %local &etls_parmvars; 
      %etls_getParameters(parameterTable=&parameterTable, row=&row, 
         startingColumnNumber=1); 
      %let etls_previousFilePrefix = &etls_filePrefix;
      %local etls_filePrefix; 
      %let etls_filePrefix = &etls_previousFilePrefix.&handleName; 
      %macro etls_jobW5N8JZQ1; 
      
         /****************************************************************************** 
          * Job:           LoopStarSchemaJob                         A5V75JN3.BN000002 * 
          * Description:                                                               * 
          *                                                                            * 
          * Repository:    Foundation                                A0000001.A5V75JN3 * 
          * Server:        SASMain                                   A5V75JN3.AT000001 * 
          *                                                                            * 
          * Source Table:  PARAMETER_LIST_STAR_SCHEMA -              A5V75JN3.BE0000I1 * 
          *                 control.PARAMETER_LIST_STAR_SCHEMA                         * 
          *                                                                            * 
          * Generated on:  Wednesday, December 10, 2008 2:42:19 PM IST                 * 
          * Generated by:  sasadm                                                      * 
          * Version:       9.1.20060626.51875                                          * 
          ******************************************************************************/ 
         
         /* Setup to capture return codes  */ 
         %global job_rc trans_rc sqlrc; 
         %let job_rc = 0;
         %let trans_rc = 0;
         %let sqlrc = 0;
         %global syserr; 
         
         %macro rcSet(error); 
            %if (&error gt &trans_rc) %then 
               %let trans_rc = &error;
            %if (&error gt &job_rc) %then 
               %let job_rc = &error;
         %mend rcSet; 
         
         %macro rcSetDS(error); 
            if &error gt input(symget('trans_rc'),12.) then 
               call symput('trans_rc',trim(left(put(&error,12.))));
            if &error gt input(symget('job_rc'),12.) then 
               call symput('job_rc',trim(left(put(&error,12.))));
         %mend rcSetDS; 
         
         %global etls_debug; 
         %macro etls_setDebug; 
            %if %str(&etls_debug) ne 0 %then 
               OPTIONS MPRINT%str(;); 
         %mend; 
         %etls_setDebug; 
         
         /*============================================================================* 
          * Step:          SAS Extract                               A5V75JN3.BO0005MS * 
          * Transform:     Extract                                                     * 
          * Description:                                                               * 
          *                                                                            * 
          * Source Table:  PARAMETER_LIST_STAR_SCHEMA -              A5V75JN3.BE0000I1 * 
          *                 control.PARAMETER_LIST_STAR_SCHEMA                         * 
          * Target Table:  Extract Target - work.W5DWKJ4G            A5V75JN3.BP0004RT * 
          *============================================================================*/ 
         
         %let SYSLAST = %nrquote(control.PARAMETER_LIST_STAR_SCHEMA); 
         
         %let trans_rc = 0; 
         
         proc datasets lib = work nolist nowarn memtype = (data view);
            delete W5DWKJ4G;
         quit;
         
         proc sql; 
            create table work.W5DWKJ4G as 
               select JOB_NM length = 40,
                      LEVEL_NO length = 8
                  from &SYSLAST
                     where LEVEL_NO = &master_LEVEL_NO  & RETURN_CD is null; 
         quit;
         
         %let SYSLAST = work.W5DWKJ4G; 
         
         %rcSet(&sqlrc); 
         
         /*============================================================================* 
          * Step:          Loop                                      A5V75JN3.BR00034A * 
          * Transform:     Loop                                                        * 
          * Description:                                                               * 
          *                                                                            * 
          * Source Table:  Extract Target - work.W5DWKJ4G            A5V75JN3.BP0004RT * 
          * Target Table:  Status Table - work.W5AR0VBB              A5V75JN3.BP0004RU * 
          *============================================================================*/ 
         
         %let SYSLAST = %nrquote(work.W5DWKJ4G); 
         
         %let trans_rc = 0; 
         
         %macro genSASCommand; 
            %local noobjserver; 
            %if "&sysscp"="OS" %then %let noobjserver=; 
            %else %if "&sysscp"="VMS_AXP" %then %let noobjserver=%quote(/noobjectserver); 
            %else %let noobjserver=%quote(-noobjectserver); 
            options sascmd = "!sascmd &noobjserver"; 
         %mend genSASCommand; 
         %genSASCommand; 
         
         %macro etls_tsLevel(macroName=, featureName=); 
            data _null_; 
               call symput("&macroName",tslvl("&featureName")); 
            run; 
         %mend etls_tsLevel; 
         
         %macro etls_signon(handleName=etlsRemote, cmacvar=etls_signonStatus, 
            gridRC=rc, useGrid=1, 
            machineIdMacroVariable=etls_machineId, workloadMacroVariable=, 
            log=, output=, additionalSignonOptions=, signonRetries=3); 
         
            %let etls_gridInstalled =;
            %etls_tsLevel(macroName=etls_gridInstalled, featureName=uwugrdsvc); 
         
            %if (&useGrid = 1) %then 
            %do; 
               %if ("&etls_gridInstalled" ne "") %then 
               %do; 
                  %if (&gridRC eq ) %then 
                     %let gridRC = &handleName.RC ; 
         
                  %global &gridRC;
                  %let workload = ; 
                  %if (&workloadMacroVariable ne ) %then 
                  %do; 
                     data _null_;
                        call symput('workload',';workload = '||symget("&workloadMacroVariable"));
                     run;
                  %end; 
                  %let &gridRC = %sysfunc(grdsvc_enable("&handleName","resource = SASMain &workload ")); 
               %end; 
               %else 
                  %put %str(NOTE: Grid service functions are not installed.);
            %end; 
         
            %local sleeptime sleepIncreaseAmount tryCount; 
            %let sleepIncreaseAmount=5; 
            %let sleeptime=5; 
            %let tryCount=1; 
            %let &cmacvar=1; 
         
            %do %until((&&&cmacvar ne 1) or (&tryCount gt %eval(&signonRetries+1))); 
               data _null_; 
               signon &handleName cmacvar=&cmacvar 
                  %if ("&log" ne "") %then 
                     log=&log; 
                  %if ("&output" ne "") %then 
                     output=&output; 
                  %if ("&additionalSignonOptions" ne "") %then 
                     &additionalSignonOptions; 
               ;run; 
         
               %if ("&machineIdMacroVariable" ne "") %then 
               %do; 
                  %if ("&etls_gridInstalled" ne "") %then 
                     %let &machineIdmacroVariable = %sysfunc(grdsvc_getname(&handleName)); 
                  %else 
                     %put %str(NOTE: Grid service functions are not installed.);
               %end; 
         
               %if "&&&cmacvar" eq "1" %then 
               %do; 
                  %if &tryCount lt %eval(&signonRetries+1) %then 
                  %do; 
                     %put NOTE: Signon attempt #&tryCount failed. Retrying in &sleeptime seconds.;
                     %let rc=%sysfunc(sleep(&sleeptime,1)); 
                  %end; 
                  %else %if &signonRetries gt 0 %then 
                     %put ERROR%QUOTE(:) Final signon attempt, #&tryCount, failed.;
         
                  %let sleeptime=%sysevalf(&sleeptime+&sleepIncreaseAmount,int); /* increase sleeptime by factor */ 
                  %let tryCount=%eval(&tryCount+1); 
               %end; 
            %end; 
            %rcSet(&syserr); 
         
         %mend etls_signon; 
         
         %macro etls_serverConnected(serverId=,macvarname=isConnected); 
            %let &macvarname=0; 
            %local search_str none_str savenotes; 
         
            /* setup information for listtask output */ 
            /* listtask output on OS/390 differs */ 
            %if %bquote(&sysscp) eq OS %then 
            %do; 
               %let search_str=Remote submit for; 
               %let token=5; 
            %end; 
            %else  
            %do; 
               %let search_str=--------------; 
               %let token=1; 
            %end; 
         
            /* Issue listtask within PROC PRINTTO - send output to file */ 
            filename __tmptxt TEMP; 
            %let savenotes=%sysfunc(getoption(notes)); 
            options nonotes; 
         
            proc printto log=__tmptxt new; 
            run; 
         
            options notes; 
            listtask; 
            proc printto; 
            run; 
         
            options nonotes; 
         
            /* read in the output from listtask */ 
            %let dsname=_null_; 
            data _null_(keep=Session); 
               length line $256 sessionId $60; 
               infile __tmptxt length=len; 
               input @1 line $varying. len; 
         
               if line=:'There are no' then 
                  stop; 
               /* look for the search string and scan for server name */ 
               if index(line,"&search_str") then  
               do; 
                  sessionId=scan(line,&token," "); 
                  sessionId=upcase(trim(left(tranwrd(sessionId,'"',' ')))); 
                  if sessionId=upcase(symget("serverId")) then 
                  do;  
                     call symput("&macvarname","1"); 
                     stop; 
                  end; 
               end; 
            run; 
            filename __tmptxt clear; 
            options &savenotes; 
         %mend etls_serverConnected; 
         
         %macro etls_signoff(handleName=rmt); 
            %local savemprint; 
            %let savemprint=%sysfunc(getoption(mprint)); 
            %put %str(NOTE: Testing connection with etls_serverConnected macro %(mprint off%).);
            options nomprint; 
            %local isConnected; 
            %etls_serverConnected(serverId=&handleName); 
            options &savemprint; 
            %if &isConnected %then 
               signoff &handleName ;; 
         %mend etls_signoff; 
         
         %macro etls_getHandle(statusTable=, handleVariable=, row=); 
            %let etls_dsid = %sysfunc(open(&statusTable)); 
            %if (&etls_dsid = 0) %then 
               %put %sysfunc(sysmsg()); 
            %else 
            %do; 
               %let rc = %sysfunc(fetchobs(&etls_dsid, &row)); 
               %if (&rc ne 0) %then 
                  %put %sysfunc(sysmsg()); 
               %else 
               %do; 
                  %let etls_varnum = %sysfunc(varnum(&etls_dsid,&handleVariable)); 
                  %if (&etls_varnum > 0) %then 
                     %sysfunc(getvarc(&etls_dsid,&etls_varnum)); 
                  %else 
                     %put %sysfunc(sysmsg()); 
               %end; 
               %let rc = %sysfunc(close(&etls_dsid)); 
            %end; 
         %mend etls_getHandle; 
         
         %macro etls_freeHandle(statusTable=, statusVariable=, handleVariable=, 
            handleName=, statusSetting="Finished", 
            endTimeVariable=endTime, startTimeVariable=startTime, signoff=1, 
            returnCodeVariable=, returnCodeMacroVariable=, setMainJobRC=1, 
            statusUnknownReturnCode=., startTimeMacroVariable=, endTimeMacroVariable= ); 
         
            %if ("&statusTable" ne "") %then 
            %do; 
               %local etls_rcMacroVarExisted; 
               %let etls_rcMacroVarExisted = 0; 
               %if ("&returnCodeMacroVariable" ne "") %then 
               %do; 
                  proc sql noprint; 
                     select '1' into: etls_rcMacroVarExisted from dictionary.macros 
                     where name=upcase("&returnCodeMacroVariable"); 
                  quit; 
         
                  %rcSet(&sqlrc); 
                  %if (&etls_rcMacroVarExisted = 0) %then 
                  %do; 
                     %put WARNING: Return code from inner job not found.  Setting status to Unknown.;
                     %let &returnCodeMacroVariable=&statusUnknownReturnCode; 
                  %end; 
                  %if (&setMainJobRC eq 1) %then 
                     %rcSet(&&&returnCodeMacroVariable); 
               %end; 
               %else 
               %do; 
                  %let returnCodeMacroVariable=etls_rcmacvar; 
                  %let &returnCodeMacroVariable=&statusUnknownReturnCode; 
               %end; 
         
               %local etls_startTimeMacroVarExisted; 
               %let etls_startTimeMacroVarExisted = 0; 
               %if ("&startTimeMacroVariable" ne "") %then 
               %do; 
                  proc sql noprint; 
                     select '1' into: etls_startTimeMacroVarExisted from dictionary.macros 
                     where name=upcase("&startTimeMacroVariable"); 
                  quit; 
         
                  %rcSet(&sqlrc); 
                  %if (&etls_startTimeMacroVarExisted = 0) %then 
                  %do; 
                     %put WARNING: Start time from inner job not found.  No value will be set.;
                     %let &startTimeMacroVariable=; 
                  %end; 
               %end; 
         
               %local etls_endTimeMacroVarExisted; 
               %let etls_endTimeMacroVarExisted = 0; 
               %if ("&endTimeMacroVariable" ne "") %then 
               %do; 
                  proc sql noprint; 
                     select '1' into: etls_endTimeMacroVarExisted from dictionary.macros 
                     where name=upcase("&endTimeMacroVariable"); 
                  quit; 
         
                  %rcSet(&sqlrc); 
                  %if (&etls_endTimeMacroVarExisted = 0) %then 
                  %do; 
                     %put WARNING: End time from inner job not found.  Setting end time to current time.;
                     %let &endTimeMacroVariable=%sysfunc(datetime()); 
                  %end; 
               %end; 
         
               data &statusTable; 
                  modify &statusTable(where=(&handleVariable = &handleName)); 
                  %if ("&startTimeMacroVariable" ne "") %then 
                  %do; 
                     &startTimeVariable = input(symget("&startTimeMacroVariable"),32.);; 
                  %end; 
                  %if ("&endTimeVariable" ne "") %then 
                  %do; 
                     %if ("&endTimeMacroVariable" ne "") %then 
                     %do; 
                        &endTimeVariable = input(symget("&endTimeMacroVariable"),32.);; 
                     %end; 
                     %else 
                        &endTimeVariable = datetime();; 
                  %end; 
                  %if ("&returnCodeVariable" ne "") %then 
                     &returnCodeVariable = input(symget("&returnCodeMacroVariable"),32.);; 
                  %if ("&statusVariable" ne "") %then 
                  %do; 
                     if (symget("etls_rcMacroVarExisted") eq "0") then 
                        &statusVariable = "Unknown Status"; 
                     else
                        &statusVariable = &statusSetting;
                  %end;
                  call symput('handle',&handleVariable); 
                  replace; 
                  stop; 
               run; 
         
               %rcSet(&syserr); 
         
               %if (&signoff eq 1) %then 
                  %etls_signoff(handleName=&handle); 
            %end; 
         %mend etls_freeHandle; 
         
         %macro etls_createHandle(statusTable=, statusVariable=, 
            handleVariable=, handlePrefix=rmt, 
            workloadMacroVariable=, row=, machineVariable=, 
            statusSetting="Running", startTimeVariable=startTime, 
            signon=1, useGrid=1, log=, output=, gridRC=, cmacvar=etls_signonStatus, 
            additionalSignonOptions=, signonRetries= ); 
         
            %local remoteSessionId; 
            %let remoteSessionId = &handlePrefix.&row; 
            %let &cmacvar = 1; 
            %local etls_machineId; 
            %if (&signon eq 1) %then  
               %etls_signon(handleName=&remoteSessionId, useGrid=&useGrid, 
                  machineIdMacroVariable=etls_machineId, workloadMacroVariable=&workloadMacroVariable, 
                  log=&log, output=&output, cmacvar=&cmacvar, gridRC=&gridRC, 
                  additionalSignonOptions=&additionalSignonOptions,signonRetries=&signonRetries); 
            %else %let &cmacvar=0; 
         
            data &statusTable; 
               retain ptr &row; 
               modify &statusTable point = ptr; 
               &handleVariable = "&remoteSessionId"; 
               %if (&signon eq 1) %then 
                  &machineVariable = "&etls_machineId";; 
               %if (&&&cmacvar ne 0) %then 
               %do; 
                  &statusVariable = "Failed Signon"; 
               %end; 
               %else 
                  &statusVariable = &statusSetting;; 
               %if (&startTimeVariable ne ) %then 
                  &startTimeVariable = datetime();; 
               replace; 
               stop; 
            run; 
         
            %rcSet(&syserr); 
         %mend etls_createHandle; 
         
         %macro etls_waitfor(statusTable=, statusVariable=, runningStatusSetting="Running", handleVariable=, 
            completeStatusSetting="Finished", endTimeVariable=endTime, 
            startTimeVariable=startTime, waitType=_ANY_, signoff=1, 
            returnCodeVariable=, returnCodeMacroVariable=, statusUnknownReturnCode=.); 
         
            proc sql noprint; 
               select count(*) into :etls_rows 
                  from &statusTable where &statusVariable = &runningStatusSetting; 
               %let etls_rows = &etls_rows; 
               %if (&etls_rows gt 0) %then 
               %do; 
                  select &handleVariable into :etlsHandles1 - :etlsHandles&etls_rows 
                     from &statusTable where &statusVariable = &runningStatusSetting; 
               %end; 
            quit; 
         
            %rcSet(&sqlrc); 
         
            %if (&etls_rows gt 0) %then 
            %do; 
               waitfor &waitType 
                  %do i=1 %to &etls_rows; 
                     &&etlsHandles&i 
                  %end; 
               ; 
            %end; 
         
            %local useDefaultRCMacVar; 
            %if ("&returnCodeMacroVariable" eq "") %then 
               %let useDefaultRCMacVar=Y; 
         
            %do i=1 %to &etls_rows; 
         
               %if ("&useDefaultRCMacVar"="Y") %then 
                  %let returnCodeMacroVariable=job_rc&&etlsHandles&i; 
         
               waitfor &&etlsHandles&i timeout=1; 
               %if (&SYSRC eq 0) or (&SYSRC eq -2) %then /* process complete  */ 
               %do; 
                  %etls_freeHandle(statusTable=&statusTable, statusVariable=&statusVariable,
                     handleVariable=&handleVariable, handleName="&&etlsHandles&i", 
                     statusSetting=&completeStatusSetting, endTimeVariable=&endTimeVariable, 
                     startTimeVariable=&startTimeVariable, signoff=&signoff, 
                     returnCodeVariable=&returnCodeVariable, returnCodeMacroVariable=&returnCodeMacroVariable, 
                     statusUnknownReturnCode=&statusUnknownReturnCode, 
                     startTimeMacroVariable=etls_startTime_&&etlsHandles&i., 
                     endTimeMacroVariable=etls_endTime_&&etlsHandles&i. ); 
                  %put NOTE: Process &&etlsHandles&i. has completed.;
               %end; 
               %else %if (&SYSRC ne -1) %then /* process status unknown  */ 
               %do; 
                  %etls_freeHandle(statusTable=&statusTable, statusVariable=&statusVariable,
                     handleVariable=&handleVariable, handleName="&&etlsHandles&i", 
                     statusSetting="Unknown Status", endTimeVariable=&endTimeVariable, 
                     startTimeVariable=&startTimeVariable, signoff=&signoff, 
                     returnCodeVariable=&returnCodeVariable, returnCodeMacroVariable=&returnCodeMacroVariable, 
                     statusUnknownReturnCode=&statusUnknownReturnCode, startTimeMacroVariable=etls_startTime_&&etlsHandles&i ); 
                  %put NOTE: Cannot retrieve status from process &&etlsHandles&i..;
               %end; 
            %end; 
         %mend etls_waitfor; 
         
         %macro etls_getProcessesRunning(statusTable=, statusVariable=, processCountMacro=, 
            statusSetting="Running"); 
         
            proc sql noprint; 
               select count(*) into: &processCountMacro 
                  from &statusTable where &statusVariable = &statusSetting; 
            quit; 
         
            %rcSet(&sqlrc); 
         %mend etls_getProcessesRunning; 
         
         %macro etls_getParameterNames(parameterTable=, parameterVariableMacro=, startingColumnNumber=1);
            %let &parameterVariableMacro = ;
            %let dsid = %sysfunc(open(&parameterTable));
            %if (&dsid gt 0) %then 
            %do; 
               %do i=&startingColumnNumber %to %sysfunc(attrn(&dsid,nvars)); 
                  %let &parameterVariableMacro = &&&parameterVariableMacro %sysfunc(varname(&dsid,&i)); 
               %end; 
               %let dsid = %sysfunc(close(&dsid)); 
            %end; 
            %else 
               %put %sysfunc(sysmsg()); 
            %rcSet(&syserr); 
         %mend etls_getParameterNames; 
         
         %macro etls_getParameters(parameterTable=, row=, startingColumnNumber=1 , handleName=); 
            data _null_; 
               length vname $256 vtype $1 value $3200; 
               dsid = open("&parameterTable"); 
               if (dsid > 0) then 
               do; 
                  do _i = 1 to &row; 
                     fetchrc = fetch(dsid); 
                  end; 
                  do _i=&startingColumnNumber to attrn(dsid,'nvars'); 
                     vname = varname(dsid,_i); 
                     vtype = vartype(dsid,_i); 
                     if (fetchrc = 0) then 
                     do; 
                        if (vtype = 'C') then 
                        do; 
                           value = getvarc(dsid,_i); 
                           value = tranwrd(value,"%","%%"); 
                           value = tranwrd(value,"(","%("); 
                           value = tranwrd(value,")","%)"); 
                           value = tranwrd(value,'"','%"'); 
                        end; 
                        else 
                           value = left(put(getvarn(dsid,_i),best32.)); 
                     end; /* fetchrc = 0 */ 
                     
                     put ;
                     if indexc(trimn(value),"+-*/<>=^~;, '()&%",'"')>0 then 
                     do; 
                        value='%str('||trim(value)||')'; 
                        put "NOTE: Special characters encountered; References may require: %nrbquote(%)UNQUOTE(&" vname+(-1)').';
                     end; 
                     %if %str(&handlename) ne %str() %then 
                     %do; 
                        value = '%syslput '||trim(vname)||'= '||trim(value)||" / remote = &handleName;"; 
                     %end; 
                     %else 
                     %do; 
                        value = '%let '||trim(vname)||'= '||trim(value)||';'; 
                     %end; 
                     
                     put "NOTE: Setting macro variable " vname "with statement:" value ;
                     call execute(value); 
                  end; /* do i= */ 
                  dsid = close(dsid); 
               end; /* dsid > 0 */ 
               else 
               do; 
                  put "ERROR" ": Parameter table, &parameterTable, could not be opened.";
                  abort; 
               end; 
               stop; 
            run; 
            
            %rcSet(&syserr); 
         %mend etls_getParameters; 
         
         %macro etls_loopW5N8JZPI; 
            %local etls_filePrefix; 
            %let etls_filePrefix = &etls_filePrefix.&handleName.-; 
            
            %macro etls_processToLoopW5N8JZPS(parameterTable=, row=, handleName=rmt);
               %etls_getParameters(parameterTable=&parameterTable, row=&row, 
                  startingColumnNumber=1, handleName=&handleName); 
               %let etls_previousFilePrefix = &etls_filePrefix;
               %local etls_filePrefix; 
               %let etls_filePrefix = &etls_previousFilePrefix.&handleName; 
               %syslput &etls_controlName = &row / remote = &handleName; 
               %syslput handleName = &handleName / remote = &handleName; 
               
               /* Setup to pass macros to remote session  */ 
               %syslput etls_filePrefix = &etls_filePrefix / remote = &handleName; 
               %syslput master_level_no = &master_level_no / remote = &handleName; 
               
               rsubmit &handleName wait = no sysrputsync = yes persist = no; 
               
                  %macro etls_jobW5N8JZQ2; 
                  
                     %sysrput etls_startTime_&handleName = %sysfunc(datetime()); 
                     
                     /****************************************************************************** 
                      * Job:           ControlStarSchemaJob                      A5V75JN3.BN000001 * 
                      * Description:                                                               * 
                      *                                                                            * 
                      * Repository:    Foundation                                A0000001.A5V75JN3 * 
                      * Server:        SASMain                                   A5V75JN3.AT000001 * 
                      *                                                                            * 
                      * Generated on:  Wednesday, December 10, 2008 2:42:19 PM IST                 * 
                      * Generated by:  sasadm                                                      * 
                      * Version:       9.1.20060626.51875                                          * 
                      ******************************************************************************/ 
                     
                     /* Setup to capture return codes  */ 
                     %global job_rc trans_rc sqlrc; 
                     %let job_rc = 0;
                     %let trans_rc = 0;
                     %let sqlrc = 0;
                     %global syserr; 
                     
                     %macro rcSet(error); 
                        %if (&error gt &trans_rc) %then 
                           %let trans_rc = &error;
                        %if (&error gt &job_rc) %then 
                           %let job_rc = &error;
                     %mend rcSet; 
                     
                     %macro rcSetDS(error); 
                        if &error gt input(symget('trans_rc'),12.) then 
                           call symput('trans_rc',trim(left(put(&error,12.))));
                        if &error gt input(symget('job_rc'),12.) then 
                           call symput('job_rc',trim(left(put(&error,12.))));
                     %mend rcSetDS; 
                     
                     %global etls_debug; 
                     %macro etls_setDebug; 
                        %if %str(&etls_debug) ne 0 %then 
                           OPTIONS MPRINT%str(;); 
                     %mend; 
                     %etls_setDebug; 
                     
                     /*============================================================================* 
                      * Pre-Process code for the job                             A5V75JN3.AY00040T * 
                      *                                                                            * 
                      * User Written:  Predecessor process                       A5V75JN3.AF000MJE * 
                      *============================================================================*/ 
                     
                     /*---- Start of User Written Code  ----*/ 
                     
                     data _null_;                            
                     var_jb=compress("&job_nm",'.sas');                            
                     logfile="Data/bisdata/log/schedule_star_schema/"||var_jb;                 
                     call symput('job_logname',trim(logfile));                                     
                     run;                                                                          
                     filename joblog "&job_logname..log";                                          
                     %put NOTE: Redirecting log to &job_logname..log;                              
                     proc printto log=joblog;                                                  
                     run;                                                                          
                     %put &job_logname;
                     
                     /*---- End of User Written Code  ----*/ 
                     
                     %rcSet(&syserr); 
                     %rcSet(&sqlrc); 
                     
                     /*============================================================================* 
                      * Step:          User Written Code                         A5V75JN3.BO0005MQ * 
                      * Transform:     User Written Code                                           * 
                      * Description:                                                               * 
                      *                                                                            * 
                      * Target Table:  User Written Code Target - work.W5AREK3F  A5V75JN3.BP0004RS * 
                      *                                                                            * 
                      * User Written:  CreateTable                               A5V75JN3.AF000MJ9 * 
                      *============================================================================*/ 
                     
                     %let trans_rc = 0; 
                     
                     %let _OUTPUT = %nrquote(work.W5AREK3F); 
                     
                     /*---- Start of User Written Code  ----*/ 
                     
                     
                     %put 'level_no=' &level_no;
                     %put 'master_level_no=' &master_level_no; 
                     
                     %if &level_no EQ &master_level_no  %then 
                     %do;
                     
                     /*%trylock(member=&status_table, timeout=100000);*/
                     /**/
                     /*proc sql;*/
                     /*select count(job_nm) into :job_count  */
                     /*from control.parameter_list_mod_abt*/
                     /*where  job_nm = "&job_nm" and level_no = &level_no and */
                     /*return_cd = .;*/
                     /*quit;*/
                     /**/
                     /*lock  &status_table clear;*/
                     /**/
                     /*%if &job_count = 1 %then*/
                     %include jobs (&job_nm) /LRECL= 1024;
                     %end;
                     
                     
                     /*---- End of User Written Code  ----*/ 
                     
                     %rcSet(&syserr); 
                     %rcSet(&sqlrc); 
                     
                     /*============================================================================* 
                      * Post-Process code for the job                            A5V75JN3.AY00040U * 
                      *                                                                            * 
                      * User Written:  Post process                              A5V75JN3.AF000MJF * 
                      *============================================================================*/ 
                     
                     /*---- Start of User Written Code  ----*/ 
                     
                     proc printto log=log;                                                     
                     run;
                     
                     /*---- End of User Written Code  ----*/ 
                     
                     %rcSet(&syserr); 
                     %rcSet(&sqlrc); 
                     
                     %sysrput job_rc&handleName = &job_rc; 
                     %sysrput etls_endTime_&handleName = %sysfunc(datetime()); 
                     
                  %mend etls_jobW5N8JZQ2; 
                  
                  %etls_jobW5N8JZQ2; 
                  
               endrsubmit;
               
            %mend etls_processToLoopW5N8JZPS;
            
            %local etls_controlTable etls_statusTable etls_controlName 
               etls_processesRunning etls_maxProcesses etls_parameterTable 
               etls_additionalSignonOptions etls_signonRetries;
            %let etls_controlName = L92_; 
            %let etls_statusTable = work.W5AR0VBB; 
            %let etls_parameterTable = work.W5N8JZPJ; 
            %let etls_workload = ;
            %let etls_additionalSignonOptions = ;%let etls_statusTable = work.loop_job_status;;
            %let etls_signonRetries = 3;
            %let &etls_controlName = 0;
            %let etls_controlTable = work.W5DWKJ4G;
            
            %put %str(NOTE: Creating status table...);
            data &etls_statusTable 
               (keep = etls_handleName etls_machineId etls_startTime etls_endTime 
                       etls_status etls_jobRC
               );
               attrib etls_handleName length = $32
                         label = 'Name of handle to remote session'; 
               attrib etls_machineId length = $32
                         label = 'Name of machine executing the task'; 
               attrib etls_startTime length = 8 format = DATETIME. informat = DATETIME.
                         label = 'Start time of task'; 
               attrib etls_endTime length = 8 format = DATETIME. informat = DATETIME.
                         label = 'End time of task'; 
               attrib etls_status length = $32
                         label = 'Current status of task'; 
               attrib etls_jobRC length = 8
                         label = 'Return code of task'; 
               set &etls_controlTable;
            run;
            
            %rcSet(&syserr); 
            
            %put %str(NOTE: Creating parameter table...);
            proc sql; 
               create table &etls_parameterTable as 
                  select LEVEL_NO as level_no, 
                         JOB_NM as job_nm, 
                         symget("master_level_no") as master_level_no, 
                         "&status_table" as status_table 
                  from &etls_controlTable; 
            quit; 
            
            %rcSet(&sqlrc); 
            
            /* Get the number of times to iterate from the number of rows in the source  */ 
            /*  table                                                                    */ 
            proc sql noprint; 
               select count(*) into :&etls_controlName._max from &etls_statusTable;
               %let &etls_controlName._max = &&&etls_controlName._max;
            quit;
            
            %rcSet(&sqlrc); 
            
            %let etls_maxProcesses = 5; 
            
            %if (&etls_maxProcesses > 0) %then 
            %do; 
               %do %until (&&&etls_controlName ge &&&etls_controlName._max); 
               
                  %let etls_lastLoopPtr = &&&etls_controlName;
                  
                  %etls_getProcessesRunning(statusTable=&etls_statusTable, statusVariable=etls_status, 
                     processCountMacro=etls_processesRunning, statusSetting="Running");
                     
                  %do %while(&etls_processesRunning lt &&&etls_controlName._max 
                     and &etls_processesRunning lt &etls_maxProcesses 
                     and &&&etls_controlName lt &&&etls_controlName._max);
                     
                     %let &etls_controlName = %eval(&&&etls_controlName+1);
                     
                     %global etls_signonStatus; 
                     
                     %etls_createHandle(statusTable=&etls_statusTable, statusVariable=etls_status, 
                        handleVariable=etls_handleName, handlePrefix=&etls_controlName, 
                        row=&&&etls_controlName, machineVariable=etls_machineId, 
                        startTimeVariable=etls_startTime, cmacvar=etls_signonStatus, signon=1, useGrid=1, 
                        additionalSignonOptions=&etls_additionalSignonOptions, signonRetries=&etls_signonRetries);
                        
                     %etls_getProcessesRunning(statusTable=&etls_statusTable, statusVariable=etls_status, 
                        processCountMacro=etls_processesRunning, statusSetting="Running");
                        
                     %if &etls_processesRunning > 0 and &etls_signonStatus ne 1 %then 
                        %etls_processToLoopW5N8JZPS(parameterTable=&etls_parameterTable, row=&&&etls_controlName,
                           handleName=%etls_getHandle(statusTable=&etls_statusTable,
                           handleVariable=etls_handleName, row=&&&etls_controlName)); 
                     %else 
                     %do; /* if signon error, set iterator to max to force loop to stop. */ 
                        %let &etls_controlName = &&&etls_controlName._max; 
                        %put %str(ERROR%QUOTE(:) A parallel process did not start.  Exiting loop.);
                     %end; 
                  %end; 
                  
                  %etls_waitFor(statusTable=&etls_statusTable, statusVariable=etls_status, 
                     runningStatusSetting="Running", handleVariable=etls_handleName, 
                     completeStatusSetting="Finished", endTimeVariable=etls_endTime, 
                     startTimeVariable=etls_startTime, waitType=_ANY_, signoff=1, 
                     returnCodeVariable=etls_jobRC, 
                     statusUnknownReturnCode=.); 
                     
               %end; 
               
               %etls_waitFor(statusTable=&etls_statusTable, statusVariable=etls_status, 
                  runningStatusSetting="Running", handleVariable=etls_handleName, 
                  completeStatusSetting="Finished", endTimeVariable=etls_endTime, 
                  startTimeVariable=etls_startTime, waitType=_ALL_, signoff=1, 
                  returnCodeVariable=etls_jobRC, 
                  statusUnknownReturnCode=.); 
                  
            %end;
            
            proc datasets lib = work nolist nowarn memtype = (data view);
               delete W5N8JZPJ;
            quit;
            
         %mend etls_loopW5N8JZPI; 
         
         %etls_loopW5N8JZPI; 
         
         /*============================================================================* 
          * Step:          Loop End                                  A5V75JN3.BR000349 * 
          * Transform:     Loop End                                                    * 
          * Description:                                                               * 
          *============================================================================*/ 
         
      %mend etls_jobW5N8JZQ1; 
      
      %etls_jobW5N8JZQ1; 
      
      %let handleName = %etls_getHandle(statusTable=&etls_statusTable,
         handleVariable=etls_handleName, row=&&&etls_controlName);
         
      %let job_rc&handleName. = &job_rc; 
      
      %etls_freeHandle(statusTable=&etls_statusTable, statusVariable=etls_status, 
         handleVariable=etls_handleName, handleName="&handleName", 
         startTimeVariable=etls_startTime, endTimeVariable=etls_endTime, signoff=0, 
         returnCodeVariable=etls_jobRC, returnCodeMacroVariable=job_rc&handleName., setMainJobRc=1); 
         
   %mend etls_processToLoopW5N8JZPR;
   
   %local etls_controlTable etls_statusTable etls_controlName 
      etls_processesRunning etls_maxProcesses etls_parameterTable 
      etls_additionalSignonOptions etls_signonRetries;
   %let etls_controlName = L46_; 
   %let etls_statusTable = work.W5AR0VBB; 
   %let etls_parameterTable = work.W5N8JZPT; 
   %let &etls_controlName = 0;
   %let etls_controlTable = work.W5D8EMYG;
   
   %put %str(NOTE: Creating status table...);
   data &etls_statusTable 
      (keep = etls_handleName etls_machineId etls_startTime etls_endTime 
              etls_status etls_jobRC
      );
      attrib etls_handleName length = $32
                label = 'Name of handle to remote session'; 
      attrib etls_machineId length = $32
                label = 'Name of machine executing the task'; 
      attrib etls_startTime length = 8 format = DATETIME. informat = DATETIME.
                label = 'Start time of task'; 
      attrib etls_endTime length = 8 format = DATETIME. informat = DATETIME.
                label = 'End time of task'; 
      attrib etls_status length = $32
                label = 'Current status of task'; 
      attrib etls_jobRC length = 8
                label = 'Return code of task'; 
      set &etls_controlTable;
   run;
   
   %rcSet(&syserr); 
   
   %put %str(NOTE: Creating parameter table...);
   proc sql; 
      create table &etls_parameterTable as 
         select master_level_no as master_level_no 
         from &etls_controlTable; 
   quit; 
   
   %rcSet(&sqlrc); 
   
   /* Get the number of times to iterate from the number of rows in the source  */ 
   /*  table                                                                    */ 
   proc sql noprint; 
      select count(*) into :&etls_controlName._max from &etls_statusTable;
      %let &etls_controlName._max = &&&etls_controlName._max;
   quit;
   
   %rcSet(&sqlrc); 
   
   %let etls_maxProcesses = 1; 
   
   %let etls_stopLoop = 0; 
   
   %if (&etls_maxProcesses > 0) %then 
   %do; 
      %do %until (&&&etls_controlName ge &&&etls_controlName._max
         or &etls_stopLoop ne 0); 
      
         %let etls_lastLoopPtr = &&&etls_controlName;
         
         %let etls_processesRunning = 0; 
         
         %do %while(&etls_processesRunning lt &&&etls_controlName._max 
            and &etls_processesRunning lt &etls_maxProcesses 
            and &&&etls_controlName lt &&&etls_controlName._max);
            
            %let &etls_controlName = %eval(&&&etls_controlName+1);
            
            %let job_rcLast=&job_rc; 
            
            %etls_createHandle(statusTable=&etls_statusTable, statusVariable=etls_status, 
               handleVariable=etls_handleName, handlePrefix=&etls_controlName, 
               row=&&&etls_controlName, machineVariable=etls_machineId, 
               startTimeVariable=etls_startTime, signon=0, useGrid=0);
               
            %let etls_processesRunning = 1; 
            %etls_processToLoopW5N8JZPR(parameterTable=&etls_parameterTable, row=&&&etls_controlName,
               handleName=%etls_getHandle(statusTable=&etls_statusTable,
               handleVariable=etls_handleName, row=&&&etls_controlName)); 
            
            /* Reset main Job_RC and Trans_RC to max return code of all iterations */ 
            %let job_rcThisIter=&job_rc; 
            %let job_rc=&job_rcLast; 
            %let trans_rc=&job_rcLast; 
            %rcSet(&job_rcThisIter); 
         %end; 
         
         %if (&job_rc ge 5) %then 
            %let etls_stopLoop = 1; 
            
      %end; 
      
   %end;
   
   proc datasets lib = work nolist nowarn memtype = (data view);
      delete W5N8JZPT;
   quit;
   
%mend etls_loopW5N8JZPH; 

%etls_loopW5N8JZPH; 

/*============================================================================* 
 * Step:          Loop End                                  A5V75JN3.BR00034B * 
 * Transform:     Loop End                                                    * 
 * Description:                                                               * 
 *============================================================================*/ 

/*============================================================================* 
 * Post-Process code for the job                            A5V75JN3.AY000411 * 
 *                                                                            * 
 * User Written:  Update the status                         A5V75JN3.AF000MJK * 
 *============================================================================*/ 

/*---- Start of User Written Code  ----*/ 

%macro upd_status;
%let max_end_dttm=;
%let month_existing=;
%let ld1=;
%let dp1=;

/* Get total count of records, and count of records for jobs which have run successfully */
proc sql;
select count(*) into :total_cnt from control.PARAMETER_LIST_STAR_SCHEMA;
select count(*) into :success_cnt from control.PARAMETER_LIST_STAR_SCHEMA where 
RETURN_CD between 0 and 4;
quit;

/* If all the jobs have run successfully then the following macro updates 
the run_status to Yes else to No */

proc sql;
      select max(LOAD_END_DTTM) format=NLDATM21. 
		into :max_end_dttm 
		from control.LOAD_CONTROL 
		where RUN_STATUS = &RUNNING_STATUS.;
quit;


/* If all the jobs have been executed successfully, update the LOAD_CONTROL table 
and STAR_SCHEMA_LOAD_DATES accordingly */

%if &total_cnt = &success_cnt and &total_cnt ne 0 %then %do;
	proc sql;

		insert into control.STAR_SCHEMA_LOAD_DATES (LOAD_DT, LOAD_STATUS)
		select load_end_dttm format=NLDATE10., &CHECK_FLAG_TRUE.
		from control.LOAD_CONTROL		
		where RUN_STATUS = &RUNNING_STATUS.
		and LOAD_FLG = &CHECK_FLAG_TRUE.; 

		update control.LOAD_CONTROL 
		set RUN_STATUS = &FINISHED_STATUS., 
		LOAD_FLG = &CHECK_FLAG_FALSE.
		where RUN_STATUS = &RUNNING_STATUS.
		and LOAD_FLG = &CHECK_FLAG_TRUE.; 
  
      select count(LOAD_START_DTTM)
		into :month_existing 
		from control.LOAD_CONTROL 
      where LOAD_START_DTTM = intnx('DTMONTH',"&max_end_dttm"dt,1,'BEGINNING');

	quit;

/* If LOAD_CONTROL table already has a row for the subsequent month after load period, 
this row will be updated. Else a new row will be inserted */

%if &month_existing eq 0 %then 
	%do;

		data _null_;
			ld=intnx('DTMONTH',"&max_end_dttm"dt,1,'BEGINNING');
			st_dt=intnx('DTMONTH',"&max_end_dttm"dt,1,'BEGINNING');
			end_dt=intnx('DTMONTH',"&max_end_dttm"dt,1,'END');
			d1=put(datepart(ld),monyy7.);
			call symput('ld_mth_yr_cd',d1);
			call symput('st_dt',st_dt);
			call symput('end_dt',end_dt);
		run;

		%if &ld_mth_yr_cd ne "" and &st_dt ne . and &end_dt ne . %then %do;

			proc sql;
			   insert into control.LOAD_CONTROL (LOAD_MTH_YR_CD, LOAD_START_DTTM,
			   LOAD_END_DTTM,  LOAD_FLG, RUN_STATUS)
	   		values ("&ld_mth_yr_cd",&st_dt,&end_dt,&CHECK_FLAG_TRUE.,&WAITING_STATUS.);
			quit;

		%end;

%end;

%else %if &month_existing gt 0 %then
%do;

		proc sql;
			update control.LOAD_CONTROL 
			set LOAD_FLG = &CHECK_FLAG_TRUE.,
		   RUN_STATUS = &WAITING_STATUS.
			where LOAD_START_DTTM = intnx('DTMONTH',"&max_end_dttm"dt,1,'BEGINNING');	   
		quit;

	%end;
%end;

/* If all the jobs have not been executed successfully, update the LOAD_CONTROL table 
and STAR_SCHEMA_LOAD_DATES accordingly */

%else %do;
	proc sql;
		update control.LOAD_CONTROL 
		set RUN_STATUS = &ERROR_STATUS. 
		where RUN_STATUS = &RUNNING_STATUS.;
	quit;
%end;
%mend;
%upd_status
/*---- End of User Written Code  ----*/ 

%rcSet(&syserr); 
%rcSet(&sqlrc); 

