/****************************************************************************** 
 * Job:           OC_EXT                                    A5V75JN3.BN00002O * 
 * Description:   This job picks up data from OUTBOUND_COMMUNICATION          * 
 *                                                                            * 
 * Repository:    Foundation                                A0000001.A5V75JN3 * 
 * Server:        SASMain                                   A5V75JN3.AT000001 * 
 *                                                                            * 
 * Source Tables: LOAD_CONTROL - control.LOAD_CONTROL       A5V75JN3.BE0000I0 * 
 *                OUTBOUND_COMMUNICATION -                  A5V75JN3.BE00005A * 
 *                 DDS.OUTBOUND_COMMUNICATION                                 * 
 * Target Table:  OC_EXT - martscr.OC_EXT                   A5V75JN3.BE0000KM * 
 *                                                                            * 
 * Generated on:  Wednesday, December 10, 2008 3:16:07 PM IST                 * 
 * Generated by:  sasadm                                                      * 
 * Version:       9.1.20060626.51875                                          * 
 ******************************************************************************
 * Notes:                                                                     * 
 * OC_EXT                                                                     * 
 * Job Name: OC_EXTJob Desc Pre Process: NoneMain: a) Extract and load data   * 
 * from OUTBOUND_COMMUNICATION using SQL join based on following              * 
 * conditions:LOAD_CONTROL.LOAD_FLG = CHECK_FLAG_TRUEand                      * 
 * LOAD_CONTROL.RUN_STATUS = RUNNING_STATUSand                                * 
 * OUTBOUND_COMMUNICATION.OB_COMMUNICATION_DT between                         * 
 * datepart(LOAD_CONTROL.LOAD_START_DTTM) and                                 * 
 * datepart(LOAD_CONTROL.LOAD_END_DTTM)Post Process: NoneParameters:          * 
 * CHECK_FLAG_TRUE and RUNNING_STATUS are the user defined parameters.        * 
 * CHECK_FLAG_TRUE is set to 'Y' and RUNNING_STATUS is to 'Running' for       * 
 *  each month of data load.Developed by: singupReviewed by:Tested by:        * 
 ******************************************************************************/ 

/* Setup for capturing job status  */ 
data _null_; 
   call symput('etls_startTime',put(datetime(),datetime.));
run;

%let etls_jobName = OC_EXT;
%let etls_recordsBefore = 0;
%let etls_recordsAfter = 0;
%let etls_lib = 0;
%let etls_table = 0;

/* Setup to capture return codes  */ 
%global job_rc trans_rc sqlrc; 
%let job_rc = 0;
%let trans_rc = 0;
%let sqlrc = 0;
%global syserr; 

%macro rcSet(error); 
   %if (&error gt &trans_rc) %then 
      %let trans_rc = &error;
   %if (&error gt &job_rc) %then 
      %let job_rc = &error;
%mend rcSet; 

%macro rcSetDS(error); 
   if &error gt input(symget('trans_rc'),12.) then 
      call symput('trans_rc',trim(left(put(&error,12.))));
   if &error gt input(symget('job_rc'),12.) then 
      call symput('job_rc',trim(left(put(&error,12.))));
%mend rcSetDS; 

%global etls_debug; 
%macro etls_setDebug; 
   %if %str(&etls_debug) ne 0 %then 
      OPTIONS MPRINT%str(;); 
%mend; 
%etls_setDebug; 

/*============================================================================* 
 * Pre-Process code for the job                             A5V75JN3.AY0004OU * 
 *                                                                            * 
 * User Written:  Oracle Date Problem Fix                   A5V75JN3.AF000PY7 * 
 *                Oracle Date Problem Fix                                     * 
 *============================================================================*/ 

/*---- Start of User Written Code  ----*/ 

proc contents data=DDS.OUTBOUND_COMMUNICATION out=_etlsEngine(keep=Engine) noprint;
run;

data _null_;
	set _etlsEngine;
	if _n_=1;
	  call symput('mEngine', kleft(kright(Engine)));
run;
/*---- End of User Written Code  ----*/ 

%rcSet(&syserr); 
%rcSet(&sqlrc); 

/*============================================================================* 
 * Step:          Extraction of data as per the loading     A5V75JN3.BO0006ZU * 
 *                 period                                                     * 
 * Transform:     SQL Join (Version 2)                                        * 
 * Description:   Extract and load data based on load period mentioned in     * 
 *                 LOAD_CONTROL table                                         * 
 *                                                                            * 
 * Source Tables: LOAD_CONTROL - control.LOAD_CONTROL       A5V75JN3.BE0000I0 * 
 *                OUTBOUND_COMMUNICATION -                  A5V75JN3.BE00005A * 
 *                 DDS.OUTBOUND_COMMUNICATION                                 * 
 * Target Table:  SQL Target - martscr.OC_EXT               A5V75JN3.BP000675 * 
 *============================================================================*/ 

/* Access the data for Control  */ 
LIBNAME control BASE "Data/bisdata/control" ;
%rcSet(&syslibrc); 

/* Access the data for Detail Data Store  */ 
LIBNAME DDS BASE "Data/bisdata/dds" ;
%rcSet(&syslibrc); 

/* Access the data for Scratch for Mart  */ 
LIBNAME martscr BASE "Data/bisdata/scratch/mart" ;
%rcSet(&syslibrc); 

%let trans_rc = 0; 

proc datasets lib = martscr nolist nowarn memtype = (data view);
   delete OC_EXT;
quit;

proc sql;
   create table martscr.OC_EXT as
      select
         OUTBOUND_COMMUNICATION.ACCOUNT_RK length = 8
                                           format = 12.
                                           informat = 12.
                                           label = "Account Key",
         LOAD_CONTROL.LOAD_END_DTTM length = 8
                                    format = NLDATM21.
                                    informat = NLDATM21.
                                    label = "Load End Datetime",
         OUTBOUND_COMMUNICATION.OB_COMMUNICATION_ID length = 32
                                                    label = "Outbound Communication ID",
         OUTBOUND_COMMUNICATION.SOURCE_SYSTEM_CD length = 3
                                                 label = "Source System Code",
         OUTBOUND_COMMUNICATION.OUTBOUND_COMM_TYPE_CD length = 3
                                                      label = "Outbound Communication Type Code",
         OUTBOUND_COMMUNICATION.DEFAULT_EVENT_RK length = 8
                                                 format = 12.
                                                 informat = 12.
                                                 label = "Default Event Retained Key",
         OUTBOUND_COMMUNICATION.CHANNEL_CD length = 3
                                           label = "Channel Code"
      from
         control.LOAD_CONTROL, 
         DDS.OUTBOUND_COMMUNICATION
      where
         LOAD_CONTROL.LOAD_FLG IN (&CHECK_FLAG_TRUE)
         and LOAD_CONTROL.RUN_STATUS IN (&RUNNING_STATUS)
         and CASE symget('mEngine')  
                 WHEN "ORACLE" THEN datepart(OUTBOUND_COMMUNICATION.OB_COMMUNICATION_DT)
                 ELSE OUTBOUND_COMMUNICATION.OB_COMMUNICATION_DT
         END >= datepart(LOAD_CONTROL.LOAD_START_DTTM)
         and CASE symget('mEngine')  
                 WHEN "ORACLE" THEN datepart(OUTBOUND_COMMUNICATION.OB_COMMUNICATION_DT)
                 ELSE OUTBOUND_COMMUNICATION.OB_COMMUNICATION_DT
         END <= datepart(LOAD_CONTROL.LOAD_END_DTTM)
      ;
quit;

%rcSet(&sqlrc); 

%macro etls_completeTarget();
%mend etls_completeTarget;
%etls_completeTarget;

/*============================================================================* 
 * Step:          Dummy Loader                              A5V75JN3.BO0006ZT * 
 * Transform:     Table Loader                                                * 
 * Description:                                                               * 
 *                                                                            * 
 * Source Table:  SQL Target - martscr.OC_EXT               A5V75JN3.BP000675 * 
 * Target Table:  OC_EXT - martscr.OC_EXT                   A5V75JN3.BE0000KM * 
 *============================================================================*
 *                                                                            * 
 * Nothing will be generated for this process because the "Do not generate    * 
 *  code for this process" option is selected.                                * 
 *                                                                            * 
 *============================================================================*/ 

data _null_; 
   call symput('etls_endTime',put(datetime(),datetime.));
run;

/* Check return code for job  */ 
%macro etls_jobRCChk; 
   %if (&job_rc eq 4) %then
   %do; 
      %on_success(Job_nm=&etls_jobName..sas, param_table=&status_table);
   %end; 
%mend etls_jobRCChk; 
%etls_jobRCChk; 

/* Check return code for job  */ 
%macro etls_jobRCChk; 
   %if (&job_rc ge 5) %then
   %do; 
      %on_success(Job_nm=&etls_jobName..sas, param_table=&status_table);
   %end; 
%mend etls_jobRCChk; 
%etls_jobRCChk; 

/* Check return code for job  */ 
%macro etls_jobRCChk; 
   %if (&job_rc eq 0) %then
   %do; 
      %on_success(Job_nm=&etls_jobName..sas, param_table=&status_table);
   %end; 
%mend etls_jobRCChk; 
%etls_jobRCChk; 

/*---- Job status macro  ----*/ 
