/****************************************************************************** 
 * Job:           REC_EXT                                   A5V75JN3.BN00002S * 
 * Description:   This job picks up data from EXPOSURE_RECOVERY.              * 
 *                                                                            * 
 * Repository:    Foundation                                A0000001.A5V75JN3 * 
 * Server:        SASMain                                   A5V75JN3.AT000001 * 
 *                                                                            * 
 * Source Tables: LOAD_CONTROL - control.LOAD_CONTROL       A5V75JN3.BE0000I0 * 
 *                EXPOSURE_RECOVERY - DDS.EXPOSURE_RECOVERY A5V75JN3.BE00002E * 
 * Target Table:  REC_EXT - martscr.REC_EXT                 A5V75JN3.BE0000KQ * 
 *                                                                            * 
 * Generated on:  Friday, December 12, 2008 11:54:06 AM GMT+05:30             * 
 * Generated by:  sasadm                                                      * 
 * Version:       9.1.20060626.51875                                          * 
 ******************************************************************************
 * Notes:                                                                     * 
 * REC_EXT                                                                    * 
 * Job Name: REC_EXTJob Desc Pre Process: NoneMain:Extract and load data      * 
 * from EXPOSURE_RECOVERY using a SQL join with table LOAD_CONTROL based on   * 
 * conditionLOAD_CONTROL.LOAD_FLG = CHECK_FLAG_TRUE                           * 
 * andLOAD_CONTROL.RUN_STATUS = RUNNING_STATUS                                * 
 * andLOAD_CONTROL.LOAD_END_DTTM betweenVALID_FROM_DTTM and VALID_TO_DTTM     * 
 * andRECOVERY_DT betweendatepart(VALID_FROM_DTTM) and                        * 
 * datepart(VALID_TO_DTTM)Post Process: Index is created                      * 
 * on(REC_EXT.DEFAULT_EVENT_RK,REC_EXT.LOAD_END_DTTM)Parameters:              * 
 * CHECK_FLAG_TRUE and RUNNING_STATUS are the user defined parameters.        * 
 * CHECK_FLAG_TRUE is set to 'Y' and RUNNING_STATUS is to 'Running' for       * 
 *  each month of data load.Developed by: sinahkReviewed by:Tested by:        * 
 ******************************************************************************/ 



%let jobID = %quote(A5V75JN3.BN00002S);

/* Setup for capturing job status  */ 
data _null_; 
   call symput('etls_startTime',put(datetime(),datetime.));
run;

%let etls_jobName = REC_EXT;
%let etls_recordsBefore = 0;
%let etls_recordsAfter = 0;
%let etls_lib = 0;
%let etls_table = 0;

/* Setup to capture return codes  */ 
%global job_rc trans_rc sqlrc; 
%let job_rc = 0;
%let trans_rc = 0;
%let sqlrc = 0;
%global syserr; 

%macro rcSet(error); 
   %if (&error gt &trans_rc) %then 
      %let trans_rc = &error;
   %if (&error gt &job_rc) %then 
      %let job_rc = &error;
%mend rcSet; 

%macro rcSetDS(error); 
   if &error gt input(symget('trans_rc'),12.) then 
      call symput('trans_rc',trim(left(put(&error,12.))));
   if &error gt input(symget('job_rc'),12.) then 
      call symput('job_rc',trim(left(put(&error,12.))));
%mend rcSetDS; 

%global etls_debug; 
%macro etls_setDebug; 
   %if %str(&etls_debug) ne 0 %then 
      OPTIONS MPRINT%str(;); 
%mend; 
%etls_setDebug; 

/*============================================================================* 
 * Pre-Process code for the job                             A5V75JN3.AY0004OW * 
 *                                                                            * 
 * User Written:  Oracle Date Problem Fix                   A5V75JN3.AF000PYR * 
 *                Oracle Date Problem Fix                                     * 
 *============================================================================*/ 

/*---- Start of User Written Code  ----*/ 

proc contents data=dds.exposure_recovery out=_etlsEngine(keep=Engine) noprint;
run;

data _null_;
	set _etlsEngine;
	if _n_=1;
	  call symput('mEngine', kleft(kright(Engine)));
run;
/*---- End of User Written Code  ----*/ 

%rcSet(&syserr); 
%rcSet(&sqlrc); 

/*============================================================================* 
 * Step:          Extracting and Loading of data as per the A5V75JN3.BO0006ZW * 
 *                 load period                                                * 
 * Transform:     SQL Join (Version 2)                                        * 
 * Description:   Join with LOAD_CONTROL table and extract appropriate data   * 
 *                 based  onVALID_FROM_DTTM and VALID_TO_DTTM                 * 
 *                                                                            * 
 * Source Tables: LOAD_CONTROL - control.LOAD_CONTROL       A5V75JN3.BE0000I0 * 
 *                EXPOSURE_RECOVERY - DDS.EXPOSURE_RECOVERY A5V75JN3.BE00002E * 
 * Target Table:  SQL Extract - martscr.REC_EXT             A5V75JN3.BP000676 * 
 *============================================================================*/ 

/* Access the data for Control  */ 
LIBNAME control BASE "Data/bisdata/control" ;
%rcSet(&syslibrc); 

/* Access the data for Detail Data Store  */ 
LIBNAME DDS BASE "Data/bisdata/dds" ;
%rcSet(&syslibrc); 

/* Access the data for Scratch for Mart  */ 
LIBNAME martscr BASE "Data/bisdata/scratch/mart" ;
%rcSet(&syslibrc); 

%let transformID = %quote(A5V75JN3.BO0006ZW); 

%let trans_rc = 0; 

proc datasets lib = martscr nolist nowarn memtype = (data view);
   delete REC_EXT;
quit;

proc sql;
   create table martscr.REC_EXT as
      select
         LOAD_CONTROL.LOAD_END_DTTM length = 8
                                    format = NLDATM21.
                                    informat = NLDATM21.
                                    label = "Load End Datetime",
         EXPOSURE_RECOVERY.RECOVERY_RK length = 8
                                       format = 12.
                                       informat = 12.
                                       label = "Recovery Key",
         EXPOSURE_RECOVERY.VALUE_AT_RECOVERY_AMT length = 8
                                                 format = NLNUM18.5
                                                 informat = NLNUM18.5
                                                 label = "Value At Recovery Amount",
         EXPOSURE_RECOVERY.VALUE_REALIZED_AMT length = 8
                                              format = NLNUM18.5
                                              informat = NLNUM18.5
                                              label = "Value Realized Amount",
         EXPOSURE_RECOVERY.DEFAULT_EVENT_RK length = 8
                                            format = 12.
                                            informat = 12.
                                            label = "Default Event Retained Key",
         EXPOSURE_RECOVERY.RECOVERY_COST_AMT length = 8
                                             format = NLNUM18.5
                                             informat = NLNUM18.5
                                             label = "Recovery Cost Amount",
         EXPOSURE_RECOVERY.RECOVERY_FROM_TYPE_CD length = 3
                                                 label = "Recovery From Type Code"
      from
         control.LOAD_CONTROL, 
         DDS.EXPOSURE_RECOVERY
      where
         LOAD_CONTROL.LOAD_FLG IN (&CHECK_FLAG_TRUE)
         and LOAD_CONTROL.RUN_STATUS IN (&RUNNING_STATUS)
         and LOAD_CONTROL.LOAD_END_DTTM >= EXPOSURE_RECOVERY.VALID_FROM_DTTM
         and LOAD_CONTROL.LOAD_END_DTTM <= EXPOSURE_RECOVERY.VALID_TO_DTTM
         and CASE symget('mEngine')
         	WHEN "ORACLE" THEN datepart(EXPOSURE_RECOVERY.RECOVERY_DT)
         	ELSE EXPOSURE_RECOVERY.RECOVERY_DT
         END >= DATEPART(LOAD_CONTROL.LOAD_START_DTTM)
         and CASE symget('mEngine')
         	WHEN "ORACLE" THEN datepart(EXPOSURE_RECOVERY.RECOVERY_DT)
         	ELSE EXPOSURE_RECOVERY.RECOVERY_DT
         END <= DATEPART(LOAD_CONTROL.LOAD_END_DTTM )
      ;
quit;

%rcSet(&sqlrc); 

%macro etls_completeTarget();
%mend etls_completeTarget;
%etls_completeTarget;

/*============================================================================* 
 * Step:          Dummy Loader                              A5V75JN3.BO0006ZV * 
 * Transform:     Table Loader                                                * 
 * Description:                                                               * 
 *                                                                            * 
 * Source Table:  SQL Extract - martscr.REC_EXT             A5V75JN3.BP000676 * 
 * Target Table:  REC_EXT - martscr.REC_EXT                 A5V75JN3.BE0000KQ * 
 *============================================================================*
 *                                                                            * 
 * Nothing will be generated for this process because the "Do not generate    * 
 *  code for this process" option is selected.                                * 
 *                                                                            * 
 *============================================================================*/ 

data _null_; 
   call symput('etls_endTime',put(datetime(),datetime.));
run;

/* Check return code for job  */ 
%macro etls_jobRCChk; 
   %if (&job_rc eq 4) %then
   %do; 
      %on_success(Job_nm=&etls_jobName..sas, param_table=&status_table);
   %end; 
%mend etls_jobRCChk; 
%etls_jobRCChk; 

/* Check return code for job  */ 
%macro etls_jobRCChk; 
   %if (&job_rc ge 5) %then
   %do; 
      %on_success(Job_nm=&etls_jobName..sas, param_table=&status_table);
   %end; 
%mend etls_jobRCChk; 
%etls_jobRCChk; 

/* Check return code for job  */ 
%macro etls_jobRCChk; 
   %if (&job_rc eq 0) %then
   %do; 
      %on_success(Job_nm=&etls_jobName..sas, param_table=&status_table);
   %end; 
%mend etls_jobRCChk; 
%etls_jobRCChk; 

/*---- Job status macro  ----*/ 
/*============================================================================* 
 * Post-Process code for the job                            A5V75JN3.AY0004OX * 
 *                                                                            * 
 * User Written:  Index creation on DEFAULT_EVENT_RK and    A5V75JN3.AF000PYS * 
 *                 LOAD_END_DTTM                                              * 
 *                Index creation on DEFAULT_EVENT_RK and LOAD_END_DTTM        * 
 *============================================================================*/ 

/*---- Start of User Written Code  ----*/ 

/*creating index on DEFAULT_EVENT_RK & LOAD_END_DTTM column */
PROC SQL NOPRINT;
     CREATE INDEX DEFAULT_EVENT_RK_LOAD_END_DTTM
      ON martscr.REC_EXT(DEFAULT_EVENT_RK,LOAD_END_DTTM);
QUIT;
/*---- End of User Written Code  ----*/ 

%rcSet(&syserr); 
%rcSet(&sqlrc); 

