/*********************************************************************************
 * Macro:         addLabelsToABT.sas                                             *
 * Description:   Updates extended attributes of metadata objects. Reads the     *
 *                attribute name-value pairs from a SAS table                    *
 *                                                                               *
 * Parameters:    libname   = library name of the target table                   *
 *                tablename = name of the target table (to update)               *
 *                analytic  = libname for the SAS CRS Analytic mart (storing the *
 *                            variable master)                                   *
 *                                                                               *
 * History:       19nov2007 Gabor Bona (SAS Hungary)                             *
 *                          Initial version                                      *
 *                                                                               *
 ********************************************************************************/

%macro addLabelsToABT(libname=, tablename=,analytic=analytic);
%let syscc=0;
%if &libname.= or &tablename.= or &analytic.= %then %do;
	%put ERROR: The parameters are not filled properly!;
	%let syscc=3000;
	%goto exit;
%end;
%if %sysfunc(exist(&libname..&tablename.)) < 1 %then %do;
	%put ERROR: the %upcase(&libname..&tablename.) table does not exist!;
	%let syscc=3000;
	%goto exit;
%end;
%if %sysfunc(exist(&analytic..var_master)) < 1 %then %do;
	%put ERROR: the %upcase(&analytic..var_master) table does not exist!;
	%let syscc=3000;
	%goto exit;
%end;
%else %do;
proc sql;
create table _var_sorted as 
select distinct VAR_NM, VAR_SHORT_NM from &analytic..var_master
order by VAR_NM;
create index VAR_NM on _var_sorted;
quit;

data _variables;
length VAR_NM $40 VAR_SHORT_NM $125;
dsid=open("&libname..&tablename.");
do i=1 to attrn(dsid,"nvars");
VAR_NM=left(upcase(varname(dsid,i)));
output;
end;
rc=close(dsid);
drop rc;
run;

data _null_;
set _variables end=last;
length errcnt 8;
if _n_=1 then call execute("proc datasets library=&libname. nowarn nolist;modify &tablename.;");
call missing(VAR_SHORT_NM);
set _var_sorted key=var_nm/unique;
if _iorc_ then do; _error_=0; errcnt+1;end;
if trimn(VAR_SHORT_NM) ne '' then call execute("label " || trim(VAR_NM) || '="' || trim(VAR_SHORT_NM) || '";');
else put 'NOTE: The ' VAR_NM 'was not found in the reference table.';
if last then do; call execute("run;quit;"); put "NOTE: Alltogether there were " errcnt "columns without any label.";end;
run;

proc sql noprint;
drop table _variables;
drop table _var_sorted;
quit;
%end;
%exit:
%if &syscc. >0 %then %do;
	%put ERROR: The process has been stopped.;
%end;
%mend;
