/*Start of CS4.3 HF2 */
/*Code to get the database engine used for dds */

proc contents data=dds.customer_model_score out=_etlsEngine(keep=Engine) noprint;
run;
data _null_;
	set _etlsEngine;
	if _n_=1;
	  call symput('mEngine',kleft(kright(Engine)));
run;
/*End of Code to get the database engine used for dds */
/*End of CS4.3 HF2 */

%global create_error_cd;
%let create_error_cd =0;
%macro chk_error(return_err);
	%if &return_err. > &create_error_cd. %then %do;
		%let create_error_cd = &return_err.;		
	%end;
%mend;
%macro write_back_dds(score_ds=, model_key=, error_cd=, model_type=, abt_level_no=, work_lib=);

	/* Handle missing values */
	%if %str(&score_ds) = %str() %then %do;
		%put ERROR: The dataset with the scores to write back to DDS has not been provided. Exiting.;
		%let error_cd=ERROR;
		%return;
	%end;

	%if %str(&model_key) = %str() %then %do;
		%put ERROR: The model key has not been provided. Exiting.;
		%let error_cd=ERROR;
		%return;
	%end;

	%if %str(&model_type) = %str() %then %do;
		%put ERROR: The model type has not been provided. Exiting.;
		%let error_cd=ERROR;
		%return;
	%end;

	%if %str(&work_lib) = %str() %then %do;
		%put WARNING: Temporary storage library not provided. Defaulting to work.;
		%let work_lib = work;
	%end;

	/* If ABT_LEVEL = Account, then write to DDS table CUSTOMER_ACCOUNT_SCORE
	else if ABT_LEVEL = Customer, then write to DDS table CUSTOMER_MODEL_SCORE. */
	data _null_;
		abt_level=put(&abt_level_no, ABTLVL.);
		call symput('abt_level',kupcase(abt_level));
	run;

	%chk_error(&syserr.); /*Call the macro to check for errors in the previous step */

	proc sql noprint;
		select model_rk into :model_k
		from dim.analytical_model_dim
		where model_sk=&model_key;
	quit;

	%chk_error(&sqlrc.); /*Call the macro to check for errors in the previous step */

	/* Get Outcome_type_cd from analytic.outcome_master */
	%let outcome_type=; 
	proc sql noprint;
		select outcome_type_cd into :outcome_type
		from analytic.abt_x_model, analytic.abt_x_outcome, analytic.outcome_master
		where abt_x_model.model_sk = &model_key and is_selected_flg = 'Y' and 
			abt_x_model.a_no = abt_x_outcome.a_no and 
			abt_x_outcome.o_no = outcome_master.o_no;
	quit;
	%let outcome_type=%sysfunc(kupcase(&outcome_type));

	%chk_error(&sqlrc.); /*Call the macro to check for errors in the previous step */

	/* Output of Models:
	PD Models: p_tgt_var1, score_points
	LGD, CCF Models: p_tgt_var
	CI Models: p_tgt_var1
	Segmentation Models: I__SEGMENT_ for profiling models
			_SEGMENT_ for behavior models

	Incase of any changes, please change code below.
	*/
	%let model_type=%nrquote(%'&model_type%');
	%if %str(%sysfunc(kupcase(&model_type))) eq %str(&SEG_MODEL) %then %do;
		proc sql noprint;
			select case when DEPLOYMENT_STATUS_CD=&PRD_MODEL_DEPLOYMENT then &STY_SEGMENT_TYPE
				else &TCT_SEGMENT_TYPE end into :segment_type
			from dim.analytical_model_dim
			where model_sk=&model_key;
		quit;

		%chk_error(&sqlrc.); /*Call the macro to check for errors in the previous step */

		data &work_lib..segment_prof(keep=CUSTOMER_RK I__SEGMENT_) 
				&work_lib..segment_beh(keep=CUSTOMER_RK _SEGMENT_);
			set &score_ds.(keep=CUSTOMER_RK I__SEGMENT_ _SEGMENT_);
		run;

		%chk_error(&syserr.); /*Call the macro to check for errors in the previous step */

		proc sql;
			create table &work_lib..segment_prof1 as
			select CUSTOMER_RK, SEGMENT_RK, dhms(today(), 0, 0, 0) as VALID_FROM_DTTM,
				&VALID_HIGH_DTTM as VALID_TO_DTTM, datetime() as PROCESSED_DTTM
			from &work_lib..segment_prof, dds.segment
			where segment.scheme_id = &PRO_SEG_SCHEME_ID and
				segment.segment_id = segment_prof.I__SEGMENT_ and
				segment.segment_type_cd = "&segment_type" and 
				calculated VALID_FROM_DTTM between segment.VALID_FROM_DTTM and 
					segment.VALID_TO_DTTM;

			create table &work_lib..segment_beh1 as
			select CUSTOMER_RK, SEGMENT_RK, dhms(today(), 0, 0, 0) as VALID_FROM_DTTM,
				&VALID_HIGH_DTTM as VALID_TO_DTTM, datetime() as PROCESSED_DTTM
			from &work_lib..segment_beh, dds.segment
			where segment.scheme_id = &BEH_SEGMENT_SCHEME and
				input(ktrim(kleft(segment.segment_id)), 8.) = segment_beh._SEGMENT_ and
				segment.segment_type_cd = "&segment_type" and 
				calculated VALID_FROM_DTTM between segment.VALID_FROM_DTTM and 
					segment.VALID_TO_DTTM;
		quit;

		%chk_error(&sqlrc.); /*Call the macro to check for errors in the previous step */

		/* Append to customer_x_segment */
		proc append data=&work_lib..segment_prof1 base=dds.customer_x_segment force;
		quit;

		%chk_error(&syserr.); /*Call the macro to check for errors in the previous step */

		proc append data=&work_lib..segment_beh1 base=dds.customer_x_segment force;
		quit;

		%chk_error(&syserr.); /*Call the macro to check for errors in the previous step */
	%end;
	%else %if %str(%upcase(&abt_level)) eq %str(APPLICATION) %then %do;
		%put ***************************APPLICATION LEVEL***************************;
		%if %str(%upcase(&model_type)) eq &PD_APP_MODEL %then %do;
			data &work_lib..temp(drop=p_tgt_var1 scorecard_points application_rk);
				set &score_ds.(keep=application_rk p_tgt_var1 scorecard_points);
				/*Start of CS4.3 HF2 */
				IF "&mEngine" = "ORACLE" THEN 
					SCORE_DT=intnx('dtmonth',datetime(), -1, 'end');
				ELSE 
					SCORE_DT=intnx('month',today(), -1, 'end');
				/*End of CS4.3 HF2 */
				MODEL_RK=&model_k;
				FINANCIAL_APPLICATION_RK=application_rk;
				APPLICATION_SCORE_NO=p_tgt_var1;
				SCORE_POINTS_NO=scorecard_points;
				ESTIMATED_RT=p_tgt_var1;
			run;

			%chk_error(&syserr.); /*Call the macro to check for errors in the previous step */

			/* Append to customer_account_score */
			proc append data=&work_lib..temp base=dds.application_score force;
			quit;
		%end;
	%end;
	%else %if %str(%upcase(&abt_level)) eq %str(ACCOUNT) %then %do;
		%put ***************************ACCOUNT LEVEL***************************;
		%if %str(%upcase(&model_type)) eq &PD_ONG_MODEL %then %do;
			data &work_lib..temp(drop=p_tgt_var1 scorecard_points);
				set &score_ds.(keep=account_rk p_tgt_var1 scorecard_points);
				/*Start of CS4.3 HF2 */
				IF "&mEngine" = "ORACLE" THEN 
					SCORE_DT=intnx('dtmonth',datetime(), -1, 'end');
				ELSE 
					SCORE_DT=intnx('month',today(), -1, 'end');
				/*End of CS4.3 HF2 */
				MODEL_RK=&model_k;
				CUSTOMER_ACCOUNT_SCORE_NO=p_tgt_var1;
				SCORE_POINTS_NO=scorecard_points;
				CR_MITIGANT_ADJUSTED_FLG='';
				PRINCIPAL_ONLY_FLG='';
				PROCESSED_DTTM=datetime();
				ESTIMATED_RT=p_tgt_var1;
				EFFECTIVE_FROM_DTTM=.;
				EFFECTIVE_TO_DTTM=.;
			run;

			%chk_error(&syserr.); /*Call the macro to check for errors in the previous step */

		%end;
		%else %if %str(&outcome_type) eq %str(LOGISTIC) %then %do;
			data &work_lib..temp(drop=p_tgt_var1);
				set &score_ds.(keep=account_rk p_tgt_var1);
				/*Start of CS4.3 HF2 */
				IF "&mEngine" = "ORACLE" THEN 
					SCORE_DT=intnx('dtmonth',datetime(), -1, 'end');
				ELSE 
					SCORE_DT=intnx('month',today(), -1, 'end');
				/*End of CS4.3 HF2 */
				MODEL_RK=&model_k;
				CUSTOMER_ACCOUNT_SCORE_NO=p_tgt_var1;
				SCORE_POINTS_NO=.;
				CR_MITIGANT_ADJUSTED_FLG='';
				PRINCIPAL_ONLY_FLG='';
				PROCESSED_DTTM=datetime();
				ESTIMATED_RT=p_tgt_var1;
				EFFECTIVE_FROM_DTTM=.;
				EFFECTIVE_TO_DTTM=.;
			run;

			%chk_error(&syserr.); /*Call the macro to check for errors in the previous step */

		%end;
		%else %do;
			data &work_lib..temp(drop=p_tgt_var);
				set &score_ds.(keep=account_rk p_tgt_var);
				/*Start of CS4.3 HF2 */
				IF "&mEngine" = "ORACLE" THEN 
					SCORE_DT=intnx('dtmonth',datetime(), -1, 'end');
				ELSE 
					SCORE_DT=intnx('month',today(), -1, 'end');
					/*End of CS4.3 HF2 */
				MODEL_RK=&model_k;
				CUSTOMER_ACCOUNT_SCORE_NO=p_tgt_var;
				SCORE_POINTS_NO=.;
				CR_MITIGANT_ADJUSTED_FLG='';
				PRINCIPAL_ONLY_FLG='';
				PROCESSED_DTTM=datetime();
				ESTIMATED_RT=p_tgt_var;
				EFFECTIVE_FROM_DTTM=.;
				EFFECTIVE_TO_DTTM=.;
			run;

			%chk_error(&syserr.); /*Call the macro to check for errors in the previous step */

		%end;

		/* Append to customer_account_score */
		proc append data=&work_lib..temp base=dds.customer_account_score force;
		quit;
	%end;
	%else %if %str(%sysfunc(kupcase(&abt_level))) eq %str(CUSTOMER) %then %do;
		%put ***************************CUSTOMER LEVEL***************************;
		/* It is assumed that CUSTOMER_MODEL_SCORE_ID in DDS.CUSTOMER_MODEL_SCORE is a number in the
		character field. Based on this assumption, the write back has been performed. If there is any change
		in this assumption the code in this section should be re-visited. */
		proc sql noprint;
			select max(input(CUSTOMER_MODEL_SCORE_ID, 8.)) into :key_cnt
			from dds.customer_model_score;
		quit;

		%chk_error(&sqlrc.); /*Call the macro to check for errors in the previous step */

		%if %str(%sysfunc(kupcase(&model_type))) eq &PD_APP_MODEL or %str(%sysfunc(kupcase(&model_type))) eq &PD_ONG_MODEL %then %do;
			data &work_lib..temp(drop=p_tgt_var1 scorecard_points temp);
				set &score_ds.(keep=customer_rk p_tgt_var1 scorecard_points);
				temp=&key_cnt+_N_;
				CUSTOMER_MODEL_SCORE_ID=put(temp, $32.);
				/*Start of CS4.3 HF2 */
				IF "&mEngine" = "ORACLE" THEN 
					SCORE_DT=intnx('dtmonth',datetime(), -1, 'end');
				ELSE 
					SCORE_DT=intnx('month',today(), -1, 'end');
				/*End of CS4.3 HF2 */
				MODEL_RK=&model_k;
				CUSTOMER_MODEL_SCORE_NO=p_tgt_var1;
				SCORE_POINTS_NO=scorecard_points;
				RANK_CD='';
				SEGMENT_RK=.;
				PROCESSED_DTTM=datetime();
				SCORE_TYPE_CD='';
			run;

			%chk_error(&syserr.); /*Call the macro to check for errors in the previous step */

		%end;
		%else %if %str(&outcome_type) eq %str(LOGISTIC) %then %do;
			data &work_lib..temp(drop=p_tgt_var1 temp);
				set &score_ds.(keep=customer_rk p_tgt_var1);
				temp=&key_cnt+_N_;
				CUSTOMER_MODEL_SCORE_ID=put(temp, $32.);
				/*Start of CS4.3 HF2 */
				IF "&mEngine" = "ORACLE" THEN 
					SCORE_DT=intnx('dtmonth',datetime(), -1, 'end');
				ELSE 
					SCORE_DT=intnx('month',today(), -1, 'end');
				/*End of CS4.3 HF2 */
				MODEL_RK=&model_k;
				CUSTOMER_MODEL_SCORE_NO=p_tgt_var1;
				SCORE_POINTS_NO=.;
				RANK_CD='';
				SEGMENT_RK=.;
				PROCESSED_DTTM=datetime();
				SCORE_TYPE_CD='';
			run;

			%chk_error(&syserr.); /*Call the macro to check for errors in the previous step */

		%end;
		%else %do;
			data &work_lib..temp(drop=p_tgt_var temp);
				set &score_ds.(keep=customer_rk p_tgt_var);
				temp=&key_cnt+_N_;
				CUSTOMER_MODEL_SCORE_ID=put(temp, $32.);
				/*Start of CS4.3 HF2 */
				IF "&mEngine" = "ORACLE" THEN 
					SCORE_DT=intnx('dtmonth',datetime(), -1, 'end');
				ELSE 
					SCORE_DT=intnx('month',today(), -1, 'end');
				/*End of CS4.3 HF2 */
				MODEL_RK=&model_k;
				CUSTOMER_MODEL_SCORE_NO=p_tgt_var;
				SCORE_POINTS_NO=.;
				RANK_CD='';
				SEGMENT_RK=.;
				PROCESSED_DTTM=datetime();
				SCORE_TYPE_CD='';
			run;

			%chk_error(&syserr.); /*Call the macro to check for errors in the previous step */

		%end;

		/* Append to customer_model_score */
		proc append data=&work_lib..temp base=dds.customer_model_score force;
		quit;
	%end;

	%if &create_error_cd. > 4 %then %do;		
		%let error_code=ERROR; 
	%end; 

%mend write_back_dds;
