/*
Macro Name	: Conf_Interval
Function	: calculate the confidence interval for AUC and AR
Created by	: BIS Team
Date		: Apr 07, 2006
SAS Version	: 9.1

			 
Calls		: compute_stderrauc

Parameters	: 

input_ds	: Name of the input data set
output_ds	: Name of the data set which stores Value of CI's.

Input Dataset(s) Format:
--------------------------------------------------------------------------
Name				Type		Format
--------------------------------------------------------------------------
Pool_Name						Character 	Default Formatting	
Pool_Seq	 					Number		Default Formatting
No_Of_ACC_Actual				Number		Default Formatting
No_of_Acc_Dev	 				Number 		Default Formatting
PD	 							Number		Default Formatting
Score_Points	 				Number		Default Formatting
No_Of_Actual_Bads				Number		Default Formatting	
value of the statistic as Area	Number		Default Formatting
Confidence interval as alpha	Number		Default Formatting
Name of the STAT				Character	Default Formatting
--------------------------------------------------------------------------

Output Dataset(s) Format:
-------------------------------------------------------------------------
Name		Type		Format
------------------------------------------------------------------------
Name of the stats		Numeric 	Default Formatting
Mid_point				Numeric 	Default Formatting
CI_Low  				Numeric 	Default Formatting
CI_High  				Numeric 	Default Formatting
------------------------------------------------------------------------
Logic:
1. Using the input data No.of goods and No.of bads are calcualted.
2. Using the relation U-sigma*cumulative standard normal(1+alpha/2)< AUC >U+sigma*cumulative standard normal(1+alpha/2)the CI limits of
   AUC are calculated.For calculating the CI limits of AR the relation AR = 2A-1 is used.	
Notes:
1. It is assumed that data set of specified as input_ds is present and has necessarry required rights.
2. It is assumed that data set of specified as input_ds has valid specified fileds.
3. For all output datasets (Viz output_ds),it is assumend that
	a. it has valid name.
	b. Macro has necessary required rights to create the datasets with specified name @ specified location.
	c. Name of the data-set is unique OR if dataset with similar name already exists then it can be safely overwritten.*/

%Let ASYM_DEF_LIMIT = 30; /*Asymptotic Std error is calculated if bad exposures are more than equal to this limit*/
%macro conf_interval(input_ds=,Area=,alpha =,output_CI_ds=,STAT=AUC);
 
%let err_code=;
/*******************************************************************************************/
%check_alldefaults_nodefaults(&input_ds, No_Of_ACC_Actual,No_Of_Actual_Bads, err_code);
 
%if (&err_code ne 'NONE')%then %goto Error_Handler;
/*******************************************************************************************/
proc sql noprint;
	select sum(No_of_actual_bads) into :NB from &input_ds;
	select (sum(No_Of_ACC_Actual)- &NB) into :NG from &input_ds;
quit;

%if %sysfunc(kUpCase("&Stat")) = "%sysfunc(sasmsg(smd_ds.bismsg,crs.measure_nm.measure_nm_ar.1, noquote))" %then  
	%Let A = %sysEvalf((&Area+1)/2.0);
%else
	%Let A = &Area;

%let Conf = %sysEvalf(1.0- &alpha/2.0);
%let Z_Alpha= %sysfunc(probit(&conf));

%if &NB >= &ASYM_DEF_LIMIT %then
%do;
	%let min_N = %sysfunc(min(&NB,&NG));
	%let Sigma_U = %sysEvalf(&A*(1.0 -&A));
	%let Sigma_U = %sysEvalf(&Sigma_U/&min_N);
	%let Sigma_U = %sysfunc(Sqrt(&Sigma_U));
%end;
%else 
%do;
/*Added for computation of exact standard error based on Mann Whitney U test*/
%let Sigma_U =0;
 %compute_stderrauc(&input_ds, &A,Sigma_U);
%end;

data &output_CI_ds;
/*Calculating the CI limits for AUC*/
	Name = "&Stat";
	Mid_Pt = &A;
	CI_low = &A- (&Sigma_U* &Z_Alpha);
	CI_high = &A + (&Sigma_U* &Z_Alpha);
	/*Calculating the CI limits for AR*/
	if UpCase("&Stat") = "%sysfunc(sasmsg(smd_ds.bismsg,crs.measure_nm.measure_nm_ar.1, noquote))" then  
	do;
		Mid_Pt = 2.0* Mid_Pt -1;
		CI_low = 2.0* CI_low -1;
		CI_high = 2.0* CI_high -1;
	end;
run;
%return;
/*****************************************************************/
%Error_Handler:
%put ERROR: &err_code;
%defdata(input_ds=&input_ds,stat="ConfAR",
		out_graph_ds = ,output_ds =&output_CI_ds ,out_stat_ds=);
%mend conf_interval;







 
