

/* Macro for Pool Stability Indicator

Logic

1. Compute 100(1-Alpha)% Confidence Interval for each Pool based on pooling scheme
	a. For PD based and Score_Points based pools compute CI for PD.
    b. For LGD based pools compute CI for LGD.
	c. For CCF based pools compute CI for CCF.
2. Treat computed CI's as new pooling scheme and determine Pool indicator for each data point .
3. Compute number of concordant pairs for each original pool
4. Compute concordance rate for each pool 
5. Compute avg. concordance rate for each pool which is nothing but pool stability indicator

Input :-

Input_ds :- 

Account Number
Score Points/PD/LGD/CCF

Input_pool_Ds:-

Pool Seq 
Estimated PD
Estimated LGD
Estimatef CCF
Number of Accounts 

Output_ds:

Pool_Stability Indicator


Calls:
PD_CI:   For Computing PD confidence Intervals
LGD_CI:  For Computing LGD confidence Intervals
CCF_CI:  For Computing CCF confidence Intervals

*/
/*%let SCORE_RANGE_TYPE = 'SCR';*/
/*%let SEGMENT_TYPE ='SEG';*/
/*%let PD_RANGE_TYPE = 'PD';*/
/*%let PD_LGD_RANGE_TYPE ='PDLGD';*/
/*%let PD_LGD_CCF_RANGE_TYPE ='PDLGDCCF';*/
/*%let  MAP_PD_MASTER_TYPE ='MAPPD';*/
/*%let EPSILON = 10e-6;*/
/*libname stab 'C:\pool_stability';*/
%macro pool_stability_index(input_ds=,input_pool_ds=,output_ds=,scheme_type_cd=);

/*data _NULL_;*/
/*	name=put(time(),mmss8.1);*/
/*	name1=kscan(name,1,":.");*/
/*	name2=kscan(name,2,":.");*/
/*	name3=kscan(name,3,":."); */
/*	name4=ktrim(kleft(name1))||ktrim(kleft(name2))||ktrim(kleft(name3));*/
/*	call symput('log_name',"&LOG_PATH"||"pool_stability_index_"||ktrim(kleft(name4))||".log");*/
/*run;*/
/*proc printto log="&log_name";*/
/*run;*/
%let EST = 0;
%let MSE = 0;
%let err_code=;
/*In few macro the exact location of change is not mentioned. Just file is known so 
  it is identified with the tag of hot fix as below*/
/*CS4.3 HF2 */
data New_pool_ds ;
set &input_pool_ds (keep = POOL_SEQ_NO);
run;
 

/*PD*/
%if &scheme_type_cd ne &SEGMENT_TYPE %then
%do;
	data temp;
		set &input_pool_ds (keep = Pool_Name NO_OF_ACCOUNTS ASSIGNED_PD POOL_SEQ_NO);
		No_Of_Actual_Bads = NO_OF_ACCOUNTS*ASSIGNED_PD;
		No_Of_ACC_Dev = NO_OF_ACCOUNTS;
		rename ASSIGNED_PD = PD;
		rename NO_OF_ACCOUNTS = No_Of_ACC_Actual;
		rename POOL_SEQ_NO = Pool_Seq;
	run;
	%pd_ci(input_ds=temp ,Alpha= &Alpha ,output_ds= out_pd_ci, ACT_FLAG= &EST);

	data out_pd_ci  (keep = POOL_SEQ_NO from_pd to_pd) ;
		set out_pd_ci;
		rename Pool_Seq =POOL_SEQ_NO; 
		rename LowerConf = from_pd UpperConf= to_pd; 
	run;
	data New_pool_ds;
	merge New_pool_ds out_pd_ci;
	by POOL_SEQ_NO;
	run;



/*****************************************************************/
%errorhandler(err_code);
%if (&err_code ne 'NONE')%then %goto Error_Handler;
/*****************************************************************/

%end;
/*LGD*/
%if (&scheme_type_cd = &PD_LGD_RANGE_TYPE) OR (&scheme_type_cd = &PD_LGD_CCF_RANGE_TYPE)  %then
%do;
	%MSE_Calculation(input_ds=&input_ds ,var_name= estimated_lgd, pool_indicator=POOL_SEQ_NO);
	data temp1;
	set &input_pool_ds (keep = NO_OF_ACCOUNTS assigned_lgd POOL_SEQ_NO);
	No_Of_ACC_Dev = NO_OF_ACCOUNTS;
	rename NO_OF_ACCOUNTS = No_Of_ACC_Actual;
	run;
	%lgd_ccf_ci(input_ds=temp1 ,MSE =&MSE,Alpha= &Alpha, output_ds= out_lgd_ci, Var= assigned_lgd,ACT_FLAG= &EST);
	data out_lgd_ci(keep = from_lgd to_lgd POOL_SEQ_NO);
	set out_lgd_ci;
	rename LowerConf = from_lgd UpperConf = to_lgd;
	run;
	data New_pool_ds;
	merge New_pool_ds out_lgd_ci;
	by POOL_SEQ_NO;
	run;
/*****************************************************************/
%errorhandler(err_code);
%if (&err_code ne 'NONE')%then %goto Error_Handler;
/*****************************************************************/
%end;
/*CCF*/
%if &scheme_type_cd = &PD_LGD_CCF_RANGE_TYPE %then
%do;
	%MSE_Calculation(input_ds=&input_ds ,var_name= estimated_ccf, pool_indicator=POOL_SEQ_NO);
	data temp1;
	set &input_pool_ds (keep = NO_OF_ACCOUNTS assigned_ccf POOL_SEQ_NO);
	No_Of_ACC_Dev = NO_OF_ACCOUNTS;
	rename NO_OF_ACCOUNTS = No_Of_ACC_Actual;
	run;
	%lgd_ccf_ci(input_ds=temp1 ,MSE =&MSE,Alpha= &Alpha, output_ds= out_ccf_ci, Var= assigned_ccf,ACT_FLAG= &EST);

	data out_ccf_ci(keep = from_ccf to_ccf POOL_SEQ_NO);
	set out_ccf_ci;
	rename LowerConf = from_ccf UpperConf = to_ccf;
	run;
	data New_pool_ds;
	merge New_pool_ds out_ccf_ci;
	by POOL_SEQ_NO;
	run;
/*****************************************************************/
%errorhandler(err_code);
%if (&err_code ne 'NONE')%then %goto Error_Handler;
/*****************************************************************/
%end;
data New_pool_ds;
set New_pool_ds;
rename POOL_SEQ_NO = NEW_POOL_SEQ_NO;
run;

%Pool_data(input_ds=&input_ds,input_pool_def=New_pool_ds,output_ds=CI_pool_ds, scheme_type_cd =&scheme_type_cd);
data CI_Pool_DS;
set CI_Pool_Ds (keep = account_rk POOL_SEQ_NO NEW_POOL_SEQ_NO);
run;
/*****************************************************************/
%errorhandler(err_code);
%if (&err_code ne 'NONE')%then %goto Error_Handler;
/*****************************************************************/
%Index_Calculation(input_ds=CI_pool_ds,Pool_ds = &input_pool_ds,output_ds=&output_ds);
%return;
/*****************************************************************/
%Error_Handler:
%put ERROR: &err_code;
Data &Output_ds;
pool_stability_index =0;
run;
/**/
/*proc printto;*/
/*run;*/
%mend pool_stability_index;

%macro Index_Calculation(input_ds=,pool_ds=,output_ds=);

/*data _NULL_;*/
/*	name=put(time(),mmss8.1);*/
/*	name1=kscan(name,1,":.");*/
/*	name2=kscan(name,2,":.");*/
/*	name3=kscan(name,3,":."); */
/*	name4=ktrim(kleft(name1))||ktrim(kleft(name2))||ktrim(kleft(name3));*/
/*	call symput('log_name',"&LOG_PATH"||"index_calc_"||ktrim(kleft(name4))||".log");*/
/*run;*/
/*proc printto log="&log_name";*/
/*run;*/
proc sql noprint;
	create table distinct_acct as
	select account_rk, count(POOL_SEQ_NO) as cnt, POOL_SEQ_NO
	from &input_ds
	group by account_rk, POOL_SEQ_NO;
quit;
proc sql noprint;
	create table index as
	select t1.account_rk, t1.POOL_SEQ_NO, t2.NEW_POOL_SEQ_NO
	from distinct_acct as t1, &input_ds as t2
	where t1.account_rk = t2.account_rk and t1.cnt = 1
	and t1.POOL_SEQ_NO = t2.NEW_POOL_SEQ_NO;
quit;
proc sql noprint;
create table index1 as 
select t1.POOL_SEQ_NO, count(account_rk) as count
from index as t1
group by POOL_SEQ_NO;
quit;
proc sql noprint;
create table index3 as
select t1.POOL_SEQ_NO, t1.count, t2.NO_OF_ACCOUNTS 
from index1 as t1, &pool_ds as t2
where t1.POOL_SEQ_NO = t2.POOL_SEQ_NO;
quit;

data index3;
set index3;
retain sum 0;
Ratio= count/NO_OF_ACCOUNTS;
sum = sum(sum,Ratio);
run;
proc sql noprint;
create table &output_ds as
select coalesce(max(sum)/Count(POOL_SEQ_NO),0) as pool_stability_index from index3;
quit;
/*proc printto;*/
/*run;*/
%mend Index_Calculation;

%macro MSE_Calculation(input_ds= ,var_name=, pool_indicator=);
/**/
/*data _NULL_;*/
/*	name=put(time(),mmss8.1);*/
/*	name1=kscan(name,1,":.");*/
/*	name2=kscan(name,2,":.");*/
/*	name3=kscan(name,3,":."); */
/*	name4=ktrim(kleft(name1))||ktrim(kleft(name2))||ktrim(kleft(name3));*/
/*	call symput('log_name',"&LOG_PATH"||"mse_calc_"||ktrim(kleft(name4))||".log");*/
/*run;*/
/*proc printto log="&log_name";*/
/*run;*/
data temp;
set &input_ds(keep = &var_name &pool_indicator);
run;
proc Anova data= Temp OutStat = Fit Noprint;
class &pool_indicator;
model &var_name = &pool_indicator;
quit;
data _null_;
set Fit;
if _TYPE_ = 'ERROR' then
do;
	a = SS/DF;
	call symput('MSE',a);
end;
run;
/**/
/*proc printto;*/
/*run;*/

%mend MSE_Calculation;

%macro Pool_data(input_ds=,input_pool_def=,output_ds=,scheme_type_cd=);
/*data _NULL_;*/
/*	name=put(time(),mmss8.1);*/
/*	name1=kscan(name,1,":.");*/
/*	name2=kscan(name,2,":.");*/
/*	name3=kscan(name,3,":."); */
/*	name4=ktrim(kleft(name1))||ktrim(kleft(name2))||ktrim(kleft(name3));*/
/*	call symput('log_name',"&LOG_PATH"||"pool_data_"||ktrim(kleft(name4))||".log");*/
/*run;*/
/*proc printto log="&log_name";*/
/*run;*/
data temp_pool;
set &input_pool_def;
run;
data longrun.temp_pool; 
set temp_pool;
run;


%if (&scheme_type_cd = &PD_RANGE_TYPE) or (&scheme_type_cd =&SCORE_RANGE_TYPE) or (&scheme_type_cd =&MAP_PD_MASTER_TYPE)   %then
%do;
	data temp_data ;
	set &input_ds (keep= account_rk POOL_SEQ_NO estimated_pd);
	run;

	data longrun.temp_data; 
	set temp_data;
	run;

	proc sql noprint;
		create table temp_out as 
		select *
		from temp_data, temp_pool
		where temp_data.estimated_pd >  temp_pool.from_pd and 
		temp_data.estimated_pd <=  temp_pool.to_pd;
	quit;
%end;
%if (&scheme_type_cd = &PD_LGD_RANGE_TYPE) %then
%do;
	data temp_data ;
	set &input_ds (keep= account_rk POOL_SEQ_NO estimated_pd estimated_lgd);
	run;
	proc sql noprint;
		create table temp_out as 
		select *
		from temp_data, temp_pool
		where temp_data.estimated_pd > temp_pool.from_pd and 
		temp_data.estimated_pd <= temp_pool.to_pd and 
		temp_data.estimated_lgd > temp_pool.from_lgd and 
		temp_data.estimated_lgd <= temp_pool.to_lgd;
	quit;
%end;
%if &scheme_type_cd = &PD_LGD_CCF_RANGE_TYPE %then
%do;
	data temp_data ;
	set &input_ds (keep= account_rk POOL_SEQ_NO estimated_pd estimated_lgd estimated_ccf);
	run;
	proc sql noprint;
		create table temp_out as 
		select *
		from temp_data, temp_pool
		where temp_data.estimated_pd > temp_pool.from_pd and 
		temp_data.estimated_pd <= temp_pool.to_pd and 
		temp_data.estimated_lgd > temp_pool.from_lgd and 
		temp_data.estimated_lgd <= temp_pool.to_lgd and
		temp_data.estimated_ccf > temp_pool.from_ccf and 
		temp_data.estimated_ccf <= temp_pool.to_ccf;
	quit;
%end;
data &output_ds;
set temp_out;
run;

/*proc printto;*/
/*run;*/
%mend Pool_data;
/*%let Alpha = 0.05;*/
/*%pool_stability_index(input_ds=stab.temp_avg,input_pool_ds=stab.Pool_def,output_ds=PSI,Alpha=&Alpha,scheme_type_cd='PD');*/

