/*
Macro Name	: ks
Function	: This macro calculates KS Stat.
Created by	: BIS Team
Date		: Nov 13, 2006
SAS Version	:  9.1

Called-by	:ks.sas
Calls		:check_alldefaults_nodefaults and defdata.
Parameters	: 

input			: Name of the input data set (Pool level FEED)
out_graph_ds	: Name of the data set which strores data calculations for KS.
 
Input Dataset(s) Format:
--------------------------------------------------------------------------
Name				Type		Format
--------------------------------------------------------------------------
Var_Name			Character 	Default Formatting	
Attr_Name	 		Character	Default Formatting
No_Of_ACC_Actual	Number		Default Formatting
No_of_Acc_Dev	 	Number 		Default Formatting
Scorecard_Points	Number		Default Formatting
No_of_events_actual	Number		Default Formatting	
--------------------------------------------------------------------------

Output Dataset(s) Format:
diststat
-------------------------------------------------------------------------
Name			Type		Format
------------------------------------------------------------------------
cum_prop_bads	Number		Default Formatting
cum_prop_goods	Number		Default Formatting
KS				Numeric		Default Format
------------------------------------------------------------------------

Logic:
1.Compute Proportion of bads, propotion of goods for a pool wrt total bads and total goods respectively
Notes:
1. It is assumed that data set of specified as input_ds is present and has necessarry required rights.
2. It is assumed that data set of specified as input_ds has valid specified fileds.
3. For all output datasets (Viz output_graph_ds,output_stat_ds),it is assumend that
	a. it has valid name.
	b. Macro has necessary required rights to create the datasets with specified name @ specified location.
	c. Name of the data-set is unique OR if dataset with similar name already exists then it can be safely overwritten.

*/
 
%macro ks(input_ds=, out_graph_ds=);
%let err_code=;
/*****************************************************************/
%check_alldefaults_nodefaults(&input_ds,No_Of_ACC_Actual,No_of_events_actual, err_code);
%if (&err_code ne 'NONE')%then %goto Error_Handler;
/*****************************************************************/
proc sql noprint ;
		create table KS as 
		select Scorecard_Points,
		/*CS4.3 HF2 */
		 No_of_events_dev/(No_of_acc_DEV - no_of_events_dev) as Prop_bads_DEV,
		No_of_events_actual/Sum(No_of_events_actual) as Prop_bads, 
		(No_Of_ACC_Actual - No_of_events_actual) /(Sum(No_Of_ACC_Actual)- Sum(No_of_events_actual))  
		as Prop_goods from &Input_ds order by SEQ_NO ;   
quit;
/*CS4.3 HF2 */
/*Sorting is done on proportion of bads in development sample.*/
proc sort data=ks;
 	by  prop_bads_dev;
run;

data &out_graph_ds; 
		retain	cum_prop_bads 0
				cum_prop_goods 0;
		set KS;
		cum_prop_bads = Sum(cum_prop_bads, prop_bads);
		cum_prop_goods = Sum(cum_prop_goods, prop_goods);
		KS = cum_prop_bads-cum_prop_goods;
		keep KS cum_prop_bads cum_prop_goods scorecard_points;
run;
%return;
/*****************************************************************/
%Error_Handler:
%put ERROR: &err_code;
%defdata(input_ds=&input_ds,stat='KS',
		out_graph_ds =&out_graph_ds,output_ds = ,out_stat_ds=);
%mend ks;


