/*----Hosmer Lemeshow test-----
Macro Name	: HL
Function	: Finds value of Hosmer Lemeshow statistic and it's p-value
Created by	: BIS Team
Date		: Apr 07, 2006
SAS Version	: 9.1

			 
Calls		: None

Parameters	: 

input_ds		: Name of the input data set
output_ds		: Name of the data set which stores data for graph of events vs non events.

Input Dataset(s) Format:
--------------------------------------------------------------------------
Name				Type		Format
--------------------------------------------------------------------------
Pool_Name			Character 	Default Formatting	
Pool_Seq	 		Number		Default Formatting
No_Of_ACC_Actual	Number		Default Formatting
No_of_Acc_Dev	 	Number 		Default Formatting
PD	 				Number		Default Formatting
Score_Points	 	Number		Default Formatting
No_Of_Actual_Bads	Number		Default Formatting	
--------------------------------------------------------------------------

Output Dataset(s) Format:
-------------------------------------------------------------------------
Name		Type		Format
------------------------------------------------------------------------
CHI_SQ		Numeric 	Default Formatting
P_Value 	Numeric 	Default Formatting
------------------------------------------------------------------------
Logic:
1. Using the input data default rate is calcualted.
2. Using PD Hosmer Lemeshow statistic is calculated .

Notes:
1. It is assumed that data set of specified as input_ds is present and has necessarry required rights.
2. It is assumed that data set of specified as input_ds has valid specified fileds.
3. For all output datasets (Viz output_ds),it is assumend that
	a. it has valid name.
	b. Macro has necessary required rights to create the datasets with specified name @ specified location.
	c. Name of the data-set is unique OR if dataset with similar name already exists then it can be safely overwritten.

*/
%macro hl_pd(input_ds=,output_ds=);
%let err_code=;
data temp;
set &input_ds;
var_exp_bads = PD*No_Of_ACC_Actual;/*CS4.3 HF2 */
run;
/*****************************************************************/
%check_alldefaults_nodefaults(temp,No_Of_ACC_Actual,var_exp_bads, err_code);
%if (&err_code ne 'NONE')%then %goto Error_Handler;
/*****************************************************************/

data Chisq;
	retain CHI_SQ 0;
	set &input_ds end = last;
	/* Hosmer Lemeshow statistic follows CHI_SQUARE distribtion with n degrees of freedom*/
	CHI_SQ = CHI_SQ+(No_Of_Actual_Bads-PD*No_Of_ACC_Actual)**2/((PD*No_Of_ACC_Actual)*(1-PD));
run;

proc sql noprint;
	select count(Score_Points) into:DF from chisq;
	create table chisq as
	select Max(CHI_SQ) as Chi_sq
	from chisq;
quit;

/*Calculating the P value of Chi square stats*/
data &output_ds;
	set chisq;
	%sysfunc(sasmsg(smd_ds.bismsg,crs.measure_nm.measure_nm_chi_sq_p.1, noquote))= 1 - CDF('CHISQUARE', Chi_sq, &DF); 
run;
/*****************************************************************/
%errorhandler(err_code);
%if (&err_code ne 'NONE')%then %goto Error_Handler;
/*****************************************************************/

%return;
%Error_Handler:
%put ERROR: &err_code;
%defdata(input_ds=&input_ds,stat='HL',
		out_graph_ds =,output_ds =&output_ds ,out_stat_ds=);
%mend hl_pd;
