/*
Macro Name	: Kend_Somers
Function	: Finds value of Kendall's Tau and somer's D and their respective p-values
Created by	: BIS Team
Date		: Apr 07, 2006
SAS Version	: 9.1

Called-by	:Called by Distance Statistics screen Stored proc : Check with Deepa.
			 
Calls		: None

Parameters	: 

input_ds		: Name of the input data set
output_ds		: Name of the data set which stores data for graph of events vs non events.

Input Dataset(s) Format:
--------------------------------------------------------------------------
Name				Type		Format
--------------------------------------------------------------------------
Pool_Name			Character 	Default Formatting	
Pool_Seq	 		Number		Default Formatting
No_Of_ACC_Actual	Number		Default Formatting
No_of_Acc_Dev	 	Number 		Default Formatting
PD	 				Number		Default Formatting
Score_Points	 	Number		Default Formatting
No_Of_Actual_Bads	Number		Default Formatting	
--------------------------------------------------------------------------

Output Dataset(s) Format:
-------------------------------------------------------------------------
Name		Type		Format
------------------------------------------------------------------------
_KENTB_		Numeric 	Default Formatting
_SMDCR_ 	Numeric 	Default Formatting
P2_KENTB  	Numeric 	Default Formatting
p2_SMDCR;	Numeric 	Default Formatting
------------------------------------------------------------------------
Logic:
1. Using the input data default rate is calcualted.
2. Using PD and Default Rate kendall's Tau and Saumer's D is calculated using SAS' Frequency procedure.

Notes:
1. It is assumed that data set of specified as input_ds is present and has necessarry required rights.
2. It is assumed that data set of specified as input_ds has valid specified fileds.
3. For all output datasets (Viz output_ds),it is assumend that
	a. it has valid name.
	b. Macro has necessary required rights to create the datasets with specified name @ specified location.
	c. Name of the data-set is unique OR if dataset with similar name already exists then it can be safely overwritten.

*/
%macro kend_somers(input_ds=,output_ds=);
%let err_code=;
/*****************************************************************/
%check_alldefaults_nodefaults(&input_ds,No_Of_ACC_Actual,No_Of_Actual_Bads, err_code);
%if (&err_code ne 'NONE')%then %goto Error_Handler;
/*****************************************************************/

data temp1;
set &input_ds;
actual_PD = (No_Of_Actual_Bads/No_of_ACC_Actual);
run;
proc freq data = temp1 noprint ;
tables  pd*actual_PD / measures  noprint ;
weight No_of_ACC_Actual;
output out= &output_ds SMDCR KENTB;
test KENTB SMDCR;
run;
/*****************************************************************/
%errorhandler(err_code);
%if (&err_code ne 'NONE')%then %goto Error_Handler;
/*****************************************************************/
data &output_ds;
keep _KENTB_ _SMDCR_  P2_KENTB  p2_SMDCR;
set &output_ds;
run;
/*CS4.3 HF2 */
data &output_ds;
rename 
_KENTB_=%sysfunc(sasmsg(smd_ds.bismsg,crs.measure_nm.measure_nm_kendal_tau_p_msr_val.1, noquote))
_SMDCR_=%sysfunc(sasmsg(smd_ds.bismsg,crs.measure_nm.measure_nm_somers_d_p_msr_val.1, noquote)) 
P2_KENTB=%sysfunc(sasmsg(smd_ds.bismsg,crs.measure_nm.measure_nm_kendal_tau_p_val.1, noquote))
p2_SMDCR=%sysfunc(sasmsg(smd_ds.bismsg,crs.measure_nm.measure_nm_somers_d_p_val.1, noquote))
;
set &output_ds;
run;
%return;
/*****************************************************************/
%Error_Handler:
%put ERROR: &err_code;
%defdata(input_ds=&input_ds,stat='KendSom',
		out_graph_ds =,output_ds = &output_ds ,out_stat_ds=);
%mend kend_somers;

