/*
Macro Name	: ks_stat
Function	: This File generates KS related reports. Confusion Matrix data set will be 
			  treated as input file to calculate all the statistic computed in this file

Created by	: BIS Team
Date		: Apr 07, 2006
SAS Version	: 9.1

Called-by	:Called by KS Chart screen Stored proc name : Check with Deepa
			 
Calls		: None

Parameters	: 

input_ds		: Name of the input data set
output_graph_ds	: Name of the data set which stores data for graph of ks.

Input Dataset(s) Format: Input data set is confusion matrix generated for each cut-off
-------------------------------------------------------------------------
Name	Type		Format
------------------------------------------------------------------------
score	Numeric 	Default Format			
FN		Numeric 	Default Format
TP		Numeric 	Default Format
TN		Numeric 	Default Format
FP		Numeric 	Default Format
PD		Numeric 	Default Format
------------------------------------------------------------------------

Output Dataset(s) Format:
output_graph_ds
-------------------------------------------------------------------------
Name		Type		Format
------------------------------------------------------------------------
score		Numeric		Default Formatting			 
Dist_good	Numeric		Default Formatting
Dist_bad	Numeric		Default Formatting
ks			Numeric		Default Formatting
------------------------------------------------------------------------
Logic:
1. Compute propotion of goods which are treated as bads in Dist_goods .
2. Compute proporion of bads which are treated as bads with Dist_bads 
3. Difference between Dist_Bad and Dist good is Ks 
4. Generated data of dist_goods and dist_bads is used to calculate KS-Chart.

Notes:
1. It is assumed that data set of specified as input_ds is present and has necessarry required rights.
2. It is assumed that data set of specified as input_ds has valid specified fileds.
3. For all output datasets (Viz output_ds),it is assumend that
	a. it has valid name.
	b. Macro has necessary required rights to create the datasets with specified name @ specified location.
	c. Name of the data-set is unique OR if dataset with similar name already exists then it can be safely overwritten.

*/

%macro ks_stat(input_ds=,output_graph_ds=);
%let err_code=;

data &input_ds;
	set &input_ds;
	var_tot_acc = TP+FP+TN+FN;
	var_no_bads = FN+TN;
run;
/***************************************************************/
%check_alldefaults_nodefaults(&input_ds,var_tot_acc,var_no_bads, err_code);
%if (&err_code ne 'NONE')%then %goto Error_Handler;
/***************************************************************/

data &output_graph_ds;
	set &input_ds;
    Dist_good   = 1.0 -(tp/(tp + fp));
    Dist_bad 	=tn/(tn + fn);
    %sysfunc(sasmsg(smd_ds.bismsg,crs.measure_nm.measure_nm_ks.1, noquote))= Dist_bad - Dist_good ;
	keep score Dist_good Dist_bad 
	%sysfunc(sasmsg(smd_ds.bismsg,crs.measure_nm.measure_nm_ks.1, noquote))
	; 
run;
%return;
%Error_Handler:
%put ERROR: &err_code;
%defdata(input_ds=&input_ds,stat='KS',
		out_graph_ds =&output_graph_ds,output_ds = ,out_stat_ds=);
%mend ks_stat;
