%macro load_ccf_model_measure_fact(model=,tgtprd=,time=,dev_flg=,product_type_cd=);

proc sql noprint;
	select 	MEASURE_SK, measure_cd into :measure_sk_list separated by "#"  
	, :measure_cd_lst  separated by "#" 
	from dim.Measure_dim
	where MODEL_TYPE_CD=&model_type. and PRODUCT_TYPE_CD="&product_type_cd."
	;
/*CS4.3 HF2 */
	/*Measure_sk of SSI is captured for a product and a  model so that the SSI should not get updated 
	  or missing in next month load. This macro is used in the updation of fact in the last
		section of this code.*/

	select 	MEASURE_SK into:measure_sk_ssi 
	from dim.Measure_dim
	where MODEL_TYPE_CD=&model_type. and PRODUCT_TYPE_CD="&product_type_cd."
	and 
	kupcase(measure_cd) =kupcase("%sysfunc(sasmsg(smd_ds.bismsg,crs.measure_nm.measure_nm_system_stability_index.1, noquote))")
	;
quit;

%let measure_sk_ssi=&measure_sk_ssi.;

%if &dev_flg eq %str(Y) %then %do;
	proc sql noprint;
		select CUT_OFF_SCORE into :cut_off 
		from martscr.analytical_model_dim_ext
		where model_sk=&model;

		create table work.out_mdl_act as
		SELECT POOL_SK, ACCOUNT_SK as account_sk, 
			case when actual_ccf > estimated_account_ccf then 1 else . end as ACTUAL_GOOD_BAD, 
			ACTUAL_CCF, ESTIMATED_ACCOUNT_CCF
		FROM fact.model_dev_fact
		where model_sk=&model
		order by 1;

		create table work.mdl_data as
		select POOL_SK, COUNT(ACCOUNT_SK) AS NO_OF_ACCOUNT_ACTUAL, 
			avg(ESTIMATED_ACCOUNT_CCF) as estimated_ccf, MAX(ACTUAL_CCF) as actual_ccf,
			SUM(ACTUAL_GOOD_BAD) as NO_OF_ACTUAL_BADS
		from work.out_mdl_act
		group by POOL_SK;
		
		create table work.mdl_data_seq as
		select mdl_data.*, pool_dim.pool_seq_no as pool_seq_no
		from work.mdl_data, dim.pool_dim
		where mdl_data.pool_sk = pool_dim.pool_sk;
	quit;

	/*Pool level feed */
	proc sql;
	create table work.out_mdl_ccf_pool AS
	select POOL_SK as pool_name, pool_seq_no as pool_seq,
		&epsilon as no_of_acc_dev, 
		coalesce(NO_OF_ACCOUNT_ACTUAL, &epsilon) as no_of_acc_actual, 
		ACTUAL_CCF as actual_ccf, estimated_ccf, 
		NO_OF_ACTUAL_BADS as no_of_actual_bads
	FROM work.mdl_data_seq
	order by 2;
	quit;

	/*Account level feed */
	proc sql;
	create table work.out_mdl_ccf_account AS
	SELECT ACCOUNT_SK, ACTUAL_CCF, ESTIMATED_ACCOUNT_CCF as estimated_ccf
	FROM work.out_mdl_act;
	quit;

	%let err_code=;
	%check_alldefaults_nodefaults(work.out_mdl_ccf_pool,No_Of_ACC_Actual,
		No_Of_Actual_Bads, err_code);

	%if (&err_code ne 'NONE')%then %do;
		%let cnt=1;
		%let measure_sk_list_insert=%qscan(&measure_sk_list,&cnt,#);
		%do %while(&measure_sk_list_insert ne %str());
		/* Start of CS4.3 HF2 */
		/*Model code which represents a code ofa statistics are resolved below.*/
				%let measure_cd_lst_rslv=%qscan(&measure_cd_lst,&cnt,#);
		/* End of CS4.3 HF2 */

			%if  &measure_cd_id_rslv.  ne   %sysfunc(sasmsg(smd_ds.bismsg,crs.measure_nm.measure_nm_system_stability_index.1, noquote))
					and &measure_cd_id_rslv.  ne   %sysfunc(sasmsg(smd_ds.bismsg,crs.measure_nm.measure_nm_confidence_interval.1, noquote))    
				%then %do;
				proc sql;
					insert into fact.MODEL_MEASURE_FACT
					(MODEL_SK, SCORE_TIME_SK, MEASURE_SK, MEASURE_VALUE, DEV_FLG) 
					values(&model, &time, &measure_sk_list_insert, ., 'Y')
					;
				quit;
			%end;
			%let cnt=%eval(&cnt+1);
			%let measure_sk_list_insert=%qscan(&measure_sk_list,&cnt,#);
		%end;		
	%end;
	%else %do;

		%ar_stat(input_ds=work.out_mdl_ccf_pool,output_graph_ds=work.graph_ar,output_stat_ds=work.ar);
		%errormeasures(input_ds=out_mdl_ccf_pool,input_ds_estvar=Estimated_CCF,input_ds_actvar=Actual_CCF,output_ds=work.mse_mad);
		%mape(input_ds=out_mdl_ccf_pool,input_ds_estvar=Estimated_CCF,input_ds_actvar=Actual_CCF,output_ds=work.mape);
		%chisq(input_ds=out_mdl_ccf_pool,input_ds_estvar=Estimated_CCF,input_ds_actvar=Actual_CCF,output_ds=work.chisq);
		%corr (input_ds=out_mdl_ccf_pool,input_ds_estvar= Estimated_CCF,input_ds_actvar=Actual_CCF,output_ds=work.corr);

		proc sql noprint;
			select %sysfunc(sasmsg(smd_ds.bismsg,crs.measure_nm.measure_nm_ar.1, noquote)) 
				into :%sysfunc(sasmsg(smd_ds.bismsg,crs.measure_nm.measure_nm_ar.1, noquote)) 
				from work.ar;
			select %sysfunc(sasmsg(smd_ds.bismsg,crs.measure_nm.measure_nm_mse.1, noquote)), 
					%sysfunc(sasmsg(smd_ds.bismsg,crs.measure_nm.measure_nm_mad.1, noquote)) 
				into :%sysfunc(sasmsg(smd_ds.bismsg,crs.measure_nm.measure_nm_mse.1, noquote)), 
					:%sysfunc(sasmsg(smd_ds.bismsg,crs.measure_nm.measure_nm_mad.1, noquote)) 
				from work.mse_mad;
			select %sysfunc(sasmsg(smd_ds.bismsg,crs.measure_nm.measure_nm_mean_absoute_percent_error.1, noquote)) 
				into :%sysfunc(sasmsg(smd_ds.bismsg,crs.measure_nm.measure_nm_mean_absoute_percent_error.1, noquote)) 
				from work.mape;
			select %sysfunc(sasmsg(smd_ds.bismsg,crs.measure_nm.measure_nm_chi_sq_p.1, noquote))
				into :%sysfunc(sasmsg(smd_ds.bismsg,crs.measure_nm.measure_nm_chi_sq_p.1, noquote)) 
				from work.chisq;
			select measure_value 
				into :%sysfunc(sasmsg(smd_ds.bismsg,crs.measure_nm.measure_nm_corr.1, noquote)) 
				from work.corr;
		quit;

		proc sql noprint;
			select count(*) into :cnt_recs
			from fact.MODEL_MEASURE_FACT
			where MODEL_SK=&model and  SCORE_TIME_SK = &time and DEV_FLG='Y';
		quit;

		%if &cnt_recs = 0 %then %do;
			%let cnt=1;
			%let measure_sk_list_insert=%qscan(&measure_sk_list,&cnt,#);
			%do %while(&measure_sk_list_insert ne %str());
				%let measure_cd_id_rslv=%qscan(&measure_cd_lst,&cnt,#);

				%if  &measure_cd_id_rslv.  ne   %sysfunc(sasmsg(smd_ds.bismsg,crs.measure_nm.measure_nm_system_stability_index.1, noquote))
						and &measure_cd_id_rslv.  ne   %sysfunc(sasmsg(smd_ds.bismsg,crs.measure_nm.measure_nm_confidence_interval.1, noquote))    
					%then %do;
					data _null_;
						length resolved_measure_id 8;
						if resolve("&&&measure_cd_id_rslv") = "" then
							resolved_measure_id=.;
						else
							resolved_measure_id=input(resolve("&&&measure_cd_id_rslv"),best32.);
						call symput('resolved_measure_id',resolved_measure_id);
					run;

					proc sql;
						insert into fact.MODEL_MEASURE_FACT 
						(MODEL_SK, SCORE_TIME_SK, MEASURE_SK, MEASURE_VALUE, DEV_FLG)
							values(&model, &time, &measure_sk_list_insert, &resolved_measure_id, 'Y')
						;
					quit;	
				%end;
				%let cnt=%eval(&cnt+1);
				%let measure_sk_list_insert=%qscan(&measure_sk_list,&cnt,#);
	 		%end;
		%end;
	%end;
%end;
%else %do;
	%let start_time = %eval(&time - &tgtprd);
	%let end_time = %eval(&time);
	
	%if &start_time > 0 %then %do;
		%do i = &start_time %to &end_time;

			%put start_time=start_time.;
			%put trg_prd=&tgtprd.;

			%let itime=%sysfunc(ktrim(%sysfunc(kleft(&i))));
			%let suff=_&model._&itime;
			%let suff=%sysfunc(ktrim(%sysfunc(kleft(&suff))));

			%if %sysfunc(exist(fact.ACCOUNT_CCF_FACT&suff.)) %then %do;
				%generate_feed(in_filter=, out_lib_nm=work, out_table_nm_pool=out_ccf_pool, 
					out_table_nm_acct=out_ccf_account, feed_for=&FEED_FOR_CCF, long_run=&LONG_RUN,
					pd_score=, range_interval=, no_of_quantile=, long_run_type=&LONG_RUN_TYPE, 
					model_time_key=&suff,product_type_code=&product_type_cd.);

				%let err_code=;
				%check_alldefaults_nodefaults(work.out_ccf_pool,No_Of_ACC_Actual,No_Of_Actual_Bads, err_code);

				 %if (&err_code ne 'NONE')%then %do;

					%if &i eq &time %then %do;
						%let cnt=1;
						%let measure_sk_list_insert=%qscan(&measure_sk_list,&cnt,#);
						%do %while(&measure_sk_list_insert ne %str());
						/* Start of CS4.3 HF2 */
						/*Stability Index is caculated irespective of all 
							default and no default condition.*/
							%let measure_cd_lst_rslv=%qscan(&measure_cd_lst,&cnt,#);
							%if  &measure_cd_lst_rslv.  eq   %sysfunc(sasmsg(smd_ds.bismsg,crs.measure_nm.measure_nm_system_stability_index.1, noquote))    
								%then %do;

									%ssi(input_ds=work.out_pd_pool,output_ds=work.ssi);

									proc sql;
										select sum(SIndex) into :ssi_val 
										from work.ssi;
									quit;

									proc sql noprint;
										insert into fact.MODEL_MEASURE_FACT
										(MODEL_SK, SCORE_TIME_SK, MEASURE_SK, MEASURE_VALUE, DEV_FLG) 
										values(&model, &i., &measure_sk_list_insert, &ssi_val., 'N')
										;
									quit;
								%end;
						/* End of CS4.3 HF2 */
							%if  &measure_cd_lst_rslv.  ne   %sysfunc(sasmsg(smd_ds.bismsg,crs.measure_nm.measure_nm_system_stability_index.1, noquote))    
								%then %do;
								proc sql;
									insert into fact.MODEL_MEASURE_FACT
									(MODEL_SK, SCORE_TIME_SK, MEASURE_SK, MEASURE_VALUE, DEV_FLG) 
									values(&model, &i., &measure_sk_list_insert, ., 'N')
									;
								quit;
							%end;
							%let cnt=%eval(&cnt+1);
							%let measure_sk_list_insert=%qscan(&measure_sk_list,&cnt,#);
						%end;
					%end;
				 %end;
				 %else %do;
					%ssi(input_ds=work.out_ccf_pool,output_ds=work.ssi);
					%ar_stat(input_ds=work.out_ccf_pool,output_graph_ds=work.graph_ar,output_stat_ds=work.ar);
					%errormeasures(input_ds=work.out_ccf_pool,input_ds_estvar=Estimated_CCF,input_ds_actvar=Actual_CCF,output_ds=work.mse_mad);
					%mape(input_ds=work.out_ccf_pool,input_ds_estvar=Estimated_CCF,input_ds_actvar=Actual_CCF,output_ds=work.mape);
					%chisq(input_ds=work.out_ccf_pool,input_ds_estvar=Estimated_CCF,input_ds_actvar=Actual_CCF,output_ds=work.chisq);
					%corr (input_ds=work.out_ccf_pool,input_ds_estvar= Estimated_CCF,input_ds_actvar=Actual_CCF,output_ds=work.corr);

					data martscr.corr;
						set work.corr;
					run;

					data martscr.chisq;
						set work.chisq;
					run;

					proc sql noprint;
						select sum(SIndex) 
							into :%sysfunc(sasmsg(smd_ds.bismsg,crs.measure_nm.measure_nm_system_stability_index.1, noquote)) 
							from work.ssi;
						select %sysfunc(sasmsg(smd_ds.bismsg,crs.measure_nm.measure_nm_ar.1, noquote)) 
							into :%sysfunc(sasmsg(smd_ds.bismsg,crs.measure_nm.measure_nm_ar.1, noquote)) 
							from work.ar;
						select %sysfunc(sasmsg(smd_ds.bismsg,crs.measure_nm.measure_nm_mse.1, noquote)), 
								%sysfunc(sasmsg(smd_ds.bismsg,crs.measure_nm.measure_nm_mad.1, noquote)) 
							into :%sysfunc(sasmsg(smd_ds.bismsg,crs.measure_nm.measure_nm_mse.1, noquote)), 
								:%sysfunc(sasmsg(smd_ds.bismsg,crs.measure_nm.measure_nm_mad.1, noquote)) 
							from work.mse_mad;
						select %sysfunc(sasmsg(smd_ds.bismsg,crs.measure_nm.measure_nm_mean_absoute_percent_error.1, noquote)) 
							into :%sysfunc(sasmsg(smd_ds.bismsg,crs.measure_nm.measure_nm_mean_absoute_percent_error.1, noquote))
							from work.mape;
						select %sysfunc(sasmsg(smd_ds.bismsg,crs.measure_nm.measure_nm_chi_sq_p.1, noquote))
							into :%sysfunc(sasmsg(smd_ds.bismsg,crs.measure_nm.measure_nm_chi_sq_p.1, noquote)) 
							from work.chisq;
						select measure_value 
							into :%sysfunc(sasmsg(smd_ds.bismsg,crs.measure_nm.measure_nm_corr.1, noquote)) 
							from work.corr;
					quit;

					proc sql noprint;
						select count(*) into :cnt_recs
						from fact.MODEL_MEASURE_FACT
						where MODEL_SK=&model and SCORE_TIME_SK = &i and DEV_FLG='N';
					quit;

					%if &cnt_recs = 0 %then %do;
						%let cnt=1;
						%let measure_sk_list_insert=%qscan(&measure_sk_list,&cnt,#);
						%do %while(&measure_sk_list_insert ne %str());
							%let measure_cd_id_rslv=%qscan(&measure_cd_lst,&cnt,#);

					        data _null_;
							  length resolved_measure_id 8;
							  if resolve("&&&measure_cd_id_rslv") = "" then
							     resolved_measure_id=.;
							  else
							     resolved_measure_id=input(resolve("&&&measure_cd_id_rslv"),best32.);
							 
							  call symput('resolved_measure_id',resolved_measure_id);
							run;

							%if  &measure_cd_id_rslv.  eq   %sysfunc(sasmsg(smd_ds.bismsg,crs.measure_nm.measure_nm_confidence_interval.1, noquote))    
								%then %do;

	 							proc sql;
								 insert into fact.MODEL_MEASURE_FACT 
								(MODEL_SK, SCORE_TIME_SK, MEASURE_SK, MEASURE_VALUE, DEV_FLG)
									values(&model, &i., &measure_sk_list_insert,1, 'N')
								;
							%end;
							%else %do;
								 proc sql;
								 insert into fact.MODEL_MEASURE_FACT 
								(MODEL_SK, SCORE_TIME_SK, MEASURE_SK, MEASURE_VALUE, DEV_FLG)
									values(&model, &i., &measure_sk_list_insert,&resolved_measure_id, 'N')
								;
							%end;							
							quit;
							%let cnt=%eval(&cnt+1);
							%let measure_sk_list_insert=%qscan(&measure_sk_list,&cnt,#);
						%end;
					%end;

					%else %do;
						/* Create temp table structure to be used later for update */
						data work.updfact;
						set fact.MODEL_MEASURE_FACT;
							stop;
						run;

						%let cnt=1;
						%let measure_sk_list_insert=%qscan(&measure_sk_list,&cnt,#);
						%do %while(&measure_sk_list_insert ne %str());
							%let measure_cd_id_rslv=%qscan(&measure_cd_lst,&cnt,#);

					        data _null_;
							  length resolved_measure_id 8;
							  if resolve("&&&measure_cd_id_rslv") = "" then
							     resolved_measure_id=.;
							  else
							     resolved_measure_id=input(resolve("&&&measure_cd_id_rslv"),best32.);
							 
							  call symput('resolved_measure_id',resolved_measure_id);
							run;

							%if  &measure_cd_id_rslv.  eq   %sysfunc(sasmsg(smd_ds.bismsg,crs.measure_nm.measure_nm_confidence_interval.1, noquote))    
								%then %do;

	 							proc sql;
								 insert into work.updfact 
								(MODEL_SK, SCORE_TIME_SK, MEASURE_SK, MEASURE_VALUE, DEV_FLG)
									values(&model, &i., &measure_sk_list_insert,1, 'N')
								;
								quit;
							%end;
							%else %do;
								 proc sql;
								 insert into work.updfact 
								(MODEL_SK, SCORE_TIME_SK, MEASURE_SK, MEASURE_VALUE, DEV_FLG)
									values(&model, &i., &measure_sk_list_insert,&resolved_measure_id, 'N')
								;
								quit;
							%end;							
							%let cnt=%eval(&cnt+1);
							%let measure_sk_list_insert=%qscan(&measure_sk_list,&cnt,#);
						%end;

						/* All records for the MEASURE_VALUE field in MODEL_MEASURE_FACT 
						are updated by going N months back from the scoring month,
						where N is the target period months count */

						/* The following UPDATE uses a correlated query */
							proc sql;
								update fact.MODEL_MEASURE_FACT m
								set MEASURE_VALUE = 
									(select MEASURE_VALUE from work.updfact where MEASURE_SK = m.MEASURE_SK)
								where SCORE_TIME_SK = &i and MODEL_SK = &model and DEV_FLG = 'N'
								  /*CS4.3 HF2 */
								  /* The SSI values should not be updated in next month load.*/
								  and MEASURE_SK ne &measure_sk_ssi. ;
							quit;
					%end;
				 %end;
			%end;
		%end;
	%end;
%end;
%mend load_ccf_model_measure_fact;
