
%macro load_model_measure_fact(model_type=,dev_flg=);

%if %sysfunc(exist(fact.MODEL_MEASURE_FACT)) eq 0 %then %do;
	proc sql;
		CREATE TABLE fact.MODEL_MEASURE_FACT (
		       MODEL_SK             NUMERIC(8) FORMAT=12. INFORMAT=12. LABEL='Surrogate key for the analytical model dimension.',
		       MEASURE_VALUE        NUMERIC(8),
		       DEV_FLG              CHARACTER(1) FORMAT=$1. INFORMAT=$1. LABEL='Flags',
		       MEASURE_SK           NUMERIC(8) FORMAT=12. INFORMAT=12. LABEL='_RKorSK',
		       SCORE_TIME_SK        NUMERIC(8) FORMAT=12. INFORMAT=12. LABEL='_RKorSK'
		);

		CREATE UNIQUE INDEX XPKMODEL_MEASURE_FACT ON fact.MODEL_MEASURE_FACT
		(
		       MODEL_SK,
		       MEASURE_SK,
		       SCORE_TIME_SK,
		       DEV_FLG
		);
	quit;
%end;

%let model = -2; /*Assuming there will not be a value of -2 in input table*/
%if &dev_flg eq %str(Y) %then %do;
	proc sql noprint;
		select MODEL_SK ,model_product_type_cd into :model separated by "#",:product separated by "#"
		from martscr.ANALYTICAL_MODEL_DIM_EXT, mdlmart.MODEL_INPUT
		where MODEL_TYPE_CD=&model_type and 
/*CS4.3 HF2 */
/*Development and production models are consider while caculating all the statistics.*/
				DEPLOYMENT_STATUS_CD in (&PRD_MODEL_DEPLOYMENT.,&DEV_MODEL_DEPLOYMENT.)
			AND	MODEL_INPUT.MODEL_NM = ANALYTICAL_MODEL_DIM_EXT.MODEL_NM
/*CS4.3 HF2 */
			AND kupcase(MODEL_INPUT.status) IN (%sysfunc(kupcase(&CS_MODEL_STATUS)))
			AND kupcase(MODEL_INPUT.ABT_TYPE) IN (%sysfunc(kupcase(&CS_ABT_TYPE_MDL)));
	quit;
/*CS4.3 HF2 */
/*This will be missing, as development data will nothave any target period.*/
	%let target_prd=.;

%end;
%else %do;
	proc sql noprint;
		select MODEL_SK, TARGET_PERIOD_MTHS_CNT ,model_product_type_cd
			into :model separated by "#",:tgtprd separated by "#",:product separated by "#"
		from martscr.ANALYTICAL_MODEL_DIM_EXT
		where MODEL_TYPE_CD=&model_type 
		/*CS4.3 HF2 */
		/*Development and production models are consider while caculating all the statistics.*/
		and DEPLOYMENT_STATUS_CD in (&PRD_MODEL_DEPLOYMENT.,&DEV_MODEL_DEPLOYMENT.);
	quit;
%end;

%put model=&model;
%put product=&product.;
%put dev_flg=&dev_flg;
%put PRD_MODEL_DEPLOYMENT=&PRD_MODEL_DEPLOYMENT;

%if &model NE -2 and &model NE . %then %do;
	proc sql noprint;
		select time_sk into :time 
		from martscr.TIME_DIM_EXT;
	quit;
	%let time=%sysfunc(ktrim(%sysfunc(kleft(&time))));
	%put time=&time;

	%let model_no=%str();
	%let cnt_index=1;
	%let product_type=%qscan(&product,&cnt_index,#);
	%let model_no=%qscan(&model,&cnt_index,#);
	%let target_prd=%qscan(&tgtprd,&cnt_index,#);
	%do %while(&model_no ne %str());
		%if &model_type=%str(&PD_ONG_MODEL) %then 
			%load_pd_model_measure_fact(model=&model_no,tgtprd=&target_prd,time=&time,dev_flg=&dev_flg,product_type_cd=&product_type.);
		%else %if &model_type=%str(&PD_APP_MODEL) %then
			%load_applpd_model_measure_fact(model=&model_no,tgtprd=&target_prd,time=&time,dev_flg=&dev_flg,product_type_cd=&product_type.);
		%else %if &model_type=%str(&LGD_MODEL) %then
			%load_lgd_model_measure_fact(model=&model_no,tgtprd=&target_prd,time=&time,dev_flg=&dev_flg,product_type_cd=&product_type.);
		%else %if &model_type=%str(&CCF_MODEL) %then
			%load_ccf_model_measure_fact(model=&model_no,tgtprd=&target_prd,time=&time,dev_flg=&dev_flg,product_type_cd=&product_type.);
		
		%let cnt_index=%eval(&cnt_index+1);
		%let model_no=%qscan(&model,&cnt_index,#);
		%let target_prd=%qscan(&tgtprd,&cnt_index,#);
		%let product_type=%qscan(&product,&cnt_index,#);
	%end;
%end;
%mend load_model_measure_fact;


