/**********************************************************************************************
       Module:  feed_pd_appl_pool
     Function:  This macro provides the view table for Application PD Model on pool level.

      Authors:  BIS Team
         Date:  05 April 2006
          SAS:  9.1
    Called-by:	All report screens. 

        Calls:  NA

Datasets used:  No input datasets required for processing of the macro.
 
 		Logic:  On selected model  and time this macro creates the 
				view for model and time.All columns of Application PD Fact 
				having name with model type and time (E.g. Appl_PD_FACT_301_1016,  
				Appl_PD_FACT_301_1014) are joined by all respective dimension.
				Log error message if it generate ,in error folder.
   Parameters: 
		INPUT: 
				in_filter 		 	:	where clause in this case it is 1.
				out_lib_nm			:	where the dataset will be created.
				out_table_nm_pool	:	The table name for pool level feed.
				out_table_nm_acct	:	The table name for account/application level feed
				model_time_key		:	This is the combination of  selected model and selected 
										time for that model E.G. 100_1025 , 103_1027).
				product_type_code	: 	This is the selected product type code (E.G. MTG, LON).
**********************************************************************************************/
%macro feed_pd_appl_pool(in_filter=, out_lib_nm=, out_table_nm_pool=, out_table_nm_acct=,
model_time_key=, product_type_code=);

%let model_key = %sysfunc(kscan(&model_time_key,1,'_'));
%let time_key = %sysfunc(kscan(&model_time_key,2,'_'));

/* To obtain the number of months to be considered for historic data */
%macro time_period;
	%let history = .;
	%let product_code = %quote(%'&product_type_code%'); 
	%if %sysfunc(kupcase(&product_code)) eq %sysfunc(kupcase(&MTG_PRD_TYPE.)) %then %do;
		%let history = &PDA_MTG_HIST;
	%end;
	%if %sysfunc(kupcase(&product_code)) eq %sysfunc(kupcase(&LON_PRD_TYPE.)) %then %do;
		%let history = &PDA_LON_HIST;
	%end;
	%if %sysfunc(kupcase(&product_code)) eq %sysfunc(kupcase(&COR_PRD_TYPE.)) %then %do;
		%let history = &PDA_COR_HIST;
	%end;
	%if %sysfunc(kupcase(&product_code)) eq %sysfunc(kupcase(&CCD_PRD_TYPE.)) %then %do;
		%let history = &PDA_CCD_HIST;
	%end;

	%let time_key_first = %sysfunc(sum(&time_key, - &history, 1));
	%do apnd = &time_key_first %to &time_key;
		%let tableExist = %sysfunc(exist(fact.APPL_PD_FACT_&model_key._&apnd, DATA));
		%if (&tableExist ne 0) %then %do; 
			proc append base=work.APPL_PD_FACT_HIST data=fact.APPL_PD_FACT_&model_key._&apnd force;
			run;
		%end;
	%end;
%mend time_period;
%time_period;

proc sql;
CREATE TABLE &out_lib_nm..&out_table_nm_pool._1m_sql AS
SELECT APPLICATION_DIM.APPLICATION_ID, APPLICATION_DIM.OUTCOME_CD,
    APPL_PD_FACT&model_time_key..PREDICTED_GOOD_BAD, 
	APPL_PD_FACT&model_time_key..ACTUAL_GOOD_BAD, 
	APPL_PD_FACT&model_time_key..ESTIMATED_APPL_PD, 
	APPL_PD_FACT&model_time_key..SCORE_POINTS,	
	ANALYTICAL_MODEL_DIM.MODEL_TYPE_CD, 
	ANALYTICAL_MODEL_DIM.DEPLOYMENT_STATUS_CD, ANALYTICAL_MODEL_DIM.MODEL_PRODUCT_TYPE_CD,
    APPLICANT_DIM.APPLICANT_ID, 
	FINANCIAL_PRODUCT_DIM.PRODUCT_ID, 
	FINANCIAL_PRODUCT_DIM.FINANCIAL_PRODUCT_TYPE_CD,
	TIME_DIM.CAL_MONTH_LAST_DT AS CAL_MON_LAST_DT, 
	APPL_PD_FACT&model_time_key..MODEL_SK, APPL_PD_FACT&model_time_key..SCORE_TIME_SK, 
	APPL_PD_FACT&model_time_key..APPLICATION_SK, APPL_PD_FACT&model_time_key..APPLICANT_SK, 
	APPL_PD_FACT&model_time_key..PRODUCT_SK, APPL_PD_FACT&model_time_key..POOL_SK 
FROM
	FACT.APPL_PD_FACT&model_time_key. 
	INNER JOIN DIM.POOL_DIM 
	ON (APPL_PD_FACT&model_time_key..POOL_SK = POOL_DIM.POOL_SK)  
	INNER JOIN DIM.ANALYTICAL_MODEL_DIM 
	ON (APPL_PD_FACT&model_time_key..MODEL_SK = ANALYTICAL_MODEL_DIM.MODEL_SK)  
	INNER JOIN DIM.APPLICATION_DIM 
	ON (APPL_PD_FACT&model_time_key..APPLICATION_SK = APPLICATION_DIM.APPLICATION_SK)  
	INNER JOIN DIM.FINANCIAL_PRODUCT_DIM 
	ON (APPL_PD_FACT&model_time_key..PRODUCT_SK = FINANCIAL_PRODUCT_DIM.PRODUCT_SK)  
	INNER JOIN DIM.APPLICANT_DIM 
	ON (APPL_PD_FACT&model_time_key..APPLICANT_SK = APPLICANT_DIM.APPLICANT_SK)  
	INNER JOIN DIM.TIME_DIM 
	ON (APPL_PD_FACT&model_time_key..SCORE_TIME_SK = TIME_DIM.TIME_SK)
 	INNER JOIN DIM.INTERNAL_ORG_DIM
	ON (APPL_PD_FACT&model_time_key..INTERNAL_ORG_SK = INTERNAL_ORG_DIM.INTERNAL_ORG_SK)
 &in_filter;
quit;

/* For historic data */
proc sql;
CREATE TABLE &out_lib_nm..&out_table_nm_pool._sql AS
SELECT APPLICATION_DIM.APPLICATION_ID, APPLICATION_DIM.OUTCOME_CD,
    APPL_PD_FACT&model_time_key..PREDICTED_GOOD_BAD, 
	APPL_PD_FACT&model_time_key..ACTUAL_GOOD_BAD, 
	APPL_PD_FACT&model_time_key..ESTIMATED_APPL_PD, 
	APPL_PD_FACT&model_time_key..SCORE_POINTS,	
	ANALYTICAL_MODEL_DIM.MODEL_TYPE_CD, 
	ANALYTICAL_MODEL_DIM.DEPLOYMENT_STATUS_CD, ANALYTICAL_MODEL_DIM.MODEL_PRODUCT_TYPE_CD,
    APPLICANT_DIM.APPLICANT_ID, 
	FINANCIAL_PRODUCT_DIM.PRODUCT_ID, 
	FINANCIAL_PRODUCT_DIM.FINANCIAL_PRODUCT_TYPE_CD,
	TIME_DIM.CAL_MONTH_LAST_DT AS CAL_MON_LAST_DT, 
	APPL_PD_FACT&model_time_key..MODEL_SK, APPL_PD_FACT&model_time_key..SCORE_TIME_SK, 
	APPL_PD_FACT&model_time_key..APPLICATION_SK, APPL_PD_FACT&model_time_key..APPLICANT_SK, 
	APPL_PD_FACT&model_time_key..PRODUCT_SK, APPL_PD_FACT&model_time_key..POOL_SK 
FROM
	work.appl_pd_fact_hist as APPL_PD_FACT&model_time_key.
	INNER JOIN DIM.POOL_DIM 
	ON (APPL_PD_FACT&model_time_key..POOL_SK = POOL_DIM.POOL_SK)  
	INNER JOIN DIM.ANALYTICAL_MODEL_DIM 
	ON (APPL_PD_FACT&model_time_key..MODEL_SK = ANALYTICAL_MODEL_DIM.MODEL_SK)  
	INNER JOIN DIM.APPLICATION_DIM 
	ON (APPL_PD_FACT&model_time_key..APPLICATION_SK = APPLICATION_DIM.APPLICATION_SK)  
	INNER JOIN DIM.FINANCIAL_PRODUCT_DIM 
	ON (APPL_PD_FACT&model_time_key..PRODUCT_SK = FINANCIAL_PRODUCT_DIM.PRODUCT_SK)  
	INNER JOIN DIM.APPLICANT_DIM 
	ON (APPL_PD_FACT&model_time_key..APPLICANT_SK = APPLICANT_DIM.APPLICANT_SK)  
	INNER JOIN DIM.TIME_DIM 
	ON (APPL_PD_FACT&model_time_key..SCORE_TIME_SK = TIME_DIM.TIME_SK)
 	INNER JOIN DIM.INTERNAL_ORG_DIM
	ON (APPL_PD_FACT&model_time_key..INTERNAL_ORG_SK = INTERNAL_ORG_DIM.INTERNAL_ORG_SK)
 &in_filter;
quit;

/*
Code to check for errors.
Possibly error will happen only if the filter condition is not properly passed. 
In this case, return to the calling program with error_code=ERROR
*/
%if &sqlrc = 8 %then
%do;
%let error_code = ERROR;
%RETURN;
%end;
/*End of code to check errors */

/*Get the no of account actual */
proc sql;
create table &out_lib_nm..&out_table_nm_pool._1m_act AS
SELECT SCORE_TIME_SK, POOL_SK,
COUNT(APPLICATION_ID) AS NO_OF_APPL_ACTUAL, 
SUM(ACTUAL_GOOD_BAD) AS NO_OF_ACTUAL_BADS,
SUM(case when OUTCOME_CD in (&outcome_accept) then 1 else 0 end) AS NO_OF_APPL_ACCEPTED,
MAX(SCORE_POINTS)AS MAX_SCORE_POINTS
FROM  &out_lib_nm..&out_table_nm_pool._1m_sql
GROUP BY SCORE_TIME_SK, POOL_SK;
quit;
/*End no. of account actual */

/*Get the no of account actual for historic data */
proc sql;
create table &out_lib_nm..&out_table_nm_pool._act AS
SELECT &time_key as SCORE_TIME_SK, POOL_SK,
COUNT(APPLICATION_ID) AS NO_OF_APPL_ACTUAL, 
SUM(ACTUAL_GOOD_BAD) AS NO_OF_ACTUAL_BADS,
SUM(case when OUTCOME_CD in (&outcome_accept) then 1 else 0 end) AS NO_OF_APPL_ACCEPTED,
MAX(SCORE_POINTS)AS MAX_SCORE_POINTS
FROM  &out_lib_nm..&out_table_nm_pool._sql
GROUP BY POOL_SK;
quit;
/*End no. of account actual for historic data */

/*Get the model_sk into a temporary table for further use */
proc sql;
create table &out_lib_nm..&out_table_nm_pool._dist
as select distinct MODEL_SK
from &out_lib_nm..&out_table_nm_pool._1m_sql;
quit;
/*End, of model_sk into a temporary table for further use */

/*For getting no of account development for a model*/
proc sql;
create table &out_lib_nm..&out_table_nm_pool._dev as
select POOL_SK, count(MODEL_DEV_APPL_FACT.APPLICATION_SK) as NO_OF_APPL_DEV,
SUM(case when OUTCOME_CD in (&outcome_accept) then 1 else 0 end) AS NO_OF_APPL_DEV_ACCEPTED 
FROM &out_lib_nm..&out_table_nm_pool._dist
INNER JOIN FACT.MODEL_DEV_APPL_FACT
ON (&out_table_nm_pool._dist.MODEL_SK = MODEL_DEV_APPL_FACT.MODEL_SK)
INNER JOIN DIM.APPLICATION_DIM
ON (APPLICATION_DIM.APPLICATION_SK = MODEL_DEV_APPL_FACT.APPLICATION_SK)
GROUP BY POOL_SK;
quit;
/*End, getting no of account development */

/*Get the pool level modeling information from model_x_pool table */
proc sql;
create table &out_lib_nm..&out_table_nm_pool._mdl as
select model_x_pool.POOL_SK as POOL_SK, model_x_pool.rate,
POOL_DIM.POOL_NAME, POOL_DIM.POOL_SEQ_NO AS POOL_SEQ_NO from
bridge.model_x_pool 
INNER JOIN &out_lib_nm..&out_table_nm_pool._dist
ON (model_x_pool.MODEL_SK = &out_table_nm_pool._dist.MODEL_SK)
INNER JOIN dim.POOL_DIM
ON (model_x_pool.POOL_SK = POOL_DIM.POOL_SK);
quit;
/*End, of pool level modeling information */

/*Get the distinct values of 
TIME_SK from _sql
POOL_NAME from _mdl 
Perform cartesian product for TIME_SK, POOL_NAME */

proc sql;
create view &out_lib_nm..&out_table_nm_pool._pool
as select distinct pool_sk from &out_lib_nm..&out_table_nm_pool._mdl;

create view &out_lib_nm..&out_table_nm_pool._time
as select distinct SCORE_TIME_SK as time_sk from &out_lib_nm..&out_table_nm_pool._1m_sql;

create table &out_lib_nm..&out_table_nm_pool._pt
as select time_sk, pool_sk from
&out_lib_nm..&out_table_nm_pool._time, &out_lib_nm..&out_table_nm_pool._pool;
quit;
/*End of cartesian product */

/*Start of pool level feed */
proc sql;
create view &out_lib_nm..&out_table_nm_pool._1m AS
 /*I18N-scnjih-20080418-1458*/
/*select TIME_SK label="Score Time", */
/*POOL_NAME as pool_name label="Pool Name", */
/*POOL_SEQ_NO as pool_seq label="Pool Sequence",*/
/*coalesce(NO_OF_APPL_DEV, &epsilon) as no_of_appl_dev label="No of Applications (Development)", */
/*NO_OF_APPL_DEV_ACCEPTED as no_of_acc_dev label="No of Applications Accepted (Development)", */
/*NO_OF_APPL_DEV - NO_OF_APPL_DEV_ACCEPTED as no_of_appl_dev_rejected label="No of Applications Rejected (Development)",*/
/*coalesce(NO_OF_APPL_ACTUAL, &epsilon) as no_of_appl_actual label="No of Applications (Actual)", */
/*NO_OF_APPL_ACCEPTED as no_of_acc_actual label="No of Applications Accepted (Actual)",*/
/*NO_OF_APPL_ACTUAL - NO_OF_APPL_ACCEPTED as no_of_appl_rejected label="No of Applications Rejected (Actual)",*/
/*NO_OF_ACTUAL_BADS as no_of_actual_bads label="No of Events (Actual)",*/
/*RATE as pd label="Estimated PD", MAX_SCORE_POINTS as score_points label="Score Points"*/
select TIME_SK label ="%sysfunc(sasmsg(smd_ds.bismsg,feed_pd_appl_pool.sas.1, noquote))", 
POOL_NAME as pool_name label ="%sysfunc(sasmsg(smd_ds.bismsg,feed_pd_appl_pool.sas.2, noquote))", 
POOL_SEQ_NO as pool_seq label ="%sysfunc(sasmsg(smd_ds.bismsg,feed_pd_appl_pool.sas.3, noquote))",
coalesce(NO_OF_APPL_DEV, &epsilon) as no_of_appl_dev label ="%sysfunc(sasmsg(smd_ds.bismsg,feed_pd_appl_pool.sas.4, noquote))", 
NO_OF_APPL_DEV_ACCEPTED as no_of_acc_dev label ="%sysfunc(sasmsg(smd_ds.bismsg,feed_pd_appl_pool.sas.5, noquote))", 
NO_OF_APPL_DEV - NO_OF_APPL_DEV_ACCEPTED as no_of_appl_dev_rejected label ="%sysfunc(sasmsg(smd_ds.bismsg,feed_pd_appl_pool.sas.6, noquote))",
coalesce(NO_OF_APPL_ACTUAL, &epsilon) as no_of_appl_actual label ="%sysfunc(sasmsg(smd_ds.bismsg,feed_pd_appl_pool.sas.7, noquote))", 
NO_OF_APPL_ACCEPTED as no_of_acc_actual label ="%sysfunc(sasmsg(smd_ds.bismsg,feed_pd_appl_pool.sas.8, noquote))",
NO_OF_APPL_ACTUAL - NO_OF_APPL_ACCEPTED as no_of_appl_rejected label ="%sysfunc(sasmsg(smd_ds.bismsg,feed_pd_appl_pool.sas.9, noquote))",
NO_OF_ACTUAL_BADS as no_of_actual_bads label ="%sysfunc(sasmsg(smd_ds.bismsg,feed_pd_appl_pool.sas.10, noquote))",
RATE as pd label ="%sysfunc(sasmsg(smd_ds.bismsg,feed_pd_appl_pool.sas.11, noquote))", MAX_SCORE_POINTS as score_points label ="%sysfunc(sasmsg(smd_ds.bismsg,feed_pd_appl_pool.sas.12, noquote))"
/*I18N-scnjih-20080418-1458*/
FROM &out_lib_nm..&out_table_nm_pool._pt
LEFT JOIN &out_lib_nm..&out_table_nm_pool._mdl
ON (&out_table_nm_pool._pt.POOL_SK = &out_table_nm_pool._mdl.POOL_SK)
LEFT JOIN &out_lib_nm..&out_table_nm_pool._1m_act
ON (&out_table_nm_pool._pt.POOL_SK = &out_table_nm_pool._1m_act.POOL_SK AND
    &out_table_nm_pool._pt.TIME_SK = &out_table_nm_pool._1m_act.SCORE_TIME_SK)
LEFT JOIN &out_lib_nm..&out_table_nm_pool._dev
ON (&out_table_nm_pool._pt.POOL_SK = &out_table_nm_pool._dev.POOL_SK)
where sum(NO_OF_APPL_DEV, NO_OF_APPL_ACTUAL) <> .
order by 1, 3;
quit;
/*End of pool level feed */

/*Start of pool level feed for historic data */
proc sql;
create view &out_lib_nm..&out_table_nm_pool. AS
/*I18N-scnjih-20080418-1458*/
/*select TIME_SK label="Score Time", */
/*POOL_NAME as pool_name label="Pool Name", */
/*POOL_SEQ_NO as pool_seq label="Pool Sequence",*/
/*coalesce(NO_OF_APPL_DEV, &epsilon) as no_of_appl_dev label="No of Applications (Development)", */
/*NO_OF_APPL_DEV_ACCEPTED as no_of_acc_dev label="No of Applications Accepted (Development)", */
/*NO_OF_APPL_DEV - NO_OF_APPL_DEV_ACCEPTED as no_of_appl_dev_rejected label="No of Applications Rejected (Development)",*/
/*coalesce(NO_OF_APPL_ACTUAL, &epsilon) as no_of_appl_actual label="No of Applications (Actual)", */
/*NO_OF_APPL_ACCEPTED as no_of_acc_actual label="No of Applications Accepted (Actual)",*/
/*NO_OF_APPL_ACTUAL - NO_OF_APPL_ACCEPTED as no_of_appl_rejected label="No of Applications Rejected (Actual)",*/
/*NO_OF_ACTUAL_BADS as no_of_actual_bads label="No of Events (Actual)",*/
/*RATE as pd label="Estimated PD", MAX_SCORE_POINTS as score_points label="Score Points"*/
select TIME_SK label ="%sysfunc(sasmsg(smd_ds.bismsg,feed_pd_appl_pool.sas.13, noquote))", 
POOL_NAME as pool_name label ="%sysfunc(sasmsg(smd_ds.bismsg,feed_pd_appl_pool.sas.14, noquote))", 
POOL_SEQ_NO as pool_seq label ="%sysfunc(sasmsg(smd_ds.bismsg,feed_pd_appl_pool.sas.15, noquote))",
coalesce(NO_OF_APPL_DEV, &epsilon) as no_of_appl_dev label ="%sysfunc(sasmsg(smd_ds.bismsg,feed_pd_appl_pool.sas.16, noquote))", 
NO_OF_APPL_DEV_ACCEPTED as no_of_acc_dev label ="%sysfunc(sasmsg(smd_ds.bismsg,feed_pd_appl_pool.sas.17, noquote))", 
NO_OF_APPL_DEV - NO_OF_APPL_DEV_ACCEPTED as no_of_appl_dev_rejected label ="%sysfunc(sasmsg(smd_ds.bismsg,feed_pd_appl_pool.sas.18, noquote))",
coalesce(NO_OF_APPL_ACTUAL, &epsilon) as no_of_appl_actual label ="%sysfunc(sasmsg(smd_ds.bismsg,feed_pd_appl_pool.sas.19, noquote))", 
NO_OF_APPL_ACCEPTED as no_of_acc_actual label ="%sysfunc(sasmsg(smd_ds.bismsg,feed_pd_appl_pool.sas.20, noquote))",
NO_OF_APPL_ACTUAL - NO_OF_APPL_ACCEPTED as no_of_appl_rejected label ="%sysfunc(sasmsg(smd_ds.bismsg,feed_pd_appl_pool.sas.21, noquote))",
NO_OF_ACTUAL_BADS as no_of_actual_bads label ="%sysfunc(sasmsg(smd_ds.bismsg,feed_pd_appl_pool.sas.22, noquote))",
RATE as pd label ="%sysfunc(sasmsg(smd_ds.bismsg,feed_pd_appl_pool.sas.23, noquote))", MAX_SCORE_POINTS as score_points label ="%sysfunc(sasmsg(smd_ds.bismsg,feed_pd_appl_pool.sas.24, noquote))"
/*I18N-scnjih-20080418-1458*/
FROM &out_lib_nm..&out_table_nm_pool._pt
LEFT JOIN &out_lib_nm..&out_table_nm_pool._mdl
ON (&out_table_nm_pool._pt.POOL_SK = &out_table_nm_pool._mdl.POOL_SK)
LEFT JOIN &out_lib_nm..&out_table_nm_pool._act
ON (&out_table_nm_pool._pt.POOL_SK = &out_table_nm_pool._act.POOL_SK AND
    &out_table_nm_pool._pt.TIME_SK = &out_table_nm_pool._act.SCORE_TIME_SK)
LEFT JOIN &out_lib_nm..&out_table_nm_pool._dev
ON (&out_table_nm_pool._pt.POOL_SK = &out_table_nm_pool._dev.POOL_SK)
where sum(NO_OF_APPL_DEV, NO_OF_APPL_ACTUAL) <> .
order by 1, 3;
quit;
/*End of pool level feed for historic data*/

/*Account level feed */
proc sql;
create view &out_lib_nm..&out_table_nm_acct._1m
/*I18N-scnjih-20080418-1458*/
/*as SELECT APPLICATION_ID as account_id label="Application Identifier", */
/*APPLICANT_ID as applicant_id label="Applicant Identifier", */
/*SCORE_POINTS as score_points label="Score Points", */
/*ACTUAL_GOOD_BAD as actual_good_bad label="Observed Default", */
/*PREDICTED_GOOD_BAD as predicted_good_bad label="Predicted Default", */
/*ESTIMATED_APPL_PD as pd label="Estimated PD"*/
as SELECT APPLICATION_ID as account_id label ="%sysfunc(sasmsg(smd_ds.bismsg,feed_pd_appl_pool.sas.25, noquote))", 
APPLICANT_ID as applicant_id label ="%sysfunc(sasmsg(smd_ds.bismsg,feed_pd_appl_pool.sas.26, noquote))", 
SCORE_POINTS as score_points label ="%sysfunc(sasmsg(smd_ds.bismsg,feed_pd_appl_pool.sas.27, noquote))", 
ACTUAL_GOOD_BAD as actual_good_bad label ="%sysfunc(sasmsg(smd_ds.bismsg,feed_pd_appl_pool.sas.28, noquote))", 
PREDICTED_GOOD_BAD as predicted_good_bad label ="%sysfunc(sasmsg(smd_ds.bismsg,feed_pd_appl_pool.sas.29, noquote))", 
ESTIMATED_APPL_PD as pd label ="%sysfunc(sasmsg(smd_ds.bismsg,feed_pd_appl_pool.sas.30, noquote))"
/*I18N-scnjih-20080418-1458*/
FROM &out_lib_nm..&out_table_nm_pool._1m_sql;
quit;
/*End of account level feed */

/*Account level feed for historic data*/
proc sql;
create view &out_lib_nm..&out_table_nm_acct.
/*I18N-scnjih-20080418-1458*/
/*as SELECT APPLICATION_ID as account_id label="Application Identifier", */
/*APPLICANT_ID as applicant_id label="Applicant Identifier", */
/*SCORE_POINTS as score_points label="Score Points", */
/*ACTUAL_GOOD_BAD as actual_good_bad label="Observed Default", */
/*PREDICTED_GOOD_BAD as predicted_good_bad label="Predicted Default", */
/*ESTIMATED_APPL_PD as pd label="Estimated PD"*/
as SELECT APPLICATION_ID as account_id label ="%sysfunc(sasmsg(smd_ds.bismsg,feed_pd_appl_pool.sas.31, noquote))", 
APPLICANT_ID as applicant_id label ="%sysfunc(sasmsg(smd_ds.bismsg,feed_pd_appl_pool.sas.32, noquote))", 
SCORE_POINTS as score_points label ="%sysfunc(sasmsg(smd_ds.bismsg,feed_pd_appl_pool.sas.33, noquote))", 
ACTUAL_GOOD_BAD as actual_good_bad label ="%sysfunc(sasmsg(smd_ds.bismsg,feed_pd_appl_pool.sas.34, noquote))", 
PREDICTED_GOOD_BAD as predicted_good_bad label ="%sysfunc(sasmsg(smd_ds.bismsg,feed_pd_appl_pool.sas.35, noquote))", 
ESTIMATED_APPL_PD as pd label ="%sysfunc(sasmsg(smd_ds.bismsg,feed_pd_appl_pool.sas.36, noquote))"
/*I18N-scnjih-20080418-1458*/
FROM &out_lib_nm..&out_table_nm_pool._sql;
quit;
/*End of account level feed for historic data*/

%mend feed_pd_appl_pool;


