/**********************************************************************************************
       Module:  feed_measure_mip
     Function:  This macro provides the view table for Applied LGD Model on pool level. 

      Authors:  BIS Team
         Date:  05 April 2006
          SAS:  9.1
    Called-by:	All report screens. 

        Calls:  NA

Datasets used:  No input datasets required for processing of the macro.
 
        Logic:  On selected model  and time this macro creates the 
				view for  variable provided.All columns of score_card_fact  
				are joined by all respective dimension by the  Applied LGD table
				having name with model type and time (E.g. APPL_LGD_FACT_301_1016,  
				APPL_LGD_FACT_301_1014)with respective dimension of score_card_fact
				with model and time key (E.g. Score_card_fact_301_1016 , 
				Score_card_fact_301_1014 ).

   Parameters: 
		INPUT: 
				in_filter 		 	:	where clause in this case it is 1.
				out_lib_nm			:	where the dataset will be created.
				out_table_nm_pool	:	The table name for pool level feed.
				out_table_nm_acct	:	The table name for account/application level feed
				var					: 	Selected variable (E.G.variable 1).
				model_time_key		:	This is the combination of  selected model and selected 
										time for that model E.G. 100_1025 , 103_1027).
**********************************************************************************************/
%macro feed_measure_mip(in_filter=, out_lib_nm=, in_table_nm=, out_table_nm_measure=);

proc sql;
create table &out_lib_nm..&out_table_nm_measure. AS 
SELECT ANALYTICAL_MODEL_DIM.MODEL_TYPE_CD, 
	ANALYTICAL_MODEL_DIM.MODEL_PRODUCT_TYPE_CD, MEASURE_DIM.MEASURE_NM, MEASURE_DIM.SEQ_NO, 
	MEASURE_DIM.LEVEL_DESC, MEASURE_DIM.PROGRAM_NM, MEASURE_DIM.BOUND_RED, MEASURE_DIM.BOUND_GREEN,
	SCORE_CARD_VARIABLE_FACT.SCORE_TIME_SK, SCORE_CARD_VARIABLE_FACT.VARIABLE_SK, 
	SCORE_CARD_VARIABLE_FACT.MEASURE_SK, SCORE_CARD_VARIABLE_FACT.MEASURE_VALUE, 
	SCORE_CARD_VARIABLE_FACT.MODEL_SK, SCORE_CARD_VARIABLE_FACT.DEV_FLG,
	TIME_DIM.CAL_MONTH_LAST_DT AS CAL_MON_LAST_DT 
FROM FACT.SCORE_CARD_VARIABLE_FACT 	
	INNER JOIN DIM.MEASURE_DIM 
	ON (SCORE_CARD_VARIABLE_FACT.MEASURE_SK = MEASURE_DIM.MEASURE_SK)  	
	INNER JOIN DIM.ANALYTICAL_MODEL_DIM 
	ON (SCORE_CARD_VARIABLE_FACT.MODEL_SK = ANALYTICAL_MODEL_DIM.MODEL_SK)  
	INNER JOIN DIM.TIME_DIM 
	ON (SCORE_CARD_VARIABLE_FACT.SCORE_TIME_SK = TIME_DIM.TIME_SK) 
	INNER JOIN &out_lib_nm..&in_table_nm
	ON (&in_table_nm..MEASURE_NM = MEASURE_DIM.MEASURE_NM)
	/* Start of CS4.3 HF2 */
	&in_filter 
	/*Model monitoring reports are for a single month so
	  time filter on SCORE_TIME_SK is required.*/ 
/*	and*/
/*	 SCORE_TIME_SK=&time_key.  */
/* End	 of CS4.3 HF2 */



order by MEASURE_SK, SCORE_TIME_SK; 
quit;

%mend feed_measure_mip;
