/**********************************************************************************************
       Module:  feed_pd_appl_pool_mip
     Function:  This macro provides the view table for Applied PD Model on pool level. 

      Authors:  BIS Team
         Date:  05 April 2006
          SAS:  9.1
    Called-by:	All report screens. 

        Calls:  NA

Datasets used:  No input datasets required for processing of the macro.
 
        Logic:  On selected model  and time this macro creates the 
				view for variable provided.All columns of score_card_fact  
				are joined by all respective dimension by the  Applied PD Fact table
				having name with model type and time (E.g. APPL_PD_FACT_301_1016,  
				APPL_PD_FACT_301_1014)with respective dimension of score_card_fact
				with model and time key (E.g. Score_card_fact_301_1016 , 
				Score_card_fact_301_1014 ).

   Parameters: 
		INPUT: 
				in_filter 		 	:	where clause in this case it is 1.
				out_lib_nm			:	where the dataset will be created.
				out_table_nm_pool	:	The table name for pool level feed.
				out_table_nm_acct	:	The table name for account/application level feed
				var					: 	Selected variable (E.G.variable 1).
				model_time_key		:	This is the combination of  selected model and selected 
										time for that model E.G. 100_1025 , 103_1027).
				product_type_code	: 	This is the selected product type code (E.G. MTG, LON).
**********************************************************************************************/
%macro feed_pd_appl_pool_mip(in_filter=, out_lib_nm=, out_table_nm_pool=, 
	out_table_nm_acct=, var=, model_time_key=, product_type_code=);

%let model_key = %sysfunc(kscan(&model_time_key,1,'_'));
%let time_key = %sysfunc(kscan(&model_time_key,2,'_'));

/* To obtain the number of months to be considered for historic data */
%macro time_period;
	%let history = .;
	%let product_code = %quote(%'&product_type_code%'); 
	%if %sysfunc(kupcase(&product_code)) eq %sysfunc(kupcase(&MTG_PRD_TYPE.)) %then %do;
		%let history = &PDA_MTG_HIST;
	%end;
	%if %sysfunc(kupcase(&product_code)) eq %sysfunc(kupcase(&LON_PRD_TYPE.)) %then %do;
		%let history = &PDA_LON_HIST;
	%end;
	/*CS4.3 HF2 */
	%if %sysfunc(kupcase(&product_code)) eq %sysfunc(kupcase(&COR_PRD_TYPE.)) %then %do;
		%let history = &PDA_COR_HIST;
	%end;
	%if %sysfunc(kupcase(&product_code)) eq %sysfunc(kupcase(&CCD_PRD_TYPE.)) %then %do;
		%let history = &PDA_CCD_HIST;
	%end;

	%let time_key_first = %sysfunc(sum(&time_key, - &history, 1));
	%do apnd = &time_key_first %to &time_key;
		%let tableExist = %sysfunc(exist(fact.SCORE_CARD_FACT_&model_key._&apnd, DATA));
		%if (&tableExist ne 0) %then %do; 
			proc append base=work.SCORE_CARD_FACT_HIST data=fact.SCORE_CARD_FACT_&model_key._&apnd force;
			run;
		%end;
		%let tableExist = %sysfunc(exist(fact.APPL_PD_FACT_&model_key._&apnd, DATA));
		%if (&tableExist ne 0) %then %do; 
			proc append base=work.APPL_PD_FACT_HIST data=fact.APPL_PD_FACT_&model_key._&apnd force;
			run;
		%end;
	%end;
%mend time_period;
%time_period;

/*Generate a table by joining score_card_fact with all respective dimensions */
/* Start of CS4.3 HF2 */
/* The following queries are changed to include the ACCOUNT_DIM and APPLICATION_DIM
  	and the join condition for APPL_PD_FACT&model_time_key and SCORE_CARD_FACT&model_time_key
	is changed */

proc sql;
CREATE TABLE &out_lib_nm..&out_table_nm_pool._1m_sql AS
SELECT SCORE_CARD_VARIABLE_DIM.VARIABLE_NAME AS VAR_NAME,
	SCORE_CARD_DIM.VARIABLE_GROUP_LABEL AS ATTR_NAME, 
	SCORE_CARD_DIM.NO_OF_ACCOUNTS AS NO_OF_ACC_DEV,
	SCORE_CARD_DIM.NO_OF_DEFAULTS AS NO_OF_EVENTS_DEV,
	SCORE_CARD_DIM.AVERAGE_SCORE AS AVERAGE_SCORE_DEV,
	SCORE_CARD_DIM.SCORE_CARD_POINTS AS SCORECARD_POINTS,
	SCORE_CARD_DIM.VARIABLE_GROUP_NO AS SEQ_NO,
	APPL_PD_FACT&model_time_key..APPLICATION_SK  AS APPLICATION_SK,
	APPL_PD_FACT&model_time_key..PREDICTED_GOOD_BAD AS PREDICTED_GOOD_BAD,
	APPL_PD_FACT&model_time_key..ACTUAL_GOOD_BAD AS ACTUAL_GOOD_BAD
FROM FACT.SCORE_CARD_FACT&model_time_key. 
	INNER JOIN DIM.ANALYTICAL_MODEL_DIM 
	ON (SCORE_CARD_FACT&model_time_key..MODEL_SK = ANALYTICAL_MODEL_DIM.MODEL_SK) 
	INNER JOIN DIM.SCORE_CARD_DIM
	ON (SCORE_CARD_FACT&model_time_key..SCORE_CARD_SK = SCORE_CARD_DIM.SCORE_CARD_SK) 
	INNER JOIN DIM.SCORE_CARD_VARIABLE_DIM
	ON (SCORE_CARD_DIM.VARIABLE_SK = SCORE_CARD_VARIABLE_DIM.VARIABLE_SK)
	INNER JOIN DIM.TIME_DIM 
	ON (SCORE_CARD_FACT&model_time_key..SCORE_TIME_SK = TIME_DIM.TIME_SK)
	INNER JOIN dim.ACCOUNT_DIM 
	ON ( SCORE_CARD_FACT&model_time_key..ACCOUNT_SK = ACCOUNT_DIM.ACCOUNT_SK AND
	TIME_DIM.CAL_MONTH_LAST_DT >= Datepart(ACCOUNT_DIM.VALID_START_DTTM) AND
	TIME_DIM.CAL_MONTH_LAST_DT <= Datepart(ACCOUNT_DIM.VALID_END_DTTM) )
	INNER JOIN dim.APPLICATION_DIM 
	ON ( ACCOUNT_DIM.APPLICATION_RK = APPLICATION_DIM.APPLICATION_RK AND
	TIME_DIM.CAL_MONTH_LAST_DT >= Datepart(APPLICATION_DIM.VALID_START_DTTM) AND
	TIME_DIM.CAL_MONTH_LAST_DT <= Datepart(APPLICATION_DIM.VALID_END_DTTM))
	INNER JOIN FACT.APPL_PD_FACT&model_time_key.
	ON (SCORE_CARD_FACT&model_time_key..MODEL_SK = APPL_PD_FACT&model_time_key..MODEL_SK AND 
	SCORE_CARD_FACT&model_time_key..SCORE_TIME_SK = APPL_PD_FACT&model_time_key..SCORE_TIME_SK AND 
	APPL_PD_FACT&model_time_key..APPLICATION_SK = APPLICATION_DIM.APPLICATION_SK)
where &in_filter and SCORE_CARD_VARIABLE_DIM.VARIABLE_SK=&var ;
quit;

/* For historic data */
proc sql;
CREATE TABLE &out_lib_nm..&out_table_nm_pool._sql AS
SELECT SCORE_CARD_VARIABLE_DIM.VARIABLE_NAME AS VAR_NAME,
	SCORE_CARD_DIM.VARIABLE_GROUP_LABEL AS ATTR_NAME, 
	SCORE_CARD_DIM.NO_OF_ACCOUNTS AS NO_OF_ACC_DEV,
	SCORE_CARD_DIM.NO_OF_DEFAULTS AS NO_OF_EVENTS_DEV,
	SCORE_CARD_DIM.AVERAGE_SCORE AS AVERAGE_SCORE_DEV,
	SCORE_CARD_DIM.SCORE_CARD_POINTS AS SCORECARD_POINTS,
	SCORE_CARD_DIM.VARIABLE_GROUP_NO AS SEQ_NO,
	APPL_PD_FACT&model_time_key..APPLICATION_SK AS APPLICATION_SK,
	APPL_PD_FACT&model_time_key..PREDICTED_GOOD_BAD AS PREDICTED_GOOD_BAD,
	APPL_PD_FACT&model_time_key..ACTUAL_GOOD_BAD AS ACTUAL_GOOD_BAD
FROM work.SCORE_CARD_FACT_HIST as SCORE_CARD_FACT&model_time_key. 
	INNER JOIN DIM.ANALYTICAL_MODEL_DIM 
	ON (SCORE_CARD_FACT&model_time_key..MODEL_SK = ANALYTICAL_MODEL_DIM.MODEL_SK) 
	INNER JOIN DIM.SCORE_CARD_DIM
	ON (SCORE_CARD_FACT&model_time_key..SCORE_CARD_SK = SCORE_CARD_DIM.SCORE_CARD_SK) 
	INNER JOIN DIM.SCORE_CARD_VARIABLE_DIM
	ON (SCORE_CARD_DIM.VARIABLE_SK = SCORE_CARD_VARIABLE_DIM.VARIABLE_SK)
	INNER JOIN DIM.TIME_DIM 
	ON (SCORE_CARD_FACT&model_time_key..SCORE_TIME_SK = TIME_DIM.TIME_SK)
	INNER JOIN dim.ACCOUNT_DIM 
	ON ( SCORE_CARD_FACT&model_time_key..ACCOUNT_SK = ACCOUNT_DIM.ACCOUNT_SK AND
	TIME_DIM.CAL_MONTH_LAST_DT >= Datepart(ACCOUNT_DIM.VALID_START_DTTM) AND
	TIME_DIM.CAL_MONTH_LAST_DT <= Datepart(ACCOUNT_DIM.VALID_END_DTTM) )
	INNER JOIN dim.APPLICATION_DIM 
	ON ( ACCOUNT_DIM.APPLICATION_RK = APPLICATION_DIM.APPLICATION_RK AND
	TIME_DIM.CAL_MONTH_LAST_DT >= Datepart(APPLICATION_DIM.VALID_START_DTTM) AND
	TIME_DIM.CAL_MONTH_LAST_DT <= Datepart(APPLICATION_DIM.VALID_END_DTTM))
	INNER JOIN FACT.APPL_PD_FACT&model_time_key.
	ON (SCORE_CARD_FACT&model_time_key..MODEL_SK = APPL_PD_FACT&model_time_key..MODEL_SK AND 
	SCORE_CARD_FACT&model_time_key..SCORE_TIME_SK = APPL_PD_FACT&model_time_key..SCORE_TIME_SK AND 
	APPL_PD_FACT&model_time_key..APPLICATION_SK = APPLICATION_DIM.APPLICATION_SK)

where &in_filter and SCORE_CARD_VARIABLE_DIM.VARIABLE_SK=&var ;
quit;

/*End, Generate a table by joining score_card_fact with all respective dimensions */
/* End of CS4.3 HF2 */
/*
Code to check for errors.
Possibly error will happen only if the filter condition is not properly passed. 
In this case, return to the calling program with error_code=ERROR
*/
%if &sqlrc = 8 %then
%do;
%let error_code = ERROR;
%RETURN;
%end;
/*End of code to check errors */


/* Attribute level data */
proc sql;
CREATE TABLE &out_lib_nm..&out_table_nm_pool._1m AS
/*I18N-scnjih-20080421-0948*/
/*SELECT VAR_NAME label="Variable Name", ATTR_NAME label="Attribute Name", */
/*	SEQ_NO label="Sequence",*/
/*	MAX(SCORECARD_POINTS) AS SCORECARD_POINTS label="Scorecard Points", */
/*	MAX(NO_OF_ACC_DEV) AS NO_OF_ACC_DEV label="No of Applications (Development)", */
/*	MAX(NO_OF_EVENTS_DEV) AS NO_OF_EVENTS_DEV label="No of Events (Development)", */
/*	MAX(AVERAGE_SCORE_DEV) AS AVERAGE_SCORE_DEV label="Average Score points (Development)", */
/*	COUNT(APPLICATION_SK) AS NO_OF_ACC_ACTUAL label="No of Applications (Actual)",*/
/*	SUM(ACTUAL_GOOD_BAD) AS NO_OF_EVENTS_ACTUAL label="No of Events (Actual)"*/
SELECT VAR_NAME label = "%sysfunc(sasmsg(smd_ds.bismsg,feed_pd_appl_pool_mip.sas.1, noquote))", ATTR_NAME label = "%sysfunc(sasmsg(smd_ds.bismsg,feed_pd_appl_pool_mip.sas.2, noquote))", 
	SEQ_NO label = "%sysfunc(sasmsg(smd_ds.bismsg,feed_pd_appl_pool_mip.sas.3, noquote))",
	MAX(SCORECARD_POINTS) AS SCORECARD_POINTS label = "%sysfunc(sasmsg(smd_ds.bismsg,feed_pd_appl_pool_mip.sas.4, noquote))", 
	MAX(NO_OF_ACC_DEV) AS NO_OF_ACC_DEV label = "%sysfunc(sasmsg(smd_ds.bismsg,feed_pd_appl_pool_mip.sas.5, noquote))", 
	MAX(NO_OF_EVENTS_DEV) AS NO_OF_EVENTS_DEV label = "%sysfunc(sasmsg(smd_ds.bismsg,feed_pd_appl_pool_mip.sas.6, noquote))", 
	MAX(AVERAGE_SCORE_DEV) AS AVERAGE_SCORE_DEV label = "%sysfunc(sasmsg(smd_ds.bismsg,feed_pd_appl_pool_mip.sas.7, noquote))", 
	COUNT(APPLICATION_SK) AS NO_OF_ACC_ACTUAL label = "%sysfunc(sasmsg(smd_ds.bismsg,feed_pd_appl_pool_mip.sas.8, noquote))",
	SUM(ACTUAL_GOOD_BAD) AS NO_OF_EVENTS_ACTUAL label = "%sysfunc(sasmsg(smd_ds.bismsg,feed_pd_appl_pool_mip.sas.9, noquote))"
	/*I18N-scnjih-20080421-0948*/
FROM &out_lib_nm..&out_table_nm_pool._1m_sql
GROUP BY VAR_NAME, SEQ_NO, ATTR_NAME;
quit;

/*CS4.3 HF2 */
/*Start of CS4.3 HF2 */
/*Create Attribute Level data for Dev sample only. There may be cases 
  where the actual sample does not contain all attribute groupings*/
proc sql;
      CREATE TABLE ALL_DEV_ATTRIBUTE_LEVELS AS
      select SCORE_CARD_VARIABLE_DIM.VARIABLE_NAME AS VAR_NAME,
           SCORE_CARD_DIM.VARIABLE_GROUP_LABEL AS ATTR_NAME ,
           SCORE_CARD_DIM.VARIABLE_GROUP_NO AS SEQ_NO , 
           MAX(SCORE_CARD_DIM.SCORE_CARD_POINTS) AS SCORECARD_POINTS , 
           MAX(SCORE_CARD_DIM.NO_OF_ACCOUNTS) AS NO_OF_ACC_DEV , 
           MAX(SCORE_CARD_DIM.NO_OF_DEFAULTS) AS NO_OF_EVENTS_DEV , 
           MAX(SCORE_CARD_DIM.AVERAGE_SCORE) AS AVERAGE_SCORE_DEV ,
           0 AS NO_OF_ACC_ACTUAL , 
           0 AS NO_OF_EVENTS_ACTUAL  
      FROM dim.score_card_dim, dim.SCORE_CARD_VARIABLE_DIM
      WHERE score_card_dim.variable_sk = SCORE_CARD_VARIABLE_DIM.VARIABLE_SK
       and SCORE_CARD_VARIABLE_DIM.VARIABLE_SK=&var
       and SCORE_CARD_DIM.VARIABLE_GROUP_no NE -2
AND SCORE_CARD_DIM.MODEL_SK = &model_key
      GROUP BY VAR_NAME, SEQ_NO, ATTR_NAME;
quit;
/*Merge the datasets so we have all of the possible Variable Grouping Covered*/
Data  &out_lib_nm..&out_table_nm_pool._1m;
      merge ALL_DEV_ATTRIBUTE_LEVELS 
              &out_lib_nm..&out_table_nm_pool._1m; 
      BY VAR_NAME SEQ_NO ATTR_NAME;
run;

/*End of CS4.3 HF2 */


/* For historic data */
proc sql;
CREATE TABLE &out_lib_nm..&out_table_nm_pool. AS
/*I18N-scnjih-20080421-0948*/
/*SELECT VAR_NAME label="Variable Name", ATTR_NAME label="Attribute Name", */
/*	SEQ_NO label="Sequence",*/
/*	MAX(SCORECARD_POINTS) AS SCORECARD_POINTS label="Scorecard Points", */
/*	MAX(NO_OF_ACC_DEV) AS NO_OF_ACC_DEV label="No of Applications (Development)", */
/*	MAX(NO_OF_EVENTS_DEV) AS NO_OF_EVENTS_DEV label="No of Events (Development)", */
/*	MAX(AVERAGE_SCORE_DEV) AS AVERAGE_SCORE_DEV label="Average Score points (Development)", */
/*	COUNT(APPLICATION_SK) AS NO_OF_ACC_ACTUAL label="No of Applications (Actual)",*/
/*	SUM(ACTUAL_GOOD_BAD) AS NO_OF_EVENTS_ACTUAL label="No of Events (Actual)"*/
SELECT VAR_NAME label = "%sysfunc(sasmsg(smd_ds.bismsg,feed_pd_appl_pool_mip.sas.10, noquote))", ATTR_NAME label = "%sysfunc(sasmsg(smd_ds.bismsg,feed_pd_appl_pool_mip.sas.11, noquote))", 
	SEQ_NO label = "%sysfunc(sasmsg(smd_ds.bismsg,feed_pd_appl_pool_mip.sas.12, noquote))",
	MAX(SCORECARD_POINTS) AS SCORECARD_POINTS label = "%sysfunc(sasmsg(smd_ds.bismsg,feed_pd_appl_pool_mip.sas.13, noquote))", 
	MAX(NO_OF_ACC_DEV) AS NO_OF_ACC_DEV label = "%sysfunc(sasmsg(smd_ds.bismsg,feed_pd_appl_pool_mip.sas.14, noquote))", 
	MAX(NO_OF_EVENTS_DEV) AS NO_OF_EVENTS_DEV label = "%sysfunc(sasmsg(smd_ds.bismsg,feed_pd_appl_pool_mip.sas.15, noquote))", 
	MAX(AVERAGE_SCORE_DEV) AS AVERAGE_SCORE_DEV label = "%sysfunc(sasmsg(smd_ds.bismsg,feed_pd_appl_pool_mip.sas.16, noquote))", 
	COUNT(APPLICATION_SK) AS NO_OF_ACC_ACTUAL label = "%sysfunc(sasmsg(smd_ds.bismsg,feed_pd_appl_pool_mip.sas.17, noquote))",
	SUM(ACTUAL_GOOD_BAD) AS NO_OF_EVENTS_ACTUAL label = "%sysfunc(sasmsg(smd_ds.bismsg,feed_pd_appl_pool_mip.sas.18, noquote))"
	/*I18N-scnjih-20080421-0948*/
FROM &out_lib_nm..&out_table_nm_pool._sql
GROUP BY VAR_NAME, SEQ_NO, ATTR_NAME;
quit;

/*CS4.3 HF2 */
/*Start of CS4.3 HF2 */

/*Merge the datasets so we have all of the possible Variable Grouping Covered*/
Data  &out_lib_nm..&out_table_nm_pool.;
      merge ALL_DEV_ATTRIBUTE_LEVELS 
              &out_lib_nm..&out_table_nm_pool.; 
      BY VAR_NAME SEQ_NO ATTR_NAME;
run;

/*End of CS4.3 HF2 */



/* Start of CS4.3 HF2 */
/* The following queries are changed to include the ACCOUNT_DIM and APPLICATION_DIM
  	and the join condition for APPL_PD_FACT&model_time_key and SCORE_CARD_FACT&model_time_key
	is changed */


/* Account level data */

proc sql;
CREATE TABLE &out_lib_nm..&out_table_nm_acct._1m_sql AS
SELECT distinct SCORE_CARD_FACT&model_time_key..MODEL_SK, 
	SCORE_CARD_DIM.VARIABLE_SK AS VARIABLE_SK,
	SCORE_CARD_VARIABLE_DIM.VARIABLE_NAME AS VAR_NAME,
	SCORE_CARD_DIM.VARIABLE_GROUP_LABEL AS ATTR_NAME, 
	SCORE_CARD_DIM.SCORE_CARD_SK,
	SCORE_CARD_DIM.VARIABLE_GROUP_NO, 
	SCORE_RANGE_FACT.FROM_SCORE, 
	SCORE_RANGE_FACT.TO_SCORE,
	APPL_PD_FACT&model_time_key..APPLICATION_SK AS APPLICATION_SK,
	APPL_PD_FACT&model_time_key..PREDICTED_GOOD_BAD AS PREDICTED_GOOD_BAD,
	APPL_PD_FACT&model_time_key..ACTUAL_GOOD_BAD AS ACTUAL_GOOD_BAD
FROM FACT.SCORE_CARD_FACT&model_time_key. 
	INNER JOIN DIM.ANALYTICAL_MODEL_DIM 
	ON (SCORE_CARD_FACT&model_time_key..MODEL_SK = ANALYTICAL_MODEL_DIM.MODEL_SK) 
	INNER JOIN DIM.SCORE_CARD_DIM
	ON (SCORE_CARD_FACT&model_time_key..SCORE_CARD_SK = SCORE_CARD_DIM.SCORE_CARD_SK) 
	INNER JOIN DIM.SCORE_CARD_VARIABLE_DIM
	ON (SCORE_CARD_DIM.VARIABLE_SK = SCORE_CARD_VARIABLE_DIM.VARIABLE_SK)
	INNER JOIN FACT.SCORE_RANGE_FACT
	ON (SCORE_CARD_FACT&model_time_key..MODEL_SK = SCORE_RANGE_FACT.MODEL_SK AND
	SCORE_CARD_FACT&model_time_key..SCORE_CARD_SK = SCORE_RANGE_FACT.SCORE_CARD_SK)
	INNER JOIN DIM.TIME_DIM 
	ON (SCORE_CARD_FACT&model_time_key..SCORE_TIME_SK = TIME_DIM.TIME_SK)
	INNER JOIN dim.ACCOUNT_DIM 
	ON ( SCORE_CARD_FACT&model_time_key..ACCOUNT_SK = ACCOUNT_DIM.ACCOUNT_SK AND
	TIME_DIM.CAL_MONTH_LAST_DT >= Datepart(ACCOUNT_DIM.VALID_START_DTTM) AND
	TIME_DIM.CAL_MONTH_LAST_DT <= Datepart(ACCOUNT_DIM.VALID_END_DTTM) )
	INNER JOIN dim.APPLICATION_DIM 
	ON ( ACCOUNT_DIM.APPLICATION_RK = APPLICATION_DIM.APPLICATION_RK AND
	TIME_DIM.CAL_MONTH_LAST_DT >= Datepart(APPLICATION_DIM.VALID_START_DTTM) AND
	TIME_DIM.CAL_MONTH_LAST_DT <= Datepart(APPLICATION_DIM.VALID_END_DTTM))
	INNER JOIN FACT.APPL_PD_FACT&model_time_key.
	ON (SCORE_CARD_FACT&model_time_key..MODEL_SK = APPL_PD_FACT&model_time_key..MODEL_SK AND 
	SCORE_CARD_FACT&model_time_key..SCORE_TIME_SK = APPL_PD_FACT&model_time_key..SCORE_TIME_SK AND 
	APPL_PD_FACT&model_time_key..APPLICATION_SK = APPLICATION_DIM.APPLICATION_SK)

where &in_filter and SCORE_CARD_VARIABLE_DIM.VARIABLE_SK=&var and 
	APPL_PD_FACT&model_time_key..SCORE_POINTS > FROM_SCORE AND 
	APPL_PD_FACT&model_time_key..SCORE_POINTS <= TO_SCORE;
quit;

/* For historic data */
proc sql;
CREATE TABLE &out_lib_nm..&out_table_nm_acct._sql AS
SELECT distinct SCORE_CARD_FACT&model_time_key..MODEL_SK, 
	SCORE_CARD_DIM.VARIABLE_SK AS VARIABLE_SK,
	SCORE_CARD_VARIABLE_DIM.VARIABLE_NAME AS VAR_NAME,
	SCORE_CARD_DIM.VARIABLE_GROUP_LABEL AS ATTR_NAME, 
	SCORE_CARD_DIM.SCORE_CARD_SK,
	SCORE_CARD_DIM.VARIABLE_GROUP_NO, 
	SCORE_RANGE_FACT.FROM_SCORE, 
	SCORE_RANGE_FACT.TO_SCORE,
	APPL_PD_FACT&model_time_key..APPLICATION_SK AS APPLICATION_SK,
	APPL_PD_FACT&model_time_key..PREDICTED_GOOD_BAD AS PREDICTED_GOOD_BAD,
	APPL_PD_FACT&model_time_key..ACTUAL_GOOD_BAD AS ACTUAL_GOOD_BAD
FROM work.SCORE_CARD_FACT_HIST as SCORE_CARD_FACT&model_time_key. 
	INNER JOIN DIM.ANALYTICAL_MODEL_DIM 
	ON (SCORE_CARD_FACT&model_time_key..MODEL_SK = ANALYTICAL_MODEL_DIM.MODEL_SK) 
	INNER JOIN DIM.SCORE_CARD_DIM
	ON (SCORE_CARD_FACT&model_time_key..SCORE_CARD_SK = SCORE_CARD_DIM.SCORE_CARD_SK) 
	INNER JOIN DIM.SCORE_CARD_VARIABLE_DIM
	ON (SCORE_CARD_DIM.VARIABLE_SK = SCORE_CARD_VARIABLE_DIM.VARIABLE_SK)
	INNER JOIN FACT.SCORE_RANGE_FACT
	ON (SCORE_CARD_FACT&model_time_key..MODEL_SK = SCORE_RANGE_FACT.MODEL_SK AND
	SCORE_CARD_FACT&model_time_key..SCORE_CARD_SK = SCORE_RANGE_FACT.SCORE_CARD_SK)
	INNER JOIN DIM.TIME_DIM 
	ON (SCORE_CARD_FACT&model_time_key..SCORE_TIME_SK = TIME_DIM.TIME_SK)
	INNER JOIN dim.ACCOUNT_DIM 
	ON ( SCORE_CARD_FACT&model_time_key..ACCOUNT_SK = ACCOUNT_DIM.ACCOUNT_SK AND
	TIME_DIM.CAL_MONTH_LAST_DT >= Datepart(ACCOUNT_DIM.VALID_START_DTTM) AND
	TIME_DIM.CAL_MONTH_LAST_DT <= Datepart(ACCOUNT_DIM.VALID_END_DTTM) )
	INNER JOIN dim.APPLICATION_DIM 
	ON ( ACCOUNT_DIM.APPLICATION_RK = APPLICATION_DIM.APPLICATION_RK AND
	TIME_DIM.CAL_MONTH_LAST_DT >= Datepart(APPLICATION_DIM.VALID_START_DTTM) AND
	TIME_DIM.CAL_MONTH_LAST_DT <= Datepart(APPLICATION_DIM.VALID_END_DTTM))
	INNER JOIN work.APPL_PD_FACT_HIST as APPL_PD_FACT&model_time_key.
	ON (SCORE_CARD_FACT&model_time_key..MODEL_SK = APPL_PD_FACT&model_time_key..MODEL_SK AND 
	SCORE_CARD_FACT&model_time_key..SCORE_TIME_SK = APPL_PD_FACT&model_time_key..SCORE_TIME_SK AND 
	APPL_PD_FACT&model_time_key..APPLICATION_SK = APPLICATION_DIM.APPLICATION_SK)

where &in_filter and SCORE_CARD_VARIABLE_DIM.VARIABLE_SK=&var and 
	APPL_PD_FACT&model_time_key..SCORE_POINTS > FROM_SCORE AND 
	APPL_PD_FACT&model_time_key..SCORE_POINTS <= TO_SCORE;
quit;

/* End of CS4.3 HF2 */

/*
Code to check for errors.
Possibly error will happen only if the filter condition is not properly passed. 
In this case, return to the calling program with error_code=ERROR
*/
%if &sqlrc = 8 %then
%do;
%let error_code = ERROR;
%RETURN;
%end;
/*End of code to check errors */

/* Group by to get the no of accounts and no of events. */
proc sql;
CREATE TABLE &out_lib_nm..&out_table_nm_acct._1m_act AS
SELECT MODEL_SK, SCORE_CARD_SK, VARIABLE_SK, VAR_NAME, ATTR_NAME, FROM_SCORE, TO_SCORE, 
	COUNT(APPLICATION_SK) AS NO_OF_ACC_ACTUAL, 
	SUM(ACTUAL_GOOD_BAD) AS NO_OF_EVENTS_ACTUAL,
	MAX(VARIABLE_GROUP_NO) AS VARIABLE_GROUP_NO
FROM &out_lib_nm..&out_table_nm_acct._1m_sql
GROUP BY MODEL_SK, SCORE_CARD_SK, VARIABLE_SK, VAR_NAME, ATTR_NAME, FROM_SCORE, TO_SCORE;
quit;

/* For historic data */
proc sql;
CREATE TABLE &out_lib_nm..&out_table_nm_acct._act AS
SELECT MODEL_SK, SCORE_CARD_SK, VARIABLE_SK, VAR_NAME, ATTR_NAME, FROM_SCORE, TO_SCORE, 
	COUNT(APPLICATION_SK) AS NO_OF_ACC_ACTUAL, 
	SUM(ACTUAL_GOOD_BAD) AS NO_OF_EVENTS_ACTUAL,
	MAX(VARIABLE_GROUP_NO) AS VARIABLE_GROUP_NO
FROM &out_lib_nm..&out_table_nm_acct._sql
GROUP BY MODEL_SK, SCORE_CARD_SK, VARIABLE_SK, VAR_NAME, ATTR_NAME, FROM_SCORE, TO_SCORE;
quit;


/* Get the complete information from the dimension tables */
%let model_no = .;
proc sql noprint;
SELECT DISTINCT MODEL_SK into :model_no
FROM &out_lib_nm..&out_table_nm_acct._sql;
quit;

proc sql;
CREATE TABLE &out_lib_nm..&out_table_nm_acct._var AS
SELECT SCORE_RANGE_FACT.MODEL_SK, SCORE_CARD_DIM.SCORE_CARD_SK, 
	VARIABLE_NAME AS VAR_NAME,
	VARIABLE_GROUP_LABEL AS ATTR_NAME,
	VARIABLE_GROUP_NO,
	SCORE_RANGE_FACT.FROM_SCORE, 
	SCORE_RANGE_FACT.TO_SCORE, 
	SCORE_RANGE_FACT.NO_OF_ACCOUNTS, 
	SCORE_RANGE_FACT.NO_OF_DEFAULTS 
FROM DIM.SCORE_CARD_DIM INNER JOIN DIM.SCORE_CARD_VARIABLE_DIM
	ON (SCORE_CARD_DIM.VARIABLE_SK = SCORE_CARD_VARIABLE_DIM.VARIABLE_SK)
	INNER JOIN FACT.SCORE_RANGE_FACT
	ON (SCORE_CARD_DIM.SCORE_CARD_SK = SCORE_RANGE_FACT.SCORE_CARD_SK)
WHERE SCORE_CARD_VARIABLE_DIM.VARIABLE_SK=&var and SCORE_CARD_DIM.model_sk=&model_no;
quit;

/* Score Range data */
proc sql;
CREATE VIEW &out_lib_nm..&out_table_nm_acct._1m AS
/*I18N-scnjih-20080421-0948*/
/*SELECT &out_table_nm_acct._var.VAR_NAME label="Variable Name",*/
/*	&out_table_nm_acct._var.ATTR_NAME label="Attribute Name",*/
/*	&out_table_nm_acct._var.FROM_SCORE label="From Score", */
/*	&out_table_nm_acct._var.TO_SCORE label="To Score", */
/*	"> "||ktrim(left(put(&out_table_nm_acct._var.FROM_SCORE,8.)))||" TO <= "||ktrim(left(put(&out_table_nm_acct._var.TO_SCORE,8.))) AS SCORE_RANGE label="Score Range", */
/*	NO_OF_ACC_ACTUAL label="No of Applications (Actual)", */
/*	NO_OF_EVENTS_ACTUAL label="No of Events (Actual)", */
/*	&out_table_nm_acct._var.NO_OF_ACCOUNTS AS NO_OF_ACC_DEV label="No of Applications (Development)", */
/*	&out_table_nm_acct._var.NO_OF_DEFAULTS AS NO_OF_EVENTS_DEV label="No of Events (Development)", */
/*	&out_table_nm_acct._var.VARIABLE_GROUP_NO label="Variable Group No"*/
SELECT &out_table_nm_acct._var.VAR_NAME label = "%sysfunc(sasmsg(smd_ds.bismsg,feed_pd_appl_pool_mip.sas.19, noquote))",
	&out_table_nm_acct._var.ATTR_NAME label = "%sysfunc(sasmsg(smd_ds.bismsg,feed_pd_appl_pool_mip.sas.20, noquote))",
	&out_table_nm_acct._var.FROM_SCORE label = "%sysfunc(sasmsg(smd_ds.bismsg,feed_pd_appl_pool_mip.sas.21, noquote))", 
	&out_table_nm_acct._var.TO_SCORE label = "%sysfunc(sasmsg(smd_ds.bismsg,feed_pd_appl_pool_mip.sas.22, noquote))", 
	"> "||ktrim(left(put(&out_table_nm_acct._var.FROM_SCORE,8.)))||" TO <= "||ktrim(left(put(&out_table_nm_acct._var.TO_SCORE,8.))) AS SCORE_RANGE label = "%sysfunc(sasmsg(smd_ds.bismsg,feed_pd_appl_pool_mip.sas.23, noquote))", 
	NO_OF_ACC_ACTUAL label = "%sysfunc(sasmsg(smd_ds.bismsg,feed_pd_appl_pool_mip.sas.24, noquote))", 
	NO_OF_EVENTS_ACTUAL label = "%sysfunc(sasmsg(smd_ds.bismsg,feed_pd_appl_pool_mip.sas.25, noquote))", 
	&out_table_nm_acct._var.NO_OF_ACCOUNTS AS NO_OF_ACC_DEV label = "%sysfunc(sasmsg(smd_ds.bismsg,feed_pd_appl_pool_mip.sas.26, noquote))", 
	&out_table_nm_acct._var.NO_OF_DEFAULTS AS NO_OF_EVENTS_DEV label = "%sysfunc(sasmsg(smd_ds.bismsg,feed_pd_appl_pool_mip.sas.27, noquote))", 
	&out_table_nm_acct._var.VARIABLE_GROUP_NO label = "%sysfunc(sasmsg(smd_ds.bismsg,feed_pd_appl_pool_mip.sas.28, noquote))"
	/*I18N-scnjih-20080421-0948*/
FROM &out_lib_nm..&out_table_nm_acct._var 
	LEFT JOIN &out_lib_nm..&out_table_nm_acct._1m_act as &out_table_nm_acct._act
	ON (&out_table_nm_acct._act.MODEL_SK = &out_table_nm_acct._var.MODEL_SK AND
		&out_table_nm_acct._act.SCORE_CARD_SK = &out_table_nm_acct._var.SCORE_CARD_SK AND
		&out_table_nm_acct._act.FROM_SCORE = &out_table_nm_acct._var.FROM_SCORE AND
		&out_table_nm_acct._act.TO_SCORE = &out_table_nm_acct._var.TO_SCORE);
quit;

/* For historic data */
proc sql;
CREATE VIEW &out_lib_nm..&out_table_nm_acct. AS
/*I18N-scnjih-20080421-0948*/
/*SELECT &out_table_nm_acct._var.VAR_NAME label="Variable Name",*/
/*	&out_table_nm_acct._var.ATTR_NAME label="Attribute Name",*/
/*	&out_table_nm_acct._var.FROM_SCORE label="From Score", */
/*	&out_table_nm_acct._var.TO_SCORE label="To Score", */
/*	"> "||ktrim(left(put(&out_table_nm_acct._var.FROM_SCORE,8.)))||" TO <= "||ktrim(left(put(&out_table_nm_acct._var.TO_SCORE,8.))) AS SCORE_RANGE label="Score Range", */
/*	NO_OF_ACC_ACTUAL label="No of Applications (Actual)", */
/*	NO_OF_EVENTS_ACTUAL label="No of Events (Actual)", */
/*	&out_table_nm_acct._var.NO_OF_ACCOUNTS AS NO_OF_ACC_DEV label="No of Applications (Development)", */
/*	&out_table_nm_acct._var.NO_OF_DEFAULTS AS NO_OF_EVENTS_DEV label="No of Events (Development)", */
/*	&out_table_nm_acct._var.VARIABLE_GROUP_NO label="Variable Group No"*/
SELECT &out_table_nm_acct._var.VAR_NAME label = "%sysfunc(sasmsg(smd_ds.bismsg,feed_pd_appl_pool_mip.sas.29, noquote))",
	&out_table_nm_acct._var.ATTR_NAME label = "%sysfunc(sasmsg(smd_ds.bismsg,feed_pd_appl_pool_mip.sas.30, noquote))",
	&out_table_nm_acct._var.FROM_SCORE label = "%sysfunc(sasmsg(smd_ds.bismsg,feed_pd_appl_pool_mip.sas.31, noquote))", 
	&out_table_nm_acct._var.TO_SCORE label = "%sysfunc(sasmsg(smd_ds.bismsg,feed_pd_appl_pool_mip.sas.32, noquote))", 
	"> "||ktrim(left(put(&out_table_nm_acct._var.FROM_SCORE,8.)))||" TO <= "||ktrim(left(put(&out_table_nm_acct._var.TO_SCORE,8.))) AS SCORE_RANGE label = "%sysfunc(sasmsg(smd_ds.bismsg,feed_pd_appl_pool_mip.sas.33, noquote))", 
	NO_OF_ACC_ACTUAL label = "%sysfunc(sasmsg(smd_ds.bismsg,feed_pd_appl_pool_mip.sas.34, noquote))", 
	NO_OF_EVENTS_ACTUAL label = "%sysfunc(sasmsg(smd_ds.bismsg,feed_pd_appl_pool_mip.sas.35, noquote))", 
	&out_table_nm_acct._var.NO_OF_ACCOUNTS AS NO_OF_ACC_DEV label = "%sysfunc(sasmsg(smd_ds.bismsg,feed_pd_appl_pool_mip.sas.36, noquote))", 
	&out_table_nm_acct._var.NO_OF_DEFAULTS AS NO_OF_EVENTS_DEV label = "%sysfunc(sasmsg(smd_ds.bismsg,feed_pd_appl_pool_mip.sas.37, noquote))", 
	&out_table_nm_acct._var.VARIABLE_GROUP_NO label = "%sysfunc(sasmsg(smd_ds.bismsg,feed_pd_appl_pool_mip.sas.38, noquote))"
	/*I18N-scnjih-20080421-0948*/
FROM &out_lib_nm..&out_table_nm_acct._var 
	LEFT JOIN &out_lib_nm..&out_table_nm_acct._act
	ON (&out_table_nm_acct._act.MODEL_SK = &out_table_nm_acct._var.MODEL_SK AND
		&out_table_nm_acct._act.SCORE_CARD_SK = &out_table_nm_acct._var.SCORE_CARD_SK AND
		&out_table_nm_acct._act.FROM_SCORE = &out_table_nm_acct._var.FROM_SCORE AND
		&out_table_nm_acct._act.TO_SCORE = &out_table_nm_acct._var.TO_SCORE);
quit;

%mend feed_pd_appl_pool_mip;
