/******************************************************************************************************
       Module:  create_pool_abt

     Function:  Creates the ABT

      Authors:  BIS Team
         Date:  14 May 2007
          SAS:  9.1
    Called-by:	macro build_sel_abt
        Calls:  

   Parameters:  abt_type		: SCR for a scoring ABT
							  		MOD for a modeling ABT
				abt_cat			: Account for account level ABT
							 		Customer for customer level ABT
							  		Application for application level ABT
				abt_phy_table	: Name of the physical table to be created
				abt_vars		: Dataset with the list of variables to be created in the ABT

******************************************************************************************************/
option SPOOL;
option msglevel=i;
option mvarsize = 32000;

/*System options for debugging purpose */
/*options SYMBOLGEN; */
/*options mprint;*/

%global lib_ana;
%let lib_ana=analytic;
/*
Macro name: Create_abt. 
The input parameters are,
ABT_TYPE: Type of the ABT to be create. 'SCR' for scoring ABT.
ABT_CAT: Category of the ABT. 'ACCOUNT' for the ABT with the grain of account
ABT_PHY_TABLE: This is the name to be given to the final ABT data set.
*/
/*filename cust_fl 'C:\MyWork\BISDirectory\Backup\20070424\cust_fl.sas';*/
/*filename acct_fl 'C:\MyWork\BISDirectory\Backup\20070424\acct_fl.sas';*/
/*filename jh1_fl 'C:\MyWork\BISDirectory\Backup\20070424\jh1_fl.sas';*/
/*filename jh2_fl 'C:\MyWork\BISDirectory\Backup\20070424\jh2_fl.sas';*/
/*filename semi_col 'C:\MyWork\BISDirectory\Backup\20070424\semi_col.sas';*/
/*filename acc_abt 'C:\MyWork\BISDirectory\Backup\20070424\acc_abt.sas';*/
/*filename jh1_abt 'C:\MyWork\BISDirectory\Backup\20070424\jh1_abt.sas';*/
/**/
/*filename appl_fl 'C:\MyWork\BISDirectory\Backup\20070424\appl_fl.sas';*/
/*filename pa_fl 'C:\MyWork\BISDirectory\Backup\20070424\pa_fl.sas';*/
/*filename ja1_fl 'C:\MyWork\BISDirectory\Backup\20070424\ja1_fl.sas';*/
/*filename pg_fl 'C:\MyWork\BISDirectory\Backup\20070424\pg_fl.sas';*/
/*filename pn_fl 'C:\MyWork\BISDirectory\Backup\20070424\pn_fl.sas';*/
/*filename appl_abt 'C:\MyWork\BISDirectory\Backup\20070424\appl_abt.sas';*/
/*filename pa_abt 'C:\MyWork\BISDirectory\Backup\20070424\pa_abt.sas';*/

/*%global create_abt_error_cd;*/
/*%let create_abt_error_cd =0;*/
/*%macro chk_error(return_err);*/
/*	%if &return_err. > &create_abt_error_cd. %then %do;*/
/*		%let create_abt_error_cd = &return_err.;		*/
/*	%end;*/
/*%mend;*/
%macro create_pool_abt(abt_type=, abt_cat=, abt_phy_table=, abt_vars=);
%let abt_cat = %upcase(&abt_cat);
/*In few macro the exact location of change is not mentioned. Just file is known so 
  it is identified with the tag of hot fix as below*/
/*CS4.3 HF2 */
/*Dummy data step to create some files required by the macro */
data _null_;
file cust_fl;
put ' ';
file acct_fl;
put ' ';
file jh1_fl;
put ' ';
file jh2_fl;	
put ' ';
file semi_col;
put ';';
file acc_abt;
put ' &acc_prev_join_table. (in=acc_present)';
file jh1_abt;
put ' &next_table. (in=acc_present)';

file appl_fl;
file pa_fl;
file ja1_fl;
file pg_fl;
file pn_fl;
file appl_abt;
put ' &appl_prev_join_table. (in=appl_present)';
file pa_abt;
put ' &next_table. (in=appl_present)';

run;

%chk_error(&syserr.); /*Call the macro to check for errors in the previous step */

/*End of Dummy data step */

%if &abt_cat = ACCOUNT %then 
	%do;
		proc sql;	
			insert into &abt_vars
			(var_nm, agg_var_nm, agg_table_nm,  agg_table_key ) values
			('ACCOUNT_RK', 'ACCOUNT_RK', 'ACC_CUS_KEY', 'ACCOUNT_RK');
		quit;
		%chk_error(&sqlrc.); /*Call the macro to check for errors in the previous step */
	%end;
%else %if &abt_cat = APPLICATION %then
	%do;
		proc sql;	
			insert into &abt_vars
			(var_nm, agg_var_nm, agg_table_nm,  agg_table_key ) values
			('APPLICATION_RK', 'APPLICATION_RK', 'APPL_APPT_KEY', 'APPLICATION_RK');
		quit;
		%chk_error(&sqlrc.); /*Call the macro to check for errors in the previous step */
	%end;

proc sql;
	insert into &abt_vars
	(var_nm, agg_var_nm, agg_table_nm,  agg_table_key ) values
	('CUSTOMER_RK', 'CUSTOMER_RK', 'CUS_CUS_BASIC_CURR_ABT', 'CUSTOMER_RK');	
quit;

%chk_error(&sqlrc.); /*Call the macro to check for errors in the previous step */	

proc sql;
	create table work.tmp_var_table as
	select b.var_table_nm , a.agg_table_key as table_key, a.var_nm as var_abt_nm, 
	a.agg_var_nm as var_nm, b.is_left_table
	from &abt_vars a inner join &lib_ana..var_table b
	on (a.agg_table_nm = b.var_table_nm)
	order by b.var_table_nm, a.agg_table_key;
quit;
%chk_error(&sqlrc.); /*Call the macro to check for errors in the previous step */

/*work.tmp_var_table_flat: This step creates the table work.tmp_var_table_flat. This table have attributes like,
VAR_TABLE_NM: Aggregate table name for the selected variable
TABLE_KEY: Key for accessing the variable from the table. (For example, CUSTOMER_RK
for primary customer, JH1_CUSTOMER_RK for joint holder 1 )
VAR_LIST: All the variables to be derived from a single table using the same key table_key
are concatenated seperated by space.
RENAME_LIST: This is the set of rename statements for the selected variables.
VAR_CNT: Number of variables to be derived from VAR_TABLE_NM, TABLE_KEY.
JOIN_CNT: Number of variables to be picked from this table 
ORG_VAR_LIST: List of variable names as in the aggregate tables. This 
variable name may be different from the selected ABT variable name.
*/

data tmp_var_table_flat 
(keep= var_table_nm table_key var_list rename_list var_cnt join_cnt org_var_list is_left_table);
		set work.tmp_var_table;
		by var_table_nm table_key;

		length var_list rename_list org_var_list $1500;

		retain var_list rename_list var_cnt join_cnt org_var_list ;
		retain join_cnt 0; 

	if first.table_key then
		do;
		
		var_list = var_abt_nm; /*Variable name on the screen (abt) */
		org_var_list = var_nm; /*Variable name in the aggregate table */
		/*Rename statement: rename aggregate table variable name with the screen (abt) name */	
		rename_list = catx(' ', var_nm, ' = ', var_abt_nm);
		var_cnt = 1;
		
		end;
	else do;
		/*Same process as in the if.
		statement */
		var_list = catx(' ', var_list, var_abt_nm);
		
		org_var_list = catx(' ', org_var_list, var_nm);

		if trim(left(var_nm)) NE trim(left(var_abt_nm)) then 
			do;
				rename_list = catx(' ', rename_list, var_nm, ' = ', var_abt_nm);
				if var_cnt IN (3, 6, 9, 12, 15, 18, 21, 24, 27, 30, 33, 
					36, 39, 42, 45, 48, 51, 54, 57, 60) then
					do;
					rename_list = catx(' ', rename_list, byte(10));		
					end;
			end;

		var_cnt = var_cnt + 1;		

		if var_cnt IN (5, 10, 15, 20, 25, 30, 35, 40, 45, 50, 55, 60) then
			do;
			org_var_list = catx(' ', org_var_list, byte(10));		
			end;
		
	end;


	if last.table_key;
	join_cnt = join_cnt + 1;
	output;
run;
%chk_error(&syserr.); /*Call the macro to check for errors in the previous step */

proc sort data= tmp_var_table_flat ;
by descending is_left_table table_key;
run;
%chk_error(&syserr.); /*Call the macro to check for errors in the previous step */


/*Global variable declarations */
%global cus_join cus_join_1 acc_join acc_join_1 jh1_join jh2_join datalibref; 

/*For applicaiton */
%global  appl_join appl_join_1 pri_appt_join jh1_appt_join pri_gur_join pri_nom_join;
/*End for application */

%global jh1_join_present jh2_join_present pri_appt_join_present jh1_appt_join_present 
pri_gur_join_present pri_nom_join_present;
%let jh1_join_present =0;
%let jh2_join_present =0;
%let pri_appt_join_present =0;
%let jh1_appt_join_present =0;
%let pri_gur_join_present =0;
%let pri_nom_join_present =0;

/*Assigning the libref pointing to the folder containing the aggregate tables 
to the global variable */
%let datalibref = abtagg;
%global cus_prev_join_table acc_prev_join_table appl_prev_join_table;

/*Data step to assign values to the macro variables using symput */
data tmp_abt_plan;
	set tmp_var_table_flat end=L;

	retain appl_var_cnt acc_var_cnt ; 
	retain cus_var_cnt;
	retain cus_prev_join_table acc_prev_join_table appl_prev_join_table;
	/*Assign length to local data step variables */
	length cus_join acc_join acc_join_1 jh1_join jh2_join cus_join_1 $32000;

	/*List of variables whose values will be retained in next iterations */
	retain cus_join  cus_join_1 acc_join jh1_join jh2_join; 

	/*For application */
	Length appl_join appl_join_1 pri_appt_join jh1_appt_join pri_gur_join pri_nom_join $32000;
	retain  appl_join appl_join_1 pri_appt_join jh1_appt_join pri_gur_join pri_nom_join;
	/*End for application */

	/*Check for the table_key (Customer_rk, account_rk, jh1_customer_rk or jh2_customer_rk) value and
	accordingly proceed */
	/*Start here - CUSTOMER*/
	if UPCASE(table_key) = 'CUSTOMER_RK' then
	do;
		/*Check whether the table being joined is a left table */
		if is_left_table = 'Y' then do;
			cus_join = catx(' ', strip(cus_join), "&datalibref.." || strip(var_table_nm) , 
			"(in=cus_present rename=(", strip(rename_list), ") keep=CUSTOMER_RK ", strip(org_var_list), ")");
			cus_join=strip(cus_join);
			file cust_fl mod LRECL=3000;
			put "data abtscr.cust_join_0001; merge ";
			cus_prev_join_table = "abtscr.cust_join_0001";
			put cus_join;
		end;
		else do;
			cus_var_cnt = sum(cus_var_cnt, var_cnt);			
			cus_join_1 = catx(' ', "&datalibref.." || strip(var_table_nm) ,  
			"(rename=(", strip(rename_list), ")", byte(10), " keep=CUSTOMER_RK ", strip(org_var_list), ")");			
			cus_join_1=strip(cus_join_1);		
			file cust_fl mod LRECL=3000;			

			if join_cnt in (100, 200, 300, 400, 500, 600, 700, 800, 900, 1000, 1100, 1200) then do;					
				put "; by CUSTOMER_RK; if cus_present ; run;";
				prochold = catx(' ', "Proc sql; ", "create index customer_rk on ",  cus_prev_join_table, "( customer_rk ); quit; ");
				put prochold; 
				prochold = cats("data abtscr.cust_join_", put(join_cnt, z4.), "; merge ");
				put prochold;
				prochold = catx(' ', cus_prev_join_table, '(in=cus_present)');
				put prochold;			
				put cus_join_1;	
				cus_prev_join_table = cats("abtscr.cust_join_", put(join_cnt, z4.));
			end;
			else do;
				put cus_join_1;
			end;
		
		end;
	end;
	/*End here - CUSTOMER*/

	/*Start here - Joint holder-1 information, applicable only for ACCOUNT level ABT */
	else if UPCASE(table_key) = 'JH1_CUSTOMER_RK' then
	do;
		jh1_join = catx(' ', "&datalibref.." || var_table_nm , 
		"(rename=(CUSTOMER_RK = JH1_CUSTOMER_RK ", rename_list, ")", byte(10), " keep=CUSTOMER_RK ", 
		org_var_list, ")");	

		call symput('jh1_join_present', 1);	

		jh1_join = strip(jh1_join);
		file jh1_fl mod LRECL=3000;
		put jh1_join;
	end;
	/*End here - Joint holder-1*/

	/*Start here - Joint holder-2 information, applicable only for ACCOUNT level ABT */
	else if UPCASE(table_key) = 'JH2_CUSTOMER_RK' then
	do;
		jh2_join = catx(' ', "&datalibref.." || var_table_nm , 
		"(rename=(CUSTOMER_RK = JH2_CUSTOMER_RK ", rename_list, ")", byte(10), " keep=CUSTOMER_RK ", 
		org_var_list, ")");	

		call symput('jh2_join_present', 1);

		jh2_join = strip(jh2_join);
		file jh2_fl mod LRECL=3000;
		put jh2_join;
	end; 

	/*End here - Joint holder-2*/

	/*Start here - ACCOUNT*/
	else if UPCASE(table_key) = 'ACCOUNT_RK' then
	do;
		/*Check whether the table being joined is a left table */
		if is_left_table = 'Y' then 
			do;
			acc_join = catx(' ', acc_join, "&datalibref.." || var_table_nm , 
			"(in=acc_present rename= (PRI_CUSTOMER_RK = CUSTOMER_RK ", rename_list, ") keep=ACCOUNT_RK PRI_CUSTOMER_RK JH1_CUSTOMER_RK JH2_CUSTOMER_RK", org_var_list, ")");
		/*Check if rename is needed for PRI_CUSTOMER_RK = CUSTOMER_RK*/
			file acct_fl mod LRECL=3000;

			put "data abtscr.acc_join_0001; merge ";
			acc_prev_join_table = "abtscr.acc_join_0001";
			put acc_join;

			end;
		else do;
			acc_join_1 = catx(' ', "&datalibref.." || var_table_nm , 
			"(rename=(", rename_list, ")",  byte(10), " keep=ACCOUNT_RK", org_var_list, ")");		
			acc_join_1 = strip(acc_join_1);

			file acct_fl mod LRECL=3000;		

			if join_cnt in (100, 200, 300, 400, 500, 600, 700, 800, 900, 1000, 1100, 1200) then do;					
				put "; by ACCOUNT_RK; if acc_present ; run;";
				prochold = catx(' ', "Proc sql; ", "create index account_rk on ",  acc_prev_join_table, "( account_rk ); quit; ");
				put prochold; 
				prochold = cats("data abtscr.acc_join_", put(join_cnt, z4.), "; merge ");
				put prochold;
				prochold = catx(' ', acc_prev_join_table, '(in=acc_present)');
				put prochold;			
				put acc_join_1;	
				acc_prev_join_table = cats("abtscr.acc_join_", put(join_cnt, z4.));
			end;
			else do;
				put acc_join_1;
			end;

		end;
	end;

	/*End here - ACCOUNT */

	/*Check if the table_key is APPLICATION_RK, meaning APPLICATION related tables */
	else if UPCASE(table_key) = 'APPLICATION_RK' then
	do;
		/*Check whether the table being joined is a left table */
		if is_left_table = 'Y' then do;
			appl_join = catx(' ', strip(appl_join), "&datalibref.." || strip(var_table_nm) , 
			"(in=appl_present rename=(", strip(rename_list), ") keep=APPLICATION_RK PRI_APPLICANT_RK JH1_APPLICANT_RK PRI_GUR_APPLICANT_RK PRI_NOM_APPLICANT_RK CUSTOMER_RK", strip(org_var_list), ")");
		/*Check if rename is needed for PRI_CUSTOMER_RK = CUSTOMER_RK*/

			file appl_fl mod LRECL=3000;
			put "data abtscr.appl_join_0001; merge ";
			appl_prev_join_table = "abtscr.appl_join_0001";
			put appl_join;
		end;	
		else do;
			appl_join_1 = catx(' ', "&datalibref.." || strip(var_table_nm) , 
			"(rename=(", strip(rename_list), ")", byte(10), " keep=APPLICATION_RK", strip(org_var_list), ")");		

			appl_join_1=strip(appl_join_1);		
			file appl_fl mod LRECL=3000;			

			if join_cnt in (100, 200, 300, 400, 500, 600, 700, 800, 900, 1000, 1100, 1200) then do;					
				put "; by APPLICATION; if cus_present ; run;";
				prochold = catx(' ', "Proc sql; ", "create index application_rk on ",  appl_prev_join_table, "( application_rk ); quit; ");
				put prochold; 
				prochold = cats("data abtscr.appl_join_", put(join_cnt, z4.), "; merge ");
				put prochold;
				prochold = catx(' ', appl_prev_join_table, '(in=cus_present)');
				put prochold;			
				put appl_join_1;	
				appl_prev_join_table = cats("abtscr.appl_join_", put(join_cnt, z4.));
			end;
			else do;
				put appl_join_1;
			end;

		end;
			
	end;

	else if UPCASE(table_key) = 'PRI_APPLICANT_RK' then
	do;
		pri_appt_join = catx(' ', pri_appt_join, "&datalibref.." || strip(var_table_nm) , 
		"(rename=(APPLICANT_RK = PRI_APPLICANT_RK ", strip(rename_list), ")", byte(10), " keep=APPLICANT_RK ",  
		strip(org_var_list), ")");

		call symput('pri_appt_join_present', 1);	

		pri_appt_join = strip(pri_appt_join);
		file pa_fl mod LRECL=3000;
		put pri_appt_join;
	end;

	else if UPCASE(table_key) = 'JH1_APPLICANT_RK' then
	do;
		jh1_appt_join = catx(' ', jh1_appt_join, "&datalibref.." || strip(var_table_nm) , 
		"(rename=(APPLICANT_RK = JH1_APPLICANT_RK ", strip(rename_list), ")", byte(10), " keep=APPLICANT_RK ", 
		strip(org_var_list), ")");

		call symput('jh1_appt_join_present', 1);	

		jh1_appt_join = strip(jh1_appt_join);
		file ja1_fl mod LRECL=3000;
		put jh1_appt_join;
	end;

	else if UPCASE(table_key) = 'PRI_GUR_APPLICANT_RK' then
	do;
		pri_gur_join = catx(' ', pri_gur_join, "&datalibref.." || strip(var_table_nm) , 
		"(rename=(APPLICANT_RK = PRI_GUR_APPLICANT_RK ", strip(rename_list), ")", byte(10), " keep=APPLICANT_RK ", 
		strip(org_var_list), ")");

		call symput('pri_gur_join_present', 1);	

		pri_gur_join = strip(pri_gur_join);
		file pg_fl mod LRECL=3000;
		put pri_gur_join;
	end;

	else if UPCASE(table_key) = 'PRI_NOM_APPLICANT_RK' then
	do;
		pri_nom_join = catx(' ', pri_nom_join, "&datalibref.." || strip(var_table_nm) , 
		"(rename=(APPLICANT_RK = PRI_NOM_APPLICANT_RK ", strip(rename_list), ")", byte(10), " keep=APPLICANT_RK ", 
		strip(org_var_list), ")");

		call symput('pri_nom_join_present', 1);	

		pri_nom_join = strip(pri_nom_join);
		file pn_fl mod LRECL=3000;
		put pri_nom_join;
	end;

	/*End application */

	if L;
		/*For application related variables */
		call symput ('cus_prev_join_table', cus_prev_join_table);
		call symput ('acc_prev_join_table', acc_prev_join_table);
		call symput ('appl_prev_join_table', appl_prev_join_table);	
		/*End application related variables */
run;

%chk_error(&syserr.); /*Call the macro to check for errors in the previous step */

/*Perform following to pick customer level variables for the 
ACCOUNT level ABT*/
%if &abt_cat = ACCOUNT %then 
	%do;
		%let cus_abt=abtscr.cus_abt;

		%include cust_fl semi_col; 
		by CUSTOMER_RK; 
		if cus_present ; 
		run;

		data &cus_abt.;
		set &cus_prev_join_table.;
		run;
		%chk_error(&syserr.); /*Call the macro to check for errors in the previous step */

		proc sql; /*Creation of index on the key column, Customer_rk */
			create index customer_rk on &cus_abt. (customer_rk);
		quit;
		%chk_error(&sqlrc.); /*Call the macro to check for errors in the previous step */
	%end;
/*Perform following if the category of the ABT is CUSTOMER*/
%else %if &abt_cat = CUSTOMER %then
	%do;
		%let cus_abt=&abt_phy_table;
		%include cust_fl semi_col; 
		by CUSTOMER_RK; 
		if cus_present ; 
		run;

		data &abt_phy_table.;
		set &cus_prev_join_table.;
		run;	
		%chk_error(&syserr.); /*Call the macro to check for errors in the previous step */
	%end;

/*For the ACCOUNT level ABT perform the following*/
%if &abt_cat = ACCOUNT %then
%do;

	%include acct_fl semi_col;
	by ACCOUNT_RK; 
	if acc_present; 
	run;

	%if &jh1_join_present. = 1 %then
	%do;	
		proc sql; /*Creation of index on the key column, JH1_CUSTOMER_RK */
		create  index JH1_CUSTOMER_RK on &acc_prev_join_table. (JH1_CUSTOMER_RK);
		quit;
		%chk_error(&sqlrc.); /*Call the macro to check for errors in the previous step */

		/*Joint holder1 for account level abt starts here */
		data jh1_abt;
		merge 
		%include acc_abt jh1_fl semi_col; 
		by JH1_CUSTOMER_RK;
		if acc_present;
		run;
		%chk_error(&syserr.); /*Call the macro to check for errors in the previous step */

		%let next_table = jh1_abt;
	%end;
	%else %do;
		%let next_table = &acc_prev_join_table.;			
	%end;

	%if &jh2_join_present. = 1 %then
	%do;	
		proc sql; 
		create  index JH2_CUSTOMER_RK on &next_table. (JH2_CUSTOMER_RK);
		quit;
		%chk_error(&sqlrc.); /*Call the macro to check for errors in the previous step */

		/*Joint holder1 code ends here */

		/*Joint holder2 for account level abt starts here */
		data jh2_abt;
		merge 
		%include jh1_abt jh2_fl semi_col; 
		by JH2_CUSTOMER_RK;
		if acc_present;
		run;
		%chk_error(&syserr.); /*Call the macro to check for errors in the previous step */

		%let next_table = jh2_abt;
	%end;

	proc sql;
	create index customer_rk on &next_table. (customer_rk);
	quit;
	%chk_error(&sqlrc.); /*Call the macro to check for errors in the previous step */

	/*Final customer and account join. Applicable only for account level abt*/
	data &abt_phy_table.;
	merge &next_table. (in=acc_present) &cus_abt.;
	by customer_rk;
	if acc_present;
	run;
	%chk_error(&syserr.); /*Call the macro to check for errors in the previous step */
	/*End of customer and account join */
%end;

/*For application level abt peform the following */
%if &abt_cat = APPLICATION %then
%do;
	%include appl_fl semi_col;
	by APPLICATION_RK; 
	if appl_present ; 
	run;

	%if &pri_appt_join_present. = 1 %then
	%do;
		proc sql; /*Creation of index on the key column, JH1_CUSTOMER_RK */
		create  index PRI_APPLICANT_RK on &appl_prev_join_table. (PRI_APPLICANT_RK);
		quit;

		%chk_error(&sqlrc.); /*Call the macro to check for errors in the previous step */

		/*Primary applicant for application level abt starts here */
		data pa_abt;
		merge 
		%include appl_abt pa_fl semi_col; 
		by PRI_APPLICANT_RK;
		if appl_present;
		run;
		%chk_error(&syserr.); /*Call the macro to check for errors in the previous step */
		
		%let next_table = pa_abt;	
	%end;
	%else %do;
		%let next_table = &appl_prev_join_table.;			
	%end;

	%if &jh1_appt_join_present. = 1 %then
	%do;	
		proc sql; 
		create  index JH1_APPLICANT_RK on &next_table. (JH1_APPLICANT_RK);
		quit;
		%chk_error(&sqlrc.); /*Call the macro to check for errors in the previous step */
	
		/*Joint applicant-1 for application level abt starts here */
		data jh1_appt_abt;
		merge 
		%include pa_abt ja1_fl semi_col; 
		by JH1_APPLICANT_RK;
		if appl_present;
		run;
		%chk_error(&syserr.); /*Call the macro to check for errors in the previous step */
		%let next_table = jh2_abt;
	%end;

	%if &pri_gur_join_present. = 1 %then
	%do;	
		proc sql; 
		create  index PRI_GUR_APPLICANT_RK on &next_table. (PRI_GUR_APPLICANT_RK);
		quit;
		%chk_error(&sqlrc.); /*Call the macro to check for errors in the previous step */
	
		/*Joint applicant-1 for application level abt starts here */
		data pri_gur_abt;
		merge 
		%include pa_abt pg_fl semi_col; 
		by PRI_GUR_APPLICANT_RK;
		if appl_present;
		run;
		%chk_error(&syserr.); /*Call the macro to check for errors in the previous step */
		%let next_table = pri_gur_abt;
	%end;

	%if &pri_nom_join_present. = 1 %then
	%do;	
		proc sql; 
		create  index PRI_NOM_APPLICANT_RK on &next_table. (PRI_NOM_APPLICANT_RK);
		quit;
		%chk_error(&sqlrc.); /*Call the macro to check for errors in the previous step */
	
		/*Joint applicant-1 for application level abt starts here */
		data pri_nom_abt;
		merge 
		%include pa_abt pn_fl semi_col; 
		by PRI_NOM_APPLICANT_RK;
		if appl_present;
		run;
		%chk_error(&syserr.); /*Call the macro to check for errors in the previous step */
		%let next_table = pri_nom_abt;
	%end;

	proc sql;
	create index customer_rk on &next_table. (customer_rk);
	quit;
	%chk_error(&sqlrc.); /*Call the macro to check for errors in the previous step */

	data &abt_phy_table.;
	merge &next_table. (in=acc_present) &cus_abt.;
	by customer_rk;
	if acc_present;
	run;

%end;
/*End for application */

%if &create_error_cd. > 0 %then 
	%do;		
		%let error_code=ERROR; /*error_code variables is defined in the calling macro (build_abt) macro*/
		%put 'Macro: Create_abt, ended with ***errors***';
	%end; 
%else %do;
	%put 'Macro: Create_abt, ended ***successfully***';
%end;

%mend create_pool_abt;


