
/********************************************************************************************
       Module:  Model Attribute 

     Function:  This stored process generates the HTML report displaying the
				weight of evidence table for the Variable selected in the calling stored process
				stored process (model_in_var).

      Authors:  BIS Team
         Date:  05 April 2006
          SAS:  9.1
    Called-by:	Stored Process model_attrib
				
        Calls:  Calls the following Stored Process
					1. Reporting		 (when Reporting link is clicked)
					2. mon_model_inputs	 (when Monitoring Model Inputs link is clicked)
					3. model_in_var    	 (when Select Variable link is clicked)

				Calls the following Macros
					1. generate_feed_mip macro for obtaining the required feed.
					2. CreateTable macro for craeting the cumulative and Proportion 
					   table with the out table of generate_feed_mip macro.
					3. graph_line_bar macro for generating the graph.
					4. draw_table macro for drawing the output table.

Datasets used:  No input datasets required for processing of the stored process
 
        Logic:  1. All inputs to the stored process are accepted as global parameters.
				2. Standards
					a. Naming of data set which are input to and output from macro using
						<prod_type_code><model_key><time_key>Extension as per requirement
						i.e.		MTG           100          1036     pool
							as MTG1001036pool.
					b. Setting the default values for where_measure, where_feed and
						feed_for. where_feed and feed_for is passed as parameter(infilter
						& feed_for) to the generate_feed_mip macro, and where_measure is 
						passed as parameter to the feed_measure_mip macro.
					c.	Naming the graphs using timestamp and two letters for  
						identifying the graph.
				3. Call the macro generate_feed_mip for obtaining the required feed.
				4. calls the CreateTable macro for craeting the cumulative and Proportion 
					   table with the out table of generate_feed_mip macro.
				5. Call the  graph_line_bar macro for generating the graph.
			    6. draw_table macro for drawing the output table.
			    7. Generate the HTML using streaming webout.
					a. Provide hidden textboxes for all output parameters so that the 
						values are easily submitted to the next page. 
					b. Provide javascript functions for the links on top of the page
						and for edit and reset buttons.
				
   Parameters:
			INPUT 
				prod_type_desc		:   Product Type Description (e.g., Credit Card,
										Mortgage, Loan, Core)
		        prod_type_code		:   Product Type Code (e.g., CCD, MTG, LON, COR)
				model_type_desc		:	Analytical Model Type Description 
										(e.g., PD Approvals, PD Ongoing, LGD, CCF)
		        model_type_code   	:   Analytical Model Type Code (e.g., PD Approvals,
										PD Ongoing, LGD, CCF)
		        model_measure_type	:   Model type code (MIP) for referring the models
										for model input reports in measure_dim.
				statistic           :   Measure name(Information Value and Other Statistics)
				model				:	The selected model (e.g., PD MODEL 1).		
				model_key			:	The surrogate key for the selected model.
				period				:	The selected period (month and year)(Eg DEC05 JAN06).
				time_key			:	The surrogate key for selected period.
				variable			:	The selected variable (e.g., Variable 1)
				variable_key		: 	The surrogate key for selected variable (e.g., 1)
                table				: 	The table which is to be ploted, the name for that data
										set is given.
				prg_name			:	The program name, for calling the report, which is
										picked from program_nm column of dim.measure_dim.
				outcome_period		:	The target period in months.
				elapsed_time		:	The time elapsed.
				
			OUTPUT
				prod_type_desc		:   Product Type Description (e.g., Credit Card,
										Mortgage, Loan, Core)
		        prod_type_code		:   Product Type Code (e.g., CCD, MTG, LON, COR)
				model_type_desc		:	Analytical Model Type Description 
										(e.g., PD Approvals, PD Ongoing, LGD, CCF)
		        model_type_code   	:   Analytical Model Type Code (e.g., PD Approvals,
										PD Ongoing, LGD, CCF)
		        model_measure_type	:   Model type code (MIP) for referring the models
										for model input reports in measure_dim.
				statistic           :   Measure name(Information Value and Other Statistics)
				model				:	The selected model (e.g. PD MODEL 1).		
				model_key			:	The surrogate key for the selected model.
				period				:	The selected period (month and year)(Eg DEC05 JAN06).
				time_key			:	The surrogate key for selected period.
				variable			:	The selected variable (Eg. Variable 1)
				variable_key		: 	The surrogate key for selected variable (Eg. 1)
                table				: 	The table which is to be ploted, the name for that data
										set is given.
				prg_name			:	The program name, for calling the report, which is
										picked from program_nm column of dim.measure_dim.
				outcome_period		:	The target period in months.
				elapsed_time		:	The time elapsed.
********************************************************************************************/
/* Global variable declaration */
goptions reset=all;
/* CS4.3 HF2 */
options symbolgen mlogic mprint MVARSIZE=1000;

%global prod_type_desc prod_type_code model_type_code model_measure_type model model_key
		period time_key variable variable_key statistic table prg_name 
		outcome_period elapsed_time model_type_desc;
/**********Initially default value of table is taken for cumulative plot***************/
 

data _null_;
	if "&table"="" then call symput('table','Attrib_prop');
run;
option mlogic mprint;
%macro macro_val_check;
%if "&prod_type_desc" ne "" %then
%let prod_type_desc=%str(%bquote(%sysfunc(ktrim(%sysfunc(kleft(&prod_type_desc))))));
%if "&prod_type_code" ne "" %then
%let prod_type_code=%sysfunc(ktrim(%sysfunc(kleft(&prod_type_code))));
%if "&model_type_code" ne "" %then
%let model_type_code=%sysfunc(ktrim(%sysfunc(kleft(&model_type_code))));
%if "&model_measure_type" ne "" %then
%let model_measure_type=%sysfunc(ktrim(%sysfunc(kleft(&model_measure_type))));
%if "&model" ne "" %then
%let model=%str(%bquote(%sysfunc(ktrim(%sysfunc(kleft(&model))))));
%if "&model_key" ne "" %then
%let model_key=%sysfunc(ktrim(%sysfunc(kleft(&model_key))));
%if "&period" ne "" %then
%let period=%str(%bquote(%sysfunc(ktrim(%sysfunc(kleft(&period))))));
%if "&time_key" ne "" %then
%let time_key=%sysfunc(ktrim(%sysfunc(kleft(&time_key))));
%if "&variable" ne "" %then
%let variable=%str(%bquote(%sysfunc(ktrim(%sysfunc(kleft(&variable))))));
%if "&variable_key" ne "" %then
%let variable_key=%str(%bquote(%sysfunc(ktrim(%sysfunc(kleft(&variable_key))))));
%if "&statistic" ne "" %then
%let statistic=%str(%bquote(%sysfunc(ktrim(%sysfunc(kleft(&statistic))))));
%if "&prg_name" ne "" %then
%let prg_name=%str(%sysfunc(ktrim(%sysfunc(kleft(&prg_name)))));
%if "&variable" ne "" %then
%let variable=%str(%bquote(%sysfunc(ktrim(%sysfunc(kleft(&variable))))));
%if "&model_type_desc" ne "" %then
%let model_type_desc=%str(%sysfunc(ktrim(%sysfunc(kleft(&model_type_desc)))));
%if "&outcome_period" ne "" %then
%let outcome_period=%str(%sysfunc(ktrim(%sysfunc(kleft(&outcome_period)))));
%if "&elapsed_time" ne "" %then
%let elapsed_time=%str(%sysfunc(ktrim(%sysfunc(kleft(&elapsed_time)))));
/*************/
%mend;
%macro_val_check
/*************/
%let ds_nme=%sysfunc(ktrim(%sysfunc(kleft(&table))));

%let out_lib=;
%debug_lib_path;

%let out_mip=%sysfunc(ktrim(%sysfunc(kleft(&prod_type_code.&model_key.&time_key.pool))));
%let out_acc_mip=%sysfunc(ktrim(%sysfunc(kleft(&prod_type_code.&model_key.&time_key.account))));
%let in_stat_ot=%sysfunc(ktrim(%sysfunc(kleft(&prod_type_code.&model_key.&time_key.sei_in))));
%let gname=;
%let data_set=%sysfunc(ktrim(%sysfunc(kleft(&table))));

/* Setting values for feed_for and where_clauses*/
%let where_feed=;
%let where_measure=;
data _null_;

/* Setting the feed_for depending on the analytical model type.
	This is passed as parameter to generate_feed_mip */
	if ktrim(kleft("&model_type_code"))=&PD_APP_MODEL then
    	call symput('feed_for',"&FEED_FOR_APPLPD");
	else if ktrim(kleft("&model_type_code"))=&PD_ONG_MODEL then
	    call symput('feed_for',"&FEED_FOR_PD");
	else if ktrim(kleft("&model_type_code"))=&LGD_MODEL then
        call symput('feed_for',"&FEED_FOR_LGD");
	else if ktrim(kleft("&model_type_code"))=&LGD_APP_MODEL then
        call symput('feed_for',"&FEED_FOR_APPLLGD");
	else if ktrim(kleft("&model_type_code"))=&CCF_MODEL then
        call symput('feed_for',"&FEED_FOR_CCF");

/* Setting the where clause for the feed_measure_mip macro */
	call symput('where_measure','where ANALYTICAL_MODEL_DIM.MODEL_PRODUCT_TYPE_CD="&prod_type_code" and ANALYTICAL_MODEL_DIM.MODEL_SK=&model_key and SCORE_CARD_VARIABLE_FACT.VARIABLE_SK=&variable_key');

/* Setting the where clause for the generate_feed_mip macro */
call symput('where_feed','1');
run;
/******************/
/* All graph options */
    /* Setting the graph name */
    /* Calling graph_options macro */
data _NULL_;
	name=put(time(),mmss8.1);
	name1=kscan(name,1,":.");
	name2=kscan(name,2,":.");
	name3=kscan(name,3,":.");
	name4="ma"||ktrim(kleft(name1))||ktrim(kleft(name2))||ktrim(kleft(name3));
	call symput('gname1',name4);
run;
%let name1=%sysfunc(ktrim(%sysfunc(kleft(&gname1))));


data _null_;
file  _webout&webout_options;
	put '<!DOCTYPE HTML PUBLIC "-//W3C//DTD HTML 4.01 Transitional//EN"';
	put '"http://www.w3.org/TR/html4/loose.dtd">';
	put '<html>';
	put '<head>';
/*I18N-scnhuh-20080418-1023*/
/*from iso-8859-1 to utf-8*/
	put '<meta http-equiv="Content-Type" content="text/html; charset=utf-8">';
/*I18N-scnhuh-20080418-1023*/	
	put '<title>'; 
	put "&statistic" @;
	put'</title>'@;
	put '<link href="SASTheme_default/themes/default/styles/default.css" rel="stylesheet" type="text/css">';
	put '<link href="/SASCSReports/styles/default.css" rel="stylesheet" type="text/css">';
	put '<style type="text/css">';
	put '<!--';
	put '.style2 {font-size: small}';
	put '-->';
	put '</style>';
	put '<script language="JavaScript" type="text/JavaScript">';
	/*Checking for missing global parameters*/
		if "&prod_type_desc" eq %str("") then 
	do;
		put 'alert("'@;
		put "%sysfunc(sasmsg(smd_ds.bismsg,crs.model_attrib_event.alert_error_put_prod_type_desc.1, noquote))"@;
		put'");';
	end;
	else if "&prod_type_code" eq %str("") then 
	do;
		put 'alert("'@;
		put "%sysfunc(sasmsg(smd_ds.bismsg,crs.model_attrib_event.alert_error_put_prod_type_desc.1, noquote))"@;
		put '");';
	end;
	else if "&model_type_code" eq %str("") then 
	do;
		put 'alert("'@;
		put "%sysfunc(sasmsg(smd_ds.bismsg,crs.model_attrib_event.alert_error_put_model_type_cd.1, noquote))"@;
		put '");';
	end;
	else if "&sel_model" eq %str("") then 
	do;
		put 'alert("'@;
		put "%sysfunc(sasmsg(smd_ds.bismsg,crs.model_attrib_event.alert_error_put_select_model.1, noquote))"@;
		put '");';
	end;
	else if "&sel_model_key" eq %str("") then 
	do;
		put 'alert("'@;
		put "%sysfunc(sasmsg(smd_ds.bismsg,crs.model_attrib_event.alert_error_put_select_model_key.1, noquote))"@;
		put '");';
	end;
	else if "&period" eq %str("") then 
	do;
		put 'alert("'@;
		put "%sysfunc(sasmsg(smd_ds.bismsg,crs.model_attrib_event.alert_error_put_period.1, noquote))"@;
		put '");';
	end;
	else if "&time_key" eq %str("") then 
	do;
		put 'alert("'@;
		put "%sysfunc(sasmsg(smd_ds.bismsg,crs.model_attrib_event.alert_error_put_time_key.1, noquote))"@;
		put '");';
	end;


/* Calls the Reporting stored process if link is clicked */
	put 'function Link1() {';
		put "form1._program.value=&CS_REPORTING";
		put 'form1.submit()';
	put '}';

/* Calls the mon_model_inputs stored process if link is clicked */
	put 'function Link2() {';
		put "form1._program.value=&CS_MON_MDL_IP";
		put 'form1.submit()';
	put '}';

/* Calls the model_in_var stored process if link is clicked */
	put 'function Link3() {';
		put "form1._program.value=&CS_VAR_LVL_DB";
		put 'form1.submit()';
	put '}';
/*********************/

	/*Function savepage() for saving the page to disk */
	%savepage;
	/*********savepage() ends here*************/

	/*Function printpage() for printing the page to a printer or to a pdf file*/
	%printpage;
	/*********printpage() ends here*************/

	put 'function assign_to_dist(val){';
		put 'form1.table.value=val';
		put 'form1.submit()';
	put '}';

	put '</script>';
	put '</head>';

	put '<body><form name="form1" method="post" action="/SASStoredProcess/do">';
	put '<input type="hidden" name="_program" VALUE="'@;
	put "&prg_name"@;
	put '">';

/* Hidden textboxes to hold the values for the program name and the output paremeters 
	to pass the values to the next Stored Process called */
	prod_type_desc=symget("prod_type_desc");
	put '<input type="hidden" name="prod_type_desc" value="' @;
	put prod_type_desc;
	put '">';
	prod_type_code=symget("prod_type_code");
	put '<input type="hidden" name="prod_type_code" value="' @;
	put prod_type_code;
	put '">';
	model_type_code=symget("model_type_code");
	put '<input type="hidden" name="model_type_code" value="' @;
	put model_type_code;
	put '">';
	model_measure_type=symget("model_measure_type");
	put '<input type="hidden" name="model_measure_type" value="' @;
	put model_measure_type;
	put '">';
	model=symget("model");
	put '<input type="hidden" name="model" value="' @;
	put model;
	put '">';
	model_key=symget("model_key");
	put '<input type="hidden" name="model_key" value="' @;
	put model_key;
	put '">';
	period=symget("period");
	put '<input type="hidden" name="period" value="' @;
	put period;
	put '">';
	time_key=symget("time_key");
	put '<input type="hidden" name="time_key" value="' @;
	put time_key;
	put '">';
	variable=symget("variable");
	put '<input type="hidden" name="variable" value="' @;
	put variable;
	put '">';
	variable_key=symget("variable_key");
	put '<input type="hidden" name="variable_key" value="' @;
	put variable_key;
	put '">';
	statistic=symget("statistic");
	put '<input type="hidden" name="statistic" value="' @;
	put statistic;
	put '">';
	table=symget("table");
	put '<input type="hidden" name="table" value="' @;
	put table;
	put '">';

	prg_name=symget("prg_name");
	put '<input type="hidden" name="prg_name" value="' @;
	put prg_name;
	put '">';
    
	outcome_period=symget("outcome_period");
	put '<input type="hidden" name="outcome_period" value="' @;
	put outcome_period;
	put '">'; 
	elapsed_time=symget("elapsed_time");
	put '<input type="hidden" name="elapsed_time" value="' @;
	put elapsed_time;
	put '">'; 
	model_type_desc=symget("model_type_desc");
	put '<input type="hidden" name="model_type_desc" value="' @;
	put model_type_desc;
	put '">';
run;

/*Calls the macro generate_feed_mip for obtaining the required feed by passing
	the following parameters
	1. in_filter		: Where clause
	2. out_lib_nm		: Library name where the output feed will be created. 
	3. out_table_nm_pool: The table name for pool level feed
	4. out_table_nm_acct: The table name for account/application level feed
	5. feed_for			: Possible values are PD, LGD, CCF, APPLPD, APPLLGD. This macro
							parameter decides whether estimated pd/lgd/ccf has to calculated 
							at account level or application level 
	6. var				: variable_key that is passed from the calling stored process
							(model_in_var)
	7. model_time_key  	: Contains the concatenated values of model and time in the
							format _<model_sk>_<time_sk>. This is used to identify
							which fact table should be considered while generating 
							the feed.
	8. product_type_code	: This is the selected product type code (E.G. MTG, LON).
*/

option mprint nomlogic;
%let model_time=_%sysfunc(ktrim(%sysfunc(kleft(&model_key.))))_%sysfunc(ktrim(%sysfunc(kleft(&time_key.))));



%generate_feed_mip(in_filter=&where_feed, out_lib_nm=&out_lib, out_table_nm_pool=&out_mip, 
					out_table_nm_acct=&out_acc_mip, feed_for=&feed_for, var=&variable_key,
					model_time_key=&model_time, product_type_code=&prod_type_code);


 
%let log_name=;
data _NULL_;
	call symput('log_name',"&CS_DEBUG_PATH./&out_mip."||".log");
run;

%debug_log_file(log_file_nm=&log_name);

%macro createtable(ds=,atb_nm1=,col_id=,col_act=,col_dev=,atb_lbl=,cl_nm=);
%let sqlstr=; 
%let token=;
data _null_;
	call symput ('b',count("&atb_nm1","#"));	
run;

%let end=%eval(&b+1);

%do i = 1 %to &end;
	%let token =  %sysfunc(kscan(&atb_nm1,&i,#));

	data &out_lib.._&token;
		set &ds;
		where &cl_nm=&token;
	run;

	proc sort data=&out_lib.._&token out=&out_lib.._&token._1 nodupkey;
		by &col_id;
	quit;

	proc transpose data=&out_lib.._&token._1 
		out=&out_lib.._&token._2;
		id  &cl_nm;
		by &col_id;
		run;
	quit;

	data &out_lib.._&token._2;
		set &out_lib.._&token._2;
		if kupcase(_NAME_)=kupcase("&col_id") or kupcase(_NAME_)=kupcase("&col_act") or
			kupcase(_NAME_)=kupcase("&col_dev");
	run;
%end;

data &out_lib..final;
	set &out_lib.._&token._2;
run;

%do for_merge_cnt = 1 %to &end;
	%let token =%sysfunc(kscan(&atb_nm1,&for_merge_cnt,#));

	data &out_lib..final;
	   merge &out_lib..final &out_lib.._&token._2;
	   by &col_id;
	run;
%end;

%let datstep=%str(data &out_lib..attrib; merge );
%do i = 1 %to 2;
	%if &i=1 %then %do;
		%let col=&col_act;
		%let suffix=act;
	%end;
	%else %do;
		%let col=&col_dev;
		%let suffix=dev;
	%end;
	%let sqlstr=create table &out_lib..graph_&suffix as select &col_id, ;
	%do for_merge_cnt = 1 %to &end;
		%let token =%sysfunc(kscan(&atb_nm1,&for_merge_cnt,#));
		%put count=&for_merge_cnt b=&end;
		%if &for_merge_cnt ne &end %then
			%let sqlstr=%str(&sqlstr)%str( )%str(_&token as _&token.&suffix.,);
		%else
			%let sqlstr=%str(&sqlstr)%str( )%str(_&token as _&token.&suffix. from &out_lib..final where kupcase(_NAME_)=kupcase("&col"));
	%end;
	%let sqlstr = %str(proc sql;) &sqlstr%str(;) %str(quit;);
	&sqlstr;
	%let datstep=%trim(%left(&datstep)) %str(&out_lib..graph_&suffix);
%end;
%let datstep=%trim(%left(&datstep))%str(;) %str(by &col_id;) %str(run;);	
&datstep;/*********Here we create a data step that separate different 
				  attribute according to development and actual accounts ******************/

/* Cumulative  & Proportion Tables */
%let cumm1=;
%let cumm2=%str(if last then do;);
%let prop1=;
%let prop2=;
%do for_cummulative_cnt= 1 %to &end;
	%let token =%sysfunc(kscan(&atb_nm1,&for_cummulative_cnt,#));
	%let atb_lbl1 =%sysfunc(kscan(&atb_lbl,&for_cummulative_cnt,#));

	%do i=1 %to 2;
		%if &i=1 %then %do;
			%let col=&col_act;
			%let suffix=act;
			%let suffix1=_;/****This is used to put name below graph**************/
			 /*I18N-scnjih-20080424-1444*/
			/*%let lbl=Actual;*/
			%let lbl=%sysfunc(sasmsg(smd_ds.bismsg,model_attrib.sas.5, noquote));
			/*I18N-scnjih-20080424-1444*/
		%end;
		%else %do;
			%let col=&col_dev;
			%let suffix=dev;
			%let suffix1=dev;
	/*I18N-scnjih-20080424-1444*/
			/*%let lbl=Development;*/
		%let lbl=%sysfunc(sasmsg(smd_ds.bismsg,model_attrib.sas.6, noquote));
	/*I18N-scnjih-20080424-1444*/
		%end;
	 	%let cumm1=%str(&cumm1) %str(_&token.&suffix._cum+_&token.&suffix;);
		%let cumm1=%str(&cumm1) %str(label _&token.&suffix._cum=&atb_lbl1.(&lbl););
		%let cumm1=%str(&cumm1) %str(drop _&token.&suffix;);
		%let cumm2=%str(&cumm2) %str(call symput("_&token.&suffix.",_&token.&suffix._cum););
		/* Start of CS4.3 HF2 */ 
		/*To remove the divide by 0 error*/
		%let prop1=%str(&prop1) %str(if )%trim(%left(&&_&token.&suffix))%str( eq 0 or )%trim(%left(&&_&token.&suffix))%str( eq . then );
		%let prop1=%str(&prop1) %str(_&token.&suffix._prop=0; else );
		/* End of CS4.3 HF2 */
		%let prop1=%str(&prop1) %str(_&token.&suffix._prop=_&token.&suffix/)%trim(%left(&&_&token.&suffix))%str(;);
		%let prop1=%str(&prop1) %str(label _&token.&suffix._prop=&atb_lbl1.(&lbl););
		%let prop1=%str(&prop1) %str(format)%str(_&token.&suffix._prop percent6.2 ;);
		%let prop1=%str(&prop1) %str(drop _&token.&suffix;);
		/* Start of CS4.3 HF2 */ 
		/*To remove the divide by 0 error*/
		%let prop2=%str(&prop2) %str(if )%trim(%left(&&_&token.&suffix))%str( eq 0 or )%trim(%left(&&_&token.&suffix))%str( eq . then );
		%let prop2=%str(&prop2) %str(_&token.&suffix._prop=0; else );
		/* End of CS4.3 HF2 */ 
		%let prop2=%str(&prop2) %str(_&token.&suffix._prop=_&token.&suffix/)%trim(%left(&&_&token.&suffix))%str(;);
		%let prop2=%str(&prop2) %str(label _&token.&suffix._prop=&atb_lbl1.(&lbl););
		%let prop2=%str(&prop2) %str(drop _&token.&suffix;);

	%end;
%end;
%let cumm2=%str(&cumm2) %str(end;);
%let sqlstr_cum = %str(data &out_lib..attrib_cumm;set &out_lib..attrib end=last;) &cumm1 &cumm2 %str( run;);
%let sqlstr_prop = %str(data &out_lib..attrib_prop;)%str( set &out_lib..attrib;) &prop1 %str( run;);
%let sqlstr_prop1 = %str(data &out_lib..attrib_prop_anno;)%str( set &out_lib..attrib;) &prop2 %str( run;);


&sqlstr_cum ;/****Here we create a data step where we do cumulating 
					and proportion for the development and actual account in to 
 					variable "sqlstr_cum" and "sqlstr_prop" ****/
&sqlstr_prop;

&sqlstr_prop1;
%mend;

%global atb_nm atb_lbl ; 

proc sql noprint;
   	select distinct VARIABLE_GROUP_NO,ATTR_NAME
   	into :atb_nm  separated by "#",:atb_lbl  separated by "#"  
    from &out_lib..&out_acc_mip;
quit;


/* Start of CS4.3 HF2 */ 

proc sql noprint;
create table &out_lib..ma_label 
as 
select distinct VARIABLE_GROUP_NO,ATTR_NAME
from &out_lib..&out_acc_mip ;
quit;
 
proc sql noprint;
create table &out_lib..&out_acc_mip.1 as
select * from
(select * from
	(select distinct var_name from &out_lib..&out_acc_mip),
	(select distinct attr_name,variable_group_no from &out_lib..&out_acc_mip),
	(select distinct from_score,to_score,score_range from &out_lib..&out_acc_mip )
) a
left join 
&out_lib..&out_acc_mip b
on a.var_name = b.var_name
and a.attr_name = b.attr_name
and a.variable_group_no =  b.variable_group_no
and a.from_score = b.from_score
and a.to_score = b.to_score
and a.score_range = b.score_range; 
quit;
/*data &out_lib..&out_acc_mip.1;*/
/*set &out_lib..&out_acc_mip;*/
/*run;*/
/* End of CS4.3 HF2 */ 
/*******relacing missing values by zero (0)************/
proc sql noprint;
	update  &out_lib..&out_acc_mip.1 set NO_OF_ACC_ACTUAL=0
	where NO_OF_ACC_ACTUAL is null  ;
	update &out_lib..&out_acc_mip.1  set  NO_OF_EVENTS_ACTUAL=0 
	where    NO_OF_EVENTS_ACTUAL is null;
	update &out_lib..&out_acc_mip.1  set  NO_OF_ACC_DEV=0 
	where  NO_OF_ACC_DEV is null;
	update &out_lib..&out_acc_mip.1  set  NO_OF_EVENTS_DEV=0 
	where    NO_OF_EVENTS_DEV is null;
quit;
/********************/
 

/****Macro create table parameter Passed
						1.ds=it is the dataset which is generated from 
							  macro generate_feed_mip.
					    2.atb_nm=This is a variable which contains the name of attribute
								 in the dataset which is out table of feed
					    3.col_id=Required for transposing the values inside the macro
						4.col_act=This is actual value colom of the dataset passed
					    5.col_dev=This is development value colom of the dataset passed 
					      **********/

%createtable(ds=&out_lib..&out_acc_mip.1, atb_nm1=&atb_nm, col_id=%str(FROM_SCORE),cl_nm=%str(VARIABLE_GROUP_NO), 
col_act=%str(NO_OF_ACC_ACTUAL), col_dev=%str(NO_OF_ACC_DEV),atb_lbl=&atb_nm);


/***********Selecting values for from score and score range******************/
Proc sql noprint;
	create table merge_range as 
	select Max(FROM_SCORE) as FROM_SCORE, Max(SCORE_RANGE) as SCORE_RANGE
	from &out_lib..&out_acc_mip
	group by FROM_SCORE;
quit; 

/***********To show the score range and giving label to score range******************/
data &out_lib..Attrib_cumm;
	merge  merge_range &out_lib..Attrib_cumm;
	by FROM_SCORE;
	 /*I18N-scnjih-20080423-1714*/
/*	label SCORE_RANGE='Score Range';*/
/*	label FROM_SCORE='From Score ';*/
		label SCORE_RANGE="%sysfunc( sasmsg(smd_ds.bismsg,model_attrib.sas.1, noquote))";
	  label FROM_SCORE="%sysfunc( sasmsg(smd_ds.bismsg,model_attrib.sas.2, noquote))";
	 /*I18N-scnjih-20080423-1714*/
	drop FROM_SCORE;
run;

/***********To show the score range and giving label to score range******************/
data &out_lib..Attrib_prop ;
	merge  merge_range &out_lib..Attrib_prop;
	by FROM_SCORE;
	 /*I18N-scnjih-20080423-1714*/
/*	label SCORE_RANGE='Score Range' ;*/
/*	label FROM_SCORE='From Score';*/
		label SCORE_RANGE="%sysfunc( sasmsg(smd_ds.bismsg,model_attrib.sas.3, noquote))" ;
		label FROM_SCORE="%sysfunc( sasmsg(smd_ds.bismsg,model_attrib.sas.4, noquote))";
	 /*I18N-scnjih-20080423-1714*/
run;
/* Start of CS4.3 HF2 */

proc sql noprint;
	select name ,label
	into :col_name separated by ",", :l_labels separated by "#"
	from sashelp.vcolumn
	where libname=kUPCASE("&out_lib.") and memname=kUPCASE("&ds_nme"); 
quit;
/* End of CS4.3 HF2 */
%let name_html=;

/* Start of CS4.3 HF2 */
proc sql noprint;
select VARIABLE_GROUP_NO,ATTR_NAME
into :l_grp_no separated by "#",:l_att_nm separated by "#"
from &out_lib..ma_label;
quit;
%macro labelgen;
	%let lab=;
	%let lab_tkn=;
	%let col_tkn=;
	data _null_;
		call symput ('cntlbl',count("&l_labels","#"));
		call symput ('cntgrp',count("&l_grp_no","#"));	
	run;
	%do i = 1 %to %eval(&cntlbl+1);
		%let lab_tkn =  %sysfunc(kscan("&l_labels",&i,"#"));
		%let col_tkn =  %sysfunc(kscan("&col_name",&i,","));
		%let grp_tkn =;
		%let att_tkn=;
		%do j=1 %to %eval(&cntgrp+1);
			%let grp_tkn =  %sysfunc(kscan("&l_grp_no",&j,"#"));
			%let att_tkn  =  %sysfunc(kscan("&l_att_nm",&j,"#"));
			%if %index(&lab_tkn,&grp_tkn) %then %do;;
				data _null_;
					l=tranwrd("&lab_tkn","&grp_tkn","&att_tkn");
					call symput('lab1',kleft(kright(l)));
				run;
				%let lab= &lab %str(label &col_tkn=) &lab1 %str(;);
				%goto break;
			%end;
		%end;
		%break:
	%end;
	%let lab2 = %str(data &out_lib..&ds_nme; set &out_lib..&ds_nme;) &lab %str( run;);
	&lab2;
%mend labelgen;
%labelgen;
/* End of CS4.3 HF2 */

/* Generates the dataset with measure names for the given model_type_cd and the called
	program name(the current stored process info_val)
	from the measure_dim dataset to be passed as a parameter to the feed_measure_mip macro*/
proc sql;
	create table &out_lib..&in_stat_ot as
	select measure_nm, help_file_nm, monotonic() as tot_count 
	from dim.measure_dim
	where kupcase(program_nm)=kupcase("&prg_name")
			and kupcase(model_type_cd)=kupcase("&model_measure_type");
/*	order by measure_nm;*/
quit;


data _null_;
	set &out_lib..&in_stat_ot;
	call symput('name_html',help_file_nm);
run;

%let cl_names=%nrquote(&col_name);
%let cl_labels=%str();


%macro graph_line_bar(out_lib=,ds=,V_bar=,grup_nm=);
options symbolgen mlogic mprint;
 
proc transpose data=&out_lib..&ds out=&out_lib..Attrib_prop_1;
	by &V_bar;
run;
/* Start of CS4.3 HF2 */
/* The % sign is included in the following code. Earlier this was a part of the bismsg key.*/

proc sql noprint;
	create  table &out_lib..Attrib_prop_2 as select * from &out_lib..Attrib_prop_1
	WHERE _LABEL_ LIKE ('%'||"%sysfunc(sasmsg(smd_ds.bismsg,crs.model_attrib.attrib_development.1, noquote))"||'%');

	create  table &out_lib..Attrib_prop_3 as select * from &out_lib..Attrib_prop_1
	WHERE _LABEL_ LIKE ('%'||"%sysfunc(sasmsg(smd_ds.bismsg,crs.model_attrib.attrib_actual.1, noquote))"||'%');
quit;

/* End of CS4.3 HF2 */

data &out_lib..Attrib_prop_cum3;
	set &out_lib..Attrib_prop_2;
	by &V_bar;
	if first.&V_bar then COL2=0;
	COL2+COL1;
run;
data &out_lib..Attrib_prop_31;
	set &out_lib..Attrib_prop_3;
	by &V_bar;
/*	if first.&V_bar then COL2=0;*/
/*	COL2+COL1;*/
run;

/* Start of CS4.3 HF2 */
/*data &out_lib..&out_acc_mip.1( rename=(ATTR_NAME=_LABEL_)); */
/*set &out_lib..&out_acc_mip;*/
/*run;*/
data &out_lib..&out_acc_mip.1( rename=(ATTR_NAME=_LABEL_)); 
set &out_lib..&out_acc_mip.1;
run;
/* End of CS4.3 HF2 */

data &out_lib..&out_acc_mip.1; 
set &out_lib..&out_acc_mip.1;

Feed_Label = _label_; *Inserted by JC - so that the feed table macro has valid descriptions;
_LABEL_=compress(tranwrd(_LABEL_, ",",""));

run;

proc sort data=&out_lib..&out_acc_mip.1;
by VARIABLE_GROUP_NO;
run;



data &out_lib..Attrib_prop_cum3; 
set &out_lib..Attrib_prop_cum3;
_LABEL_=compress(tranwrd(_LABEL_, "(%sysfunc(sasmsg(smd_ds.bismsg,model_attrib.sas.6, noquote)))",""));
/*_LABEL_=compress(tranwrd(_LABEL_, "and",""));*/
run;

data &out_lib..Attrib_prop_cum3(rename=(temp_var_grp_nm=_LABEL_));
drop _LABEL_;
set &out_lib..Attrib_prop_cum3;
temp_var_grp_nm=input(_LABEL_,best12.);
run;

proc sort data=&out_lib..Attrib_prop_cum3(rename=(_LABEL_=VARIABLE_GROUP_NO));
by VARIABLE_GROUP_NO;
run;

data &out_lib..Attrib_prop_cum2 (Keep=&V_bar COL1 _NAME_ &grup_nm _LABEL_);
	merge &out_lib..&out_acc_mip.1 &out_lib..Attrib_prop_cum3;
/*	by _LABEL_;*/
	by VARIABLE_GROUP_NO;

run;

proc sort data=&out_lib..Attrib_prop_cum2 out=&out_lib..out_account_1;
	by  VARIABLE_GROUP_NO;
quit;

proc sql noprint;/******We take minimum value of from score to get the plot drawn from initial point**/ 
	select min(&V_bar),max(&grup_nm) into: first_obs ,:max_no
	from &out_lib..Out_account_1;
quit;

%let color=;/*********Here we create dynamic color variable selection making them
								global variabels**********/
%do i=1 %to &max_no ;
        %let color=%str(&color)%str(color_symbol&i.);
%end;

%global &color;
%graph_options;
goptions xpixels= 1000 ypixels=700 htitle=5 htext=2 reset=legend;
%let strcol=;
%let footnote=;
%let pattern=;
%let color=;
%do i=1 %to &max_no ;
			%let atb_lbl1 =%scan("&atb_lbl",&i,"#");
    		%let strcol=%str(&strcol)%str(  if &grup_nm=)%trim(%left("&i"))
			 %sysfunc(ktrim(%sysfunc(kleft(then color=))))%str("&&color_symbol&i")%str(;);
		%let footnote=%str(&footnote)%str(footnote)%eval(&i+1)%str(   c=)%str("&&color_symbol&i")%str( ___ )%str(c=black  )%str(&atb_lbl1 )%str(;);
%end; 
	 /*I18N-scnjih-20080425-1320*/
/*%let footnote=%str(footnote1  Legend:  ;)%str(&footnote)%str(;);*/
/*%let footnote3=%str("Bar represents Actual samples and  Line represents Development samples")%str(;);*/
/*%let footnote3=%str("Bar represents Actual samples and  Line represents Development samples")%str(;);proc sql noprint;*/
%let footnote=%str(footnote1  )%sysfunc(sasmsg(smd_ds.bismsg,model_attrib.sas.8, noquote))%str(:  ;)%str(&footnote)%str(;);
%let footnote3=%sysfunc(sasmsg(smd_ds.bismsg,model_attrib.sas.9, noquote))%str(;);
	 /*I18N-scnjih-20080425-1320*/
	proc sql noprint;
	create table &out_lib..anno1 as 
	select * ,1 as fakeby
	from  &out_lib..Out_account_1 ;
quit; run;

data &out_lib..anno1(drop=COL1); 
set  &out_lib..anno1;
PLOT_VAL=COL1;
run;
data &out_lib..anno1; 
	length function color  $8 text $30;
	retain xsys ysys '2' color 'black' when 'a' size 4 ;
	set &out_lib..anno1 end=last; by fakeby;
	&strcol;/****This select values for  the colors for line come from above do loop*********/

	if &V_bar=&first_obs   then function='move'; else function='draw';
		midpoint=&V_bar; y=PLOT_VAL ; output;
	function='symbol';
	text='dot';size=.5; 
	midpoint=&V_bar	; y=PLOT_VAL ; output;
run;

 &footnote;/****This select values for  the colors and labels for footnote 
 							come from above do loop*********/

 footnote%eval(&max_no+3) &footnote3;
 ODS LISTING CLOSE;

/* legend1 label=('Actual') shape=bar(3,3);*/

%do i=1 %to &max_no ; /***Here we give the color for pattren for bar ***/
	%let pattern=%str(pattern&i)%str(  v=s c=)%str(&&color_symbol&i)%str(;);
	&pattern;
%end; 

axis1  /*minor=none */ label=(angle=90)label=(a=90 "%sysfunc(sasmsg(smd_ds.bismsg,crs.model_attrib_event.graph_axis1.1, noquote))") STYLE=1;
 axis2  label=( "%sysfunc(sasmsg(smd_ds.bismsg,crs.model_attrib_event.graph_axis2.1, noquote))");
 

proc sort data=&out_lib..anno1;
by   _LABEL_  ;
run;

data &out_lib..anno1(drop=PLOT_VAL); 
set  &out_lib..anno1;
by _LABEL_ ;
if first._LABEL_  then function='move';
if y eq .  then y=0;
/*PLOT_VAL=COL1;*/
/*if PLOT_VAL=. then PLOT_VAL=0;*/
run;


data &out_lib..Attrib_prop_31; 
set &out_lib..Attrib_prop_31;
if COL1=. then COL1=0;
run;



/*
 axis1  minor=none label=(angle=90)label=(a=90 "%sysfunc(sasmsg(smd_ds.bismsg,crs.model_attrib_event.graph_axis1.1, noquote))");
 axis2  label=( "%sysfunc(sasmsg(smd_ds.bismsg,crs.model_attrib_event.graph_axis2.1, noquote))");
 axis3   minor=none label=none ;*/

 proc gchart data=&out_lib..Attrib_prop_3 anno=&out_lib..anno1;
  vbar &V_bar		
	  	/  axis=axis1 maxis=axis2 coutline=black 
     autoref clipref cref=white width=5 space=6
     sumvar=COL1 discrete nolegend
     des="" name="&name1"
     subgroup=_NAME_;      
 	run;
 quit;
 ODS HTML CLOSE;
 ODS LISTING;
 
%mend;

/****Macro graph_line_bar parameter Passed
				1.Input Dataset which is ouput of feed
				2.Subgroup the values for which we want to do group ( for e.g. Attribute  name).
				3.Vertical bar which we see on graph.It is values for y axis
				4.Line which is to cumulated and to be drawn over bar.
				5.Sumvar values to be stack for the vertical bar graph.
				6.Group number to be values Corresponding to score range.
					                            *******************************************/

%graph_line_bar(out_lib=&out_lib.,ds=Attrib_prop_anno,V_bar=FROM_SCORE,grup_nm=VARIABLE_GROUP_NO);
 
%debug_log_web;

%let view_feed=&out_mip..html;
data _null_;
file  _webout&webout_options;
	name_html=symget("name_html");
	put'<script>';
		/**************Help File *********************/
	%helpfile(filename=&name_html);

		/*************feed Table*********************/
	put 'function feed_table(){';
		put'window.open("/SASCSReports/'@; 
		put "&view_feed"@; 
	put '")};';
			
		/*********************************************/
	put'</script>';

	put '<table width="100%"  border="0" cellpadding="0" cellspacing="0" bgcolor="#FAF8ED">';
	put '<tr>';
	put '<td align="left">';
	put '<table width="100%"  border="0" align="left" cellpadding="3" cellspacing="0">';
	put '<tr>';
	put '<td><table width="100%"  border="0" cellspacing="0" cellpadding="0">';
	put '<tr>';
	put '<td><span class="BreadCrumb">'@;
	put '<a href="javascript:Link1()">'@;
	put "%sysfunc(sasmsg(smd_ds.bismsg,crs.model_attrib_event.linnk_reporting.1, noquote))"@;
	put '</a> &gt; ';
	put '<a href="javascript:Link2()">'@;
	put "%sysfunc(sasmsg(smd_ds.bismsg,crs.model_attrib_event.linnk_mon_model_input.1, noquote))"@;
	put '</a> &gt; ';
	put '<a href="javascript:Link3()">'@;
	put "%sysfunc(sasmsg(smd_ds.bismsg,crs.model_attrib_event.linnk_sel_var.1, noquote))"@;
	put '</a> &gt;'@;
	put '</span><span class="BreadCrumb">'@;
	put "%sysfunc(sasmsg(smd_ds.bismsg,crs.model_attrib.linnk_model_attrib.1, noquote))"@;
	put'</span></td> ';

	/* To display SAS credit scoring as heading */
	put '<td width="215"><div align="right"><img src="/SASCSReports/images/CrBanner.gif" width="259" height="29"></div></td>';
	put '</tr>';
	/* Heading ends */
	put '</table><H2 align="left"><table width="100%"  border="0" cellspacing="0" cellpadding="0"><tr><td>';
	put "&statistic" @;
	put '</td>';
	if kupcase(&print) eq 'Y' then do;
		put '<td width=65><div align="center"><span class="LabelFont">';
		put '<a href="javascript:printpage()">';
		put '<img src="/SASCSReports/images/Print.gif" border="0"></a>'@;
		put "%sysfunc(sasmsg(smd_ds.bismsg,crs.report_print.1, noquote))"@;
		put '</div></td>';
	end;
	if kupcase(&save) eq 'Y' then do;
		put '<td width=50><div align="center"><span class="LabelFont">';
		put '<a href="javascript:enregistre()">';
		put '<img src="/SASCSReports/images/SaveFile.gif" border="0"></a>'@;
		put "%sysfunc(sasmsg(smd_ds.bismsg,crs.report_save.1, noquote))"@;
		put '</div></td>';
	end;
	if kupcase(&help) eq 'Y' then do;
		put '<td width=50><div align="center"><span class="LabelFont">';
		put '<a href="javascript:Info()">';
		put '<img src="/SASCSReports/images/Info.gif" border="0"></a>'@;
		put "%sysfunc(sasmsg(smd_ds.bismsg,crs.report_help.1, noquote))"@;
		put '</div></td>';
	end;
	put '</tr></table></H2>';
	put '</td></tr>';

	put '<tr>';
	put '<td align="left">';
	put '<p class="LabelFont">'@;
	put "%sysfunc(sasmsg(smd_ds.bismsg,crs.model_attrib_event.label_model_type.1, noquote))"@;
	put "&model_type_desc"@;
	put '</p>';
	put '<p class="LabelFont">'@;
	put "%sysfunc(sasmsg(smd_ds.bismsg,crs.model_attrib_event.label_product_type.1, noquote))"@;
	put "&prod_type_desc";
	put '</p> ';
	put '<p class="LabelFont">'@;
	put "%sysfunc(sasmsg(smd_ds.bismsg,crs.model_attrib_event.label_period.1, noquote))"@;
/*I18N-scnhuh-20080427-1455*/	
/* del one line, add two lines. For displaying in NLS format */	
/*	put "&period" @;*/
		Period_WEBUI=put(input("&period",&CS_TIME_PER_FMT.),&NLDATE_FMT.);
		put Period_WEBUI @;
/*I18N-scnhuh-20080427-1455*/		
	put '</p> ';
	put '<p class="LabelFont">'@;
	put "%sysfunc(sasmsg(smd_ds.bismsg,crs.model_attrib_event.label_model.1, noquote))"@;
	put "&model";
	put '</p> ';
	put '<p class="LabelFont">'@;
	put "%sysfunc(sasmsg(smd_ds.bismsg,crs.model_attrib_event.label_variable.1, noquote))"@;
	put "&variable";
	put '</p> ';

	/* Target period and elapsed time*/
	put '<p class="LabelFont">'@;
	put "%sysfunc(sasmsg(smd_ds.bismsg,crs.model_attrib_event.label_outcome_period.1, noquote))"@;
	put ': '@;
	put "&outcome_period" @;
	put '  '@;
	put "%sysfunc(sasmsg(smd_ds.bismsg,crs.model_attrib_event.label_months.1, noquote))"@;
	put '  '@;
	put "&elapsed_time" @;
	put '  '@;
	put "%sysfunc(sasmsg(smd_ds.bismsg,crs.model_attrib_event.label_month_elapsed.1, noquote))"@;
	put '</p>';

	/* Number of months of Historic data */
	if kupcase("&model_type_code") eq kupcase(&PD_APP_MODEL.) then do;
		put '<p class="LabelFont">'@;
		put "%sysfunc(sasmsg(smd_ds.bismsg,crs.pd_stored_proc_hist.label_historic_data.1, noquote))"@;
		if kupcase("&prod_type_code") eq kupcase(&MTG_PRD_TYPE.) then do;
			put "&PDA_MTG_HIST" @;
		end;
		if kupcase("&prod_type_code") eq kupcase(&LON_PRD_TYPE.) then do;
			put "&PDA_LON_HIST" @;
		end;
		if kupcase("&prod_type_code") eq kupcase(&COR_PRD_TYPE.) then do;
			put "&PDA_COR_HIST" @;
		end;
		if kupcase("&prod_type_code") eq kupcase(&CCD_PRD_TYPE.) then do;
			put "&PDA_CCD_HIST" @;
		end;
		put "%sysfunc(sasmsg(smd_ds.bismsg,crs.pd_stored_proc_month.label_months.1, noquote))"@;
		put '</p>';
	end;

	put '<table width="100%"   border="0" cellspacing="0" cellpadding="0">';
	put '<p class="LabelFont">&nbsp;</p><fieldset>';
	put '<legend><span class="style2"></span></legend>';
			/*****HERE YOU CAN PUT NAME FOR RADIO BUTTON********/						
	put '<p class="style2">';
	put '<input name="radiobutton" type="radio" value="Attrib_prop" onClick="javascript:assign_to_dist(this.value)"'@;

	if "&table" eq "Attrib_prop" then do;
		put ' checked="checked"'@;
	end;
/*put ' >Attribute Proportion by Score';*/
	put ' >'@;
	put "%sysfunc(sasmsg(smd_ds.bismsg,crs.model_attrib.radio_nm_attrib_score.1, noquote))"@;
	put '&nbsp;&nbsp;&nbsp;&nbsp;&nbsp; '; 
	put '<input name="radiobutton" type="radio" value="Attrib_cumm" onClick="javascript:assign_to_dist(this.value)"'@; 

	if "&table" eq "Attrib_cumm" then do;
		put ' checked="checked"'@;
	end;
/*put ' >Attribute Cumulative Population by Score</p>';*/
	put ' >'@;
	put "%sysfunc(sasmsg(smd_ds.bismsg,crs.model_attrib.radio_nm_attrib_population_score.1, noquote))"@;
	put '</p>';
	put '</fieldset>';
	put '</td>';
	put '</tr>';
	put '<p>&nbsp;&nbsp;</p>';
run;

/***Macro Draw table 
1.Input datas set
2.column name of passed data set,this is defined above as col_name where name of column 
  are provide this is  compulsary to be given by the user while defining col_names;
3.column lables of the datset ,this is defined as col_lables above this feild might be 
  empty for in that case  column lables should be there in the dataset	 	 
********************************/


%draw_table(ds=&out_lib..&ds_nme., col_names=&cl_names., col_labels=&cl_labels.);


data _null_;
file  _webout&webout_options;
	put '<p class=NoteFont>'@;
/*put '<strong>Note:</strong> All pools with no actual and development information will be ignored</p>';*/
	put '<strong>'@;
	put "%sysfunc(sasmsg(smd_ds.bismsg,crs.model_attrib_event.note_note.1, noquote))"@;
	put ':</strong>'@;
	put "%sysfunc(sasmsg(smd_ds.bismsg,crs.model_attrib_event.note_note1.1, noquote))"@;
	put '</p>';
	put '<tr>';
	put '<td width="50"><span class="LabelFont"></span></td>';
	put '</tr>';
	put '</table>';
	put '<tr>';
	put '<td align="left">';
	put '<p>';
	put '<H2 align="left">'@;
	put "%sysfunc(sasmsg(smd_ds.bismsg,crs.model_attrib_event.lable_attribute.1, noquote))"@;

	if  "&table" eq "Attrib_prop" then do;
		put '   ';
		put "%sysfunc(sasmsg(smd_ds.bismsg,crs.model_attrib.lable_prop_by_score.1, noquote))"@;
		put '</H2>';
/*		put ' Proportion  by Score</H2>';*/
	end;

	if "&table" eq "Attrib_cumm" then do;
		put '   ';
		put "%sysfunc(sasmsg(smd_ds.bismsg,crs.model_attrib.lable_cumm_prop_by_score.1, noquote))"@;
/*		put '</H2>';*/
/*		put 'cumulative Population by Score</H2>';*/
	end;

	put '</td>';
	put '</tr>';
	put '<tr><td><table width="100%"  border="0" cellspacing="0" cellpadding="0">';
	put '<tr>';
	put '<td width="49%" valign="top"><fieldset>';
	put '<legend><span class="style2"></span></legend>';
					
	put '<p><img src="/SASCSReports/'@;
	put "&name1";
	put '.gif" width="1000" height="700" ></p>';
	put '</fieldset></td>';
	put '<td width="2%">&nbsp;</td>';
	put '<td width="49%" valign="top">';

	put '</td>';
	put '</tr>';

	put '</tr> ';
	put '</table>';
	put '</td> ';
	put '</tr> ';
	put '<tr> ';
	put '<td height="32" bgcolor="#F1EACB">&nbsp;&nbsp;';
	put '<INPUT type=button class=mmhide_btn onClick="feed_table()" value="'@;
	put "%sysfunc(sasmsg(smd_ds.bismsg,crs.model_attrib_event.button_view_feed.1, noquote))"@;
	put '">';
	put '</td> ';
	put '</tr> ';
	put '</table> ';
	put '</form> ';
	put '</body> ';
	put '</html> ';
run;
 
/*******relacing missing values by zero (0)************/
proc sql noprint;
	update  &out_lib..&out_acc_mip.1 set NO_OF_ACC_ACTUAL=0
	where NO_OF_EVENTS_ACTUAL is null  ;
	update &out_lib..&out_acc_mip.1  set  NO_OF_EVENTS_ACTUAL=0 
	where   NO_OF_EVENTS_ACTUAL is null;
	update &out_lib..&out_acc_mip.1  set  NO_OF_ACC_DEV=0 
	where   NO_OF_ACC_DEV is null;
	update &out_lib..&out_acc_mip.1  set  NO_OF_EVENTS_DEV=0 
	where   NO_OF_EVENTS_DEV is null;
quit;
/********************/
/******macro feed_table   pass parameter  separated by #

		Input parameter 
		1.dt_st =Pass dataset name in string separated by #
		2.dt_nm=pass name you want to give to the table
		3.out_libout library  which is defined above
		        *****************************************************************/
 
 /*I18N-scnjih-20080424-1507*/
/*%let dt_nm=Attribute Feed;*/
%let dt_nm=%sysfunc(sasmsg(smd_ds.bismsg,model_attrib.sas.7, noquote));
 /*I18N-scnjih-20080424-1505*/
%let dt_st=&out_acc_mip.1;

proc sort data=&out_lib..&dt_st;
	by VARIABLE_GROUP_NO FROM_SCORE;
run;

data &out_lib..&dt_st(drop = feed_label);
	set &out_lib..&dt_st;
	_label_ = feed_label;
run;

%feed_table(ds=&dt_st,out_lib1=&out_lib.,data_name=&dt_nm,name_html=&view_feed);

goptions reset=all;
options nomprint;
 
