/*****************************************************************************************
  Module:  Misc_Report

  Function: This stored process creates the HTML screen Which is used to show the 
			Actual and Modeling values of different distance statistic and show 
			the overtime graph for that statistic which is selected from the drop down box 
			Graph will be shown only when the filter condition is 'no'.


  Authors:  BIS Team
     Date:  05 April 2006
      SAS:  9.1

Called-by:	 This stored process Misc_Report is called by the stored process test_levels.

    Calls:  Stored Process    
			1.Reporting		 (Reporting )
			2.mon_models     (Monitoring Models)  
			3.select_models  (Select Models) 
			4.test_levels    (Select Statistic)
			5.Misc_Report    (calls the same reports on click of reset button)
			6.filtering_criteria(when the Filter/Re-Pool button is clicked)
			7.Call to filter screen

			Macros
				a.	Macro feed_measure used to generate dataset for statistic overtime.
				b.	Macros Distance_stats, Kend_somers, Chisq are used to calculate the statistics. 
				c.	Macro Model_traffic is used to generate the traffic light for the actual 
					value of the calculated measure.
				d.	Statistic overtime macro plots the graph for the values statistic over time. 
				e.  Macro pool_technique is used to show the string, which will tell which
					Pooling technique used.
				f.  Macro Brier has been used to calculate Brier score using the output 
					of the generate feed macro.

Datasets used:  No Input dataset used.
 
        Logic:  1. All inputs to the stored process are accepted as global parameters. 
				2. Standards followed across all reports.
					a.	Naming of data set which are input to macro using using 
							<prod_type_code><sel_model_key><time_key> Extension as per requirement  
						eg.		Cor           106          1030     pool
							as Cor1061030pool.
					b.	Naming the graphs using timestamp and two letters for id for the graph.
					c.	Staring providing the Pooling technique is created as per the default 
						pooling technique or the dynamic pooling technique for printing on the 
						HTML screen.	
				3.	Creating HTML 
					a.	Validation for the different parameter which is to be passed to this 
						stored 	process .
					b.	Function JavaScript for links to be provided on top of report, and the 
						Function onchange for the combo box.
					c.	Hidden text box are made to collect different parameters, which will get 
						submitted to the store process provided on submit function.       
					d.	Data set used to display name, values and populate combo box.
					e.	Only when the filter condition is 'NO', the statistic overtime graph and 
						modeling values	will be displayed.
				
Parameters:  INPUT (From Report Screen when link is used for navigation):
		INPUT 
				prod_type_desc		:   Product Type Description (e.g., Credit Card,
										Mortgage, Loan, Core)
		        prod_type_code		:   Product Type Code (e.g., CCD, MTG, LON, COR)
				model_type_desc		:	Analytical Model Type Description 
										(e.g., PD Approvals, PD Ongoing, LGD, CCF)
		        model_type_code   	:   Analytical Model Type Code (e.g., PD Approvals, PD Ongoing,
										LGD, CCF)
		        include_exp_mdl		:   Information to include the expired models for selection of
										model from the traffic light dashboard.
				statistic           :   Measure name(e.g., Accuracy, Precision, Error Rate,
										Specificity, Sensitivity)
				model1				:	The first model if selected (Eg. PD MODEL 1).		
				model1_key			:	The surrogate key for the first selected model.
				model2				:	The  second model if  selected. (Eg. PD MODEL 2)
				model2_key			:	The surrogate key for the second selected model.
				sel_model			: 	Model selected on the Measure level dashboard screen.
				sel_model_key		:	Key of the selected model.
				period				:	The selected period (month and year)(Eg DEC05 JAN06).
				time_key			:	The surrogate key for selected period.
				filter				:	Used for displaying or hiding the modeling values and
										overtime graph.
				filter_clause		: 	Contains the selected business filter.
		        pd_score 			:	If null then shown  as DEFAULT stautus.
		 	    no_of_quantile      :	The range for dynamic pooling will be decided based on the 
								 	    quantile.Quantile ranges will be calculated based on the 
								 	    SCORE/PD/LGD/CCF of the scoring  population for the
										selected score period  
		  		range_interval      : 	Dynamic pooling based on the range specified.
										E.g. 100, 200 for SCORE and .2, .3 for PD.
				prg_name			:	The program name, for calling the report, which is
										picked from program_nm column of dim.measure_dim.
				outcome_period		:	The target period in months.
				elapsed_time		:	The time elapsed.
				
			OUTPUT
				prod_type_desc		:   Product Type Description (e.g., Credit Card,
										Mortgage, Loan, Core)
		        prod_type_code		:   Product Type Code (e.g., CCD, MTG, LON, COR)
				model_type_desc		:	Analytical Model Type Description 
										(e.g., PD Approvals, PD Ongoing, LGD, CCF)
		        model_type_code   	:   Analytical Model Type Code (e.g., PD Approvals, PD Ongoing,
										LGD, CCF)
		        include_exp_mdl		:   Information to include the expired models for selection of
										model from the traffic light dashboard.
				statistic           :   Measure name(e.g., Accuracy, Precision, Error Rate,
										Specificity, Sensitivity)
				model1				:	The first model if selected (Eg. PD MODEL 1).		
				model1_key			:	The surrogate key for the first selected model.
				model2				:	The  second model if  selected. (Eg. PD MODEL 2)
				model2_key			:	The surrogate key for the second selected model.
				sel_model			: 	Model selected on the Measure level dashboard screen.
				sel_model_key		:	Key of the selected model.
				period				:	The selected period (month and year)(Eg DEC05 JAN06).
				time_key			:	The surrogate key for selected period.
				filter				:	Used for displaying or hiding the modeling values and
										overtime graph.
				filter_clause		: 	Contains the selected business filter.
		        pd_score 			:	If null then shown  as DEFAULT stautus.
		 	    no_of_quantile      :	The range for dynamic pooling will be decided based on the 
								 	    quantile.Quantile ranges will be calculated based on the 
								 	    SCORE/PD/LGD/CCF of the scoring  population for the
										selected score period  
		  		range_interval      : 	Dynamic pooling based on the range specified.
										E.g. 100, 200 for SCORE and .2, .3 for PD.
				called_program		:	Passes the path of the current program(conf_matrix)
				prg_name			:	The program name, for calling the report, which is
										picked from program_nm column of dim.measure_dim.
				outcome_period		:	The target period in months.
				elapsed_time		:	The time elapsed.

******************************************************************************************/

goptions reset=all;
options nomprint;
/*****************************GLOBAL VARIABLE DECLERATION ***********************************/
%global prod_type_desc prod_type_code model_type_code include_exp_mdl model1 model1_key
		model2 model2_key period time_key filter filter_clause statistic
		pd_score range_interval no_of_quantile prg_name model_type_desc outcome_period 
		elapsed_time sel_model sel_model_key format_name;
  
options mlogic mprint;
/*%test_reports(stat_nm=%str(&statistic));*/

/*%test_reports_lgd(stat_nm=%str(&statistic));*/
    %let prod_type_desc=&prod_type_desc;
    %let prod_type_code=&prod_type_code;
    %let model_type_code=&model_type_code;
    %let model1=&model1;
    %let model1_key=&model1_key;
    %let model2=&model2;
    %let model2_key=&model2_key;
    %let sel_model=&sel_model;
    %let sel_model_key=&sel_model_key;
    %let period=&period;
    %let time_key=&time_key;
    %let filter_clause=&filter_clause;
    %let pd_score=&pd_score;
    %let prg_name=&prg_name;
    %let model_type_desc=&model_type_desc;
    %let outcome_period=&outcome_period;
    %let elapsed_time=&elapsed_time;
	%let statistic=%str(%bquote(%trim(%left(&statistic))));

%let out_lib=;
%debug_lib_path;

/*This macro outputs the format for the stattistics for combination of 
  product type code and the model type code.*/
%format_for_model_product(model_type_code_fm=&model_type_code,prod_type_code_fm=&prod_type_code)
/*This macro chnage the dataset name and hardcode it on the product type*/
%change_dataset_name

/**********************/
%let out_pool=%sysfunc(ktrim(%sysfunc(kleft(&prod_type_code.&sel_model_key.&time_key.pool))));
%let out_account=%sysfunc(ktrim(%sysfunc(kleft(&prod_type_code.&sel_model_key.&time_key.account))));
%let out_data_prep=%sysfunc(ktrim(%sysfunc(kleft(work.&prod_type_code.&sel_model_key.&time_key.data_prep))));
%let out_graph_ds=%sysfunc(ktrim(%sysfunc(kleft(work.&prod_type_code.&sel_model_key.&time_key.ar_graph))));
%let out_stat_ds=%sysfunc(ktrim(%sysfunc(kleft(work.&prod_type_code.&sel_model_key.&time_key.ar_stat))));
%let out_stat_ot=%sysfunc(ktrim(%sysfunc(kleft(&prod_type_code.&sel_model_key.&time_key.ar_ot))));
%let in_stat_ot=%sysfunc(ktrim(%sysfunc(kleft(&prod_type_code.&sel_model_key.&time_key.ar_in))));
%let prg_name=%str(%sysfunc(ktrim(%sysfunc(kleft(&prg_name)))));
%let model_type_desc=%str(%sysfunc(ktrim(%sysfunc(kleft(&model_type_desc)))));
%let outcome_period=%str(%sysfunc(ktrim(%sysfunc(kleft(&outcome_period)))));
%let elapsed_time=%str(%sysfunc(ktrim(%sysfunc(kleft(&elapsed_time)))));

/**************************WHERE CLAUSE***************************************/
/*   Creation of where_clauses */ 
%let where_feed=;
%let where_measure=;
%let feed_pd=;


data _NULL_;
    if ktrim(kleft("&statistic"))="" then
            	call symput('statistic',"%sysfunc(sasmsg(smd_ds.bismsg,crs.measure_nm.measure_nm_info.1, noquote))");

/* Setting value for filter depending on whether the filter_clause and pd_score has any
	value set.
		The filter_clause and pd_score value is getting passed from the Filter Screen
		(stored process FilteringCriteria)
		If the filter is NO then the modeling value and the statistic overtime graph
		is displayed else it is not displayed */

    if ktrim(kleft("&filter_clause"))="" and ktrim(kleft("&pd_score"))=""  then
                call symput('filter','NO');
	else
				call symput('filter','YES');

/* Setting the feed_pd depending on whether its an application model or not.
	This is passed as parameter to generate_feed */
	if ktrim(kleft("&model_type_code"))=&PD_APP_MODEL then
	            call symput('feed_pd',"&FEED_FOR_APPLPD");
	else
	            call symput('feed_pd',"&FEED_FOR_PD");



	call symput('where_measure','where ANALYTICAL_MODEL_DIM.MODEL_PRODUCT_TYPE_CD="&prod_type_code" 
							and ANALYTICAL_MODEL_DIM.MODEL_SK=&sel_model_key');
/* Setting the where clause for the generate_feed macro depending upon the value of the
		filter_clause*/ 
	if ktrim(kleft("&filter_clause"))="" then
		call symput('where_feed','where 1');
	else
		call symput('where_feed','where &filter_clause');
run;

/*******Setting the graph name by timestamp**************************/
 %let name=;
data _NULL_;
	name=put(time(),mmss8.1);
	name1=kscan(name,1,":.");
	name2=kscan(name,2,":.");
	name3=kscan(name,3,":.");
	name4=ktrim(kleft(name1))||ktrim(kleft(name2))||ktrim(kleft(name3));
	call symput('name',name4);
run;

/********Macro graph_options NO parameter passed 
		 color_symbol1 and color_symbol2 is used 
		 for putting color for that graph            ************/
%let graph_name=%sysfunc(ktrim(%sysfunc(kleft(&name))));
%let color_symbol1=;
%let color_symbol2=;
%graph_options;

/* All data _null_ statements to create the html */
data _null_;
file _webout&webout_options;
	rep="%sysfunc(sasmsg(smd_ds.bismsg,crs.measure_nm.measure_nm_info.1, noquote))";
	format rep &format_name..;
	put'<!DOCTYPE HTML PUBLIC "-//W3C//DTD HTML 4.01 Transitional//EN" ';
	put'"http://www.w3.org/TR/html4/loose.dtd"> ';
	put'<html> ';
	put'<head> ';
/*I18N-scnhuh-20080418-1023*/
/*from iso-8859-1 to utf-8*/
	put'<meta http-equiv="Content-Type" content="text/html; charset=utf-8"> ';
/*I18N-scnhuh-20080418-1023*/	
	put'<title>'@;
	put "%sysfunc(sasmsg(smd_ds.bismsg,crs.misc_report.title_misc_rep.1, noquote))"@;
	put '</title> ';
	put'<link href="/SASCSReports/styles/default.css"rel="stylesheet" type="text/css"> ';
	put'<link href="/SASCSReports/styles/default.css" type="text/css"> ';
	put'<style type="text/css"> ';
	put'<!-- ';
	put'.style2 {font-size: small} ';
	put'--> ';
	put'</style> ';
	/************************SCRITP STARTS******************************************/
	/************************WE ARE PASSING THE VALUES IN INDEX FORM**************/
	/************************COLLECTING IT IN THE HIDDEN TEXT BOX PARAMETER*******/
	put'<script language="JavaScript" type="text/JavaScript"> ';
	
	/*Functions for the links on top of the html page*/

	put 'function Link1() {';
		put "form1._program.value=&CS_REPORTING";
		put 'form1.submit()';
	put '}';

	put 'function Link2() {';
		put "form1._program.value=&CS_MON_MDL";
		put 'form1.submit()';
	put '}';

	put 'function Link3() {';
		put "form1._program.value=&CS_MDL_LVL_DB";
		put 'form1.submit()';
	put '}';

	put 'function Link4() {';
		put "form1._program.value=&CS_MSR_LVL_DB";
		put 'form1.submit()';
	put '}';
	
	/*********************/

    put 'function ResetPage() {';
    put 'form1.filter_clause.value=""';
    put 'form1.pd_score.value=""';
    put 'form1.range_interval.value=""';
    put 'form1.no_of_quantile.value=""';
    put 'form1.filter.value="NO"';
	put 'form1._program.value="'@;
	put "&prg_name"@;
	put '";';
	put 'form1.submit()';
    put '}'; 

	/* Call the filter screen stored process */
	put 'function EditPage() {';
	put "form1._program.value=&CS_FLTR_SCRN";
	put 'form1.submit();';
	put '}';

	/*Function savepage() for saving the page to disk */
	%savepage;
	/*********savepage() ends here*************/

	/*Function printpage() for printing the page to a printer or to a pdf file*/
	%printpage;
	/*********printpage() ends here*************/

	put '</script>';
	put'</head> ';
	put '<body>';	

	put '<form name="form1" method="post" ACTION="/SASStoredProcess/do"> ';
	put '<input type="hidden" name="_program" VALUE="'@;
	put "&prg_name"@;
	put '">';
	prod_type_desc=symget("prod_type_desc");
	put '<input type="hidden" name="prod_type_desc" value="' @;
	put prod_type_desc;
	put '">';
	prod_type_code=symget("prod_type_code");
	put '<input type="hidden" name="prod_type_code" value="' @;
	put prod_type_code;
	put '">';
	model_type_code=symget("model_type_code");
	put '<input type="hidden" name="model_type_code" value="' @;
	put model_type_code;
	put '">';
	model1=symget("model1");
	put '<input type="hidden" name="model1" value="' @;
	put model1;
	put '">';
	model1_key=symget("model1_key");
	put '<input type="hidden" name="model1_key" value="' @;
	put model1_key;
	put '">';
	model2=symget("model2");
	put '<input type="hidden" name="model2" value="' @;
	put model2;
	put '">';
	model2_key=symget("model2_key");
	put '<input type="hidden" name="model2_key" value="' @;
	put model2_key;
	put '">';
	sel_model=symget("sel_model");
	put '<input type="hidden" name="sel_model" value="' @;
	put sel_model @;
	put '">';
	sel_model_key=symget("sel_model_key");
	put '<input type="hidden" name="sel_model_key" value="' @;
	put sel_model_key @;
	put '">';
	period=symget("period");
	put '<input type="hidden" name="period" value="' @;
	put period;
	put '">';
	time_key=symget("time_key");
	put '<input type="hidden" name="time_key" value="' @;
	put time_key;
	put '">';

	statistic=symget("statistic");
	put '<input type="hidden" name="statistic" value="'@;
	put statistic;
	put '">';
	filter=symget("filter");
	put '<input type="hidden" name="filter" value="'@;
	put filter;
	put '">';
	filter_clause=symget("filter_clause");
	put '<input type="hidden" name="filter_clause" value="'@;
	put filter_clause;
	put '">';
	
	  
	pd_score=symget("pd_score");
	put '<input type="hidden" name="pd_score" value="' @;
	put pd_score;
	put '">';
	range_interval=symget("range_interval");
	put '<input type="hidden" name="range_interval" value="' @;
	put range_interval;
	put '">';
	no_of_quantile=symget("no_of_quantile");
	put '<input type="hidden" name="no_of_quantile" value="' @;
	put no_of_quantile;
	put '">';
	
	include_exp_mdl=symget("include_exp_mdl");
	put '<input type="hidden" name="include_exp_mdl" value="' @;
	put include_exp_mdl;
	put '">';

	prg_name=symget("prg_name");
	put '<input type="hidden" name="prg_name" value="' @;
	put prg_name;
	put '">';

	model_type_desc=symget("model_type_desc");
	put '<input type="hidden" name="model_type_desc" value="' @;
	put model_type_desc;
	put '">';
		
	outcome_period=symget("outcome_period");
	put '<input type="hidden" name="outcome_period" value="' @;
	put outcome_period;
	put '">';

	elapsed_time=symget("elapsed_time");
	put '<input type="hidden" name="elapsed_time" value="' @;
	put  elapsed_time;
	put '">';

	put '<input type="hidden" name="called_program" value="'@;
	put "&prg_name"@;
	put '">';
run;

/******** Thses values are used for alert if  no   data set is availabel i.e. out put of 
          feed mesure macro**********/
%global error_code;
%let error_code=NONE;
	/************ Macro generate_feed parameter passed
	in_filter				: Where clause (inclusive of the keyword where),
	out_lib_nm				: Library name where the output feed will be created. 
	out_table_nm_pool		: The table name for pool level feed
	out_table_nm_acct		: The table name for account/application level feed
	feed_for				: Possible values are PD, LGD, CCF, APPLPD, APPLLGD. This macro 
							  parameter decides whether estimated pd/lgd/ccf has to calculated 
							  at account level or application level
	pd_score				: Possible values are (Empty), PD, SCORE
	(empty)					: The default pooling technique will be used
	PD						: If PD then dynamic pooling technique will be used, 
							  based on PD/LGD/CCF as mentioned in the previous parameter 
								(feed_for) 
	SCORE					: If SCORE then dynamic pooling technique will be used,
							  based on SCORE_POINTS. Applicable only if PD or APPLPD value 
							  is set in the previous variable (feed_for)
	range_interval			: Dynamic pooling based on the range specified. E.g. 100, 200 for 
							  SCORE	and .2, .3 for PD. Similar ranges for LGD/CCF
	no_of_quantile			: The range for dynamic pooling will be decided based on the 
							  quantile.Quantile ranges will be calculated based on the 
							  SCORE/PD/LGD/CCF of  the scoring population for the selected 
								score period
	long_run				: Possible values Y/N. Whether the long run calculation is to be used 
							  to find estimated pd/lgd/ccf
	long_run_type			: Possible values are MAX/AVG. Method for calculating the long run 
							  pd/lgd/ccf macro_call example,
	model_time_key		:	This is the combination of  selected model and selected 
								time for that model (E.G. 100_1025 , 103_1027).
	product_type_code	: 	This is the selected product type code (E.G. MTG, LON).
*/
%let model_time=_%sysfunc(ktrim(%sysfunc(kleft(&sel_model_key.))))_%sysfunc(ktrim(%sysfunc(kleft(&time_key.))));
%generate_feed(in_filter=&where_feed, out_lib_nm=&out_lib., 
	out_table_nm_pool=&out_pool, out_table_nm_acct=&out_account, feed_for=&feed_pd, long_run=&LONG_RUN,
	pd_score=&pd_score, range_interval=&range_interval, no_of_quantile=&no_of_quantile,
	long_run_type=&LONG_RUN_TYPE, model_time_key=&model_time, product_type_code=&prod_type_code);
 

/* Checks whether the generate_feed macro generated any error.
	If any error is generated then the ResetPage function defined above is called*/
 
data _NULL_;
	file _webout&webout_options;
	if ktrim(kleft("&error_code")) ne "NONE" and (ktrim(kleft("&filter_clause")) ne "" or ktrim(kleft("&pd_score")) ne "") then do;
		put '<script>';
		put '<!--';
		put 'alert("'@;
		put "%sysfunc(sasmsg(smd_ds.bismsg,crs.misc_report_lgd.alert_error_selec_filter_criteria.1, noquote))"@;
		put '")';
		put 'ResetPage()';
		put '//-->';
		put '</script>';
	end;
run;
/* Checks whether the dataset created in the generate_feed macro has any observations
			and sets cnt to the number of observations in the dataset*/

%let cnt=.;
proc sql noprint;
	select Count(*) into :cnt from &out_lib..&out_pool.;
quit;

/* If there is no observation in the above dataset i.e. cnt=0 then the ResetPage function
	defined above is called */
%let log_name=;
data _NULL_;
	file _webout&webout_options;
	if &cnt eq 0 and (ktrim(kleft("&filter_clause")) ne "" or ktrim(kleft("&pd_score")) ne "") then do;
        put '<script>';
        put '<!--';
		put 'alert("'@;
		put "%sysfunc(sasmsg(smd_ds.bismsg,crs.misc_report_lgd.alert_error_no_data_available.1, noquote))"@;
		put'")';
        put 'ResetPage()';
        put '//-->';
        put '</script>';
	end;
	call symput('log_name',"&CS_DEBUG_PATH./&out_pool."||".log");
run;
/******ERROR TO GET LOG IN THE Specified LIBNAME*************/
%debug_log_file(log_file_nm=&log_name);

%let name_html=;

/* Data creation for measure_nm in a dataset and call for feed_measure values are 
	taken on model type code and program_nm */
proc sql;
	create table &out_lib..&in_stat_ot as
	select measure_nm,help_file_nm, monotonic() as tot_count
	from dim.measure_dim
	where kupcase(program_nm)=kupcase("&prg_name") 
			and model_type_cd="&model_type_code"
			and kupcase(PRODUCT_TYPE_CD)=kupcase("&prod_type_code");
quit;
data _null_;
	set &out_lib..&in_stat_ot;
	call symput('name_html',help_file_nm);
run;
/******Macro feed_measure parameter passed
	   1.where condition on basis of filter clause
       2.out_lib=output library  
	   3.Input dataset  
	   4. output dataset(required for statistic overtime graph)**********************/
%feed_measure(in_filter=&where_measure, out_lib_nm=&out_lib,in_table_nm=&in_stat_ot, out_table_nm_measure=&out_stat_ot);

/************Below here three macro are using same dataset as input ***********************/

/*****MACRO Distance_Stats parameter passed
	1. Input : Dataset with  values and name of distance statistics  
	2. Output: Table will have distance statistic 
		(PH ((1-PH) Statistic), D (D Statistic) etc.)**/
%distance_stats (input=&out_lib..&out_pool., diststat=&out_lib..Diststat);
 

/*****MACRO Distance_Stats parameter passed
	1. Input : Dataset with  values and name of distance statistics   
	2. Output: Tbale will have distance statistic (Kandall's Tau, Sommers' D)**/
%kend_somers(input_ds=&out_lib..&out_pool.,output_ds=work.kensom);
 


/*****MACRO hl_pd parameter passed
	1. Input : Dataset with  values and name of distance statistics   
	2. Output: Tbale will have distance statistic (Chi_sq,P_valueChisq)
 			   here two diffrent values of same statics is there, one having prifix as P_ is 
			   used for taking  the color form draw table macro and other to display diffrent 
			   values        **/
%hl_pd(input_ds=&out_lib..&out_pool.,output_ds=work.chisq);
 


/*****MACRO Brier parameter passed
	1. Input : Dataset with  values and name of distance statistics   
	2. Output: Tbale will have distance statistic Brier
 		      **/
%brier(input_ds=&out_lib..&out_pool.,output_ds=Work.brier);
 

/*****Data step to integrate diffrent dataset out of three macro Distance_Stats,
	  Kend_Somers, Chisq  buid dataset one for finding the color as (stats_nm_colr)
      other for displaying the name (stats_nm_disp)***********/
proc transpose data=work.Chisq 
				out=work.Chisq1;
run;
proc transpose  data=work.Kensom
				out=work.Kensom1;
run;

proc transpose  data=work.Brier
				out=work.Brier1;
run;
proc sql;
ALTER TABLE work.Kensom1  
DROP COLUMN _LABEL_;
quit;

proc append base=work.Kensom1   data=work.Chisq1 force	;
run;
proc append base=work.Kensom1  data=&out_lib..Diststat;
run;
proc append base=work.Kensom1  data=work.Brier1;
run;
 

data work.stats_nm_disp1;
	length measure_nm $100 ; 
	format measure_value &CS_DEC_FMT.;
	format p_value &CS_PVAL_FMT.;
	set work.Kensom1 (rename=(_name_=measure_nm col1=measure_value));
		if measure_nm="%sysfunc(sasmsg(smd_ds.bismsg,crs.measure_nm.measure_nm_chi_sq_p.1, noquote))" 
			then p_value=measure_value;
		if measure_nm="%sysfunc(sasmsg(smd_ds.bismsg,crs.measure_nm.measure_nm_kendal_tau_p_msr_val.1, noquote))" 
			then p_value=measure_value;
		if measure_nm="%sysfunc(sasmsg(smd_ds.bismsg,crs.measure_nm.measure_nm_somers_d_p_msr_val.1, noquote))" 
			then p_value=measure_value;
run;
 

data work.stats_nm_disp2(drop=measure_value);
	length measure_nm $100 ;
	format p_value &CS_PVAL_FMT.;
	set work.Kensom1 (rename=(_name_=measure_nm col1=measure_value));
		if measure_nm in ("%sysfunc(sasmsg(smd_ds.bismsg,crs.measure_nm.measure_nm_chi_sq_p.1, noquote))",
						  "%sysfunc(sasmsg(smd_ds.bismsg,crs.measure_nm.measure_nm_kendal_tau_p_val.1, noquote))",
						  "%sysfunc(sasmsg(smd_ds.bismsg,crs.measure_nm.measure_nm_somers_d_p_val.1, noquote))"
						  ) then
		p_value=measure_value;
run;
 


proc sort data=stats_nm_disp2 out=stats_nm_disp2;
by measure_nm;
run;
proc sort data=stats_nm_disp1 out=stats_nm_disp1;
by measure_nm;
run;
data work.stats_nm_disp;
	merge stats_nm_disp1 stats_nm_disp2;
	by measure_nm;
run;
 

data work.stats_nm_colr;
	length measure_nm $100;
	set work.Kensom1 (rename=(_name_=measure_nm col1=measure_value));
run;


proc sql noprint;
DELETE FROM work.stats_nm_colr
WHERE measure_nm="%sysfunc(sasmsg(smd_ds.bismsg,crs.measure_nm.measure_nm_chi_sq.1, noquote))" 
   or measure_nm="%sysfunc(sasmsg(smd_ds.bismsg,crs.measure_nm.measure_nm_kendal_tau_p_msr_val.1, noquote))" 
   or measure_nm="%sysfunc(sasmsg(smd_ds.bismsg,crs.measure_nm.measure_nm_somers_d_p_msr_val.1, noquote))";
quit;

%let a=%sysfunc(sasmsg(smd_ds.bismsg,crs.misc_report_lgd.dev_flag_y.1, noquote));
%let dev_flag_temp=%sysfunc(ktrim(%sysfunc(kleft(&a))));
 

/*********Here we create a dataset having Distant statistic name and modeling value *****/
proc sql noprint;
	create table work.mdl_measure_values as
	select Measure_nm,LEVEL_DESC, Measure_value format =&CS_DEC_FMT. as MDL_MEASURE_VALUE
	from &out_lib..&out_stat_ot
	where kupcase(dev_flg)=kupcase("&dev_flag_temp")
	order by Measure_nm;
quit;
 
/*****Macro model_traffic 
		1.data set as(work.datset)   
		2.Model type code for eg.PDA which will passed from calling stored process
		  output willbe the color for that value and statistic we will 
		  collect that in 'color' parameter***************/
%let color=;
%model_traffic(data1=work.stats_nm_colr,model_cd=&model_type_code, product_type_code=&prod_type_code);
 data martscr.stats_nm_colr;
set work.stats_nm_colr;
run;
proc sql noprint;
	create table work.mdl_measure_values1 as select 
	mdl_measure_values.*,Measure_dim.measure_cd as measure_cd 
	from work.mdl_measure_values  inner join dim.Measure_dim
	on (Measure_dim.measure_nm = mdl_measure_values.measure_nm)
	;

	create table int1
	as select measure_nm,measure_value from stats_nm_disp
	where measure_nm in ("%sysfunc(sasmsg(smd_ds.bismsg,crs.measure_nm.measure_nm_kendal_tau_p_msr_val.1, noquote))"
						 ,"%sysfunc(sasmsg(smd_ds.bismsg,crs.misc_report_lgd.stats_chi_squ.1, noquote))"
						 ,"%sysfunc(sasmsg(smd_ds.bismsg,crs.measure_nm.measure_nm_somers_d_p_msr_val.1, noquote))");

	update stats_nm_disp
	set measure_value =(select measure_value from int1 
						where measure_nm ="%sysfunc(sasmsg(smd_ds.bismsg,crs.measure_nm.measure_nm_kendal_tau_p_msr_val.1, noquote))")
	where measure_nm ="%sysfunc(sasmsg(smd_ds.bismsg,crs.measure_nm.measure_nm_kendal_tau_p_val.1, noquote))";

	update stats_nm_disp
	set measure_value = (select measure_value from int1 where measure_nm ="%sysfunc(sasmsg(smd_ds.bismsg,crs.misc_report_lgd.stats_chi_squ.1, noquote))")
	where measure_nm ="%sysfunc(sasmsg(smd_ds.bismsg,crs.measure_nm.measure_nm_chi_sq_p.1, noquote))";

	update stats_nm_disp
	set measure_value = (select measure_value from int1 
						where measure_nm ="%sysfunc(sasmsg(smd_ds.bismsg,crs.measure_nm.measure_nm_somers_d_p_msr_val.1, noquote))")
	where measure_nm ="%sysfunc(sasmsg(smd_ds.bismsg,crs.measure_nm.measure_nm_somers_d_p_val.1, noquote))";

  	create table work.stats_nm1 as
	select stats_nm_disp.measure_nm, stats_nm_disp.measure_value,
		   stats_nm_disp.p_value,mdl_measure_values1.LEVEL_DESC,
		mdl_measure_values1.mdl_measure_value, stats_nm_colr.color, 
		monotonic() as rowid
	from work.stats_nm_disp  inner join work.mdl_measure_values1
		on (upcase(stats_nm_disp.measure_nm) =upcase(mdl_measure_values1.measure_cd))
		inner join work.stats_nm_colr
		on (stats_nm_disp.measure_nm = stats_nm_colr.measure_nm);
quit; 

data &out_lib..test__misc_rep;
set work.stats_nm1;
run;

proc sql noprint;
select max(rowid) into:count_graph
from work.stats_nm1;
run;

/*	Calls statistic_overtime to get the overtime graph.
	The following parameters are passed to this macro
			1. ds		: Input dataset with the data for the	selected measure.
            2. statistic: Name of the measure for which the graph is being generated.
            3. name		: Name to be given to the gif when the graph is generated.*/
/*%statistic_overtime(&out_lib..&out_stat_ot,&statistic,&graph_name);*/

%let fst_graph=;
%let cnt_stat=.;
%macro name();
	proc sql noprint;
		select tot_count into :fst_cnt
		from &out_lib..&in_stat_ot
		where measure_nm=put("&statistic",&format_name..);
	quit;

	proc sql noprint;
		select count(*) into :cnt_stat from &out_lib..&in_stat_ot;
		%let cnt_stat=%sysfunc(ktrim(%sysfunc(kleft(&cnt_stat))));
		select measure_nm into :statistic1 - :statistic&cnt_stat
		from &out_lib..&in_stat_ot;
	quit;
	%do indx=1 %to &cnt_stat;
		data _NULL_;
			call execute('%global ' || ktrim("graph_nm&indx"));
		run;
		%let graph_nm&indx = %sysfunc(ktrim(c&indx&graph_name));

		%statistic_overtime(&out_lib..&out_stat_ot,&&statistic&indx,&&graph_nm&indx);
	%end;
	%let fst_cnt=%sysfunc(ktrim(%sysfunc(kleft(&fst_cnt))));
	%let fst_graph = &&graph_nm&fst_cnt;
	%put &fst_graph;
%mend name;

%name();
%let fst_graph=%sysfunc(ktrim(%sysfunc(kleft(&fst_graph))));


/***********Macro Pool_technique parameter passed
	1.pd_score 			:	If null then shown  as DEFAULT stautus.
	2.time_key        	:	The surrogate key for selected period.
    3.sel_model_key        :	The surrogate key for the selected model.
 	4.no_of_quantile    :	The range for dynamic pooling will be decided based on the 
						 	quantile.Quantile ranges will be calculated based on the 
						 	SCORE/PD/LGD/CCF of the scoring  population for the selected 
						 	score period  
    5.range_interval    : 	Dynamic pooling based on the range specified. E.g. 100, 200 
	  						for SCORE and .2, .3 for PD.			
 ********************************************************************************/

%let pool_tech=;
%let time_period=;
%pool_technique;

%debug_log_web;

data _NULL_;
	file _webout&webout_options;
	put '<script>';
	put '<!--';
 /*Calls this stored process again after assigning statistic the value selected from the
		combo box and hence displaying the overtime graph for the selected statistic */
	put 'function display(){';
		put 'var indx=form1.measure_name.selectedIndex';
/*		put 'form1.statistic.value=form1.measure_name.options[indx].value';*/
		put 'var choice=form1.measure_name.options[indx].value';
		put	'if(document.images) {';
		put	'document.form1.my_img.src=choice';
		put	'}';
/*		put 'form1._program.value="'@;*/
/*		put "&prg_name"@;*/
/*		put '";';*/
/*		put 'document.form1.submit();';*/
	put '}';

	put '//-->';
	put '</script>';
run;
%let view_feed=&out_pool..html;
data _NULL_;
	file _webout&webout_options;
	if &cnt = 0 then do;
	      put '<script>';
	      put '<!--';
	      put 'alert("'@;
		  put "%sysfunc(sasmsg(smd_ds.bismsg,crs.misc_report_lgd.alert_error_no_data_available.1, noquote))"@;
		  put '")';
	      put 'ResetPage()';
	      put '//-->';
	      put '</script>';
	end;

	name_html=symget("name_html");
	put'<script>';
		/**************Help File *********************/
	%helpfile(filename=&name_html);

		/*************feed Table*********************/
	put 'function feed_table(){';
		put'window.open("/SASCSReports/'@; 
				put "&view_feed"@; 
	put '")};';
			
		/*********************************************/
	put'</script>';
	put '<table width="100%"  border="0" cellpadding="0" cellspacing="0" bgcolor="#FAF8ED"> ';
	put '<tr> ';
	put '<td align="left"> ';
	put '<table width="100%"  border="0" align="left" cellpadding="3" cellspacing="0"> ';
	put '<tr> ';
	put '<td><table width="100%"  border="0" cellspacing="0" cellpadding="0"> ';
	put '<tr> ';

	/*Links on Top of the HTML Page*/
	put '<td><span class="BreadCrumb"><a href="javascript:Link1()">'@;
	put "%sysfunc(sasmsg(smd_ds.bismsg,crs.misc_report_lgd.link_reporting.1, noquote))"@;
	put'</a> &gt; 
								<a href="javascript:Link2()">'@;
	put "%sysfunc(sasmsg(smd_ds.bismsg,crs.misc_report_lgd.link_monitoring_model.1, noquote))"@;
	put'</a> &gt; 
								<a href="javascript:Link3()">'@;
	put "%sysfunc(sasmsg(smd_ds.bismsg,crs.misc_report_lgd.link_sel_model.1, noquote))"@;
	put'</a> &gt; 
								<a href="javascript:Link4()">'@;
	put "%sysfunc(sasmsg(smd_ds.bismsg,crs.misc_report_lgd.link_sel_stats.1, noquote))"@;
	put'</a> &gt; '@;
	 /*I18N-scnjih-20080506-1440*/
	/*put'</span><span class="BreadCrumb">Miscellaneous  Statistic </span></td>';*/
		put'</span><span class="BreadCrumb">'@;
		put  "%sysfunc(sasmsg(smd_ds.bismsg,misc_report.sas.1, noquote))"@;
		put '</span></td>';
	/*I18N-scnjih-20080506-1440*/
   /********************************/	

	put '<td width="215"><div align="right"><img src="/SASCSReports/images/CrBanner.gif" width="259" height="29"></div></td> ';
	put '</tr> ';                                     /****Banner insert image********/

	/*I18N-scnjih-20080506-1440*/
/*	put '</table><H2 align="left"><table width="100%"  border="0" cellspacing="0" cellpadding="0"><tr><td>Miscellaneous Statistic</td>';*/
	put '</table><H2 align="left"><table width="100%"  border="0" cellspacing="0" cellpadding="0"><tr><td>'@;
	put "%sysfunc(sasmsg(smd_ds.bismsg,misc_report.sas.1, noquote))"@;
	put '</td>';
	/*I18N-scnjih-20080506-1440*/
	if kupcase(&print) eq 'Y' then do;
		put '<td width=65><div align="center"><span class="LabelFont">';
		put '<a href="javascript:printpage()">';
		put '<img src="/SASCSReports/images/Print.gif" border="0"></a>'@;
		put "%sysfunc(sasmsg(smd_ds.bismsg,crs.report_print.1, noquote))"@;
		put '</div></td>';
	end;
	if kupcase(&save) eq 'Y' then do;
		put '<td width=50><div align="center"><span class="LabelFont">';
		put '<a href="javascript:enregistre()">';
		put '<img src="/SASCSReports/images/SaveFile.gif" border="0"></a>'@;
		put "%sysfunc(sasmsg(smd_ds.bismsg,crs.report_save.1, noquote))"@;
		put '</div></td>';
	end;
	if kupcase(&help) eq 'Y' then do;
		put '<td width=50><div align="center"><span class="LabelFont">';
		put '<a href="javascript:Info()">';
		put '<img src="/SASCSReports/images/Info.gif" border="0"></a>'@;
		put "%sysfunc(sasmsg(smd_ds.bismsg,crs.report_help.1, noquote))"@;
		put '</div></td>';
	end;
	put '</tr></table></H2>';
	put '</td></tr>';

	/*Values of Product_type Period and Model*/
	put '<tr> ';
	put '<td align="left"> '; 
	put '			  <p class="LabelFont">'@;
	put "%sysfunc(sasmsg(smd_ds.bismsg,crs.misc_report_lgd.label_model_type.1, noquote))"@;
	put "&model_type_desc";
	put' </p> ';
	put '<p class="LabelFont">'@;
	put "%sysfunc(sasmsg(smd_ds.bismsg,crs.misc_report_lgd.label_product_type.1, noquote))"@;
	put "&prod_type_desc";
	put '</p> ';
	put '<p class="LabelFont">'@;
	put "%sysfunc(sasmsg(smd_ds.bismsg,crs.misc_report_lgd.label_period.1, noquote))"@;
/*I18N-scnhuh-20080427-1455*/	
/* del one line, add two lines. For displaying in NLS format */	
/*	put "&period" @;*/
		Period_WEBUI=put(input("&period",&CS_TIME_PER_FMT.),&NLDATE_FMT.);
		put Period_WEBUI @;
/*I18N-scnhuh-20080427-1455*/		
	put '</p>';
	put '<p class="LabelFont">'@;
	put "%sysfunc(sasmsg(smd_ds.bismsg,crs.misc_report_lgd.label_model.1, noquote))"@;
	put"&sel_model";
	put '</p> ';
	put '<p class="LabelFont">'@;
	put "%sysfunc(sasmsg(smd_ds.bismsg,crs.misc_report_lgd.label_pooling_tech.1, noquote))"@;
	put"&pool_tech";
	put '</p> ';

	put '<p class="LabelFont">'@;
	put "%sysfunc(sasmsg(smd_ds.bismsg,crs.misc_report_lgd.label_outcome_period.1, noquote))"@;
	put ': '@;
	put "&outcome_period" @;
	put '  '@;
	put "%sysfunc(sasmsg(smd_ds.bismsg,crs.misc_report_lgd.label_months.1, noquote))"@;
	put '  '@;
	put "&elapsed_time" @;
	put '  '@;
	put "%sysfunc(sasmsg(smd_ds.bismsg,crs.misc_report_lgd.label_month_elapsed.1, noquote))"@;
	put '</p>';

	/* Number of months of Historic data */
	if kupcase("&model_type_code") eq kupcase(&PD_APP_MODEL.) then do;
		put '<p class="LabelFont">'@;
		put "%sysfunc(sasmsg(smd_ds.bismsg,crs.pd_stored_proc_hist.label_historic_data.1, noquote))"@;
		if kupcase("&prod_type_code") eq kupcase(&MTG_PRD_TYPE.) then do;
			put "&PDA_MTG_HIST" @;
		end;
		if kupcase("&prod_type_code") eq kupcase(&LON_PRD_TYPE.) then do;
			put "&PDA_LON_HIST" @;
		end;
		if kupcase("&prod_type_code") eq kupcase(&COR_PRD_TYPE.) then do;
			put "&PDA_COR_HIST" @;
		end;
		if kupcase("&prod_type_code") eq kupcase(&CCD_PRD_TYPE.) then do;
			put "&PDA_CCD_HIST" @;
		end;
		put "%sysfunc(sasmsg(smd_ds.bismsg,crs.pd_stored_proc_month.label_months.1, noquote))"@;
		put '</p>';
	end;

run;

%let level=;
proc sort  data=work.stats_nm1 out=test_lev;
	by measure_nm LEVEL_DESC ;
run;
data test_lev; 
set test_lev;
by measure_nm; 
if  first.measure_nm then output;
run;
proc sort  data=test_lev;
	by LEVEL_DESC measure_nm  ;
run;
data _NULL_;
	set test_lev;
	if _N_=1 then do;
		call symput('level',level_desc);
	end;
run;
 data martscr.test_lev;
set test_lev;
run;

data _null_;
	 file _webout&webout_options;
	 set test_lev end=last;
	 format measure_nm &format_name..;
	 by LEVEL_DESC measure_nm;
	if _N_=1 then
		put '<table  border="0" cellspacing="0" cellpadding="0"> ';
	if first.level_desc then do;
		level=substr(level_desc,index(level_desc,":")+1);
		put'<td><span class="LabelFont">' @;
		put level @;
		put'<br>'@;
		put'</span></td> ';
	end;
	/*************************VALUE SHOWN FOR ACTUAL AND MODELING**********************/
	
		put'<tr> ';
		put'<td></td><td><span class="LabelFont">' @;
		put measure_nm @;
		put "%sysfunc(sasmsg(smd_ds.bismsg,crs.misc_report_lgd.stats_act_value.1, noquote))"@;

		if measure_nm in ("%sysfunc(sasmsg(smd_ds.bismsg,crs.measure_nm.measure_nm_chi_sq_p.1, noquote))",
						  "%sysfunc(sasmsg(smd_ds.bismsg,crs.measure_nm.measure_nm_kendal_tau_p_val.1, noquote))",
						  "%sysfunc(sasmsg(smd_ds.bismsg,crs.measure_nm.measure_nm_somers_d_p_val.1, noquote))"
						  )then do; 
			put p_value @;
			put'('@;
			put "%sysfunc(sasmsg(smd_ds.bismsg,crs.misc_report_lgd.statistic.1, noquote))"@;
			put measure_value @;	put')';
		end;
		else 
			put measure_value @;	
		put'</span></td><td>&nbsp;</td> ';
		
		put'<td width="25"><div align="center"><span class="LabelFont"><img src="/SASCSReports/images/' @;
		if color="%sysfunc(sasmsg(smd_ds.bismsg,crs.misc_report_lgd.color_white.1, noquote))" then do;
			put 'spacer.gif"';
		end;
		else do;
			put 'Sphere' @;
			put color;
			put'.gif"';
		end;
		put 'width="16" height="16" border="0"></a> </span></div></td> ';
		put'<td width="50"><span class="LabelFont"></span></td> ';
	/* Modeling value for the given statistic.
		This will get displayed only if the filter is set to NO*/

		if kupcase("&filter") eq kupcase("no") then do; 
			put'<td><span class="LabelFont">' @;
			put measure_nm @;
			put "%sysfunc(sasmsg(smd_ds.bismsg,crs.misc_report_lgd.stats_mod_value.1, noquote))"@;	
			put mdl_measure_value @; 
			if measure_nm in ("%sysfunc(sasmsg(smd_ds.bismsg,crs.measure_nm.measure_nm_chi_sq_p.1, noquote))",
						  "%sysfunc(sasmsg(smd_ds.bismsg,crs.measure_nm.measure_nm_kendal_tau_p_msr_val.1, noquote))",
						  "%sysfunc(sasmsg(smd_ds.bismsg,crs.measure_nm.measure_nm_somers_d_p_msr_val.1, noquote))"
						  ) then 
				put'</span></td> ';
		end;
		put'<td>&nbsp;</td> ';
		put'</tr> ';
			
		if last then do;
			put'</table>			 ';
		end;
run;
/**************/
%let count=1;
%macro over_time();
	data _NULL_;
		file _webout&webout_options;
/* Code for displaying overtime graph.
	This will get displayed only if filter is set to NO */
		if kupcase("&filter") eq "NO" then do;
			set &out_lib..&in_stat_ot end=last;
			%do %while(&count le &cnt_stat);
				if &count eq _N_ then do;
					if _N_= 1 then do;
						put '<tr>';
					    put '<td align="left">';
					    put '<p>';
					    put '<H2 align="left">'@;
						put "%sysfunc(sasmsg(smd_ds.bismsg,crs.misc_report_lgd.graph.1, noquote))"@;
						put'</H2>';
					    put '</td></tr>';
						put	'<tr><td><table width="100%"  border="0" cellspacing="0" cellpadding="0">';
				        put '<tr>';
				        put '<td width="49%" valign="top"><fieldset>';
				        put '<legend><span class="style2">';
/*						put "&statistic" @;*/
						put "%sysfunc(sasmsg(smd_ds.bismsg,crs.misc_report_lgd.stats_over_time_graph.1, noquote))"@;
						put '</span></legend>';
						put '<p><select name="measure_name" onChange="javascript:display()">';
					end;
					put "<option value='/SASCSReports/&&graph_nm&count...gif'";
					if measure_nm = put("&statistic",&format_name..) then do;
						put 'selected';
					end;
					put '>';
					put measure_nm;
					put '</option>';
					if last then do;
						put '</select></p>';
					    put '<p><img name=my_img src="/SASCSReports/'@;
						put "&fst_graph";
						put '.gif" width="460" height="200"></p>';
					    put '</fieldset></td>';
						put '<td width="2%">&nbsp;</td>';
				        put '<td width="49%" valign="top">';
				        put '</td>';
				        put '</tr></table>';
					end;
				end;
				%let count=%eval(&count+1);
	/*			%put &count;*/
			%end;
		end;
	run;
%mend over_time;

%over_time();
data _null_;
	file _webout&webout_options;
	put '<p>&nbsp;</p></td> ';
	put '</tr> ';
	put '</table> ';
	put '</td> ';
	put '</tr> ';
	put '<tr> ';
	put '<td height="32" bgcolor="#F1EACB">&nbsp;&nbsp;';

	/* Edit and Reset button will get displayed only if the pooling technique
	 is not of clustering type*/
	val=PRXMATCH(kupcase('/cluster/'),kupcase("&pool_tech"));
	if val = 0 then do;
	    put '<INPUT type=button class=mmhide_btn onClick="EditPage()" value="'@;
		put "%sysfunc(sasmsg(smd_ds.bismsg,crs.misc_report_lgd.button_filter_repool.1, noquote))"@;
		put '">';
	    put '<INPUT type=button class=mmhide_btn onClick="ResetPage()" value="'@;
		put "%sysfunc(sasmsg(smd_ds.bismsg,crs.misc_report_lgd.button_reset.1, noquote))"@;
		put '">';
    end;
	put '<INPUT type=button class=mmhide_btn onClick="feed_table()" value="'@;
	put "%sysfunc(sasmsg(smd_ds.bismsg,crs.misc_report_lgd.button_view_feed.1, noquote))"@;
	put '">';
	put '</td>';
	put '</tr>';
	put '</table>';
	put '</form>';
	put '</body>';
	put '</html>';
run;
/******macro feed_table pass parameter  separated by #

		Input parameter 
		1.dt_st =Pass dataset name in string separated by #
		2.dt_nm=pass name u want to give to the table
		3.out_libout library  which is defined above
		        *****************************************************************/
	 /*I18N-scnjih-20080421-1517*/
/*%let dt_nm=Pool Feed;*/
%let dt_nm=%sysfunc(sasmsg(smd_ds.bismsg,Call_feed_table.sas.dt_nm.1, noquote));
data &out_lib..&out_pool._1; 
set &out_lib..&out_pool.;
SCORE_POINTS=round(SCORE_POINTS);
run;

/*I18N-scnjih-20080424-0928*/
%let dt_st=&out_pool._1;
%feed_table(ds=&dt_st,out_lib1=&out_lib,data_name=&dt_nm,name_html=&view_feed);

goptions reset=all;
options nomprint;
