 /**
 * <p>Title: CheckBoxList</p>
 * <p>Description: Class associates check box with list items</p>
 * <p>Copyright: Copyright (c) 2004</p>
 * <p>Company: </p>
 * @author Ajit Singh
 * @version 1.0
 */
 
package com.sas.metadata.imp;

import java.awt.Component;
import java.awt.event.KeyAdapter;
import java.awt.event.KeyEvent;
import java.awt.event.MouseAdapter;
import java.awt.event.MouseEvent;
import java.util.List;
import java.util.Vector;

import javax.swing.JCheckBox;
import javax.swing.JList;
import javax.swing.ListCellRenderer;
import javax.swing.ListSelectionModel;
import javax.swing.UIManager;
import javax.swing.border.Border;
import javax.swing.border.EmptyBorder;


public class CheckBoxList extends JList
{
	protected static Border noFocusBorder = new EmptyBorder(1, 1, 1, 1);

	public CheckBoxList() {
		setCellRenderer(new CellRenderer());
		addMouseListener(new MouseAdapter() {
			public void mousePressed(MouseEvent e) {
				int index = locationToIndex(e.getPoint());
				if (index != -1) {
					JCheckBox checkbox = (JCheckBox) getModel().getElementAt(
							index);
					checkbox.setSelected(!checkbox.isSelected());
					repaint();
				}
			}
		});
		addKeyListener(new KeyAdapter() {
			public void keyPressed(KeyEvent e) {
				int keycode = e.getKeyCode();
				if (keycode == 32) {
					JCheckBox checkbox = (JCheckBox) getModel().getElementAt(
							getSelectedIndex());
					checkbox.setSelected(!checkbox.isSelected());
					repaint();
				}
			}
		});
		setSelectionMode(ListSelectionModel.SINGLE_SELECTION);
	}
	
	/**
	 * Inner Renderer class 
	 */
	protected class CellRenderer implements ListCellRenderer
	{
		public Component getListCellRendererComponent(
                   JList list, Object value, int index,
                   boolean isSelected, boolean cellHasFocus)
		{
			JCheckBox checkbox = (JCheckBox) value;
			checkbox.setBackground(isSelected? getSelectionBackground() : getBackground());
			checkbox.setForeground(isSelected? getSelectionForeground() : getForeground());
			checkbox.setEnabled(isEnabled());
			checkbox.setFont(getFont());
			checkbox.setFocusPainted(false);
			checkbox.setBorderPainted(true);
			checkbox.setBorder(isSelected? UIManager.getBorder("List.focusCellHighlightBorder") : noFocusBorder);
			return checkbox;
		}
	}

	/**
	 * @param No Parameters
	 * @return java.lang.String[]
	 * Returns the String array of items which are checked(Selected) 
	 */
	public String[] getCheckedItems()
	{
		Vector v = new Vector();
		for(int i=0; i < getModel().getSize(); i++)
		{
			JCheckBox checkbox = (JCheckBox)getModel().getElementAt(i);
			if(checkbox.isSelected())
			{
				v.addElement(checkbox.getText());
			}
		}
		return (String[])v.toArray(new String[0]);
	}
  
	/**
	 * @param No Parameters
	 * @return java.util.List
	 * Returns the list of items which are not checked(Not Selected)
	 */
	public List getNotCheckedItems()
	{
		List v = new Vector();
		for (int i = 0; i < getModel().getSize(); i++)
		{
			JCheckBox checkbox = (JCheckBox) getModel().getElementAt(i);
			if (!checkbox.isSelected())
			{
				v.add(checkbox.getText());
			}
		}
		return v;
	}
}
